<?xml version="1.0" encoding="utf-8"?>
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:msxsl="urn:schemas-microsoft-com:xslt" xmlns:Error="Errors.uri" exclude-result-prefixes="Error">
	<xsl:variable name="ErrorList">
		<!-- Version Details -->
		<CensusDetail type="School Census 2023-2024"/>
		<!-- Current Version Details -->
		<CurrentVersion>
			<Version number="2024.1.2" released="2023-09-27" author="Andy Naylor" comment="Corrected rules 2392 and 5165"/>
		</CurrentVersion>
		<!-- History (old Current Version Details) -->
		<VersionHistory>
			<Version number="2024.1.1" released="2023-09-08" author="Andy Naylor" comment="Corrected allowed DOB ranges for rule 2492. RFC 1253 change to rule 3125. Corrected headings on Table 14 of school summary"/>
			<Version number="2024.1.0" released="2023-08-25" author="Ian Windress" comment="Baselined version for release"/>		
			<Version number="2024.0.1" released="2023-07-01" author="Andy Naylor" comment="rolled over from summer census 2023 and updated for Autumn 23"/>
		</VersionHistory>
		<!-- End of Version Details -->
	</xsl:variable>	
	<!--Errors and appropriate messages-->

	<!-- Survey Date -->
	<Error:rule number="100" outputno="100" term="AUT SPR SUM" type="Error" phase="NS PS MP MS SS AT SP PR" message="Reference date must be present and valid for the term."/>

	<!-- School Characteristics -->
	<Error:rule number="110" outputno="110" term="AUT SPR SUM" type="Error" phase="NS PS MP MS SS AT SP PR" message="School name missing."/>
	<Error:rule number="120" outputno="120" term="AUT SPR SUM" type="Error" phase="NS PS MP MS SS AT SP PR" message="Phase is missing or invalid."/>
	<Error:rule number="130" outputno="130" term="AUT SPR SUM" type="Error" phase="NS PS MP MS SS AT SP PR" message="DfE number and phase are not consistent."/>
	<Error:rule number="140" outputno="140" term="AUT SPR SUM" type="Error" phase="NS PS MP MS SS AT SP PR" message="School type is missing."/>
	<Error:rule number="150" outputno="150" term="AUT SPR SUM" type="Error" phase="NS PS MP MS SS AT SP PR" message="School type and phase not consistent."/>
	<Error:rule number="160" outputno="160" term="AUT SPR SUM" type="Error" phase="NS PS MP MS SS AT SP PR" message="The URN is missing or does not match the URN recorded on GIAS."/>
	<Error:rule number="165" outputno="165" term="AUT SPR SUM" type="Error" phase="NS PS MP MS SS AT SP PR" message="No school details have been recorded."/>
	<Error:rule number="210" outputno="210" term="AUT SPR SUM" type="Error" phase="NS PS MP MS SS AT SP PR" message="School&apos;s highest national curriculum year group is missing or invalid."/>
	<Error:rule number="220" outputno="220" term="AUT SPR SUM" type="Error" phase="NS PS MP MS SS AT SP PR" message="School&apos;s lowest national curriculum year group is missing or invalid."/>
	<Error:rule number="221" outputno="221" term="AUT SPR SUM" type="Error" phase="PR" message="Intake type is missing or invalid. Intake type must be &apos;COMP&apos;."/>
	<Error:rule number="222" outputno="222" term="AUT SPR SUM" type="Error" phase="PR" message="Governance is missing or invalid. Governance must be &apos;CO&apos; or &apos;CA&apos;."/>
	<Error:rule number="223" outputno="223" term="AUT SPR SUM" type="Error" phase="NS PS MP MS SS AT PR" message="Intake of SPEC (special) or HOSP (hospital special) can only be returned for schools with a phase of SP (special)."/>
	<Error:rule number="224" outputno="224" term="AUT SPR SUM" type="Error" phase="SP" message="Intake type is missing or invalid. Intake type must be &apos;SPEC&apos; or &apos;HOSP&apos;."/>
	<Error:rule number="230" outputno="230" term="AUT SPR SUM" type="Error" phase="NS PS MP MS SS AT SP PR" message="School&apos;s lowest national curriculum year group cannot be greater than school&apos;s highest national curriculum year group."/>
	<Error:rule number="240" outputno="240" term="AUT SPR SUM" type="Error" phase="NS PS MP MS SS AT SP" message="Intake type is missing or invalid."/>
	<Error:rule number="260" outputno="260" term="AUT SPR SUM" type="Error" phase="NS PS MP MS SS AT SP PR" message="Governance is missing or invalid."/>
	<Error:rule number="261" outputno="261" term="AUT SPR SUM" type="Error" phase="NS PS MP MS SS AT SP PR" message="If school type is recorded as an academy (49) then the school governance must also be recorded as an academy with code CA."/>
	<Error:rule number="262" outputno="262" term="AUT SPR SUM" type="Error" phase="NS PS MP MS SS AT SP PR" message="If school governance is recorded as an academy (CA) then school type must also be recorded as an academy with code 49."/>
	<Error:rule number="263" outputno="263" term="AUT SPR SUM" type="Error" phase="NS PS MP MS SS AT SP" message="If school type is recorded as a CTC (47) then governance must also be recorded as a CTC with code CT."/>
	<Error:rule number="264" outputno="264" term="AUT SPR SUM" type="Error" phase="NS PS MP MS SS AT SP" message="If governance is recorded as a CTC (CT) then school type must also be recorded as a CTC with code 47."/>
	<Error:rule number="270" outputno="270Q" term="AUT SPR SUM" type="Query" phase="NS PS MP MS SS AT SP PR" message="Please check: school email address is missing."/>
	<Error:rule number="420" outputno="420" term="AUT SPR SUM" type="Error" phase="NS PS MP MS SS AT SP PR" message="School telephone number is missing."/>
	<Error:rule number="280" outputno="280" term="SPR" type="Error" phase="SP" message="School organisation (day, boarding or hospital) is missing or invalid."/>
	<Error:rule number="290" outputno="290Q" term="SPR" type="Query" phase="SP" message="Please check: day school with a majority of boarding pupils."/>
	<Error:rule number="300" outputno="300Q" term="SPR" type="Query" phase="SP" message="Please check: boarding school with a majority of day pupils."/>
	<Error:rule number="310" outputno="310" term="SPR" type="Error" phase="SP" message="Approved maximum for day pupils is missing."/>
	<Error:rule number="320" outputno="320" term="SPR" type="Error" phase="SP" message="Approved maximum for boarding pupils is missing (or, for hospital special schools, is provided when it is not required)."/>
	<Error:rule number="330" outputno="330Q" term="SPR" type="Query" phase="SP" message="Please check: more day pupils on roll than the approved maximum."/>
	<Error:rule number="340" outputno="340Q" term="SPR" type="Query" phase="SP" message="Please check: more boarding pupils on roll than the approved maximum."/>
	<Error:rule number="350" outputno="350" term="SPR" type="Error" phase="SP" message="Boys on roll not provided, or age not in range 2 to 27."/>
	<Error:rule number="360" outputno="360" term="SPR" type="Error" phase="SP" message="Girls on roll not provided, or age not in range 2 to 27."/>
	<Error:rule number="370" outputno="370" term="SPR" type="Error" phase="SP" message="Approved maximum age (boys) is shown but there is no minimum, or vice versa."/>
	<Error:rule number="380" outputno="380" term="SPR" type="Error" phase="SP" message="Approved maximum age (girls) is shown but there is no minimum, or vice versa."/>
	<Error:rule number="390" outputno="390" term="SPR" type="Error" phase="SP" message="Approved maximum age (boys) must be equal to or greater than minimum."/>
	<Error:rule number="400" outputno="400" term="SPR" type="Error" phase="SP" message="Approved maximum age (girls) must be equal to or greater than minimum."/>
	<Error:rule number="410" outputno="410" term="SPR" type="Error" phase="SP" message="Information on SEN school types for which school is approved is missing or invalid."/>
	<Error:rule number="540" outputno="540" term="SPR" type="Error" phase="PR" message="Child mothers indicator is missing or invalid."/>
	<Error:rule number="541" outputno="541" term="SPR" type="Error" phase="PR" message="Count of places for teenage mothers is missing."/>
	<Error:rule number="542" outputno="542" term="SPR" type="Error" phase="PR" message="Childcare facilities indicator is missing or invalid."/>
	<Error:rule number="5005" outputno="5005" term="SPR" type="Error" phase="NS PS MP MS SS AT SP PR" message="Data items in the special school module are only required from schools with a phase of SP."/>

	<!-- Admissions Appeals -->
	<Error:rule number="560" outputno="560" term="SPR" type="Error" phase="PS MP AT" message="Primary admissions appeals withdrawn plus heard do not equal those lodged."/>
	<Error:rule number="564" outputno="564Q" term="SPR" type="Query" phase="PS MP AT" message="Please check: primary admission appeals figures should be provided and are expected to be greater than zero."/>
	<Error:rule number="566" outputno="566Q" term="SPR" type="Query" phase="PS AT" message="Please check: infant admissions appeals figures should be provided and are expected to be greater than zero."/>
	<Error:rule number="570" outputno="570" term="SPR" type="Error" phase="PS MP AT" message="Primary admission appeals upheld plus appeals rejected should match the number of appeals heard."/>
	<Error:rule number="5013" outputno="5013" term="SPR" type="Error" phase="NS PS MP MS SS AT SP PR" message="Data items in the primary admission appeals module are only required from schools with governance type of VA, FO or CA."/>
	<Error:rule number="5014" outputno="5014" term="SPR" type="Error" phase="NS PS MP MS SS AT SP PR" message="Data items in the primary admission appeals module are not required from schools with a phase of NS, SP or PR."/>
	<Error:rule number="5018" outputno="5018" term="SPR" type="Error" phase="NS PS MP MS SS AT SP PR" message="Data items in the infant admission appeals module are only required from schools with governance type of VA, FO or CA."/>
	<Error:rule number="5019" outputno="5019" term="SPR" type="Error" phase="NS PS MP MS SS AT SP PR" message="Data items in the infant admission appeals module are only required from schools with a phase of PS or AT."/>
	<Error:rule number="580" outputno="580" term="SPR" type="Error" phase="PS AT" message="Overall appeals lodged is less than infant appeals lodged."/>
	<Error:rule number="590" outputno="590" term="SPR" type="Error" phase="PS AT" message="Overall appeals withdrawn is less than infant appeals withdrawn."/>
	<Error:rule number="600" outputno="600" term="SPR" type="Error" phase="PS AT" message="Overall appeals heard is less than infant appeals heard."/>
	<Error:rule number="610" outputno="610" term="SPR" type="Error" phase="PS AT" message="Overall appeals upheld is less than infant appeals upheld."/>
	<Error:rule number="620" outputno="620" term="SPR" type="Error" phase="PS AT" message="Overall appeals rejected is less than infant appeals rejected."/>
	<Error:rule number="630" outputno="630" term="SPR" type="Error" phase="PS AT" message="More appeals withdrawn or heard than were lodged for infant classes."/>
	<Error:rule number="640" outputno="640" term="SPR" type="Error" phase="PS AT" message="Infant appeals upheld plus Infant appeals rejected should match the number of Infant appeals heard."/>
	<Error:rule number="561" outputno="561" term="SPR" type="Error" phase="MS SS AT" message="There were more secondary admission appeals withdrawn and / or heard than were actually lodged."/>
	<Error:rule number="565" outputno="565Q" term="SPR" type="Query" phase="MS SS AT" message="Please check: secondary admission appeals figures should be provided and are expected to be greater than zero."/>
	<Error:rule number="571" outputno="571" term="SPR" type="Error" phase="MS SS AT" message="Secondary admission appeals upheld plus appeals rejected should match the number of appeals heard."/>
	<Error:rule number="5125" outputno="5125" term="SPR" type="Error" phase="NS PS MP MS SS AT SP PR" message="Data items in the secondary admission appeals module are only required from schools with governance type of VA, FO or CA."/>
	<Error:rule number="5126" outputno="5126" term="SPR" type="Error" phase="NS PS MP MS SS AT SP PR" message="Data items in the secondary admission appeals module are not required from schools with a phase of NS, SP or PR."/>

	<!-- School - Reconciliation -->
	<Error:rule number="920" outputno="920" term="SPR" type="Error" phase="PS MP MS SS AT" message="Number of part-time pupils not at school is missing."/>
	<Error:rule number="930" outputno="930" term="SPR" type="Error" phase="PS MP MS SS AT" message="More part-time pupils not in school than total part-time pupils registered."/>
	<Error:rule number="940" outputno="940" term="SPR" type="Error" phase="PS MP MS SS AT" message="Number of private study pupils is missing."/>
	<Error:rule number="950" outputno="950" term="SPR" type="Error" phase="PS MP MS SS AT" message="Number of pupils at another school is missing."/>
	<Error:rule number="953" outputno="953" term="SPR" type="Error" phase="MS SS AT" message="Number of pupils on work experience is missing."/>
	<Error:rule number="957" outputno="957" term="SPR" type="Error" phase="MS SS AT" message="Number of pupils at FE colleges is missing."/>
	<Error:rule number="1000" outputno="1000" term="SPR" type="Error" phase="PS MP MS SS AT" message="Pupil reconciliation does not match number of pupils on roll."/>
	<Error:rule number="1010" outputno="1010Q" term="SPR" type="Query" phase="PS MP MS SS AT" message="Please check:10% or more of pupils not in class at selected time."/>
	<Error:rule number="5023" outputno="5023" term="SPR" type="Error" phase="NS PS MP MS SS AT SP PR" message="Data items in the pupil reconciliation module are only required from schools with a phase of PS, MP, MS, SS or AT."/>
	<Error:rule number="5026" outputno="5026" term="SPR" type="Error" phase="NS PS MP MS SS AT SP PR" message="Pupils can only be on work experience if the census return is from a school with a phase of MS, SS or AT."/>
	<Error:rule number="5027" outputno="5027" term="SPR" type="Error" phase="NS PS MP MS SS AT SP PR" message="Pupils can only be attending an FE college if the census return is from a school with a phase of MS, SS or AT."/>

	<!-- School - Class Information -->
	<Error:rule number="1050" outputno="1050" term="SPR" type="Error" phase="PS MP MS SS AT" message="Class name is missing."/>
	<Error:rule number="1060" outputno="1060" term="SPR" type="Error" phase="PS MP MS SS AT" message="Two (or more) classes have the same name."/>
	<Error:rule number="1070" outputno="1070Q" term="SPR" type="Query" phase="PS MP MS SS AT" message="Please check: number of teachers in class is missing or invalid."/>
	<Error:rule number="1090" outputno="1090" term="SPR" type="Error" phase="PS MP MS SS AT" message="Number of support staff in class is missing."/>
	<Error:rule number="1100" outputno="1100" term="SPR" type="Error" phase="PS MP MS SS AT" message="Class with no staff."/>
	<Error:rule number="1110" outputno="1110Q" term="SPR" type="Query" phase="PS MP MS SS AT" message="Please check: no support staff reported for any class."/>
	<Error:rule number="1130" outputno="1130" term="SPR" type="Error" phase="PS AT" message="Class type is missing or invalid."/>
	<Error:rule number="1140" outputno="1140" term="SPR" type="Error" phase="PS MP MS SS AT" message="Class year group is missing, or invalid for this phase of school."/>
	<Error:rule number="1150" outputno="1150Q" term="SPR" type="Query" phase="PS AT" message="Please check: class type and class year group different."/>
	<Error:rule number="1155" outputno="1155Q" term="SPR" type="Query" phase="PS AT" message="Please check: class type and class year group different."/>
	<Error:rule number="1160" outputno="1160" term="SPR" type="Error" phase="PS AT" message="Class key stage not present or invalid."/>
	<Error:rule number="1170" outputno="1170" term="SPR" type="Error" phase="PS AT" message="Class activity is missing or invalid."/>
	<Error:rule number="1180" outputno="1180Q" term="SPR" type="Query" phase="PS AT" message="Please check: activity shown as other for all classes."/>
	<Error:rule number="1190" outputno="1190" term="SPR" type="Error" phase="PS AT" message="Class year group and key stage not consistent."/>
	<Error:rule number="1200" outputno="1200" term="SPR" type="Error" phase="PS MP MS SS AT" message="Number of home pupils in class is missing."/>
	<Error:rule number="1210" outputno="1210" term="SPR" type="Error" phase="PS MP MS SS AT" message="Number of guest pupils in class is missing."/>
	<Error:rule number="1220" outputno="1220" term="SPR" type="Error" phase="PS MP MS SS AT" message="Class with no pupils."/>
	<Error:rule number="1230" outputno="1230Q" term="SPR" type="Query" phase="PS AT" message="Please check: KS1 or reception class with pupil / teacher ratio greater than 30."/>
	<Error:rule number="1235" outputno="1235" term="SPR" type="Error" phase="PS AT" message="For KS1 or reception classes class activity must reflect an &quot;academic&quot; activity."/>
	<Error:rule number="1240" outputno="1240Q" term="SPR" type="Query" phase="NS PS MP MS SS AT SP PR" message="Please check: the number of guest pupils in the class is equal to or greater than the number of home pupils."/>
	<Error:rule number="1245" outputno="1245" term="SPR" type="Error" phase="NS PS MP MS SS AT SP PR" message="Number of teachers on PPA can only be returned from schools with a phase of 'PS' or 'AT', and may only be present where either Keystage equals 1 or the year group equals 'R'."/>
	<Error:rule number="1250" outputno="1250" term="SPR" type="Error" phase="NS PS MP MS SS AT SP PR" message="Infant class size exceptions can only be returned from schools with a phase of 'PS' or 'AT', and may only be present where either Keystage equals 1 or the year group equals 'R'."/>	
	<Error:rule number="1260" outputno="1260Q" term="SPR" type="Query" phase="PS AT" message="Please check: nursery class with pupils / adult ratio greater than expected."/>
	<Error:rule number="1270" outputno="1270Q" term="SPR" type="Query" phase="PS MP MS SS AT" message="Please check: no classes shown for an expected year group."/>
	<Error:rule number="1280" outputno="1280Q" term="SPR" type="Query" phase="PS MP MS SS AT" message="Please check: classes shown for an unexpected year group."/>
	<Error:rule number="1300" outputno="1300Q" term="SPR" type="Query" phase="PS AT" message="Please check: nursery classes shown but no nursery pupil records."/>
	<Error:rule number="5032" outputno="5032" term="SPR" type="Error" phase="NS SP PR" message="Data items in the class information module are only required from schools with a phase of PS, MP, MS, SS or AT."/>
	<Error:rule number="5036" outputno="5036" term="SPR" type="Error" phase="NS PS MP MS SS SP PR AT" message="Class type can only be returned from schools with a phase of PS or AT, and may be present only for year groups E1, E2, N1, N2, R, 1-7, or M."/>
	<Error:rule number="5037" outputno="5037" term="SPR" type="Error" phase="NS PS MP MS SS SP PR AT" message="Class key stage can only be returned from schools with a phase of PS or AT, and may be present only for year groups E1, E2, N1, N2, R, 1-7, or M."/>
	<Error:rule number="5038" outputno="5038" term="SPR" type="Error" phase="NS PS MP MS SS SP PR AT" message="Class activity can only be returned from schools with a phase of PS or AT, and may be present only for year groups E1, E2, N1, N2, R, 1-7, or M."/>
	<Error:rule number="5039" outputno="5039" term="SPR" type="Error" phase="NS PS MP MS SS SP PR AT" message="The number of home pupils is only required from schools with a phase of PS, MP, MS, SS or AT."/>
	<Error:rule number="5040" outputno="5040" term="SPR" type="Error" phase="NS PS MP MS SS SP PR AT" message="The number of guest pupils is only required from schools with a phase of PS, MP, MS, SS or AT."/>
	<Error:rule number="5160" outputno="5160" term="SPR" type="Error" phase="PS MP MS SS AT" message="Class information is missing."/>

	<!-- School - Miscellaneous -->
	<Error:rule number="1873" outputno="1873Q" term="SPR SUM" type="Query" phase="SS AT SP PR" message="Please check: No pupils currently on roll are recorded as being in receipt of the 16-19 bursary - Are you sure?"/>
	<Error:rule number="1310" outputno="1310" term="SPR" type="Error" phase="NS PS MP MS SS AT SP" message="Number of free school meals taken is missing."/>
	<Error:rule number="1320" outputno="1320" term="SPR" type="Error" phase="NS PS MP MS SS AT SP" message="Free meals taken exceeds total eligible pupils."/>
	<Error:rule number="1330" outputno="1330Q" term="SPR" type="Query" phase="NS PS MP MS SS AT SP" message="Please check: free school meals taken equals zero.Your school has one or more pupils who are eligible for free school meals."/>
	<Error:rule number="2900" outputno="2900" term="SPR" type="Error" phase="NS PS MP MS SS SP PR AT" message="Details of whether childcare is provided on site is missing."/>
	<Error:rule number="2910" outputno="2910" term="SPR" type="Error" phase="NS PS MP MS SS SP PR AT" message="Signposting or promotion of off-site childcare is missing."/>
	<Error:rule number="2915" outputno="2915" term="SPR" type="Error" phase="NS PS MP MS SS SP PR AT" message="Opening time must be provided in the format HH:MM for on site childcare."/>
	<Error:rule number="2916" outputno="2916" term="SPR" type="Error" phase="NS PS MP MS SS SP PR AT" message="Opening time is not required for after school childcare."/>	
	<Error:rule number="2920" outputno="2920" term="SPR" type="Error" phase="NS PS MP MS SS SP PR AT" message="Closing time must be provided in the format HH:MM for on site childcare."/>
	<Error:rule number="2921" outputno="2921" term="SPR" type="Error" phase="NS PS MP MS SS SP PR AT" message="Closing time is not required for before school childcare."/>
	<Error:rule number="2925" outputno="2925" term="SPR" type="Error" phase="NS PS MP MS SS SP PR AT" message="Number of childcare place for on site childcare missing."/>
	<Error:rule number="2930" outputno="2930" term="SPR" type="Error" phase="NS PS MP MS SS SP PR AT" message="The service provider of childcare for on site childcare missing."/>
	<Error:rule number="2935" outputno="2935" term="SPR" type="Error" phase="NS PS MP MS SS SP PR AT" message="Ability to accept pupils from other schools is missing."/>
	<Error:rule number="2936" outputno="2936" term="SPR" type="Error" phase="NS PS MP MS SS SP PR AT" message="Ability to accept pupils from other schools is not required for under 5 childcare."/>
	<Error:rule number="2940" outputno="2940" term="SPR" type="Error" phase="NS PS MP MS SS SP PR AT" message="Number of weeks which regular childcare provision is open is missing or out of the range 1 to 38."/>
	<Error:rule number="2941" outputno="2941" term="SPR" type="Error" phase="NS PS MP MS SS SP PR AT" message="Number of weeks which regular childcare provision is open is not required for before and after school childcare."/>
	<Error:rule number="2945" outputno="2945" term="SPR" type="Error" phase="NS PS MP MS SS SP PR AT" message="Only details on the type of childcare and childcare signposting are required. Other childcare details are not required where childcare is not provided on site."/>
	<Error:rule number="29501" outputno="2950" term="SPR" type="Error" phase="NS PS MP MS SS SP PR AT" message="Childcare type &apos;A&apos; has not been provided."/>
	<Error:rule number="29502" outputno="2950" term="SPR" type="Error" phase="NS PS MP MS SS SP PR AT" message="Childcare type &apos;B&apos; has not been provided."/>
	<Error:rule number="29503" outputno="2950" term="SPR" type="Error" phase="NS PS MP MS SS SP PR AT" message="Childcare type &apos;H&apos; has not been provided."/>
	<Error:rule number="29504" outputno="2950" term="SPR" type="Error" phase="NS PS MP MS SS SP PR AT" message="Childcare type &apos;U&apos; has not been provided."/>
	<Error:rule number="2955" outputno="2955" term="SPR" type="Error" phase="NS PS MP MS SS SP PR AT" message="The type of childcare has been reported more than once."/>
	<Error:rule number="2960" outputno="2960Q" term="SPR" type="Query" phase="NS PS MP MS SS SP PR AT" message="Please check: opening time is expected to be within the range 06:00 to 09:00."/>
	<Error:rule number="2965" outputno="2965Q" term="SPR" type="Query" phase="NS PS MP MS SS SP PR AT" message="Please check: closing time is expected to be within the range 16:00 to 20:00."/>
	<Error:rule number="2970" outputno="2970" term="SPR" type="Error" phase="NS PS MP MS SS SP PR AT" message="If the school has under 5 childcare, the number of hour for this provision must be equal to or greater than 9."/>
	<Error:rule number="2975" outputno="2975" term="SPR" type="Error" phase="NS PS MP MS SS SP PR AT" message="Number of weeks which regular childcare provision is open is missing or out of the range 1 to 15."/>
	<Error:rule number="2980" outputno="2980" term="SPR" type="Error" phase="PS MP MS SS SP PR AT" message="School time is invalid."/>
	<Error:rule number="2981" outputno="2981" term="SPR" type="Error" phase="NS" message="School time is not required from nursery schools."/>
	<Error:rule number="2982" outputno="2982Q" term="SPR" type="Query" phase="PS MP MS SS SP PR AT" message="Please check: school time is outside of the expected range."/>

	<!-- Pupil - Identifiers -->
	<Error:rule number="1490" outputno="1490Q" term="AUT SPR SUM" type="Query" phase="NS PS MP MS SS AT SP PR" message="Please check: no pupils on roll have been recorded."/>
	<Error:rule number="1495" outputno="1495Q" term="SPR SUM" type="Query" phase="PS MP MS SS AT SP PR" message="Please check: no pupils no longer on roll have been recorded."/>
	<Error:rule number="1496" outputno="1496" term="AUT" type="Error" phase="PS MP MS SS AT SP PR" message="No pupils no longer on roll have been recorded."/>
	<Error:rule number="1500" outputno="1500" term="AUT SPR SUM" type="Error" phase="NS PS MP MS SS AT SP PR" message="UPN missing."/>
	<Error:rule number="1510" outputno="1510" term="AUT SPR SUM" type="Error" phase="NS PS MP MS SS AT SP PR" message="UPN invalid (wrong check letter at character 1)."/>
	<Error:rule number="1520" outputno="1520" term="AUT SPR SUM" type="Error" phase="NS PS MP MS SS AT SP PR" message="More than one pupil record with the same UPN."/>
	<Error:rule number="1530" outputno="1530" term="AUT SPR SUM" type="Error" phase="NS PS MP MS SS AT SP PR" message="UPN invalid (characters 2-4 not a recognised LA code)."/>
	<Error:rule number="1540" outputno="1540" term="AUT SPR SUM" type="Error" phase="NS PS MP MS SS AT SP PR" message="UPN invalid (characters 5-12 not all numeric)."/>
	<Error:rule number="1550" outputno="1550" term="AUT SPR SUM" type="Error" phase="NS PS MP MS SS AT SP PR" message="UPN invalid (character 13 not a recognised value or is missing)."/>
	<Error:rule number="1570" outputno="1570" term="AUT SPR SUM" type="Error" phase="MS SS AT SP PR" message="Unique learner number must be provided for pupils aged 14 and over on census day."/>
	<Error:rule number="1573" outputno="1573" term="AUT SPR SUM" type="Error" phase="MS SS AT SP PR" message="Unique learner number must be provided for pupils aged 14 and over at date of leaving."/>
	<Error:rule number="1575" outputno="1575" term="AUT SPR SUM" type="Error" phase="MS SS AT SP PR" message="ULN format incorrect. Either number is less than 10 digits or the check digit is incorrect - please check."/>
	<Error:rule number="1578" outputno="1578" term="AUT SPR SUM" type="Error" phase="MS SS AT SP PR" message="More than one pupil record with the same ULN."/>
	<Error:rule number="1580" outputno="1580" term="AUT SPR SUM" type="Error" phase="NS PS MP MS SS AT SP PR" message="Pupil with last name missing."/>
	<Error:rule number="1590" outputno="1590" term="AUT SPR SUM" type="Error" phase="NS PS MP MS SS AT SP PR" message="Pupil with forename missing."/>
	<Error:rule number="1600" outputno="1600" term="AUT SPR SUM" type="Error" phase="NS PS MP MS SS AT SP PR" message="Pupil&apos;s date of birth is missing."/>
	<Error:rule number="1601" outputno="1601Q" term="AUT SPR SUM" type="Query" phase="NS PS MP MS SS AT PR" message="Please check: pupil&apos;s age is out of range for school type."/>
	<Error:rule number="1610" outputno="1610" term="AUT SPR SUM" type="Error" phase="NS PS MP MS SS AT SP PR" message="Pupil&apos;s sex is missing or invalid."/>
	<Error:rule number="1620" outputno="1620Q" term="AUT SPR SUM" type="Query" phase="NS PS MP MS SS AT SP PR" message="Please check: duplicate pupil records with the same surname, forename, sex and date of birth."/>
	<Error:rule number="1633" outputno="1633" term="AUT" type="Error" phase="SS AT PR" message="Please check: pupil has an exemption for English GCSE funding due to learning difficulties but does not have an education, health and care (EHC) plan." />
	<Error:rule number="1634" outputno="1634" term="AUT" type="Error" phase="SS AT PR" message="Please check: pupil has an exemption for maths GCSE funding due to learning difficulties but does not have an education, health and care (EHC) plan." />
	<Error:rule number="1635" outputno="1635" term="AUT" type="Error" phase="SS AT PR" message="Where the learner has not achieved grade A*-C / 9-4 in maths GCSE the stage that the learner achieved this must not be equal to 1 or 2." />
	<Error:rule number="1636" outputno="1636" term="AUT" type="Error" phase="SS AT PR" message="Where learner has achieved grade A*-C / 9-4 in maths the prior attainment stage must be equal to 1 or 2." />
	<Error:rule number="1637" outputno="1637" term="AUT" type="Error" phase="SS AT PR" message="Where the learner has not achieved grade A*-C / 9-4 in English GCSE the stage that the learner achieved this must not be equal to 1 or 2." />
	<Error:rule number="1638" outputno="1638" term="AUT" type="Error" phase="SS AT PR" message="Where learner has achieved grade A*-C / 9-4 in English the prior attainment stage must be equal to 1 or 2." />
	<Error:rule number="5065" outputno="5065" term="AUT SPR SUM" type="Error" phase="NS PS MP MS SS AT SP PR" message="Schools with a phase of NS should not submit any records for pupils no longer on roll."/>

	<!-- Pupil - Characteristics -->
	<Error:rule number="1630" outputno="1630" term="SPR" type="Error" phase="NS PS MP MS SS AT SP PR" message="Pupil's ethnicity is missing or invalid."/>
	<Error:rule number="3080" outputno="3080Q" term="AUT SPR SUM" type="Query" phase="NS PS MP MS SS AT SP PR" message="Please check: take up of school lunches for pupils in reception (plus pupils aged 4 in year X) is 50% or fewer. A reason must be provided why 50% or fewer reception pupils took a school lunch on census day."/>
	<Error:rule number="3085" outputno="3085Q" term="AUT SPR SUM" type="Query" phase="NS PS MP MS SS AT SP PR" message="Please check: take up of school lunches for pupils in year 1 (plus pupils aged 5 in year X) is 50% or fewer. A reason must be provided why 50% or fewer pupils in year 1 took a school lunch on census day."/>
	<Error:rule number="3090" outputno="3090Q" term="AUT SPR SUM" type="Query" phase="NS PS MP MS SS AT SP PR" message="Please check: take up of school lunches for pupils in year 2 (plus pupils aged 6 in year X) is 50% or fewer. A reason must be provided why 50% or fewer pupils in year 2 took a school lunch on census day."/>
	<Error:rule number="1700" outputno="1700Q" term="SPR" type="Query" phase="NS PS MP MS SS AT SP PR" message="Please check: Percentage of pupils on roll for whom ethnicity has not been obtained is high (greater than 10%)."/>
	<Error:rule number="1741" outputno="1741Q" term="SPR SUM AUT" type="Query" phase="NS PS MP MS SS AT SP PR" message="Based on Ministry of Defence criteria, service children (parents designated as personnel category 1 or 2) are not eligible for free school meals."/>
	<Error:rule number="1745" outputno="1745" term="AUT SPR SUM" type="Error" phase="NS PS MP MS SS AT SP PR" message="The start date and end date are the same within a single free school meal period."/>
	<Error:rule number="1750" outputno="1750Q" term="AUT SPR SUM" type="Query" phase="NS PS MP MS SS AT SP PR" message="Please check: percentage of pupils with periods of free school meal eligibility is high (greater than 45%)."/>
	<Error:rule number="1751" outputno="1751Q" term="AUT SPR SUM" type="Query" phase="NS PS MP MS SS AT SP PR" message="Please check: percentage of pupils in reception with periods of free school meal eligibility is high (greater than 50%)."/>
	<Error:rule number="1752" outputno="1752Q" term="AUT SPR SUM" type="Query" phase="NS PS MP MS SS AT SP PR" message="Please check: percentage of pupils in NC year 1 with periods of free school meal eligibility is high (greater than 50%)."/>
	<Error:rule number="1753" outputno="1753Q" term="AUT SPR SUM" type="Query" phase="NS PS MP MS SS AT SP PR" message="Please check: percentage of pupils in NC year 7 with periods of free school meal eligibility is high (greater than 50%)."/>
	<Error:rule number="1760" outputno="1760Q" term="AUT SPR SUM" type="Query" phase="NS PS MP MS SS AT SP PR" message="Please check: no pupils in the school eligible for free school meals during the period since the last census."/>
	<Error:rule number="1761" outputno="1761" term="AUT SPR SUM" type="Error" phase="NS PS MP MS SS AT SP PR" message="A start date must be provided for each period of free school meal eligibility."/>
	<Error:rule number="1762" outputno="1762" term="AUT SPR SUM" type="Error" phase="NS PS MP MS SS AT SP PR" message="Periods of free school meal eligibility that started after the census day should not be included in the return."/>
	<Error:rule number="1763" outputno="1763" term="AUT SPR SUM" type="Error" phase="NS PS MP MS SS AT SP PR" message="Periods of free school meal eligibility that ended before or on the previous census day or after the current census day should not be included in the return."/>
	<Error:rule number="1764" outputno="1764" term="AUT SPR SUM" type="Error" phase="NS PS MP MS SS AT SP PR" message="The country code associated with the period of free school meal eligibility is not a valid value."/>
	<Error:rule number="1765" outputno="1765" term="AUT SPR SUM" type="Error" phase="NS PS MP MS SS AT SP PR" message="Any period of FSM eligibility outside of England, ie country of UK = NIR, SCT or WLS, must have an FSM eligibility end date before census day."/>
	<Error:rule number="1766" outputno="1766" term="AUT SPR SUM" type="Error" phase="NS PS MP MS SS AT SP PR" message="The FSM end date is prior to the FSM start date."/>
	<Error:rule number="1767" outputno="1767Q" term="AUT SPR SUM" type="Query" phase="NS PS MP MS SS AT SP PR" message="Due to FSM protection, FSM periods are not expected to have an end date. Please provide a reason."/>
	<Error:rule number="1768" outputno="1768" term="AUT SPR SUM" type="Error" phase="NS PS MP MS SS AT SP PR" message="Pupil cannot have multiple open FSM periods."/>
	<Error:rule number="1770" outputno="1770" term="AUT SPR SUM" type="Error" phase="MP MS SS AT SP PR" message="Youth support services agreement is missing or invalid."/>
	<Error:rule number="1840" outputno="1840" term="AUT SPR SUM" type="Error" phase="NS PS MP MS SS AT SP PR" message="Language is missing or invalid value."/>
	<Error:rule number="1843" outputno="1843" term="SPR" type="Error" phase="NS PS MP MS SS AT SP PR" message="Early years pupil premium basis for funding is missing or invalid."/>
	<Error:rule number="1844" outputno="1844" term="SPR" type="Error" phase="NS PS MP MS SS AT SP PR" message="Early years pupil premium basis for funding is only required where early years pupil premium eligibility is &apos;Y&apos;."/>
	<Error:rule number="1846" outputno="1846" term="SPR" type="Error" phase="NS PS MP MS SS AT SP PR" message="Early years pupil premium must be recorded for all 3 year olds."/>
	<Error:rule number="1847" outputno="1847" term="SPR" type="Error" phase="NS PS MP MS SS AT SP PR" message="Early years pupil premium must be recorded for 4 year olds in nursery provision."/>
	<Error:rule number="1848" outputno="1848" term="SPR" type="Error" phase="NS PS MP MS SS AT SP PR" message="Early years pupil premium must be recorded for 4 year olds in E1, E2, N1 or N2."/>
	<Error:rule number="1849" outputno="1849Q" term="SPR" type="Query" phase="NS PS MP MS SS AT SP PR" message="Please check: Pupil aged 3 or 4 recorded with post looked after arrangements would be expected to be in receipt of early years pupil premium with a basis for funding of &apos;RO&apos; or &apos;RB&apos;."/>
	<Error:rule number="1850" outputno="1850Q" term="AUT SPR SUM" type="Query" phase="NS PS MP MS SS AT SP PR" message="Please check: percentage of pupils where language has not been obtained is high (greater than 10%)."/>
	<Error:rule number="1851" outputno="1851" term="AUT SPR SUM" type="Error" phase="NS PS MP MS SS AT SP PR" message="Child&apos;s funded hours must not be provided for pupil aged 5 and over or pupils aged under 2."/>
	<Error:rule number="1852" outputno="1852" term="AUT SPR SUM" type="Error" phase="NS PS MP MS SS AT SP PR" message="Child&apos;s funded hours not provided or out of the range 0 to 15 to two decimal places."/>
	<Error:rule number="1853" outputno="1853Q" term="SPR" type="Query" phase="NS PS MP MS SS AT SP PR" message="Please check: A pupil aged 3 or 4 eligible for FSM would be expected to be in receipt of early years pupil premium with a basis for funding of &apos;RE&apos; or &apos;RB&apos;."/>
	<Error:rule number="1854" outputno="1854" term="AUT SPR SUM" type="Error" phase="NS PS MP MS SS AT SP PR" message="Childs hours at setting must not be provided for pupil aged 5 and over or pupils aged under 2."/>
	<Error:rule number="1855" outputno="1855" term="AUT SPR SUM" type="Error" phase="NS PS MP MS SS AT SP PR" message="Hours at setting is missing or outside of the valid range (0 to 70) for 2 and 3 year olds."/>
	<Error:rule number="1856" outputno="1856" term="SPR SUM AUT" type="Error" phase="NS PS MP MS SS AT SP PR" message="Service children in education indicator missing or invalid."/>
	<Error:rule number="1859" outputno="1859" term="AUT SPR SUM" type="Error" phase="NS PS MP MS SS AT SP PR" message="Funded hours plus any extended hours cannot be more than the hours at setting."/>
	<Error:rule number="1864" outputno="1864" term="SPR SUM" type="Error" phase="MS SS AT SP PR" message="Learner support code should not be provided for subsidiary pupils."/>
	<Error:rule number="1865" outputno="1865" term="SPR SUM" type="Error" phase="MS SS AT SP PR" message="Learner support code is invalid."/>
	<Error:rule number="1866" outputno="1866" term="SPR SUM" type="Error" phase="MS SS AT SP PR" message="The same learner support code should not appear more than once for the same pupil."/>
	<Error:rule number="1867" outputno="1867" term="SPR SUM" type="Error" phase="MS SS AT SP PR" message="Learner is aged under 16 years as at 31 August and not eligible for bursary funding."/>
	<Error:rule number="1868" outputno="1868" term="SPR SUM" type="Error" phase="MS SS AT SP PR" message="Learner is aged 20 years or over as at 31 August and not eligible for bursary funding."/>
	<Error:rule number="1869" outputno="1869" term="AUT SPR SUM" type="Error" phase="NS PS MP MS SS AT SP PR" message="Top up funding indicator is missing or invalid."/>
	<Error:rule number="1871" outputno="1871" term="AUT SPR SUM" type="Error" phase="NS PS MP MS SS AT SP PR" message="Post looked after arrangements indicator is missing or invalid."/>
	<Error:rule number="1872" outputno="1872Q" term="AUT SPR SUM" type="Query" phase="NS PS MP MS SS AT SP PR" message="Please check: percentage of pupils on roll on census day reported as having ceased to be looked after through adoption, a special guardianship order, residence order or child arrangement order is high (greater than 5%)."/>
	<Error:rule number="1874" outputno="1874" term="AUT SPR SUM" type="Error" phase="NS PS MP MS SS AT SP PR" message="Post looked after arrangements code is invalid. Residence orders were replaced with Child Arrangement Orders in 2014"/>
	<Error:rule number="1875" outputno="1875" term="AUT SPR SUM" type="Error" phase="NS PS MP MS SS AT SP PR" message="School lunch taken is missing or invalid."/>
	<Error:rule number="1876" outputno="1876" term="AUT SPR SUM" type="Error" phase="NS PS MP MS SS AT SP PR" message="School lunch taken only required from pupils in reception, year 1 or year 2 or from pupils aged 4 to 6 in year X."/>
	<Error:rule number="1877" outputno="1877Q" term="AUT SPR SUM" type="Query" phase="NS PS MP MS SS AT SP PR" message="Please check: take up of school lunches for pupils in reception, year 1 and year 2 (plus pupils aged 4 to 6 in year X) greater than 95%. Please confirm more than 95% of infant pupils took a school lunch on census day."/>
	<Error:rule number="1878" outputno="1878Q" term="AUT SPR SUM" type="Query" phase="NS PS MP MS SS AT SP PR" message="Please check: no infant pupils are recorded as having a school lunch on census day?"/>
	<Error:rule number="1894" outputno="1894" term="AUT" type="Error" phase="SS AT PR" message="Student has at least one T Level learning aim which has been active during the current year but there are no T Level planned learning hours recorded "/>
	<Error:rule number="1895" outputno="1895" term="AUT" type="Error" phase="SS AT PR" message="Student does not have at least one T Level component recorded therefore T Level planned learning hours and/or T level planned employability, enrichment and pastoral hours should not be present"/>
	<Error:rule number="1896" outputno="1896" term="AUT" type="Error" phase="SS AT PR" message="If a student has both planned learning hours and T Level planned learning hours they must have a programme aim with a programme type of T Level AND a programme aim with a programme type of Study programme or 'T Level transition programme'"/>
	<Error:rule number="1990" outputno="1990Q" term="AUT SPR SUM" type="Query" phase="NS PS MP MS SS AT" message="Please check: pupil is in receipt of top-up funding but is not classed as having an EHC Plan?"/>
	<Error:rule number="1991" outputno="1991Q" term="AUT SPR SUM" type="Query" phase="NS PS MP MS SS AT SP PR" message="Please check: no pupils with an EHC Plan are reported as being in receipt of top-up funding?"/>
	<Error:rule number="2695" outputno="2695Q" term="AUT SPR SUM" type="Query" phase="NS PS MP MS SS AT SP PR" message="Please check: 90% or more of infant pupils have free school meal eligibility."/>
	<Error:rule number="3160" outputno="3160" term="AUT SPR SUM" type="Error" phase="NS PS MP MS SS AT SP PR" message="More than one pupil is recorded with the same 30-hour eligibility code."/>
	<Error:rule number="5046" outputno="5046" term="AUT SPR SUM" type="Error" phase="NS PS" message="Youth support services indicator is not required from schools with a phase of NS or PS."/>
	<Error:rule number="5094" outputno="5094" term="AUT SPR SUM" type="Error" phase="NS PS MP MS SS AT SP PR" message="Hours at setting is not required from CTCs or non-maintained special schools."/>
	<Error:rule number="5095" outputno="5095" term="AUT SPR SUM" type="Error" phase="NS PS MP MS SS AT SP PR" message="Funded hours are not required from CTCs or non-maintained special schools."/>
	<Error:rule number="5096" outputno="5096" term="AUT SPR SUM" type="Error" phase="NS PS MP MS SS AT SP PR" message="30-hour eligibility code is not required from CTCs or non-maintained special schools." />
	<Error:rule number="5097" outputno="5097" term="SPR" type="Error" phase="NS PS MP MS SS AT SP PR" message="Early Years Pupil Premium (EYPP) is not required from CTCs  or non-maintained special schools." /> 
	<!--Error:rule number="5140" outputno="5140" term="SPR" type="Error" phase="NS PS MP MS SS AT SP PR" message="Proficiency in English is missing or invalid for child in reception and above with language not equal to ENG (English), ENB (believed to be English) or BSL (British sign language)." /-->
	<Error:rule number="5170" outputno="5170" term="AUT SPR SUM" type="Error" phase="NS PS MP MS SS AT SP PR" message="Child&apos;s funded hours must not be provided for pupil aged 4 in reception or above." />
	<!--Error:rule number="5180" outputno="5180" term="AUT SPR SUM" type="Error" phase="NS PS MP MS SS AT SP PR" message="Child&apos;s funded hours not provided or out of the range 0 to 25 to two decimal places for pupils aged 4 not in reception or above." /-->
	<Error:rule number="5190" outputno="5190" term="AUT SPR SUM" type="Error" phase="NS PS MP MS SS AT SP PR" message="Child&apos;s hours at setting must not be provided for pupils aged 4 in reception or above." />
	<Error:rule number="5200" outputno="5200" term="AUT SPR SUM" type="Error" phase="NS PS MP MS SS AT SP PR" message="Child’s hours at setting is missing or outside of the valid range (0 to 70) for pupils aged 4 in nursery provision." />
	<Error:rule number="5210" outputno="5210" term="AUT SPR SUM" type="Error" phase="NS PS MP MS SS AT SP PR" message="Extended hours are not required from CTCs or non-maintained special schools."/>
	<Error:rule number="5215" outputno="5215" term="AUT SPR SUM" type="Error" phase="NS PS MP MS SS AT SP PR" message="Disability access fund information is not required from CTCs or non-maintained special schools."/>
	<Error:rule number="5220" outputno="5220" term="AUT SPR SUM" type="Error" phase="NS PS MP MS SS AT SP PR" message="The disability access fund indicator is only available for pupils with funded or extended hours."/>
	<Error:rule number="5230" outputno="5230" term="AUT SPR SUM" type="Error" phase="NS PS MP MS SS AT SP PR" message="The disability access fund indicator is missing or not a valid value for pupils aged 3 or 4 in nursery provision."/>
	<Error:rule number="5235" outputno="5235" term="SPR" type="Error" phase="NS PS MP MS SS AT SP PR" message="2-year-old basis for funding is missing or an invalid value for a two year old with funded hours."/>	
	<Error:rule number="5236" outputno="5236" term="SPR" type="Error" phase="NS PS MP MS SS AT SP PR" message="Pupil has a special educational need of EHC plan, but high-level SEN or disability (HSD) is not recorded as one of their basis for funding."/>	
	<Error:rule number="5240" outputno="5240Q" term="AUT SPR SUM" type="Query" phase="NS PS MP MS SS AT SP PR" message="Please check: the number of hours at setting indicates that the pupil may be attending the school full time. However, they have been recorded as part-time."/>
	<Error:rule number="1846" outputno="1846" term="SPR" type="Error" phase="NS PS AT SP PR" message="Early years pupil premium must be recorded for all 3 year olds."/>
	<Error:rule number="1847" outputno="1847" term="SPR" type="Error" phase="NS" message="Early years pupil premium must be recorded for 4 year olds in Nursery provision."/>
	<Error:rule number="1848" outputno="1848" term="SPR" type="Error" phase="PS AT SP PR" message="Early years pupil premium must be recorded for 4 year olds in N1 or N2 provision."/>
	<Error:rule number="1849" outputno="1849Q" term="SPR" type="Query" phase="NS PS AT SP PR" message="Please check: pupil aged 3 or 4 eligible for early years pupil premium and recorded as adopted from care would be expected to have reason &apos;EO&apos; or &apos;EB&apos;."/>
	<Error:rule number="1861" outputno="1861" term="SPR" type="Error" phase="NS PS MP MS SS AT SP PR" message="Early years pupil premium only required for pupils aged 3 and 4."/>
	<Error:rule number="1862" outputno="1862" term="SPR" type="Error" phase="PS MP MS SS AT SP PR" message="Early years pupil premium not required for pupils aged 4 in reception or above."/>	
	<Error:rule number="1992" outputno="1992" term="AUT" type="Error" phase="SS AT PR" message="Pupil has at least one learning aim which was active during the current year but there are no planned learning hours recorded for the current academic year."/>
	<Error:rule number="1993" outputno="1993" term="AUT" type="Error" phase="SS AT PR" message="Pupil does not have any study programme or T level Transition learning aims recorded therefore planned learning hours and/or planned employability, enrichment and pastoral hours should not be present."/>
	<Error:rule number="1996" outputno="1996Q" term="AUT" type="Query" phase="SS AT PR" message="Please check: The sum of planned learning hour and the planned employability, enrichment and pastoral hours should not be greater than 1,000 hours. Planned hours should reflect the planned hours for the academic year."/>
	<Error:rule number="1997" outputno="1997" term="AUT" type="Error" phase="SS AT PR" message="The sum of planned learning hours and planned employability, enrichment and pastoral hours must not be greater than 4,000 hours."/>
	<Error:rule number="1998" outputno="1998Q" term="AUT" type="Query" phase="SS AT PR" message="Please check: the pupil has  planned employability, enrichment and pastoral hours but no planned learning hours."/>
	<Error:rule number="1999" outputno="1999Q" term="AUT" type="Query" phase="SS AT PR" message="Please check: no pupils have planned employability, enrichment and pastoral hours."/>
	<Error:rule number="2690" outputno="2690" term="SPR" type="Error" phase="PR" message="Unit contact time is missing."/>
	<Error:rule number="2691" outputno="2691Q" term="SPR" type="Query" phase="PR" message="Please check: unit contact time is greater than normal full time education hours (which is 25 hours per week)."/>
	<Error:rule number="2692" outputno="2692Q" term="SPR" type="Query" phase="PR" message="Pupils would be expected to have some unit contact time with the establishment in the previous week. Please provide a reason."/>
	<Error:rule number="2775" outputno="2775Q" term="AUT" type="Query" phase="SS AT PR" message="Please check: the sum of planned learning hours and the planned employability, enrichment and pastoral hours is lower than 40.  Total planned hours should reflect the annual planned hours for the academic year."/>
	<Error:rule number="3000" outputno="3000" term="AUT" type="Error" phase="SS AT PR" message="Maths GCSE attainment grade is missing or invalid."/>
	<Error:rule number="3005" outputno="3005" term="AUT" type="Error" phase="SS AT PR" message="The stage at which the learner achieved a maths GCSE at grade A*-C / 9 - 4 or not is missing or invalid."/>
	<Error:rule number="3010" outputno="3010" term="AUT" type="Error" phase="SS AT PR" message="English GCSE attainment grade is missing or invalid."/>
	<Error:rule number="3015" outputno="3015" term="AUT" type="Error" phase="SS AT PR" message="The stage at which the learner achieved a English GCSE at grade A*-C / 9 - 4 or not is missing or invalid."/>
	<Error:rule number="3020" outputno="3020Q" term="AUT" type="Query" phase="SS AT PR" message="Please check:  Maths GCSE grade achieved is 'D'-'G' / '3'-'1',  'U' or 'NR' and the student is recorded as not having a funding exemption. If the student is not undertaking a valid maths qualification that meets the condition of funding or you have not recorded this re-take in the student's learning aim record,  they may have funding removed for being non-compliant with the condition of funding."/>
	<Error:rule number="3025" outputno="3025Q" term="AUT" type="Query" phase="SS AT PR" message="Please check: Student has achieved A*-C or 9-4 Maths GCSE and therefore would not be expected to have a funding exemption of L or F"/>
	<Error:rule number="3027" outputno="3027Q" term="AUT" type="Query" phase="SS AT PR" message="Please check: If student has exemption of O or U, the Maths highest prior attainment should be NR."/>
	<Error:rule number="3030" outputno="3030Q" term="AUT" type="Query" phase="SS AT PR" message="Please check:  English GCSE grade achieved is 'D'-'G' / '3'-'1',  'U' or 'NR' and the student is recorded as not having a funding exemption. If the student is not undertaking a valid English qualification that meets the condition of funding or you have not recorded this re-take in the student's learning aim record,  they may have funding removed for being non-compliant with the condition of funding."/>
	<Error:rule number="3035" outputno="3035Q" term="AUT" type="Query" phase="SS AT PR" message="Please check: Student has achieved A*-C or 9-4 English GCSE and therefore would not be expected to have a funding exemption of L or F"/>
	<Error:rule number="3037" outputno="3037Q" term="AUT" type="Query" phase="SS AT PR" message="Please check: If student has exemption of O or U, the English highest prior attainment should be NR."/>	
	<Error:rule number="3040" outputno="3040" term="AUT" type="Error" phase="SS AT PR" message="Maths GCSE funding exemption is missing or invalid."/>
	<Error:rule number="3045" outputno="3045" term="AUT" type="Error" phase="SS AT PR" message="English GCSE funding exemption is missing or invalid."/>
	<Error:rule number="3100" outputno="3100" term="AUT SPR SUM" type="Error" phase="NS PS MP MS SS AT SP PR" message="Extended childcare hours have been entered where pupil is not in the eligible age range or year groups 'E1', 'E2', 'N1' or 'N2', or does not have a valid 30-hour code."/>
	<Error:rule number="3105" outputno="3105" term="AUT SPR SUM" type="Error" phase="NS PS MP MS SS AT SP PR" message="The 30-hour code must be 11 digits long and contain numerical characters only."/>
	<Error:rule number="3110" outputno="3110" term="AUT SPR SUM" type="Error" phase="NS PS MP MS SS AT SP PR" message="A 30-hour code has been entered where pupil is not in the eligible age range or in year groups E1, E2, N1 or N2, or extended hours is missing."/>
	<Error:rule number="3120" outputno="3120" term="AUT SPR SUM" type="Error" phase="NS PS MP MS SS AT SP PR" message="The disability access fund indicator should only be recorded for all pupils aged 3 and those aged 4 who are in nursery provision."/>
	<Error:rule number="3130" outputno="3130" term="AUT SPR SUM" type="Error" phase="NS PS MP MS SS AT SP PR" message="30-hours eligibility code missing for pupil aged 3 or 4 with extended hours present."/>
	<Error:rule number="3140" outputno="3140" term="AUT SPR SUM" type="Error" phase="NS PS MP MS SS AT SP PR" message="Child&apos;s extended hours not provided or out of the range of 0 to 15 hours."/>
	<!--Error:rule number="3150" outputno="3150" term="AUT SPR SUM" type="Error" phase="NS PS MP MS SS AT SP PR" message="Child with extended hours greater than zero cannot have more than 15 funded hours."/-->
	<Error:rule number="3200" outputno="3200" term="SPR" type="Error" phase="NS PS MP MS SS AT SP PR" message="The basis for funding should only be recorded for pupils aged 2 with funded hours greater than zero."/>
	<Error:rule number="3210" outputno="3210" term="SPR" type="Error" phase="NS PS MP MS SS AT SP PR" message="Each reason for funding code must be unique and used only once."/>
	<Error:rule number="3211" outputno="3211" term="SPR" type="Error" phase="NS PS MP MS SS AT SP PR" message="High-level SEN or disability (HSD) is given as the basis for funding, but the pupil does not have an EHC plan."/>
	<Error:rule number="1886" outputno="1886" term="AUT" type="Error" phase="SS AT PR" message="Pupil has at least one learning aim which was active in the previous academic year but there are no previous year planned learning hours recorded."/>
	<Error:rule number="1887" outputno="1887" term="AUT" type="Error" phase="SS AT PR" message="Pupil does not have at least one learning aim recorded that was active in the previous academic year therefore the previous academic year's planned learning hours and/or previous year's planned employability, enrichment and pastoral hours should not be present for the previous year."/>	
	<Error:rule number="1888" outputno="1888Q" term="AUT" type="Query" phase="SS AT PR" message="Please check: The sum of previous year's planned learning hours and the previous year's planned employability, enrichment and pastoral hours should not be greater than 1,000 hours."/>
	<Error:rule number="1889" outputno="1889" term="AUT" type="Error" phase="SS AT PR" message="The sum of previous year's planned learning hours and previous year's planned employability, enrichment and pastoral hours must not be greater than 4,000 hours."/>	
	<Error:rule number="1891" outputno="1891Q" term="AUT" type="Query" phase="SS AT PR" message="Please check: The pupil has previous year's planned employability, enrichment and pastoral hours but no previous year's planned learning hours."/>
	<Error:rule number="1892" outputno="1892Q" term="AUT" type="Query" phase="SS AT PR" message="Please check: No pupils have previous year's  planned employability, enrichment and pastoral hours."/>	
	<Error:rule number="1893" outputno="1893Q" term="AUT" type="Query" phase="SS AT PR" message="Please check: The sum of previous year's planned learning hours and the previous year's planned employability, enrichment and pastoral hours is lower than 40.  Total previous year's planned hours should reflect the annual planned hours for the previous academic year."/>	
<!-- RFC1183 - IW ADDED 2021-08-18-->
	<Error:rule number="1897" outputno="1897" term="AUT" type="Error" phase="SS AT PR" message="Only previous year’s planned hours and attainment data is required for a pupil who left during the previous term"/>
	<Error:rule number="3046" outputno="3046" term="AUT" type="Error" phase="SS AT PR" message="Maths GCSE highest prior attainment grade for the previous year is missing or invalid."/>
	<Error:rule number="3047" outputno="3047" term="AUT" type="Error" phase="SS AT PR" message="English GCSE highest prior attainment grade for the previous year is missing or invalid."/>		
	<Error:rule number="4040" outputno="4040" term="SPR" type="Error" phase="PS MP MS SS AT SP PR" message="Young carer indicator is missing or invalid."/>		

	<!-- Pupil - Status -->
	<Error:rule number="2112" outputno="2112" term="AUT SPR SUM" type="Error" phase="SP" message="The school has indicated that it does not follow the national curriculum (year &apos;X&apos;) therefore the pupil’s national curriculum year group must be &apos;X&apos;."/>
	<Error:rule number="1860" outputno="1860" term="AUT SPR SUM" type="Error" phase="NS PS MP MS SS AT SP PR" message="Enrolment status is missing or invalid."/>
	<Error:rule number="1870" outputno="1870Q" term="AUT SPR SUM" type="Query" phase="NS PS MP MS SS AT SP" message="Please check: percentage of pupils with sole registrations at the school is low (fewer than 95%)."/>
	<Error:rule number="1880" outputno="1880" term="AUT SPR SUM" type="Error" phase="NS PS MP MS SS AT SP PR" message="Pupil&apos;s entry date to school missing or after census date."/>
	<!--Note difference in error text for 1881 depending on term-->
	<Error:rule number="18814" outputno="1881Q" term="AUT" type="Query" phase="PS MP MS SS AT PR" message="Please check the entry date as the sessions possible indicate that the pupil attended the school during the first half of the summer term. If the pupil left and was subsequently readmitted, the query will be accepted by DfE on condition that a suitable explanatory notepad entry is provided."/>
	<Error:rule number="18815" outputno="1881Q" term="SPR SUM" type="Query" phase="PS MP MS SS AT SP PR" message="Please check the entry date as the sessions possible indicate that the pupil attended the school during the term prior to this date. If the pupil left and was subsequently readmitted, the query will be accepted by DfE on condition that a suitable explanatory notepad entry is provided."/>
	<Error:rule number="1882" outputno="1882" term="AUT" type="Error" phase="PS MP MS SS AT PR" message="A new entry date should not be given for pupils moving directly from nursery to reception or entering year 12 directly from within the same school. Sessions possible indicate that the pupil attended the school during the summer second half term. If the pupil left and was subsequently readmitted, the error will be accepted by DfE on condition that a suitable explanatory notepad entry is provided."/>
	<Error:rule number="1883" outputno="1883Q" term="AUT" type="Query" phase="PS MP MS SS AT PR" message="Please check entry date as the sessions possible indicate that the pupil attended the school during the second half of the summer term. If the pupil left and was subsequently readmitted, the query will be accepted by DfE on condition that a suitable explanatory notepad entry is provided."/>
	<Error:rule number="1885" outputno="1885Q" term="AUT SPR SUM" type="Query" phase="NS PS MP MS SS AT SP PR" message="Please check: percentage of pupils with a new entry date seems high (greater than 50%)."/>
	<Error:rule number="1890" outputno="1890Q" term="SPR" type="Query" phase="NS PS MP MS SS AT SP" message="Please check: percentage of new admissions in autumn term in school seems high (greater than 40%)."/>
	<Error:rule number="1900" outputno="1900Q" term="SUM" type="Query" phase="NS PS MP MS SS AT SP" message="Please check: percentage of new admissions in spring term in school seems high (greater than 30%)."/>
	<Error:rule number="1910" outputno="1910Q" term="AUT" type="Query" phase="NS PS MP MS SS AT SP" message="Please check: percentage of new admissions in summer term in school seems high (greater than 25%)."/>
	<Error:rule number="1920" outputno="1920" term="AUT SPR SUM" type="Error" phase="PS MP MS SS AT SP PR" message="Pupils leaving date is either missing, before entry date or equal to or after census date."/>
<!-- RFC1183 UPDATED - IW 2021-08-18-->		
	<Error:rule number="19254" outputno="1925Q" term="AUT" type="Query" phase="PS MP MS SS AT SP PR" message="Please check: Pupil no longer on roll record should not be submitted if there is no attendance, suspensions, permanent exclusions or learner, AP placement details, learner funding and monitoring  support item for the required period."/>
<!-- RFC1183 UPDATED - IW 2021-08-18-->		
	<Error:rule number="19255" outputno="1925Q" term="SPR SUM" type="Query" phase="PS MP MS SS AT SP PR" message="Please check: Pupil no longer on roll record should not be submitted if there is no attendance, suspensions, permanent exclusions, AP placement details, learner funding and monitoring or learner support item for the required period."/>
	<Error:rule number="1930" outputno="1930" term="AUT SPR SUM" type="Error" phase="NS PS MP MS SS AT SP PR" message="Pupil part-time indicator is missing or invalid."/>
	<Error:rule number="1940" outputno="1940" term="AUT SPR SUM" type="Error" phase="NS PS MP MS SS AT SP PR" message="Pupils aged 5-15 cannot be shown as having part-time status."/>
	<Error:rule number="1950" outputno="1950" term="AUT SPR SUM" type="Error" phase="NS PS MP MS SS AT SP PR" message="Part-time pupil shown as boarder."/>
	<Error:rule number="1960" outputno="1960Q" term="AUT SPR SUM" type="Query" phase="PS MP MS SS AT SP PR" message="Please check: percentage of part-time pupils in school seems high (greater than 35%)."/>
	<Error:rule number="1970" outputno="1970" term="AUT SPR SUM" type="Error" phase="NS PS MP MS SS AT SP PR" message="Pupil boarder indicator is invalid."/>
	<Error:rule number="1980" outputno="1980Q" term="AUT SPR SUM" type="Query" phase="PS MP MS SS AT PR" message="Please check: school has reported boarding pupils."/>
	<Error:rule number="2000" outputno="2000" term="AUT SPR SUM" type="Error" phase="NS PS MP MS SS AT SP PR" message="Pupil actual year group is missing or invalid."/>
	<Error:rule number="2002" outputno="2002" term="AUT SPR SUM" type="Error" phase="NS PS MP MS SS AT SP PR" message="Pupil&apos;s NC year is not within the range of the school&apos;s lowest and highest NC year."/>
	<Error:rule number="2010" outputno="2010Q" term="AUT SPR SUM" type="Query" phase="PS MP MS SS AT PR" message="Please check: 10% or more pupils&apos; year group differing from their age."/>
	<Error:rule number="2020" outputno="2020Q" term="AUT SPR SUM" type="Query" phase="PS MP MS SS AT PR" message="Please check: pupil year group and age inconsistent."/>
	<Error:rule number="2030" outputno="2030Q" term="AUT SPR SUM" type="Query" phase="PS MP MS SS" message="Please check: pupil in unexpected year group for this school."/>
	<Error:rule number="2040" outputno="2040Q" term="AUT SPR SUM" type="Query" phase="PS MP MS SS AT" message="Please check: expected year group with no pupils (apart from year 14)."/>
	<Error:rule number="2050" outputno="2050Q" term="AUT SPR SUM" type="Query" phase="PS MP MS SS" message="Please check: is school type correct? Some pupils are outside the expected age range for this type."/>
	<Error:rule number="2060" outputno="2060" term="AUT SPR SUM" type="Error" phase="PS AT" message="Pupil&apos;s type of class is missing or invalid for pupils in primary classes with phase PS or AT."/>
	<Error:rule number="2070" outputno="2070Q" term="AUT SPR SUM" type="Query" phase="PS AT" message="Please check: pupil&apos;s class type and year group incompatible."/>
	<Error:rule number="2080" outputno="2080" term="AUT SPR SUM" type="Error" phase="PS AT" message="Pupil aged 6 or over is shown as being in a nursery class."/>
	<Error:rule number="5048" outputno="5048" term="AUT SPR SUM" type="Error" phase="NS PS MP MS SS AT SP PR" message="Pupil&apos;s type of class can only be returned from schools with a phase of PS or AT and may be present only for pupils in NC Year E1, E2, N1, N2, R, or 1-7."/>
	<Error:rule number="2090" outputno="2090Q" term="SPR" type="Query" phase="PS AT" message="Please check: nursery pupils reported but no nursery class records."/>
	<Error:rule number="2100" outputno="2100Q" term="SPR" type="Query" phase="PS AT" message="Please check: more FT nursery pupils on roll than number on nursery class records."/>
	<Error:rule number="2110" outputno="2110Q" term="SPR" type="Query" phase="PS AT" message="Please check: more pupils in nursery classes than nursery pupils on roll."/>
	<Error:rule number="2005" outputno="2005" term="AUT" type="Error" phase="MS SS AT PR" message="Pupil&apos;s NC year on leaving is not a valid value for pupils who have learning aims or is missing."/>

	<!-- Pupil - Special Education Needs -->
	<Error:rule number="2115" outputno="2115" term="AUT SPR SUM" type="Error" phase="NS PS MP MS SS AT" message="Code S (statement of SEN) has been discontinued and is no longer in use. Please re-code this as code E and carry out a review of the pupil&apos;s SEN."/>
	<Error:rule number="2120" outputno="2120" term="AUT SPR SUM" type="Error" phase="NS PS MP MS SS AT SP PR" message="SEN provision is missing or invalid."/>
	<Error:rule number="2180" outputno="2180" term="AUT SPR SUM" type="Error" phase="SP" message="Pupil in special school with no SEN."/>
	<Error:rule number="2190" outputno="2190Q" term="AUT SPR SUM" type="Query" phase="PS MP MS SS AT PR" message="Please check: percentage of pupils in school with EHC plans seems high (greater than 10%)."/>
	<Error:rule number="2200" outputno="2200Q" term="AUT SPR SUM" type="Query" phase="PS MP MS SS AT PR" message="Please check: there are no pupils in the school with SEN provision."/>
	<Error:rule number="2205" outputno="2205Q" term="AUT SPR SUM" type="Query" phase="PS MP MS SS AT PR" message="Please check: percentage of pupils in school with SEN provision of SEN support seems high (greater than 40%)."/>
	<Error:rule number="2210" outputno="2210Q" term="AUT SPR SUM" type="Query" phase="SP" message="Please check: percentage of pupils in school with an EHC plan seems low for a special school (less than 70%)."/>
	<Error:rule number="2125" outputno="2125" term="AUT SPR SUM" type="Error" phase="NS PS MP MS SS AT SP PR" message="SEN details not requred where provision is 'N'."/>
	<Error:rule number="2130" outputno="2130" term="SPR" type="Error" phase="NS PS MP MS SS AT SP PR" message="Where SEN type ranking is present, SEN type code must be provided."/>
	<Error:rule number="2140" outputno="2140" term="SPR" type="Error" phase="NS PS MP MS SS AT SP PR" message="SEN type rank is missing or invalid."/>
	<Error:rule number="2160" outputno="2160" term="SPR" type="Error" phase="NS PS MP MS SS AT SP PR" message="If only one SEN type is present, SEN type rank must equal '1'."/>
	<Error:rule number="2165" outputno="2165" term="SPR" type="Error" phase="NS PS MP MS SS AT SP PR" message="Each SEN type must have a different ranking."/>
	<Error:rule number="2166" outputno="2166" term="SPR" type="Error" phase="NS PS MP MS SS AT SP PR" message="A maximum of two types of SEN need should be included in the return."/>
	<Error:rule number="2167" outputno="2167" term="SPR" type="Error" phase="NS PS MP MS SS AT SP PR" message="Each SEN type must be unique."/>
	<Error:rule number="2170" outputno="2170" term="SPR" type="Error" phase="NS PS MP MS SS AT SP PR" message="A valid SEN type must be provided for pupils with a SEN provision = K or E."/>
	<Error:rule number="2175" outputno="2175" term="SPR" type="Error" phase="NS PS MP MS SS AT SP PR" message="SEN type code NSA (SEN support but no specialist assessment of type of need) can only be used where SEN provision is code K (SEN support),"/>
	<Error:rule number="2230" outputno="2230" term="AUT SPR SUM" type="Error" phase="NS PS MP MS SS AT" message="SEN unit indicator must be provided if SEN provision is equal to K or E."/>
	<Error:rule number="2250" outputno="2250" term="AUT SPR SUM" type="Error" phase="NS PS MP MS SS AT" message="Resourced provision indicator must be provided if SEN provision is equal to K or E."/>
	<Error:rule number="5049" outputno="5049" term="AUT SPR SUM" type="Error" phase="NS PS MP MS SS AT SP PR" message="SEN unit indicator is not required from schools with a phase of SP or PR."/>
	<Error:rule number="5050" outputno="5050" term="AUT SPR SUM" type="Error" phase="NS PS MP MS SS AT SP PR" message="Resourced provision indicator is not required from schools with a phase of SP or PR."/>

	<!-- Pupil - Termly Exclusions -->
	<Error:rule number="2270" outputno="2270" term="AUT SPR SUM" type="Error" phase="PS MP MS SS AT SP PR" message="Start date, SEN provision or category is missing from a suspension or permanent exclusion record."/>
	<Error:rule number="2275" outputno="2275" term="AUT SPR SUM" type="Error" phase="PS MP MS SS AT SP PR" message="Suspension or permanent exclusion category is invalid."/>
	<Error:rule number="2280" outputno="2280" term="AUT SPR SUM" type="Error" phase="PS MP MS SS AT SP PR" message="A valid suspension or permanent exclusion reason(s) must be provided."/>
	<Error:rule number="2285" outputno="2285" term="AUT SPR SUM" type="Error" phase="PS MP MS SS AT SP PR" message="Pupil has more than one permanent exclusion record."/>
	<Error:rule number="2290" outputno="2290" term="AUT SPR SUM" type="Error" phase="PS MP MS SS AT SP PR" message="Suspension or permanent exclusion start date invalid."/>
	<Error:rule number="2295" outputno="2295" term="AUT SPR SUM" type="Error" phase="PS MP MS SS AT SP PR" message="Due to the appeal process the pupil should not be removed off roll on the same day they are excluded."/>
	<Error:rule number="2300" outputno="2300" term="AUT SPR SUM" type="Error" phase="PS MP MS SS AT SP PR" message="Where category is suspension, the number of sessions must also be provided"/>
	<Error:rule number="2303" outputno="2303" term="AUT SPR SUM" type="Error" phase="PS MP MS SS AT SP PR" message="Pupil&apos;s leaving date suggests they left the school prior to the start of their suspension or permanent exclusion."/>
	<Error:rule number="2310" outputno="2310" term="AUT SPR SUM" type="Error" phase="PS MP MS SS AT SP PR" message="SEN provision is not a valid value."/>
	<Error:rule number="2320" outputno="2320Q" term="AUT SPR SUM" type="Query" phase="PS MP MS SS AT SP PR" message="Please check: number of sessions suspended is greater than 90."/>
<!-- NEW RULE 2321 - RFC 1251 -->
	<Error:rule number="2321" outputno="2321" term="AUT SPR SUM" type="Error" phase="PS MP MS SS AT SP PR" message="A valid suspension or permanent exclusion reason(s) must be provided."/>	
<!-- NEW RULE 2322 - RFC 1252 -->
	<Error:rule number="2322" outputno="2322" term="AUT SPR SUM" type="Error" phase="PS MP MS SS AT SP PR" message="Reason 3 is present, Reason 2 must also be present."/>
	<Error:rule number="2330" outputno="2330" term="AUT SPR SUM" type="Error" phase="PS MP MS SS AT SP PR" message="Where category is permanent exclusion the number of sessions is not applicable."/>
	<Error:rule number="2335" outputno="2335" term="AUT SPR SUM" type="Error" phase="PS MP MS SS AT SP PR" message="Permanent exclusion appears for pupil still on roll."/>
	<Error:rule number="2336" outputno="2336" term="AUT SPR SUM" type="Error" phase="PS MP MS SS AT SP PR" message="Duplicate exclusion record - each termly exclusion record must be unique."/>
	<Error:rule number="5051" outputno="5051" term="AUT SPR SUM" type="Error" phase="NS" message="Suspensions or permanent exclusions must not be present for nursery schools."/>
	<Error:rule number="2260" outputno="2260" term="AUT SPR SUM" type="Error" phase="PS MP MS SS AT SP PR" message="Where more than one reason is provided for a suspension or permanent exclusion, it must be unique"/>
	<Error:rule number="2265" outputno="2265" term="SPR SUM" type="Error" phase="PS MP MS SS AT SP PR" message="Exclusion reason is invalid."/>
	<Error:rule number="2880" outputno="2880" term="SPR SUM" type="Error" phase="PS MP MS SS AT SP PR" message="Exclusions with a start date prior to 01 August 2020 must only have one reason "/>
	
	<!-- Pupil - Home Information -->
	<Error:rule number="2340" outputno="2340" term="AUT SPR SUM" type="Error" phase="NS PS MP MS SS AT SP PR" message="Postcode is missing or provided in an invalid format."/>
	<Error:rule number="2350" outputno="2350" term="AUT SPR SUM" type="Error" phase="NS PS MP MS SS AT SP PR" message="Insufficient address information provided."/>
	<Error:rule number="2355" outputno="2355Q" term="AUT SPR SUM" type="Query" phase="NS PS MP MS SS AT SP PR" message="Please check: pupil record with no address details."/>
	<Error:rule number="2380" outputno="2380" term="AUT SPR SUM" type="Error" phase="NS PS MP MS SS AT SP PR" message="Where dwelling is present at least one of: street, locality, town, administrative area or post town must be shown."/>
	<Error:rule number="2400" outputno="2400" term="AUT SPR SUM" type="Error" phase="NS PS MP MS SS AT SP PR" message="Where address line one is present, at least one other address line must also be present.."/>
	<Error:rule number="2445" outputno="2445" term="AUT SPR SUM" type="Error" phase="NS PS MP MS SS AT SP PR" message="Address information drawn from two conflicting formats."/>
	<Error:rule number="5155" outputno="5155" term="AUT SPR SUM" type="Error" phase="NS PS MP MS SS AT SP PR" message="UPRN is not in the correct format (12 numeric characters)."/>
	<Error:rule number="2341" outputno="2341" term="AUT" type="Error" phase="MS SS AT PR" message="Postcode is missing or invalid for an off roll pupil for whom programme aims data are being submitted."/>

	<!-- Pupil - Termly Attendance -->
	<Error:rule number="2470" outputno="2470" term="AUT SPR SUM" type="Error" phase="PS MP MS SS AT SP PR" message="Attendance information is not required for this pupil as they are either aged less than 4, over 15 or are a boarder."/>
	<Error:rule number="2475" outputno="2475" term="AUT SPR SUM" type="Error" phase="PS MP MS SS AT SP PR" message="Attendance code is invalid."/>
	<Error:rule number="2480" outputno="2480" term="AUT SPR SUM" type="Error" phase="PS MP MS SS AT SP PR" message="Where a reason for attendance or absence is provided the number of sessions should be greater than zero."/>
	<Error:rule number="2485" outputno="2485Q" term="AUT SPR SUM" type="Query" phase="PS MP MS SS AT SP PR" message="Pupil attendance indicates they are excluded but no exclusion is recorded."/>
	<Error:rule number="2490" outputno="2490" term="AUT SPR SUM" type="Error" phase="PS MP MS SS AT SP PR" message="Pupil reporting number of attendance or absence sessions with no corresponding reason (attendance code)."/>
	<Error:rule number="2491" outputno="2491" term="AUT SPR SUM" type="Error" phase="PS MP MS SS AT SP PR" message="Attendance code 'X' must only be used for non-compulsory school age children."/>
	<!--Note difference in error text for 2500 depending on term-->
	<Error:rule number="25004" outputno="2500" term="AUT" type="Error" phase="PS MP MS SS AT SP PR" message="For pupil on roll in the first summer half term the attendance sessions possible must be greater than or equal to zero."/>
	<Error:rule number="25005" outputno="2500" term="SPR SUM" type="Error" phase="PS MP MS SS AT SP PR" message="For pupil on roll the attendance sessions possible must be greater than or equal to zero."/>
	<!--Note difference in error text for 2502 depending on term-->
<!-- RFC1183 UPDATED - IW 2021-08-18-->
	<Error:rule number="25024" outputno="2502Q" term="AUT" type="Query" phase="PS MP MS SS AT SP PR" message="Please check: Zero attendance sessions possible has been recorded for the pupil in the first half of the summer term. Pupil should only be recorded with zero sessions possible if dually registered and they spent all of the period for which attendance data is being collected at the other registration. This query will be accepted by DfE on condition that a suitable explanatory notepad entry is provided in COLLECT."/>
<!-- RFC1183 UPDATED - IW 2021-08-18-->	
	<Error:rule number="25025" outputno="2502Q" term="SPR SUM" type="Query" phase="PS MP MS SS AT SP PR" message="Please check: Zero attendance sessions possible recorded for the pupil. Pupil should only be recorded with zero sessions possible if dually registered and they spent all of the previous term for which attendance data is being collected at the other registration. This query will be accepted by DfE on condition that a suitable explanatory notepad entry is provided in COLLECT."/>
	<Error:rule number="2505" outputno="2505" term="AUT SPR SUM" type="Error" phase="PS MP MS SS AT SP PR" message="Pupil with double-reporting of termly absences and attendance."/>
	<!--Note difference in error text for 2510 depending on term-->
	<Error:rule number="25104" outputno="2510" term="AUT" type="Error" phase="PS MP MS SS AT SP PR" message="For pupil no longer on roll in the first summer half term the attendance sessions possible is missing or invalid."/>
	<Error:rule number="25105" outputno="2510" term="SPR SUM" type="Error" phase="PS MP MS SS AT SP PR" message="For pupil no longer on roll the attendance sessions possible is missing or invalid."/>
	
	<Error:rule number="2530" outputno="2530" term="AUT SPR SUM" type="Error" phase="PS MP MS SS AT SP PR" message="Total sessions missed must be less than or equal to sessions possible."/>
	<Error:rule number="2531" outputno="2531" term="AUT SPR SUM" type="Error" phase="PS MP MS SS AT SP PR" message="Sessions possible must be equal to the total of all attendance and absence sessions."/>	
<!-- RFC1183 - IW ADDED 2021-08-18-->
	<Error:rule number="2532" outputno="2532" term="AUT SPR SUM" type="Error" phase="PS MP MS SS AT SP PR" message="Where a reason for attendance or absence is provided it must be unique"/>
<!-- RFC1183 - IW ADDED 2021-08-18-->
	<Error:rule number="2533" outputno="2533" term="AUT SPR SUM" type="Error" phase="PS MP MS SS AT SP PR" message="Educational sessions reported must be less than or equal to sessions possible"/>
	<Error:rule number="2540" outputno="2540Q" term="AUT SPR SUM" type="Query" phase="PS MP MS SS AT SP PR" message="Please check: There would normally be at least one pupil who would have at least one authorised absence during the previous term."/>
	<Error:rule number="2550" outputno="2550Q" term="AUT SPR SUM" type="Query" phase="PS MP MS SS AT SP PR" message="Please check: There would normally be at least one pupil who would have at least one unauthorised absence during the previous term."/>
	<Error:rule number="2560" outputno="2560Q" term="AUT SPR SUM" type="Query" phase="PS MP MS SS AT SP PR" message="Please check: percentage of authorised absence is greater than 30% - are you sure?"/>
	<Error:rule number="2570" outputno="2570Q" term="AUT SPR SUM" type="Query" phase="PS MP MS SS AT SP PR" message="Please check: percentage of unauthorised absence is greater than 30% - are you sure?"/>
	<Error:rule number="5057" outputno="5057" term="AUT SPR SUM" type="Error" phase="NS" message="Attendance information is not required from schools with a phase of NS."/>
	<Error:rule number="2520" outputno="2520Q" term="AUT SPR SUM" type="Query" phase="PS MP MS SS AT SP PR" message="Please check: sessions possible should not be greater than 150."/>

	<!-- Summer Half Term 2 Attendance - Autumn only -->
<!-- RFC1250 ADDED - IW 2023-08-22-->	
	<Error:rule number="2492" outputno="2492" term="AUT " type="Error" phase="PS MP MS SS AT SP PR" message="Attendance code 'X' must only be used for non-compulsory school age children."/>
	<Error:rule number="2571" outputno="2571" term="AUT" type="Error" phase="PS MP MS SS AT SP PR" message="Attendance data for the second half of the summer term is not required for this pupil as they are either aged less than 4, over 15 or are a boarder."/>
<!-- RFC1183 UPDATED - IW 2021-08-18-->	
	<Error:rule number="2572" outputno="2572" term="AUT" type="Error" phase="PS MP MS SS AT SP PR" message="Attendance code is invalid for the second half of the summer term."/>
<!-- RFC1183 UPDATED - IW 2021-08-18-->	
	<Error:rule number="2573" outputno="2573" term="AUT" type="Error" phase="PS MP MS SS AT SP PR" message="Where a reason for attendance or absence is provided the number of sessions should be greater than zero."/>
<!-- RFC1183 UPDATED - IW 2021-08-18-->	
	<Error:rule number="2574" outputno="2574" term="AUT" type="Error" phase="PS MP MS SS AT SP PR" message="Pupil reporting number of attendance or absence sessions with no corresponding reason (attendance code) for the second half of the summer term."/>
	<Error:rule number="2575" outputno="2575" term="AUT" type="Error" phase="PS MP MS SS AT SP PR" message="For pupils on roll the attendance sessions possible must be greater than or equal to zero for the second half of the summer term."/>
<!-- RFC1183 UPDATED - IW 2021-08-18-->	
	<Error:rule number="2576" outputno="2576Q" term="AUT" type="Query" phase="PS MP MS SS AT SP PR" message="Please check: Zero attendance sessions possible recorded for the pupil in the second half of the summer term. Pupil should only be recorded with zero sessions possible if they spent all of the period which attendance data is being collected at the other registration or were not expected to be in school. This query will be accepted by DfE on condition that a suitable explanatory notepad entry is provided in COLLECT."/>	<Error:rule number="2577" outputno="2577" term="AUT" type="Error" phase="PS MP MS SS AT SP PR" message="Pupil with double-reporting of termly absences in the second half of the summer term."/>
	<Error:rule number="2578" outputno="2578" term="AUT" type="Error" phase="PS MP MS SS AT SP PR" message="Attendance data for the 2nd half of the summer term is not required for this pupil as leaving date shows they left prior to this."/>

	<Error:rule number="2579" outputno="2579" term="AUT" type="Error" phase="PS MP MS SS AT SP PR" message="For pupils no longer on roll the attendance sessions possible must be greater than or equal to zero for the second half of the summer term."/>
	<Error:rule number="2582" outputno="2582" term="AUT" type="Error" phase="PS MP MS SS AT SP PR" message="Total sessions missed must be less than or equal to sessions possible for the second half of the summer term."/>
	<Error:rule number="2583" outputno="2583Q" term="AUT" type="Query" phase="PS MP MS SS AT SP PR" message="Please check: there would normally be at least one pupil who would have at least one authorised absence for the second half of the summer term."/>
	<Error:rule number="2584" outputno="2584Q" term="AUT" type="Query" phase="PS MP MS SS AT SP PR" message="Please check: there would normally be at least one pupil who would have at least one unauthorised absence for the second half of the summer term."/>
	<Error:rule number="2586" outputno="2586" term="AUT" type="Error" phase="PS MP MS SS AT SP PR" message="Sessions possible must be equal to the total of all attendance and absence sessions for the second half of the summer term."/>
<!-- RFC1183 - IW ADDED 2021-08-18-->
	<Error:rule number="2587" outputno="2587" term="AUT" type="Error" phase="PS MP MS SS AT SP PR" message="Where a reason for attendance or absence is provided it must be unique"/>
<!-- RFC1183 - IW ADDED 2021-08-18-->
	<Error:rule number="2588" outputno="2588Q" term="AUT" type="Query" phase="PS MP MS SS AT SP PR" message="Pupil attendance for second half of summer term indicates they are suspended or permanently excluded but no suspension or permanent exclusion is recorded"/>
	<Error:rule number="2589" outputno="2589" term="AUT SPR SUM" type="Error" phase="PS MP MS SS AT SP PR" message="Pupil has educational sessions reported but has zero possible sessions"/>	
	<Error:rule number="5080" outputno="5080" term="AUT" type="Error" phase="NS PS MP MS SS AT SP PR" message="Summer half term 2 attendance not required if nursery school." />

	<!-- Pupil Learning Aims - Autumn only -->
	<Error:rule number="1999" outputno="1999Q" term="AUT" type="Query" phase="SS AT PR" message="Please check: no pupils have planned employability, enrichment and pastoral hours ."/>	
	<Error:rule number="2700" outputno="2700" term="AUT" type="Error" phase="SS AT PR" message="Qualification accreditation number is missing."/>	
	<Error:rule number="2701" outputno="2701" term="AUT" type="Error" phase="SS AT PR" message="A learning aim withdrawal reason is only required where the learner has withdrawn and the learning aim status is recorded as &apos;3&apos;."/>	
	<Error:rule number="2705" outputno="2705" term="AUT" type="Error" phase="NS PS MP SS AT SP PR" message="Programme aims are only required for schools with 6th forms."/>	
	<Error:rule number="2706" outputno="2706Q" term="AUT" type="Query" phase="SS AT PR" message="Please check: post 16 data would not normally be expected for a pupil on roll below year 12."/>	
	<Error:rule number="2707" outputno="2707Q" term="AUT" type="Query" phase="SS AT PR" message="Please check: post 16 data would not normally be expected for a pupil who was below year 12 when they left school."/>
	<Error:rule number="2708" outputno="2708Q" term="AUT" type="Query" phase="SS AT PR" message="Please check: learning aims for the previous academic year would normally be expected for a pupil in year 13 or above who was also on roll last year (unless they had subsidiary registration at the time of the learning aims)."/>	
	<Error:rule number="2712" outputno="2712" term="AUT" type="Error" phase="SS AT PR" message="Full-time employment indicator is missing or invalid." />
	<Error:rule number="2709" outputno="2709Q" term="AUT" type="Query" phase="SS AT PR" message="Please check: learning aims would normally be expected for a pupil who was on roll in Year 12 and above and left since the last autumn census."/>	
	<Error:rule number="2710" outputno="2710" term="AUT" type="Error" phase="SS AT PR" message="Qualification number has invalid characters or is incorrectly formatted."/>	
	<Error:rule number="2711" outputno="2711Q" term="AUT" type="Query" phase="SS AT PR" message="Please check: learning aims for the previous academic year would normally be expected for a pupil who was in year 13 or above when they left the school this academic year (unless they had subsidiary registration at the time of the learning aims)."/>	
	<Error:rule number="2715" outputno="2715Q" term="AUT" type="Query" phase="SS AT PR" message="Please check: post 16 data should not be provided for pupils with subsidiary registration in the current term. However, if the post 16 data submitted relates to the previous academic year when the pupil had single or main registration then they should be included in the return."/>	
	<Error:rule number="2717" outputno="2717" term="AUT" type="Error" phase="PS MP MS SP" message="Please check: Post 16 data should not be provided from schools which do not have a phase of ‘AT’, ‘SS’ or ‘PR’."/>		
	<Error:rule number="2720" outputno="2720" term="AUT" type="Error" phase="SS AT PR" message="Qualification number is not a recognised value."/>	
	<Error:rule number="2722" outputno="2722" term="AUT" type="Error" phase="SS AT PR" message="Subject classification code is missing."/>	
	<Error:rule number="2724" outputno="2724" term="AUT" type="Error" phase="SS AT PR" message="Subject classification code is not a recognised value."/>	
	<Error:rule number="2730" outputno="2730" term="AUT" type="Error" phase="SS AT PR" message="Learning start date is missing or invalid."/>	
	<Error:rule number="2735" outputno="2735" term="AUT" type="Error" phase="SS AT PR" message="Learning start date is after the census date."/>	
	<Error:rule number="2740" outputno="2740Q" term="AUT" type="Query" phase="SS AT PR" message="Please check: learning start date seems too early."/>	
	<Error:rule number="2750" outputno="2750" term="AUT" type="Error" phase="SS AT PR" message="Learning planned end date is missing or invalid."/>	
	<Error:rule number="2759" outputno="2759" term="AUT" type="Error" phase="SS AT PR" message="Traineeship must not be present for learning aims which started after 31 July of the current year."/>
	<Error:rule number="2760" outputno="2760" term="AUT" type="Error" phase="SS AT PR" message="Learning aim - the planned end date must be on or after the start date."/>	
	<Error:rule number="2761" outputno="2761" term="AUT" type="Error" phase="SS AT PR" message="Learning aim - the actual end date must be on or after the start date."/>	
	<Error:rule number="2765" outputno="2765" term="AUT" type="Error" phase="SS AT PR" message="Learning planned end date is more than 5 years after census date."/>	
	<Error:rule number="2766" outputno="2766" term="AUT" type="Error" phase="SS AT PR" message="Learning planned end date must be on or before the 31st July of the academic year the learner is due to finish."/>	
	<Error:rule number="2767" outputno="2767Q" term="AUT" type="Query" phase="SS AT PR" message="Please check the learning planned end date as only short courses would be expected to have a planned end date in September."/>	
	<Error:rule number="2770" outputno="2770" term="AUT" type="Error" phase="SS AT PR" message="Learning aim end date is not a valid date."/>	
	<Error:rule number="2780" outputno="2780" term="AUT" type="Error" phase="SS AT PR" message="Learning aim actual end date has incorrectly been provided for a learning aim which is continuing ie for which learning aim status = 1."/>	
	<Error:rule number="2785" outputno="2785" term="AUT" type="Error" phase="SS AT PR" message="Learning aim withdrawal reason is missing or invalid value."/>	
	<Error:rule number="2790" outputno="2790" term="AUT" type="Error" phase="SS AT PR" message="Learning aim actual end date must be provided where the learning aim status is 2 (completed), 3 (withdrawn) or 4 (transferred)."/>	
	<Error:rule number="2795" outputno="2795" term="AUT" type="Error" phase="SS AT PR" message="For pupils no longer on roll the learning aim status must be 2 (completed), 3 (withdrawn) or 4 (transferred)."/>	
	<Error:rule number="2805" outputno="2805" term="AUT" type="Error" phase="SS AT PR" message="Learning aim actual end date must be the same as, or earlier than the census date."/>	
	<Error:rule number="2810" outputno="2810Q" term="AUT" type="Query" phase="SS AT PR" message="Please check: learning aim actual end date should not be later than the pupil&apos;s leaving date for pupils no longer on roll."/>	
	<Error:rule number="2815" outputno="2815" term="AUT" type="Error" phase="SS AT PR" message="Programme type for each learning aim must be the same as the programme type of the parent programme aim"/>
	<Error:rule number="2820" outputno="2820" term="AUT" type="Error" phase="SS AT PR" message="Learning aim status is missing or invalid."/>	
	<Error:rule number="2870" outputno="2870" term="AUT" type="Error" phase="SS AT PR" message="Programme aims for the current academic year must be submitted for a pupil in year 12 or above with single or main registration at the school."/>	

	<Error:rule number="5130" outputno="5130" term="AUT" type="Error" phase="NS PS MP MS SS AT SP PR" message="Postcode is not required for off roll pupils without programme aims."/>
	<Error:rule number="5165" outputno="5165" term="AUT" type="Error" phase="SS AT PR" message="Traineeship is missing or invalid for learning aims that started prior 1 August 2023"/>

	<!--Post-16 Programme Aims-->
	<Error:rule number="2885" outputno="2885" term="AUT" type="Error" phase="SS AT PR" message="Qualification number is missing or invalid (programme aim)"/>
	<Error:rule number="2886" outputno="2886" term="AUT" type="Error" phase="SS AT PR" message="A programme aim withdrawal reason is only required where the learner has withdrawn and the programme aim status is recorded as '3'"/>
	<Error:rule number="2887" outputno="2887" term="AUT" type="Error" phase="SS AT PR" message="Programme aim start date is missing or invalid"/>
	<Error:rule number="2888" outputno="2888" term="AUT" type="Error" phase="SS AT PR" message="Programme aim planned end date is missing or invalid"/>
	<Error:rule number="2889" outputno="2889" term="AUT" type="Error" phase="SS AT PR" message="Programme aim planned end date must be on or after the programme start date"/>
	<Error:rule number="2890" outputno="2890" term="AUT" type="Error" phase="SS AT PR" message="Programme aim actual end date must be on or after the programme start date"/>
	<Error:rule number="2891" outputno="2891" term="AUT" type="Error" phase="SS AT PR" message="Programme aim planned end date is more than 5 years after census date"/>
	<Error:rule number="2892" outputno="2892" term="AUT" type="Error" phase="SS AT PR" message="Programme aim planned end date must be on or before the 31st July of the academic year the learner is due to finish"/>
	<Error:rule number="2893" outputno="2893" term="AUT" type="Error" phase="SS AT PR" message="Programme aim actual end date is not a valid date"/>
	<Error:rule number="2894" outputno="2894" term="AUT" type="Error" phase="SS AT PR" message="Programme aim actual end date has incorrectly been provided for a programme aim which is continuing that is, for which programme aim status equals '1'"/>
	<Error:rule number="2895" outputno="2895" term="AUT" type="Error" phase="SS AT PR" message="Programme aim withdrawal reason is missing or invalid value"/>
	<Error:rule number="2896" outputno="2896" term="AUT" type="Error" phase="SS AT PR" message="Programme aim actual end date must be provided where the programme aim status is '2' (completed), '3' (withdrawn) or '4' (transferred)"/>
	<Error:rule number="2897" outputno="2897" term="AUT" type="Error" phase="SS AT PR" message="Please check: Programme aim actual end date must be the same as, or earlier than the census date"/>
	<Error:rule number="2898" outputno="2898" term="AUT" type="Error" phase="SS AT PR" message="Programme aim status is missing or invalid"/>
<!--Note - flags are from spec but I think should just be SS AT PR like the rest of these-->
	<Error:rule number="2899" outputno="2899" term="AUT" type="Error" phase="NS PS MP MS SS AT SP PR" message="Programme aim traineeship is missing or invalid for programme aims that started prior to 1 August of the current year"/>
	<Error:rule number="2908" outputno="2908" term="AUT" type="Error" phase="NS PS MP MS SS AT SP PR" message="Traineeship can not be true for a T Level or T Level transition programme which started prior to 1 August of the current year"/>
<!--	<Error:rule number="2901" outputno="2901" term="AUT" type="Error" phase="SS AT PR" message="Programme aim missing or invalid"/>	-->
	<Error:rule number="2902" outputno="2902" term="AUT" type="Error" phase="SS AT PR" message="Programme aim's programme type is missing or invalid"/>
	<Error:rule number="2903" outputno="2903" term="AUT" type="Error" phase="SS AT PR" message="A programme aim must contain at least one learning aim"/>
	<Error:rule number="2906" outputno="2906Q" term="AUT" type="Query" phase="SS AT PR" message="Please check: Programme aim start date seems too early"/>
	<Error:rule number="2907" outputno="2907" term="AUT" type="Error" phase="SS AT PR" message="The latest planned end date of all learning aims must equal the programme aim planned end date"/>
	<Error:rule number="2909" outputno="2909" term="AUT" type="Error" phase="SS AT PR" message="The latest actual end date of all learning aims must equal the programme aim actual end date"/>	
	<Error:rule number="2911" outputno="2911" term="AUT" type="Error" phase="SS AT PR" message="Student cannot have more than one programme with a status of continuing"/>
	<Error:rule number="2912" outputno="2912" term="AUT" type="Error" phase="SS AT PR" message="Traineeship must not be present for programme aims which started after 31 July of the current year"/>

	<!-- Generic error - module is missing -->
	<Error:rule number="9999" outputno="9999" term="AUT SPR SUM" type="Error" phase="SS MS NS PS MP SP PR AT" message=" module is missing."/>

	<Error:rule number="5166" outputno="5166" term="AUT" type="Error" phase="NS PS MP MS SS AT SP PR" message="Traineeship can not be true for a T Level or T Level transition programme which started prior to 1 August 2023."/>
	<Error:rule number="2874" outputno="2874" term="AUT" type="Error" phase="SS AT PR" message="Work placement start date is not a valid date"/>
	<Error:rule number="2875" outputno="2875" term="AUT" type="Error" phase="SS AT PR" message="Work placement end date is not a valid date"/>
	<Error:rule number="2876" outputno="2876" term="AUT" type="Error" phase="SS AT PR" message="Work placement mode must be a valid value"/>
	<Error:rule number="2877" outputno="2877" term="AUT" type="Error" phase="SS AT PR" message="Work placement Employer ID must be a valid value"/>
	<Error:rule number="2878" outputno="2878" term="AUT" type="Error" phase="SS AT PR" message="Workplace entity items are missing for student undertaking work experience or industry placement"/>
	<Error:rule number="2879" outputno="2879" term="AUT" type="Error" phase="SS AT PR" message="Workplace entity items are only required for those students undertaking work experience or industry placements "/>	
<!--	<Error:rule number="2816" outputno="2816" term="AUT" type="Error" phase="SS AT PR" message="Each learning aim must be accompanied by a programme aim of the same programme type"/>	-->
	<Error:rule number="2755" outputno="2755" term="AUT" type="Error" phase="SS AT PR" message="Work placement hours must be a valid value"/>
<!--	<Error:rule number="2756" outputno="2756" term="AUT" type="Error" phase="SS AT PR" message="Work placement start date, Work placement end date, Work placement mode, Work placement hours or Work placement employer ID is missing"/>	-->
	<Error:rule number="2757" outputno="2757" term="AUT" type="Error" phase="SS AT PR" message="Work placement start date cannot be before the work experience or industry placement learning start date"/>
	<Error:rule number="2758" outputno="2758" term="AUT" type="Error" phase="SS AT PR" message="Work placement end date cannot be after the work experience or industry placement learning actual end date"/>
	
	<!-- Learner FAM new for 21/22 -->
	<Error:rule number="4000" outputno="4000" term="AUT SPR SUM" type="Error" phase="PS MP MS SS AT SP PR" message="Learner Funding and Monitoring information is missing or invalid"/>
	<Error:rule number="4001" outputno="4001" term="AUT SPR SUM" type="Error" phase="PS MP MS SS AT SP PR" message="Pupil is not eligible for National Tutoring Programme (NTP)"/>
	<Error:rule number="4002" outputno="4002" term="AUT SPR SUM" type="Error" phase="PS MP MS SS AT SP PR" message="Pupil is not eligible for National Tutoring Programme (NTP)"/>
	<Error:rule number="4003" outputno="4003" term="AUT SPR SUM" type="Error" phase="SS AT PR" message="Pupil is not eligible for 16-19 Tuition Fund"/>
	<Error:rule number="4004" outputno="4004" term="AUT SPR SUM" type="Error" phase="SS AT PR" message="Pupil is not eligible for 16-19 Tuition Fund"/>
	<Error:rule number="4005" outputno="4005" term="AUT SPR SUM" type="Error" phase="SS AT PR" message="Pupil is not eligible for repeat year funding"/>
	<Error:rule number="4006" outputno="4006Q" term="AUT SPR SUM" type="Query" phase="SS AT PR" message="Please check: Learner Funding and Monitoring should not be returned for 16-19 students with subsidiary registration in the current term, unless the data relates to the previous term when the pupil had single or main registration "/>
	<!-- RFC1183 - IW ADDED 2021-08-18-->
	<Error:rule number="4007" outputno="4007Q" term="AUT SPR SUM" type="Query" phase="PS MP MS SS AT SP PR" message="Please check: no pupils on roll are in receipt of National Tutoring Programme (NTP)"/>
	<!-- RFC1183 - IW ADDED 2021-08-18-->
	<Error:rule number="4008" outputno="4008Q" term="AUT SPR SUM" type="Query" phase="SS AT PR" message="Please check: no students on roll are in receipt of 16-19 Learner Funding and Monitoring"/>
	<!-- RFC1183 - IW ADDED 2021-08-18-->
	<Error:rule number="4009" outputno="4009" term="AUT SPR SUM" type="Error" phase="PS MP MS SS AT SP PR" message="Learner Funding and Monitoring must not be returned for pupils who left in the previous academic year"/>
	<Error:rule number="4010" outputno="4010" term="AUT SPR SUM" type="Error" phase="PS MP MS SP" message="Post 16 learner funding and monitoring information should not be provided from schools which do not have a phase of ‘AT’, ‘SS’ or ‘PR’"/>
	<Error:rule number="4011" outputno="4011" term="AUT SPR SUM" type="Error" phase="SS AT PR" message="Due to the pupil’s age they are not eligible for repeat year funding"/>
	<Error:rule number="4012" outputno="4012" term="AUT SPR SUM" type="Error" phase="PS MP MS SS AT SP PR" message="Number of hours of tuition must be provided and be greater than zero for pupils recorded as in receipt of National Tutoring Programme (NTP)"/>
	<Error:rule number="4013" outputno="4013" term="AUT SPR SUM" type="Error" phase="PS MP MS SS AT SP PR" message="Number of hours of tuition are only required for National Tutoring Programme (NTP)"/>
	<Error:rule number="4014" outputno="4014" term="AUT SPR SUM" type="Error" phase="PS MP MS SS AT SP PR" message="Each learner funding and monitoring code must be unique and used only once "/>	
	<Error:rule number="4017" outputno="4017Q" term="AUT" type="Query" phase="PS MP MS SS AT SP PR" message="Please check: Number of hours of tuition seem too high. Have previous term’s hours of tuition been included? Only the number of hours of tuition provided from the beginning of the autumn term to census day should be returned. Please either amend your data or provide a reason. "/>

	<!-- AP Placements Module new for 21/22 -->	
	<Error:rule number="4015" outputno="4015Q" term="AUT SPR SUM" type="Query" phase="PS MP MS SS AT SP PR" message="Please check: no School Arranged Alternative Provision (AP) placements have been provided"/>
	<Error:rule number="4016" outputno="4016Q" term="AUT SPR SUM" type="Query" phase="PR" message="Please check: no Alternative Provision (AP)  placements have been provided."/>
	<Error:rule number="2360" outputno="2360" term="AUT SPR SUM" type="Error" phase="PR" message="Previous URN is invalid for a single registered AP placement "/>
	<Error:rule number="2361" outputno="2361" term="AUT SPR SUM" type="Error" phase="PR" message="Alternative Provision (AP) reason is missing or invalid for a single registered placement "/>
	<Error:rule number="2362" outputno="2362" term="AUT SPR SUM" type="Error" phase="PR" message="SEN Provision on entry is missing or invalid for a single registered placement"/>
	<Error:rule number="2363" outputno="2363" term="AUT SPR SUM" type="Error" phase="PR" message="Pupil was placed in the provision as it was named on their EHC plan; their SEN provision indicates they do not have an EHC plan"/>
	<Error:rule number="2364" outputno="2364" term="AUT SPR SUM" type="Error" phase="PS MP MS SS AT SP PR" message="URN, UKPRN or AP setting type should be provided for a school arranged alternative provision (AP) placement"/>
	<Error:rule number="2365" outputno="2365" term="AUT SPR SUM" type="Error" phase="PS MP MS SS AT SP PR" message="URN is invalid for a school arranged alternative provision (AP) placement"/>
	<Error:rule number="2366" outputno="2366" term="AUT SPR SUM" type="Error" phase="PS MP MS SS AT SP PR" message="UKPRN is invalid for a school arranged alternative provision (AP) placement"/>
	<Error:rule number="2367" outputno="2367" term="AUT SPR SUM" type="Error" phase="PS MP MS SS AT SP PR" message="AP setting type is invalid for a school arranged alternative provision (AP) placement"/>
	<Error:rule number="2368" outputno="2368" term="AUT SPR SUM" type="Error" phase="PS MP MS SS AT SP PR" message="The URN provided for a school arranged alternative provision (AP) placement cannot be that of the school placing the pupil into alternative provision"/>
	<Error:rule number="2369" outputno="2369" term="AUT SPR SUM" type="Error" phase="PS MP MS SS AT SP PR" message="The placement reason is invalid for a school arranged alternative provision (AP) placement"/>
	<Error:rule number="2370" outputno="2370" term="AUT SPR SUM" type="Error" phase="PS MP MS SS AT SP PR" message="The pupils entry date is invalid for a school arranged alternative provision (AP) placement"/>
	<Error:rule number="2371" outputno="2371" term="AUT SPR SUM" type="Error" phase="PS MP MS SS AT SP PR" message="The pupils SEN provision on entry is invalid for a school arranged alternative provision (AP) placement"/>
	<Error:rule number="2372" outputno="2372" term="AUT SPR SUM" type="Error" phase="PS MP MS SS AT SP PR" message="Pupil's date of leaving a school arranged alternative provision (AP) placement must be present and on or before the date the pupil left the commissioning school"/>
	<Error:rule number="2373" outputno="2373" term="AUT SPR SUM" type="Error" phase="PS MP MS SS AT SP PR" message="The pupils SEN provision on leaving is invalid for a school arranged alternative provision (AP) placement"/>
	<Error:rule number="2374" outputno="2374" term="AUT SPR SUM" type="Error" phase="PS MP MS SS AT SP PR" message="Pupils SEN provision on leaving is not required for an open school arranged alternative provision (AP) placement"/>
	<Error:rule number="2375" outputno="2375" term="AUT SPR SUM" type="Error" phase="PS MP MS SS AT SP PR" message="The pupil's attendance pattern should equal 'FT' or 'PT' for a school arranged alternative provision (AP) placement"/>
	<Error:rule number="2376" outputno="2376" term="AUT SPR SUM" type="Error" phase="PS MP MS SS AT SP PR" message="For pupils recorded as part-time at a school arranged alternative provision (AP) placement, planned sessions per week should be present and between 1 and 9"/>
	<Error:rule number="2377" outputno="2377" term="AUT SPR SUM" type="Error" phase="PS MP MS SS AT SP PR" message="The pupil is shown as full-time therefore, sessions per week are not required for a school arranged alternative provision (AP) placement"/>
	<Error:rule number="2378" outputno="2378" term="AUT SPR SUM" type="Error" phase="PS MP MS SS AT SP PR" message="School arranged alternative provision (AP) placement leaving date is outside of the collection period"/>
	<Error:rule number="2379" outputno="2379Q" term="AUT SPR SUM" type="Query" phase="PR" message="Please check: AP Placement information should not be returned for pupils with main or subsidiary registration. Unless the data relates to a previous term when the pupil had sole registration."/>
	<Error:rule number="2385" outputno="2385" term="AUT SPR SUM" type="Error" phase="PS MP MS SS AT SP PR" message="The UKPRN has been provided, AP Setting Type is not required"/>
	<Error:rule number="2386" outputno="2386" term="AUT SPR SUM" type="Error" phase="PS MP MS SS AT SP PR" message="The URN has been provided, UKPRN and/or AP Setting Type are not required"/>
	<Error:rule number="2390" outputno="2390" term="AUT SPR SUM" type="Error" phase="NS PS MP MS SS AT SP PR" message="AP provision detail is only required from a school with a Phase of ‘PR’."/>	
	<Error:rule number="2391" outputno="2391" term="AUT SPR SUM" type="Error" phase="NS PS MP MS SS AT SP PR" message="School arranged AP is not required from schools with a phase of 'NS'"/>		
	<Error:rule number="2392" outputno="2392" term="AUT SPR SUM" type="Error" phase="NS PS MP MS SS AT SP PR" message="Pupil has multiple open placements where the attendance pattern is not a valid combination. It is expected the pupil would be PT at each open placement"/>	
	<Error:rule number="2393" outputno="2393" term="AUT SPR SUM" type="Error" phase="NS PS MP MS SS AT SP PR" message="Pupil has multiple open part time placements where the total number of sessions equals more than 10. It is expected that the total number of sessions across these placements would equal 10 or fewer sessions"/>		
	<Error:rule number="2395" outputno="2395" term="AUT SPR SUM" type="Error" phase="NS PS MP MS SS AT SP PR" message="Where AP Setting Type is provided, AP Postcode must also be provided"/>	
	<Error:rule number="2396" outputno="2396" term="AUT SPR SUM" type="Error" phase="NS PS MP MS SS AT SP PR" message="Where AP Setting type has not been provided, Company Number and AP Postcode are not required"/>
	<Error:rule number="2397" outputno="2397" term="AUT SPR SUM" type="Error" phase="NS PS MP MS SS AT SP PR" message="Company number is invalid for a school arranged alternative provision (AP) placement"/>
	<Error:rule number="2398" outputno="2398" term="AUT SPR SUM" type="Error" phase="NS PS MP MS SS AT SP PR" message="Postcode is invalid for a school arranged alternative provision (AP) placement"/>
	<Error:rule number="3125" outputno="3125" term="AUT SPR SUM" type="Error" phase="PS MP MS SS AT SP PR" message="Pupil with an EHC plan should not receive full time education in an unregistered setting. Please see the Independent School Registration Guidance for more information about what constitutes full time education."/>	
	<Error:rule number="3131" outputno="3131" term="AUT SPR SUM" type="Error" phase="PR" message="AP Placement information should be returned for pupils who are single-registered (those with an enrolment status of ‘C’, ‘F’ or ‘O’)."/>
	<Error:rule number="3132" outputno="3132Q" term="AUT SPR SUM" type="Query" phase="PS MP MS SS AT SP PR" message="Where AP Setting Type is provided, Company number should also be provided."/>
	
	<!--Blank template
	<Error:rule number="" outputno="" term="AUT SPR SUM" type="Error" phase="NS PS MP MS SS AT SP PR" message=" "/>
	-->	

</xsl:stylesheet>
