<?xml version="1.0" encoding="utf-8" ?> 
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:msxsl="urn:schemas-microsoft-com:xslt" xmlns:Error="Errors.uri" exclude-result-prefixes="Error">
	<xsl:output method="xml" indent="yes"/>
	<xsl:variable name="IntermediateFile">
		<!-- Version Details -->
		<CensusDetail type="School Census 2023-2024"/>
		<!-- Current Version Details -->
		<CurrentVersion>
			<Version number="2024.1.2" released="2023-09-27" author="Andy Naylor" comment="Corrected rules 2392 and 5165"/>
		</CurrentVersion>
		<!-- History (old Current Version Details) -->
		<VersionHistory>
			<Version number="2024.1.1" released="2023-09-08" author="Andy Naylor" comment="Corrected allowed DOB ranges for rule 2492. RFC 1253 change to rule 3125. Corrected headings on Table 14 of school summary"/>
			<Version number="2024.1.0" released="2023-08-25" author="Ian Windress" comment="Baselined version for release"/>		
			<Version number="2024.0.1" released="2023-07-01" author="Andy Naylor" comment="rolled over from summer census 2023 and updated for Autumn 23"/>
		</VersionHistory>
		<!-- End of Version Details -->
	</xsl:variable>
	<xsl:template match="/">
	<ProcessingResults>
		<XSLTVersion>
			Validation 2024.1.2 - Updated: 2023-09-27
			ErrorList 2024.1.2 - Updated: 2023-09-27
			Summary 2024.1.2 - Updated: 2023-09-27
		</XSLTVersion>
		<ValidationResults>
			<xsl:copy-of select="/Message/Header"/>
			<Summary>
				<SchoolName>
					<xsl:value-of select="/Message/School/SchoolCharacteristics/SchoolName"/>
				</SchoolName>
				<SchoolPhase>
					<xsl:choose>
						<xsl:when test="/Message/School/SchoolCharacteristics/Phase = 'PR' ">PR</xsl:when>
						<xsl:when test="/Message/School/SchoolCharacteristics/Phase = 'SP' ">SP</xsl:when> 
						<xsl:when test="/Message/School/SchoolCharacteristics/Phase = 'SS' ">SS</xsl:when>						
						<xsl:when test="/Message/School/SchoolCharacteristics/Phase = 'MS' ">MS</xsl:when>	
						<xsl:when test="/Message/School/SchoolCharacteristics/Phase = 'MP' ">MP</xsl:when>	
						<xsl:when test="/Message/School/SchoolCharacteristics/Phase = 'PS' ">PS</xsl:when>	
						<xsl:when test="/Message/School/SchoolCharacteristics/Phase = 'NS' ">NS</xsl:when>
						<xsl:when test="/Message/School/SchoolCharacteristics/Phase = 'AT' ">AT</xsl:when>
						<xsl:otherwise>Unknown</xsl:otherwise>
					</xsl:choose>
				</SchoolPhase>
				<PupilsOnRoll>
					<xsl:value-of select="$PupilOnRollCount"/>
				</PupilsOnRoll>
				<PupilsNoLongerOnRoll>
					<xsl:value-of select="$PupilNoLongerOnRollCount"/>
				</PupilsNoLongerOnRoll>				
				<!--Classes>
					<xsl:value-of select="count(/Message/School/Classes/Class)"/>
				</Classes-->
			</Summary>
			<ReferenceDates>
				<School>
					<xsl:value-of select="/Message/Header/CollectionDetails/ReferenceDate"/>
				</School>
				<Pupils>
					<xsl:value-of select="/Message/Header/CollectionDetails/ReferenceDate"/>
				</Pupils>
			</ReferenceDates>
		</ValidationResults>
		<xsl:element name="Errors">
			<xsl:apply-templates select="/Message"/>
		</xsl:element>
	</ProcessingResults>
	</xsl:template>
	<xsl:include href="./SchoolCensus23-24-ValidationRules.xsl"/>
</xsl:stylesheet>
