<?xml version="1.0" encoding="utf-8" ?> 
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:msxsl="urn:schemas-microsoft-com:xslt" xmlns:Error="Errors.uri" exclude-result-prefixes="Error">
	<xsl:output method="xml" indent="yes"/>
<xsl:variable name="XMLPresentation">
		<!-- Version Details -->
		<CensusDetail type="School Census 2023-2024"/>
		<!-- Current Version Details -->
		<CurrentVersion>
			<Version number="2024.1.2" released="2023-09-27" author="Andy Naylor" comment="Corrected rules 2392 and 5165"/>
		</CurrentVersion>
		<!-- History (old Current Version Details) -->
		<VersionHistory>
			<Version number="2024.1.1" released="2023-09-08" author="Andy Naylor" comment="Corrected allowed DOB ranges for rule 2492. RFC 1253 change to rule 3125. Corrected headings on Table 14 of school summary"/>
			<Version number="2024.1.0" released="2023-08-25" author="Ian Windress" comment="Baselined version for release"/>		
			<Version number="2024.0.1" released="2023-07-01" author="Andy Naylor" comment="rolled over from summer census 2023 and updated for Autumn 23"/>
		</VersionHistory>
		<!-- End of Version Details -->
</xsl:variable>
	<xsl:template match="/">
		<ValidationResults>
			<xsl:copy-of select="ProcessingResults/XSLTVersion"/>
			<xsl:copy-of select="/ProcessingResults/ValidationResults/Header"/>
			<Summary>
				<xsl:copy-of select="/ProcessingResults/ValidationResults/Summary/SchoolName"/>
				<xsl:copy-of select="/ProcessingResults/ValidationResults/Summary/SchoolPhase"/>
				<xsl:copy-of select="/ProcessingResults/ValidationResults/Summary/PupilsOnRoll"/>	
				<xsl:copy-of select="/ProcessingResults/ValidationResults/Summary/PupilsNoLongerOnRoll"/>									
				<xsl:copy-of select="/ProcessingResults/ValidationResults/Summary/Classes"/>					
				<Errors>
					<xsl:value-of select="count(/ProcessingResults/Errors/Error[Type='Error' and contains(Term, /ProcessingResults/ValidationResults/Header/CollectionDetails/Term) and contains(Phase, /ProcessingResults/ValidationResults/Summary/SchoolPhase)])"/>				
				</Errors>
				<Queries>
					<xsl:value-of select="count(/ProcessingResults/Errors/Error[Type='Query' and contains(Term, /ProcessingResults/ValidationResults/Header/CollectionDetails/Term)  and contains(Phase, /ProcessingResults/ValidationResults/Summary/SchoolPhase)])"/>
				</Queries>				
			</Summary>
			<xsl:copy-of select="/ProcessingResults/ValidationResults/ReferenceDates"/>			
			<Errors>
				<xsl:for-each select="/ProcessingResults/Errors/Error[Type='Error' and contains(Term, /ProcessingResults/ValidationResults/Header/CollectionDetails/Term)  and contains(Phase, /ProcessingResults/ValidationResults/Summary/SchoolPhase)]">
					<xsl:sort select="Sequence" data-type="number"/>
					<xsl:call-template name="ErrorOut"/>
				</xsl:for-each>
			</Errors>
			<Queries>
				<xsl:for-each select="/ProcessingResults/Errors/Error[Type='Query' and contains(Term, /ProcessingResults/ValidationResults/Header/CollectionDetails/Term)  and contains(Phase, /ProcessingResults/ValidationResults/Summary/SchoolPhase)]">
					<xsl:sort select="translate(Sequence,'Q','')" data-type="number"/>
					<xsl:call-template name="QueryOut"/>
				</xsl:for-each>				
			</Queries>		
		</ValidationResults>
	</xsl:template>

	<xsl:template name="ErrorOut">
		<xsl:element name="Error">
			<xsl:element name="Sequence">
				<xsl:value-of select="./Sequence"/>
			</xsl:element>
			<xsl:element name="Location">
				<xsl:value-of select="./Location"/>
			</xsl:element>
			<xsl:element name="ErrorMessage">
				<xsl:value-of select="./Message"/>
			</xsl:element>
		</xsl:element>
	</xsl:template>

	<xsl:template name="QueryOut">
		<xsl:element name="Query">
			<xsl:element name="Sequence">
				<xsl:value-of select="./Sequence"/>
			</xsl:element>
			<xsl:element name="Location">
				<xsl:value-of select="./Location"/>
			</xsl:element>
			<xsl:element name="ErrorMessage">
				<xsl:value-of select="./Message"/>
			</xsl:element>
		</xsl:element>
	</xsl:template>
	
</xsl:stylesheet>
