<?xml version="1.0" encoding="utf-8"?>
<!--NOTE - when updating for next term make sure variable dates are updated. These variables are defined towards the end.-->
<!--be sure to update dates used by EYPPNS and EYPOTH variables defined towards the end and used by Pupil Premium tables (currently 7 & 8 as at Spr 21) -->
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:msxsl="urn:schemas-microsoft-com:xslt" xmlns:Error="Errors.uri">
	<xsl:variable name="SchoolSummaryPresentation">
		<!-- Version Details -->
		<CensusDetail type="School Census 2023-2024"/>
		<!-- Current Version Details -->
		<CurrentVersion>
			<Version number="2024.1.2" released="2023-09-27" author="Andy Naylor" comment="Corrected rules 2392 and 5165"/>
		</CurrentVersion>
		<!-- History (old Current Version Details) -->
		<VersionHistory>
			<Version number="2024.1.1" released="2023-09-08" author="Andy Naylor" comment="Corrected allowed DOB ranges for rule 2492. RFC 1253 change to rule 3125. Corrected headings on Table 14 of school summary"/>
			<Version number="2024.1.0" released="2023-08-25" author="Ian Windress" comment="Baselined version for release"/>		
			<Version number="2024.0.1" released="2023-07-01" author="Andy Naylor" comment="rolled over from summer census 2023 and updated for Autumn 23"/>
		</VersionHistory>
		<!-- End of Version Details -->
	</xsl:variable>
	<xsl:variable name="DisplayVersion" select="' Version 2024.1.2 - Updated: 2023-09-27'"/>
	<xsl:variable name="DisplayTitle" select="concat('School census collection: ', $thiscensus,' ', $etyear) "/>
	<xsl:output method="html"/>
	<xsl:template match="/">
		<html>
			<head>
				<title>School Census 2023-24 School Summary</title>
				<link rel="stylesheet" type="text/css">
					<xsl:attribute name="href"><xsl:value-of select=" './SchoolSummaryStylesheet.css' "/></xsl:attribute>
				</link>
			</head>
			<body bgcolor="#FFFFFF">
				<p/>
				<xsl:call-template name="SchoolSummaryReport"/>
			</body>
		</html>
	</xsl:template>
	<xsl:template name="HandleEmptyNumerics">
		<xsl:param name="NullNode"/>
		<xsl:choose>
			<xsl:when test="number($NullNode) = $NullNode">
				<xsl:value-of select="$NullNode"/>
			</xsl:when>
			<xsl:otherwise>
				<xsl:value-of select=" '0' "/>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>
	<xsl:template name="HandlePercentage">
		<xsl:param name="Numerator"/>
		<xsl:param name="Denominator"/>
		<xsl:choose>
			<xsl:when test="$Denominator = 0">
				<xsl:value-of select="N/a"/>
			</xsl:when>
			<xsl:when test="$Numerator = 0">
				<xsl:value-of select="0"/>
			</xsl:when>
			<xsl:otherwise>
				<xsl:value-of select="format-number(($Numerator div $Denominator), '#.##%')"/>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>
	<!---=-=-=-=-=-=-=-=-=-=-=-=-=- ** ** Template for School Summary report  ** **-=-=-=-=-=-=-=-=-=-=-=-=-=-=-==-=-= -->
	<xsl:template name="SchoolSummaryReport">
		<h1>
			<xsl:value-of select=" $DisplayTitle "/>
		</h1>
		<h2>
			<font color="#027087">
				<xsl:value-of select=" $DisplayVersion "/>
			</font>
		</h2>
		<br/>
		
		<h2>There are <xsl:value-of select="$nErrors"/> errors and <xsl:value-of select="$nQueries"/> queries.</h2>
		<h2>Table 1: School characteristics [ALL schools]</h2>
		<p/>
		<table border="1" class="PageBreak" cellpadding="10">
			<tr>
				<td>
					<table border="0" bgcolor="#99ccff" cellpadding="7">
						<tr>
							<td class="clsNormalFont">
								<b>Summary for: </b>
								<xsl:value-of select="/Message/School/SchoolCharacteristics/SchoolName"/>
							</td>
						</tr>
						<tr>
							<td class="clsNormalFont">
								<b>Local authority code: </b>
								<xsl:value-of select="/Message/Header/Source/LEA"/>
							</td>
						</tr>
						<tr>
							<td class="clsNormalFont">
								<b>Establishment number: </b>
								<xsl:value-of select="/Message/Header/Source/Estab"/>
							</td>
						</tr>
						<tr>
							<td class="clsNormalFont">
								<b>Telephone number: </b>
								<xsl:value-of select="/Message/School/SchoolCharacteristics/PhoneNo"/>
							</td>
						</tr>
						<tr>
							<td class="clsNormalFont">
								<b>Email address: </b>
								<xsl:value-of select="/Message/School/SchoolCharacteristics/Email"/>
							</td>
						</tr>
						<tr>
							<td class="clsNormalFont">
								<b>Phase: </b>
								<xsl:value-of select="$phase"/>
							</td>
						</tr>
						<tr>
							<td class="clsNormalFont">
								<b>Type: </b>
								<xsl:value-of select="/Message/School/SchoolCharacteristics/SchoolType"/>
							</td>
						</tr>
						<tr>
							<td class="clsNormalFont">
								<b>Governance: </b>
								<xsl:value-of select="/Message/School/SchoolCharacteristics/Governance"/>
							</td>
						</tr>
						<tr>
							<td class="clsNormalFont">
								<b>Intake type: </b>
								<xsl:value-of select="/Message/School/SchoolCharacteristics/Intake"/>
							</td>
						</tr>
						<tr>
							<td class="clsNormalFont">
								<b>Lowest national curriculum year group: </b>
								<xsl:value-of select="/Message/School/SchoolCharacteristics/LowestNCyear"/>
							</td>
						</tr>
						<tr>
							<td class="clsNormalFont">
								<b>Highest national curriculum year group: </b>
								<xsl:value-of select="/Message/School/SchoolCharacteristics/HighestNCyear"/>
							</td>
						</tr>
						<!--New test added 2015-03-24 SS - Selected by both term and phase (previously term only)-->
						<xsl:if test="$term = 'SPR' and $phase = 'PR' ">
							<tr>
								<td class="clsNormalFont">
									<b>Provision for child mothers: </b>
									<xsl:value-of select="/Message/School/SchoolCharacteristics/ChildMothers"/>
								</td>
							</tr>
							<tr>
								<td class="clsNormalFont">
									<b>Number of teen mother places: </b>
									<xsl:value-of select="/Message/School/SchoolCharacteristics/TeenMotherPlaces"/>
								</td>
							</tr>
							<tr>
								<td class="clsNormalFont">
									<b>Provision for childcare: </b>
									<xsl:value-of select="/Message/School/SchoolCharacteristics/ChildcarePlaces"/>
								</td>
							</tr>
						</xsl:if>
						<xsl:if test="$term = 'SPR' and $phase != 'NS' ">
							<tr>
								<td class="clsNormalFont">
									<b>School time: </b>
									<xsl:value-of select="/Message/School/Miscellaneous/SchoolTime"/>
								</td>
							</tr>
						</xsl:if>
						<!--End of optional elements-->
					</table>
				</td>
			</tr>
		</table>
		<br/>

		
		<h2>Table 2: Pupils on roll by age and sex [ALL schools]</h2>
		<table class="summaryreport" border="1">
			<tr>
				<th class="clsHeading" rowspan="3">Age as at 31 August <xsl:value-of select="$AcademicYear"/>
				</th>
				<th class="clsHeading" rowspan="3">Date of Birth</th>
				<th class="clsHeading" colspan="7">Number of pupils</th>
			</tr>
			<tr>
				<th class="clsHeading" colspan="3">Full-time</th>
				<th class="clsHeading" colspan="3">Part-time</th>
				<th class="clsHeading" colspan="1">All</th>
			</tr>
			<tr>
				<th class="clsHeading">Male</th>
				<th class="clsHeading">Female</th>
				<th class="clsHeading">Total</th>
				<th class="clsHeading">Male</th>
				<th class="clsHeading">Female</th>
				<th class="clsHeading">Total</th>
				<th class="clsHeading">Total</th>
			</tr>
			<tr>
				<td class="clsHeading">19 or over</td>
				<td class="clsSubhead">
					<xsl:value-of select="$dt31Aug"/>
					<xsl:value-of select="$AcademicYear - 19"/> or earlier</td>
				<td class="clsNumber">
					<xsl:value-of select="count(/Message/Pupils/PupilsOnRoll/PupilOnRoll[ floor(($AgeCalcDate - translate(PupilIdentifiers/DOB, '-','')) div 10000) &gt;= 19 and PupilIdentifiers/Sex='M' and contains( $false, concat( ' ', PupilStatus/PartTime, ' ' ) ) ] )"/>
				</td>
				<td class="clsNumber">
					<xsl:value-of select="count(/Message/Pupils/PupilsOnRoll/PupilOnRoll[ floor(($AgeCalcDate - translate(PupilIdentifiers/DOB, '-','')) div 10000) &gt;= 19 and PupilIdentifiers/Sex='F' and contains( $false, concat( ' ', PupilStatus/PartTime, ' ' ) ) ] )"/>
				</td>
				<td class="clsNumber">
					<xsl:value-of select="count(/Message/Pupils/PupilsOnRoll/PupilOnRoll[ floor(($AgeCalcDate - translate(PupilIdentifiers/DOB, '-','')) div 10000) &gt;= 19 and (PupilIdentifiers/Sex='M' or PupilIdentifiers/Sex='F') and contains( $false, concat( ' ', PupilStatus/PartTime, ' ' ) ) ] )"/>
				</td>
				<td class="clsNumber">
					<xsl:value-of select="count(/Message/Pupils/PupilsOnRoll/PupilOnRoll[ floor(($AgeCalcDate - translate(PupilIdentifiers/DOB, '-','')) div 10000) &gt;= 19 and PupilIdentifiers/Sex='M' and contains( $true, concat( ' ', PupilStatus/PartTime, ' ' ) ) ] )"/>
				</td>
				<td class="clsNumber">
					<xsl:value-of select="count(/Message/Pupils/PupilsOnRoll/PupilOnRoll[ floor(($AgeCalcDate - translate(PupilIdentifiers/DOB, '-','')) div 10000) &gt;= 19 and PupilIdentifiers/Sex='F' and contains( $true, concat( ' ', PupilStatus/PartTime, ' ' ) ) ] )"/>
				</td>
				<td class="clsNumber">
					<xsl:value-of select="count(/Message/Pupils/PupilsOnRoll/PupilOnRoll[ floor(($AgeCalcDate - translate(PupilIdentifiers/DOB, '-','')) div 10000) &gt;= 19 and (PupilIdentifiers/Sex='M' or PupilIdentifiers/Sex='F') and contains( $true, concat( ' ', PupilStatus/PartTime, ' ' ) ) ] )"/>
				</td>
				<td class="clsNumber">
					<xsl:value-of select="count(/Message/Pupils/PupilsOnRoll/PupilOnRoll[ floor(($AgeCalcDate - translate(PupilIdentifiers/DOB, '-','')) div 10000) &gt;= 19 ] )"/>
				</td>
			</tr>
			<tr>
				<td class="clsHeading">18</td>
				<td class="clsSubhead">
					<xsl:value-of select="$dt01Sep"/>
					<xsl:value-of select="$AcademicYear - 19"/> - <xsl:value-of select="$dt31Aug"/>
					<xsl:value-of select="$AcademicYear - 18"/>
				</td>
				<td class="clsNumber">
					<xsl:value-of select="count(/Message/Pupils/PupilsOnRoll/PupilOnRoll[ floor(($AgeCalcDate - translate(PupilIdentifiers/DOB, '-','')) div 10000) = 18 and PupilIdentifiers/Sex='M' and contains( $false, concat( ' ', PupilStatus/PartTime, ' ' ) ) ] )"/>
				</td>
				<td class="clsNumber">
					<xsl:value-of select="count(/Message/Pupils/PupilsOnRoll/PupilOnRoll[ floor(($AgeCalcDate - translate(PupilIdentifiers/DOB, '-','')) div 10000) = 18 and PupilIdentifiers/Sex='F' and contains( $false, concat( ' ', PupilStatus/PartTime, ' ' ) ) ] )"/>
				</td>
				<td class="clsNumber">
					<xsl:value-of select="count(/Message/Pupils/PupilsOnRoll/PupilOnRoll[ floor(($AgeCalcDate - translate(PupilIdentifiers/DOB, '-','')) div 10000) = 18 and (PupilIdentifiers/Sex='M' or PupilIdentifiers/Sex='F') and contains( $false, concat( ' ', PupilStatus/PartTime, ' ' ) ) ] )"/>
				</td>
				<td class="clsNumber">
					<xsl:value-of select="count(/Message/Pupils/PupilsOnRoll/PupilOnRoll[ floor(($AgeCalcDate - translate(PupilIdentifiers/DOB, '-','')) div 10000) = 18 and PupilIdentifiers/Sex='M' and contains( $true, concat( ' ', PupilStatus/PartTime, ' ' ) ) ] )"/>
				</td>
				<td class="clsNumber">
					<xsl:value-of select="count(/Message/Pupils/PupilsOnRoll/PupilOnRoll[ floor(($AgeCalcDate - translate(PupilIdentifiers/DOB, '-','')) div 10000) = 18 and PupilIdentifiers/Sex='F' and contains( $true, concat( ' ', PupilStatus/PartTime, ' ' ) ) ] )"/>
				</td>
				<td class="clsNumber">
					<xsl:value-of select="count(/Message/Pupils/PupilsOnRoll/PupilOnRoll[ floor(($AgeCalcDate - translate(PupilIdentifiers/DOB, '-','')) div 10000) = 18 and (PupilIdentifiers/Sex='M' or PupilIdentifiers/Sex='F') and contains( $true, concat( ' ', PupilStatus/PartTime, ' ' ) ) ] )"/>
				</td>
				<td class="clsNumber">
					<xsl:value-of select="count(/Message/Pupils/PupilsOnRoll/PupilOnRoll[ floor(($AgeCalcDate - translate(PupilIdentifiers/DOB, '-','')) div 10000) = 18 ] )"/>
				</td>
			</tr>
			<tr>
				<td class="clsHeading">17</td>
				<td class="clsSubhead">
					<xsl:value-of select="$dt01Sep"/>
					<xsl:value-of select="$AcademicYear - 18"/> - <xsl:value-of select="$dt31Aug"/>
					<xsl:value-of select="$AcademicYear - 17"/>
				</td>
				<td class="clsNumber">
					<xsl:value-of select="count(/Message/Pupils/PupilsOnRoll/PupilOnRoll[ floor(($AgeCalcDate - translate(PupilIdentifiers/DOB, '-','')) div 10000) = 17 and PupilIdentifiers/Sex='M' and contains( $false, concat( ' ', PupilStatus/PartTime, ' ' ) ) ] )"/>
				</td>
				<td class="clsNumber">
					<xsl:value-of select="count(/Message/Pupils/PupilsOnRoll/PupilOnRoll[ floor(($AgeCalcDate - translate(PupilIdentifiers/DOB, '-','')) div 10000) = 17 and PupilIdentifiers/Sex='F' and contains( $false, concat( ' ', PupilStatus/PartTime, ' ' ) ) ] )"/>
				</td>
				<td class="clsNumber">
					<xsl:value-of select="count(/Message/Pupils/PupilsOnRoll/PupilOnRoll[ floor(($AgeCalcDate - translate(PupilIdentifiers/DOB, '-','')) div 10000) = 17 and (PupilIdentifiers/Sex='M' or PupilIdentifiers/Sex='F') and contains( $false, concat( ' ', PupilStatus/PartTime, ' ' ) ) ] )"/>
				</td>
				<td class="clsNumber">
					<xsl:value-of select="count(/Message/Pupils/PupilsOnRoll/PupilOnRoll[ floor(($AgeCalcDate - translate(PupilIdentifiers/DOB, '-','')) div 10000) = 17 and PupilIdentifiers/Sex='M' and contains( $true, concat( ' ', PupilStatus/PartTime, ' ' ) ) ] )"/>
				</td>
				<td class="clsNumber">
					<xsl:value-of select="count(/Message/Pupils/PupilsOnRoll/PupilOnRoll[ floor(($AgeCalcDate - translate(PupilIdentifiers/DOB, '-','')) div 10000) = 17 and PupilIdentifiers/Sex='F' and contains( $true, concat( ' ', PupilStatus/PartTime, ' ' ) ) ] )"/>
				</td>
				<td class="clsNumber">
					<xsl:value-of select="count(/Message/Pupils/PupilsOnRoll/PupilOnRoll[ floor(($AgeCalcDate - translate(PupilIdentifiers/DOB, '-','')) div 10000) = 17 and (PupilIdentifiers/Sex='M' or PupilIdentifiers/Sex='F') and contains( $true, concat( ' ', PupilStatus/PartTime, ' ' ) ) ] )"/>
				</td>
				<td class="clsNumber">
					<xsl:value-of select="count(/Message/Pupils/PupilsOnRoll/PupilOnRoll[ floor(($AgeCalcDate - translate(PupilIdentifiers/DOB, '-','')) div 10000) = 17 ] )"/>
				</td>
			</tr>
			<tr>
				<td class="clsHeading">16</td>
				<td class="clsSubhead">
					<xsl:value-of select="$dt01Sep"/>
					<xsl:value-of select="$AcademicYear - 17"/> - <xsl:value-of select="$dt31Aug"/>
					<xsl:value-of select="$AcademicYear - 16"/>
				</td>
				<td class="clsNumber">
					<xsl:value-of select="count(/Message/Pupils/PupilsOnRoll/PupilOnRoll[ floor(($AgeCalcDate - translate(PupilIdentifiers/DOB, '-','')) div 10000) = 16 and PupilIdentifiers/Sex='M' and contains( $false, concat( ' ', PupilStatus/PartTime, ' ' ) ) ] )"/>
				</td>
				<td class="clsNumber">
					<xsl:value-of select="count(/Message/Pupils/PupilsOnRoll/PupilOnRoll[ floor(($AgeCalcDate - translate(PupilIdentifiers/DOB, '-','')) div 10000) = 16 and PupilIdentifiers/Sex='F' and contains( $false, concat( ' ', PupilStatus/PartTime, ' ' ) ) ] )"/>
				</td>
				<td class="clsNumber">
					<xsl:value-of select="count(/Message/Pupils/PupilsOnRoll/PupilOnRoll[ floor(($AgeCalcDate - translate(PupilIdentifiers/DOB, '-','')) div 10000) = 16 and (PupilIdentifiers/Sex='M' or PupilIdentifiers/Sex='F') and contains( $false, concat( ' ', PupilStatus/PartTime, ' ' ) ) ] )"/>
				</td>
				<td class="clsNumber">
					<xsl:value-of select="count(/Message/Pupils/PupilsOnRoll/PupilOnRoll[ floor(($AgeCalcDate - translate(PupilIdentifiers/DOB, '-','')) div 10000) = 16 and PupilIdentifiers/Sex='M' and contains( $true, concat( ' ', PupilStatus/PartTime, ' ' ) ) ] )"/>
				</td>
				<td class="clsNumber">
					<xsl:value-of select="count(/Message/Pupils/PupilsOnRoll/PupilOnRoll[ floor(($AgeCalcDate - translate(PupilIdentifiers/DOB, '-','')) div 10000) = 16 and PupilIdentifiers/Sex='F' and contains( $true, concat( ' ', PupilStatus/PartTime, ' ' ) ) ] )"/>
				</td>
				<td class="clsNumber">
					<xsl:value-of select="count(/Message/Pupils/PupilsOnRoll/PupilOnRoll[ floor(($AgeCalcDate - translate(PupilIdentifiers/DOB, '-','')) div 10000) = 16 and (PupilIdentifiers/Sex='M' or PupilIdentifiers/Sex='F') and contains( $true, concat( ' ', PupilStatus/PartTime, ' ' ) ) ] )"/>
				</td>
				<td class="clsNumber">
					<xsl:value-of select="count(/Message/Pupils/PupilsOnRoll/PupilOnRoll[ floor(($AgeCalcDate - translate(PupilIdentifiers/DOB, '-','')) div 10000) = 16 ] )"/>
				</td>
			</tr>
			<tr>
				<td class="clsHeading">15</td>
				<td class="clsSubhead">
					<xsl:value-of select="$dt01Sep"/>
					<xsl:value-of select="$AcademicYear - 16"/> - <xsl:value-of select="$dt31Aug"/>
					<xsl:value-of select="$AcademicYear - 15"/>
				</td>
				<td class="clsNumber">
					<xsl:value-of select="count(/Message/Pupils/PupilsOnRoll/PupilOnRoll[ floor(($AgeCalcDate - translate(PupilIdentifiers/DOB, '-','')) div 10000) = 15 and PupilIdentifiers/Sex='M' and contains( $false, concat( ' ', PupilStatus/PartTime, ' ' ) ) ] )"/>
				</td>
				<td class="clsNumber">
					<xsl:value-of select="count(/Message/Pupils/PupilsOnRoll/PupilOnRoll[ floor(($AgeCalcDate - translate(PupilIdentifiers/DOB, '-','')) div 10000) = 15 and PupilIdentifiers/Sex='F' and contains( $false, concat( ' ', PupilStatus/PartTime, ' ' ) ) ] )"/>
				</td>
				<td class="clsNumber">
					<xsl:value-of select="count(/Message/Pupils/PupilsOnRoll/PupilOnRoll[ floor(($AgeCalcDate - translate(PupilIdentifiers/DOB, '-','')) div 10000) = 15 and (PupilIdentifiers/Sex='M' or PupilIdentifiers/Sex='F') and contains( $false, concat( ' ', PupilStatus/PartTime, ' ' ) ) ] )"/>
				</td>
				<td class="clsNumber">
					<xsl:value-of select="count(/Message/Pupils/PupilsOnRoll/PupilOnRoll[ floor(($AgeCalcDate - translate(PupilIdentifiers/DOB, '-','')) div 10000) = 15 and PupilIdentifiers/Sex='M' and contains( $true, concat( ' ', PupilStatus/PartTime, ' ' ) ) ] )"/>
				</td>
				<td class="clsNumber">
					<xsl:value-of select="count(/Message/Pupils/PupilsOnRoll/PupilOnRoll[ floor(($AgeCalcDate - translate(PupilIdentifiers/DOB, '-','')) div 10000) = 15 and PupilIdentifiers/Sex='F' and contains( $true, concat( ' ', PupilStatus/PartTime, ' ' ) ) ] )"/>
				</td>
				<td class="clsNumber">
					<xsl:value-of select="count(/Message/Pupils/PupilsOnRoll/PupilOnRoll[ floor(($AgeCalcDate - translate(PupilIdentifiers/DOB, '-','')) div 10000) = 15 and (PupilIdentifiers/Sex='M' or PupilIdentifiers/Sex='F') and contains( $true, concat( ' ', PupilStatus/PartTime, ' ' ) ) ] )"/>
				</td>
				<td class="clsNumber">
					<xsl:value-of select="count(/Message/Pupils/PupilsOnRoll/PupilOnRoll[ floor(($AgeCalcDate - translate(PupilIdentifiers/DOB, '-','')) div 10000) = 15 ] )"/>
				</td>
			</tr>
			<tr>
				<td class="clsHeading">14</td>
				<td class="clsSubhead">
					<xsl:value-of select="$dt01Sep"/>
					<xsl:value-of select="$AcademicYear - 15"/> - <xsl:value-of select="$dt31Aug"/>
					<xsl:value-of select="$AcademicYear - 14"/>
				</td>
				<td class="clsNumber">
					<xsl:value-of select="count(/Message/Pupils/PupilsOnRoll/PupilOnRoll[ floor(($AgeCalcDate - translate(PupilIdentifiers/DOB, '-','')) div 10000) = 14 and PupilIdentifiers/Sex='M' and contains( $false, concat( ' ', PupilStatus/PartTime, ' ' ) ) ] )"/>
				</td>
				<td class="clsNumber">
					<xsl:value-of select="count(/Message/Pupils/PupilsOnRoll/PupilOnRoll[ floor(($AgeCalcDate - translate(PupilIdentifiers/DOB, '-','')) div 10000) = 14 and PupilIdentifiers/Sex='F' and contains( $false, concat( ' ', PupilStatus/PartTime, ' ' ) ) ] )"/>
				</td>
				<td class="clsNumber">
					<xsl:value-of select="count(/Message/Pupils/PupilsOnRoll/PupilOnRoll[ floor(($AgeCalcDate - translate(PupilIdentifiers/DOB, '-','')) div 10000) = 14 and (PupilIdentifiers/Sex='M' or PupilIdentifiers/Sex='F') and contains( $false, concat( ' ', PupilStatus/PartTime, ' ' ) ) ] )"/>
				</td>
				<td class="clsNumber">
					<xsl:value-of select="count(/Message/Pupils/PupilsOnRoll/PupilOnRoll[ floor(($AgeCalcDate - translate(PupilIdentifiers/DOB, '-','')) div 10000) = 14 and PupilIdentifiers/Sex='M' and contains( $true, concat( ' ', PupilStatus/PartTime, ' ' ) ) ] )"/>
				</td>
				<td class="clsNumber">
					<xsl:value-of select="count(/Message/Pupils/PupilsOnRoll/PupilOnRoll[ floor(($AgeCalcDate - translate(PupilIdentifiers/DOB, '-','')) div 10000) = 14 and PupilIdentifiers/Sex='F' and contains( $true, concat( ' ', PupilStatus/PartTime, ' ' ) ) ] )"/>
				</td>
				<td class="clsNumber">
					<xsl:value-of select="count(/Message/Pupils/PupilsOnRoll/PupilOnRoll[ floor(($AgeCalcDate - translate(PupilIdentifiers/DOB, '-','')) div 10000) = 14 and (PupilIdentifiers/Sex='M' or PupilIdentifiers/Sex='F') and contains( $true, concat( ' ', PupilStatus/PartTime, ' ' ) ) ] )"/>
				</td>
				<td class="clsNumber">
					<xsl:value-of select="count(/Message/Pupils/PupilsOnRoll/PupilOnRoll[ floor(($AgeCalcDate - translate(PupilIdentifiers/DOB, '-','')) div 10000) = 14 ] )"/>
				</td>
			</tr>
			<tr>
				<td class="clsHeading">13</td>
				<td class="clsSubhead">
					<xsl:value-of select="$dt01Sep"/>
					<xsl:value-of select="$AcademicYear - 14"/> - <xsl:value-of select="$dt31Aug"/>
					<xsl:value-of select="$AcademicYear - 13"/>
				</td>
				<td class="clsNumber">
					<xsl:value-of select="count(/Message/Pupils/PupilsOnRoll/PupilOnRoll[ floor(($AgeCalcDate - translate(PupilIdentifiers/DOB, '-','')) div 10000) = 13 and PupilIdentifiers/Sex='M' and contains( $false, concat( ' ', PupilStatus/PartTime, ' ' ) ) ] )"/>
				</td>
				<td class="clsNumber">
					<xsl:value-of select="count(/Message/Pupils/PupilsOnRoll/PupilOnRoll[ floor(($AgeCalcDate - translate(PupilIdentifiers/DOB, '-','')) div 10000) = 13 and PupilIdentifiers/Sex='F' and contains( $false, concat( ' ', PupilStatus/PartTime, ' ' ) ) ] )"/>
				</td>
				<td class="clsNumber">
					<xsl:value-of select="count(/Message/Pupils/PupilsOnRoll/PupilOnRoll[ floor(($AgeCalcDate - translate(PupilIdentifiers/DOB, '-','')) div 10000) = 13 and (PupilIdentifiers/Sex='M' or PupilIdentifiers/Sex='F') and contains( $false, concat( ' ', PupilStatus/PartTime, ' ' ) ) ] )"/>
				</td>
				<td class="clsNumber">
					<xsl:value-of select="count(/Message/Pupils/PupilsOnRoll/PupilOnRoll[ floor(($AgeCalcDate - translate(PupilIdentifiers/DOB, '-','')) div 10000) = 13 and PupilIdentifiers/Sex='M' and contains( $true, concat( ' ', PupilStatus/PartTime, ' ' ) ) ] )"/>
				</td>
				<td class="clsNumber">
					<xsl:value-of select="count(/Message/Pupils/PupilsOnRoll/PupilOnRoll[ floor(($AgeCalcDate - translate(PupilIdentifiers/DOB, '-','')) div 10000) = 13 and PupilIdentifiers/Sex='F' and contains( $true, concat( ' ', PupilStatus/PartTime, ' ' ) ) ] )"/>
				</td>
				<td class="clsNumber">
					<xsl:value-of select="count(/Message/Pupils/PupilsOnRoll/PupilOnRoll[ floor(($AgeCalcDate - translate(PupilIdentifiers/DOB, '-','')) div 10000) = 13 and (PupilIdentifiers/Sex='M' or PupilIdentifiers/Sex='F') and contains( $true, concat( ' ', PupilStatus/PartTime, ' ' ) ) ] )"/>
				</td>
				<td class="clsNumber">
					<xsl:value-of select="count(/Message/Pupils/PupilsOnRoll/PupilOnRoll[ floor(($AgeCalcDate - translate(PupilIdentifiers/DOB, '-','')) div 10000) = 13 ] )"/>
				</td>
			</tr>
			<tr>
				<td class="clsHeading">12</td>
				<td class="clsSubhead">
					<xsl:value-of select="$dt01Sep"/>
					<xsl:value-of select="$AcademicYear - 13"/> - <xsl:value-of select="$dt31Aug"/>
					<xsl:value-of select="$AcademicYear - 12"/>
				</td>
				<td class="clsNumber">
					<xsl:value-of select="count(/Message/Pupils/PupilsOnRoll/PupilOnRoll[ floor(($AgeCalcDate - translate(PupilIdentifiers/DOB, '-','')) div 10000) = 12 and PupilIdentifiers/Sex='M' and contains( $false, concat( ' ', PupilStatus/PartTime, ' ' ) ) ] )"/>
				</td>
				<td class="clsNumber">
					<xsl:value-of select="count(/Message/Pupils/PupilsOnRoll/PupilOnRoll[ floor(($AgeCalcDate - translate(PupilIdentifiers/DOB, '-','')) div 10000) = 12 and PupilIdentifiers/Sex='F' and contains( $false, concat( ' ', PupilStatus/PartTime, ' ' ) ) ] )"/>
				</td>
				<td class="clsNumber">
					<xsl:value-of select="count(/Message/Pupils/PupilsOnRoll/PupilOnRoll[ floor(($AgeCalcDate - translate(PupilIdentifiers/DOB, '-','')) div 10000) = 12 and (PupilIdentifiers/Sex='M' or PupilIdentifiers/Sex='F') and contains( $false, concat( ' ', PupilStatus/PartTime, ' ' ) ) ] )"/>
				</td>
				<td class="clsNumber">
					<xsl:value-of select="count(/Message/Pupils/PupilsOnRoll/PupilOnRoll[ floor(($AgeCalcDate - translate(PupilIdentifiers/DOB, '-','')) div 10000) = 12 and PupilIdentifiers/Sex='M' and contains( $true, concat( ' ', PupilStatus/PartTime, ' ' ) ) ] )"/>
				</td>
				<td class="clsNumber">
					<xsl:value-of select="count(/Message/Pupils/PupilsOnRoll/PupilOnRoll[ floor(($AgeCalcDate - translate(PupilIdentifiers/DOB, '-','')) div 10000) = 12 and PupilIdentifiers/Sex='F' and contains( $true, concat( ' ', PupilStatus/PartTime, ' ' ) ) ] )"/>
				</td>
				<td class="clsNumber">
					<xsl:value-of select="count(/Message/Pupils/PupilsOnRoll/PupilOnRoll[ floor(($AgeCalcDate - translate(PupilIdentifiers/DOB, '-','')) div 10000) = 12 and (PupilIdentifiers/Sex='M' or PupilIdentifiers/Sex='F') and contains( $true, concat( ' ', PupilStatus/PartTime, ' ' ) ) ] )"/>
				</td>
				<td class="clsNumber">
					<xsl:value-of select="count(/Message/Pupils/PupilsOnRoll/PupilOnRoll[ floor(($AgeCalcDate - translate(PupilIdentifiers/DOB, '-','')) div 10000) = 12 ] )"/>
				</td>
			</tr>
			<tr>
				<td class="clsHeading">11</td>
				<td class="clsSubhead">
					<xsl:value-of select="$dt01Sep"/>
					<xsl:value-of select="$AcademicYear - 12"/> - <xsl:value-of select="$dt31Aug"/>
					<xsl:value-of select="$AcademicYear - 11"/>
				</td>
				<td class="clsNumber">
					<xsl:value-of select="count(/Message/Pupils/PupilsOnRoll/PupilOnRoll[ floor(($AgeCalcDate - translate(PupilIdentifiers/DOB, '-','')) div 10000) = 11 and PupilIdentifiers/Sex='M' and contains( $false, concat( ' ', PupilStatus/PartTime, ' ' ) ) ] )"/>
				</td>
				<td class="clsNumber">
					<xsl:value-of select="count(/Message/Pupils/PupilsOnRoll/PupilOnRoll[ floor(($AgeCalcDate - translate(PupilIdentifiers/DOB, '-','')) div 10000) = 11 and PupilIdentifiers/Sex='F' and contains( $false, concat( ' ', PupilStatus/PartTime, ' ' ) ) ] )"/>
				</td>
				<td class="clsNumber">
					<xsl:value-of select="count(/Message/Pupils/PupilsOnRoll/PupilOnRoll[ floor(($AgeCalcDate - translate(PupilIdentifiers/DOB, '-','')) div 10000) = 11 and (PupilIdentifiers/Sex='M' or PupilIdentifiers/Sex='F') and contains( $false, concat( ' ', PupilStatus/PartTime, ' ' ) ) ] )"/>
				</td>
				<td class="clsNumber">
					<xsl:value-of select="count(/Message/Pupils/PupilsOnRoll/PupilOnRoll[ floor(($AgeCalcDate - translate(PupilIdentifiers/DOB, '-','')) div 10000) = 11 and PupilIdentifiers/Sex='M' and contains( $true, concat( ' ', PupilStatus/PartTime, ' ' ) ) ] )"/>
				</td>
				<td class="clsNumber">
					<xsl:value-of select="count(/Message/Pupils/PupilsOnRoll/PupilOnRoll[ floor(($AgeCalcDate - translate(PupilIdentifiers/DOB, '-','')) div 10000) = 11 and PupilIdentifiers/Sex='F' and contains( $true, concat( ' ', PupilStatus/PartTime, ' ' ) ) ] )"/>
				</td>
				<td class="clsNumber">
					<xsl:value-of select="count(/Message/Pupils/PupilsOnRoll/PupilOnRoll[ floor(($AgeCalcDate - translate(PupilIdentifiers/DOB, '-','')) div 10000) = 11 and (PupilIdentifiers/Sex='M' or PupilIdentifiers/Sex='F') and contains( $true, concat( ' ', PupilStatus/PartTime, ' ' ) ) ] )"/>
				</td>
				<td class="clsNumber">
					<xsl:value-of select="count(/Message/Pupils/PupilsOnRoll/PupilOnRoll[ floor(($AgeCalcDate - translate(PupilIdentifiers/DOB, '-','')) div 10000) = 11 ] )"/>
				</td>
			</tr>
			<tr>
				<td class="clsHeading">10</td>
				<td class="clsSubhead">
					<xsl:value-of select="$dt01Sep"/>
					<xsl:value-of select="$AcademicYear - 11"/> - <xsl:value-of select="$dt31Aug"/>
					<xsl:value-of select="$AcademicYear - 10"/>
				</td>
				<td class="clsNumber">
					<xsl:value-of select="count(/Message/Pupils/PupilsOnRoll/PupilOnRoll[ floor(($AgeCalcDate - translate(PupilIdentifiers/DOB, '-','')) div 10000) = 10 and PupilIdentifiers/Sex='M' and contains( $false, concat( ' ', PupilStatus/PartTime, ' ' ) ) ] )"/>
				</td>
				<td class="clsNumber">
					<xsl:value-of select="count(/Message/Pupils/PupilsOnRoll/PupilOnRoll[ floor(($AgeCalcDate - translate(PupilIdentifiers/DOB, '-','')) div 10000) = 10 and PupilIdentifiers/Sex='F' and contains( $false, concat( ' ', PupilStatus/PartTime, ' ' ) ) ] )"/>
				</td>
				<td class="clsNumber">
					<xsl:value-of select="count(/Message/Pupils/PupilsOnRoll/PupilOnRoll[ floor(($AgeCalcDate - translate(PupilIdentifiers/DOB, '-','')) div 10000) = 10 and (PupilIdentifiers/Sex='M' or PupilIdentifiers/Sex='F') and contains( $false, concat( ' ', PupilStatus/PartTime, ' ' ) ) ] )"/>
				</td>
				<td class="clsNumber">
					<xsl:value-of select="count(/Message/Pupils/PupilsOnRoll/PupilOnRoll[ floor(($AgeCalcDate - translate(PupilIdentifiers/DOB, '-','')) div 10000) = 10 and PupilIdentifiers/Sex='M' and contains( $true, concat( ' ', PupilStatus/PartTime, ' ' ) ) ] )"/>
				</td>
				<td class="clsNumber">
					<xsl:value-of select="count(/Message/Pupils/PupilsOnRoll/PupilOnRoll[ floor(($AgeCalcDate - translate(PupilIdentifiers/DOB, '-','')) div 10000) = 10 and PupilIdentifiers/Sex='F' and contains( $true, concat( ' ', PupilStatus/PartTime, ' ' ) ) ] )"/>
				</td>
				<td class="clsNumber">
					<xsl:value-of select="count(/Message/Pupils/PupilsOnRoll/PupilOnRoll[ floor(($AgeCalcDate - translate(PupilIdentifiers/DOB, '-','')) div 10000) = 10 and (PupilIdentifiers/Sex='M' or PupilIdentifiers/Sex='F') and contains( $true, concat( ' ', PupilStatus/PartTime, ' ' ) ) ] )"/>
				</td>
				<td class="clsNumber">
					<xsl:value-of select="count(/Message/Pupils/PupilsOnRoll/PupilOnRoll[ floor(($AgeCalcDate - translate(PupilIdentifiers/DOB, '-','')) div 10000) = 10 ] )"/>
				</td>
			</tr>
			<tr>
				<td class="clsHeading">9</td>
				<td class="clsSubhead">
					<xsl:value-of select="$dt01Sep"/>
					<xsl:value-of select="$AcademicYear - 10"/> - <xsl:value-of select="$dt31Aug"/>
					<xsl:value-of select="$AcademicYear - 9"/>
				</td>
				<td class="clsNumber">
					<xsl:value-of select="count(/Message/Pupils/PupilsOnRoll/PupilOnRoll[ floor(($AgeCalcDate - translate(PupilIdentifiers/DOB, '-','')) div 10000) = 9 and PupilIdentifiers/Sex='M' and contains( $false, concat( ' ', PupilStatus/PartTime, ' ' ) ) ] )"/>
				</td>
				<td class="clsNumber">
					<xsl:value-of select="count(/Message/Pupils/PupilsOnRoll/PupilOnRoll[ floor(($AgeCalcDate - translate(PupilIdentifiers/DOB, '-','')) div 10000) = 9 and PupilIdentifiers/Sex='F' and contains( $false, concat( ' ', PupilStatus/PartTime, ' ' ) ) ] )"/>
				</td>
				<td class="clsNumber">
					<xsl:value-of select="count(/Message/Pupils/PupilsOnRoll/PupilOnRoll[ floor(($AgeCalcDate - translate(PupilIdentifiers/DOB, '-','')) div 10000) = 9 and (PupilIdentifiers/Sex='M' or PupilIdentifiers/Sex='F') and contains( $false, concat( ' ', PupilStatus/PartTime, ' ' ) ) ] )"/>
				</td>
				<td class="clsNumber">
					<xsl:value-of select="count(/Message/Pupils/PupilsOnRoll/PupilOnRoll[ floor(($AgeCalcDate - translate(PupilIdentifiers/DOB, '-','')) div 10000) = 9 and PupilIdentifiers/Sex='M' and contains( $true, concat( ' ', PupilStatus/PartTime, ' ' ) ) ] )"/>
				</td>
				<td class="clsNumber">
					<xsl:value-of select="count(/Message/Pupils/PupilsOnRoll/PupilOnRoll[ floor(($AgeCalcDate - translate(PupilIdentifiers/DOB, '-','')) div 10000) = 9 and PupilIdentifiers/Sex='F' and contains( $true, concat( ' ', PupilStatus/PartTime, ' ' ) ) ] )"/>
				</td>
				<td class="clsNumber">
					<xsl:value-of select="count(/Message/Pupils/PupilsOnRoll/PupilOnRoll[ floor(($AgeCalcDate - translate(PupilIdentifiers/DOB, '-','')) div 10000) = 9 and (PupilIdentifiers/Sex='M' or PupilIdentifiers/Sex='F') and contains( $true, concat( ' ', PupilStatus/PartTime, ' ' ) ) ] )"/>
				</td>
				<td class="clsNumber">
					<xsl:value-of select="count(/Message/Pupils/PupilsOnRoll/PupilOnRoll[ floor(($AgeCalcDate - translate(PupilIdentifiers/DOB, '-','')) div 10000) = 9 ] )"/>
				</td>
			</tr>
			<tr>
				<td class="clsHeading">8</td>
				<td class="clsSubhead">
					<xsl:value-of select="$dt01Sep"/>
					<xsl:value-of select="$AcademicYear - 9"/> - <xsl:value-of select="$dt31Aug"/>
					<xsl:value-of select="$AcademicYear - 8"/>
				</td>
				<td class="clsNumber">
					<xsl:value-of select="count(/Message/Pupils/PupilsOnRoll/PupilOnRoll[ floor(($AgeCalcDate - translate(PupilIdentifiers/DOB, '-','')) div 10000) = 8 and PupilIdentifiers/Sex='M' and contains( $false, concat( ' ', PupilStatus/PartTime, ' ' ) ) ] )"/>
				</td>
				<td class="clsNumber">
					<xsl:value-of select="count(/Message/Pupils/PupilsOnRoll/PupilOnRoll[ floor(($AgeCalcDate - translate(PupilIdentifiers/DOB, '-','')) div 10000) = 8 and PupilIdentifiers/Sex='F' and contains( $false, concat( ' ', PupilStatus/PartTime, ' ' ) ) ] )"/>
				</td>
				<td class="clsNumber">
					<xsl:value-of select="count(/Message/Pupils/PupilsOnRoll/PupilOnRoll[ floor(($AgeCalcDate - translate(PupilIdentifiers/DOB, '-','')) div 10000) = 8 and (PupilIdentifiers/Sex='M' or PupilIdentifiers/Sex='F') and contains( $false, concat( ' ', PupilStatus/PartTime, ' ' ) ) ] )"/>
				</td>
				<td class="clsNumber">
					<xsl:value-of select="count(/Message/Pupils/PupilsOnRoll/PupilOnRoll[ floor(($AgeCalcDate - translate(PupilIdentifiers/DOB, '-','')) div 10000) = 8 and PupilIdentifiers/Sex='M' and contains( $true, concat( ' ', PupilStatus/PartTime, ' ' ) ) ] )"/>
				</td>
				<td class="clsNumber">
					<xsl:value-of select="count(/Message/Pupils/PupilsOnRoll/PupilOnRoll[ floor(($AgeCalcDate - translate(PupilIdentifiers/DOB, '-','')) div 10000) = 8 and PupilIdentifiers/Sex='F' and contains( $true, concat( ' ', PupilStatus/PartTime, ' ' ) ) ] )"/>
				</td>
				<td class="clsNumber">
					<xsl:value-of select="count(/Message/Pupils/PupilsOnRoll/PupilOnRoll[ floor(($AgeCalcDate - translate(PupilIdentifiers/DOB, '-','')) div 10000) = 8 and (PupilIdentifiers/Sex='M' or PupilIdentifiers/Sex='F') and contains( $true, concat( ' ', PupilStatus/PartTime, ' ' ) ) ] )"/>
				</td>
				<td class="clsNumber">
					<xsl:value-of select="count(/Message/Pupils/PupilsOnRoll/PupilOnRoll[ floor(($AgeCalcDate - translate(PupilIdentifiers/DOB, '-','')) div 10000) = 8 ] )"/>
				</td>
			</tr>
			<tr>
				<td class="clsHeading">7</td>
				<td class="clsSubhead">
					<xsl:value-of select="$dt01Sep"/>
					<xsl:value-of select="$AcademicYear - 8"/> - <xsl:value-of select="$dt31Aug"/>
					<xsl:value-of select="$AcademicYear - 7"/>
				</td>
				<td class="clsNumber">
					<xsl:value-of select="count(/Message/Pupils/PupilsOnRoll/PupilOnRoll[ floor(($AgeCalcDate - translate(PupilIdentifiers/DOB, '-','')) div 10000) = 7 and PupilIdentifiers/Sex='M' and contains( $false, concat( ' ', PupilStatus/PartTime, ' ' ) ) ] )"/>
				</td>
				<td class="clsNumber">
					<xsl:value-of select="count(/Message/Pupils/PupilsOnRoll/PupilOnRoll[ floor(($AgeCalcDate - translate(PupilIdentifiers/DOB, '-','')) div 10000) = 7 and PupilIdentifiers/Sex='F' and contains( $false, concat( ' ', PupilStatus/PartTime, ' ' ) ) ] )"/>
				</td>
				<td class="clsNumber">
					<xsl:value-of select="count(/Message/Pupils/PupilsOnRoll/PupilOnRoll[ floor(($AgeCalcDate - translate(PupilIdentifiers/DOB, '-','')) div 10000) = 7 and (PupilIdentifiers/Sex='M' or PupilIdentifiers/Sex='F') and contains( $false, concat( ' ', PupilStatus/PartTime, ' ' ) ) ] )"/>
				</td>
				<td class="clsNumber">
					<xsl:value-of select="count(/Message/Pupils/PupilsOnRoll/PupilOnRoll[ floor(($AgeCalcDate - translate(PupilIdentifiers/DOB, '-','')) div 10000) = 7 and PupilIdentifiers/Sex='M' and contains( $true, concat( ' ', PupilStatus/PartTime, ' ' ) ) ] )"/>
				</td>
				<td class="clsNumber">
					<xsl:value-of select="count(/Message/Pupils/PupilsOnRoll/PupilOnRoll[ floor(($AgeCalcDate - translate(PupilIdentifiers/DOB, '-','')) div 10000) = 7 and PupilIdentifiers/Sex='F' and contains( $true, concat( ' ', PupilStatus/PartTime, ' ' ) ) ] )"/>
				</td>
				<td class="clsNumber">
					<xsl:value-of select="count(/Message/Pupils/PupilsOnRoll/PupilOnRoll[ floor(($AgeCalcDate - translate(PupilIdentifiers/DOB, '-','')) div 10000) = 7 and (PupilIdentifiers/Sex='M' or PupilIdentifiers/Sex='F') and contains( $true, concat( ' ', PupilStatus/PartTime, ' ' ) ) ] )"/>
				</td>
				<td class="clsNumber">
					<xsl:value-of select="count(/Message/Pupils/PupilsOnRoll/PupilOnRoll[ floor(($AgeCalcDate - translate(PupilIdentifiers/DOB, '-','')) div 10000) = 7 ] )"/>
				</td>
			</tr>
			<tr>
				<td class="clsHeading">6</td>
				<td class="clsSubhead">
					<xsl:value-of select="$dt01Sep"/>
					<xsl:value-of select="$AcademicYear - 7"/> - <xsl:value-of select="$dt31Aug"/>
					<xsl:value-of select="$AcademicYear - 6"/>
				</td>
				<td class="clsNumber">
					<xsl:value-of select="count(/Message/Pupils/PupilsOnRoll/PupilOnRoll[ floor(($AgeCalcDate - translate(PupilIdentifiers/DOB, '-','')) div 10000) = 6 and PupilIdentifiers/Sex='M' and contains( $false, concat( ' ', PupilStatus/PartTime, ' ' ) ) ] )"/>
				</td>
				<td class="clsNumber">
					<xsl:value-of select="count(/Message/Pupils/PupilsOnRoll/PupilOnRoll[ floor(($AgeCalcDate - translate(PupilIdentifiers/DOB, '-','')) div 10000) = 6 and PupilIdentifiers/Sex='F' and contains( $false, concat( ' ', PupilStatus/PartTime, ' ' ) ) ] )"/>
				</td>
				<td class="clsNumber">
					<xsl:value-of select="count(/Message/Pupils/PupilsOnRoll/PupilOnRoll[ floor(($AgeCalcDate - translate(PupilIdentifiers/DOB, '-','')) div 10000) = 6 and (PupilIdentifiers/Sex='M' or PupilIdentifiers/Sex='F') and contains( $false, concat( ' ', PupilStatus/PartTime, ' ' ) ) ] )"/>
				</td>
				<td class="clsNumber">
					<xsl:value-of select="count(/Message/Pupils/PupilsOnRoll/PupilOnRoll[ floor(($AgeCalcDate - translate(PupilIdentifiers/DOB, '-','')) div 10000) = 6 and PupilIdentifiers/Sex='M' and contains( $true, concat( ' ', PupilStatus/PartTime, ' ' ) ) ] )"/>
				</td>
				<td class="clsNumber">
					<xsl:value-of select="count(/Message/Pupils/PupilsOnRoll/PupilOnRoll[ floor(($AgeCalcDate - translate(PupilIdentifiers/DOB, '-','')) div 10000) = 6 and PupilIdentifiers/Sex='F' and contains( $true, concat( ' ', PupilStatus/PartTime, ' ' ) ) ] )"/>
				</td>
				<td class="clsNumber">
					<xsl:value-of select="count(/Message/Pupils/PupilsOnRoll/PupilOnRoll[ floor(($AgeCalcDate - translate(PupilIdentifiers/DOB, '-','')) div 10000) = 6 and (PupilIdentifiers/Sex='M' or PupilIdentifiers/Sex='F') and contains( $true, concat( ' ', PupilStatus/PartTime, ' ' ) ) ] )"/>
				</td>
				<td class="clsNumber">
					<xsl:value-of select="count(/Message/Pupils/PupilsOnRoll/PupilOnRoll[ floor(($AgeCalcDate - translate(PupilIdentifiers/DOB, '-','')) div 10000) = 6 ] )"/>
				</td>
			</tr>
			<tr>
				<td class="clsHeading">5</td>
				<td class="clsSubhead">
					<xsl:value-of select="$dt01Sep"/>
					<xsl:value-of select="$AcademicYear - 6"/> - <xsl:value-of select="$dt31Aug"/>
					<xsl:value-of select="$AcademicYear - 5"/>
				</td>
				<td class="clsNumber">
					<xsl:value-of select="count(/Message/Pupils/PupilsOnRoll/PupilOnRoll[ floor(($AgeCalcDate - translate(PupilIdentifiers/DOB, '-','')) div 10000) = 5 and PupilIdentifiers/Sex='M' and contains( $false, concat( ' ', PupilStatus/PartTime, ' ' ) ) ] )"/>
				</td>
				<td class="clsNumber">
					<xsl:value-of select="count(/Message/Pupils/PupilsOnRoll/PupilOnRoll[ floor(($AgeCalcDate - translate(PupilIdentifiers/DOB, '-','')) div 10000) = 5 and PupilIdentifiers/Sex='F' and contains( $false, concat( ' ', PupilStatus/PartTime, ' ' ) ) ] )"/>
				</td>
				<td class="clsNumber">
					<xsl:value-of select="count(/Message/Pupils/PupilsOnRoll/PupilOnRoll[ floor(($AgeCalcDate - translate(PupilIdentifiers/DOB, '-','')) div 10000) = 5 and (PupilIdentifiers/Sex='M' or PupilIdentifiers/Sex='F') and contains( $false, concat( ' ', PupilStatus/PartTime, ' ' ) ) ] )"/>
				</td>
				<td class="clsNumber">
					<xsl:value-of select="count(/Message/Pupils/PupilsOnRoll/PupilOnRoll[ floor(($AgeCalcDate - translate(PupilIdentifiers/DOB, '-','')) div 10000) = 5 and PupilIdentifiers/Sex='M' and contains( $true, concat( ' ', PupilStatus/PartTime, ' ' ) ) ] )"/>
				</td>
				<td class="clsNumber">
					<xsl:value-of select="count(/Message/Pupils/PupilsOnRoll/PupilOnRoll[ floor(($AgeCalcDate - translate(PupilIdentifiers/DOB, '-','')) div 10000) = 5 and PupilIdentifiers/Sex='F' and contains( $true, concat( ' ', PupilStatus/PartTime, ' ' ) ) ] )"/>
				</td>
				<td class="clsNumber">
					<xsl:value-of select="count(/Message/Pupils/PupilsOnRoll/PupilOnRoll[ floor(($AgeCalcDate - translate(PupilIdentifiers/DOB, '-','')) div 10000) = 5 and (PupilIdentifiers/Sex='M' or PupilIdentifiers/Sex='F') and contains( $true, concat( ' ', PupilStatus/PartTime, ' ' ) ) ] )"/>
				</td>
				<td class="clsNumber">
					<xsl:value-of select="count(/Message/Pupils/PupilsOnRoll/PupilOnRoll[ floor(($AgeCalcDate - translate(PupilIdentifiers/DOB, '-','')) div 10000) = 5 ] )"/>
				</td>
			</tr>
			<tr>
				<td class="clsHeading">4 (8 - 11 months)</td>
				<td class="clsSubhead">
					<xsl:value-of select="$dt01Sep"/>
					<xsl:value-of select="$AcademicYear - 5"/> - <xsl:value-of select="$dt31Dec"/>
					<xsl:value-of select="$AcademicYear - 5"/>
				</td>
				<td class="clsNumber">
					<xsl:value-of select="count(/Message/Pupils/PupilsOnRoll/PupilOnRoll[ floor(($AgeCalcDate - translate(PupilIdentifiers/DOB, '-','')) div 10000) = 4 and PupilIdentifiers/Sex='M' and contains( $false, concat( ' ', PupilStatus/PartTime, ' ' ) ) and (substring( PupilIdentifiers/DOB, 6, 2 ) &gt; 8 and substring( PupilIdentifiers/DOB, 6, 2 ) &lt;= 12) ] )"/>
				</td>
				<td class="clsNumber">
					<xsl:value-of select="count(/Message/Pupils/PupilsOnRoll/PupilOnRoll[ floor(($AgeCalcDate - translate(PupilIdentifiers/DOB, '-','')) div 10000) = 4 and PupilIdentifiers/Sex='F' and contains( $false, concat( ' ', PupilStatus/PartTime, ' ' ) )  and (substring( PupilIdentifiers/DOB, 6, 2 ) &gt; 8 and substring( PupilIdentifiers/DOB, 6, 2 ) &lt;= 12) ] )"/>
				</td>
				<td class="clsNumber">
					<xsl:value-of select="count(/Message/Pupils/PupilsOnRoll/PupilOnRoll[ floor(($AgeCalcDate - translate(PupilIdentifiers/DOB, '-','')) div 10000) = 4 and (PupilIdentifiers/Sex='M' or PupilIdentifiers/Sex='F') and contains( $false, concat( ' ', PupilStatus/PartTime, ' ' ) ) and (substring( PupilIdentifiers/DOB, 6, 2 ) &gt; 8 and substring( PupilIdentifiers/DOB, 6, 2 ) &lt;= 12) ] )"/>
				</td>
				<td class="clsNumber">
					<xsl:value-of select="count(/Message/Pupils/PupilsOnRoll/PupilOnRoll[ floor(($AgeCalcDate - translate(PupilIdentifiers/DOB, '-','')) div 10000) = 4 and PupilIdentifiers/Sex='M' and contains( $true, concat( ' ', PupilStatus/PartTime, ' ' ) )	  and (substring( PupilIdentifiers/DOB, 6, 2 ) &gt; 8 and substring( PupilIdentifiers/DOB, 6, 2 ) &lt;= 12) ] )"/>
				</td>
				<td class="clsNumber">
					<xsl:value-of select="count(/Message/Pupils/PupilsOnRoll/PupilOnRoll[ floor(($AgeCalcDate - translate(PupilIdentifiers/DOB, '-','')) div 10000) = 4 and PupilIdentifiers/Sex='F' and contains( $true, concat( ' ', PupilStatus/PartTime, ' ' ) )	  and (substring( PupilIdentifiers/DOB, 6, 2 ) &gt; 8 and substring( PupilIdentifiers/DOB, 6, 2 ) &lt;= 12) ] )"/>
				</td>
				<td class="clsNumber">
					<xsl:value-of select="count(/Message/Pupils/PupilsOnRoll/PupilOnRoll[ floor(($AgeCalcDate - translate(PupilIdentifiers/DOB, '-','')) div 10000) = 4 and (PupilIdentifiers/Sex='M' or PupilIdentifiers/Sex='F') and contains( $true, concat( ' ', PupilStatus/PartTime, ' ' ) )	  and (substring( PupilIdentifiers/DOB, 6, 2 ) &gt; 8 and substring( PupilIdentifiers/DOB, 6, 2 ) &lt;= 12) ] )"/>
				</td>
				<td class="clsNumber">
					<xsl:value-of select="count(/Message/Pupils/PupilsOnRoll/PupilOnRoll[ floor(($AgeCalcDate - translate(PupilIdentifiers/DOB, '-','')) div 10000) = 4 and (substring( PupilIdentifiers/DOB, 6, 2 ) &gt; 8 and substring( PupilIdentifiers/DOB, 6, 2 ) &lt;= 12) ] )"/>
				</td>
			</tr>
			<tr>
				<td class="clsHeading">4 (5 - 7 months)</td>
				<td class="clsSubhead">
					<xsl:value-of select="$dt01Jan"/>
					<xsl:value-of select="$AcademicYear - 4"/> - <xsl:value-of select="$dt31Mar"/>
					<xsl:value-of select="$AcademicYear - 4"/>
				</td>
				<td class="clsNumber">
					<xsl:value-of select="count(/Message/Pupils/PupilsOnRoll/PupilOnRoll[ floor(($AgeCalcDate - translate(PupilIdentifiers/DOB, '-','')) div 10000) = 4 and PupilIdentifiers/Sex='M' and contains( $false, concat( ' ', PupilStatus/PartTime, ' ' ) ) and (substring( PupilIdentifiers/DOB, 6, 2 ) &gt;= 1 and substring( PupilIdentifiers/DOB, 6, 2 ) &lt; 4) ] )"/>
				</td>
				<td class="clsNumber">
					<xsl:value-of select="count(/Message/Pupils/PupilsOnRoll/PupilOnRoll[ floor(($AgeCalcDate - translate(PupilIdentifiers/DOB, '-','')) div 10000) = 4 and PupilIdentifiers/Sex='F' and contains( $false, concat( ' ', PupilStatus/PartTime, ' ' ) )  and (substring( PupilIdentifiers/DOB, 6, 2 ) &gt;= 1 and substring( PupilIdentifiers/DOB, 6, 2 ) &lt; 4) ] )"/>
				</td>
				<td class="clsNumber">
					<xsl:value-of select="count(/Message/Pupils/PupilsOnRoll/PupilOnRoll[ floor(($AgeCalcDate - translate(PupilIdentifiers/DOB, '-','')) div 10000) = 4 and (PupilIdentifiers/Sex='M' or PupilIdentifiers/Sex='F') and contains( $false, concat( ' ', PupilStatus/PartTime, ' ' ) ) and (substring( PupilIdentifiers/DOB, 6, 2 ) &gt;= 1 and substring( PupilIdentifiers/DOB, 6, 2 ) &lt; 4) ] )"/>
				</td>
				<td class="clsNumber">
					<xsl:value-of select="count(/Message/Pupils/PupilsOnRoll/PupilOnRoll[ floor(($AgeCalcDate - translate(PupilIdentifiers/DOB, '-','')) div 10000) = 4 and PupilIdentifiers/Sex='M' and contains( $true, concat( ' ', PupilStatus/PartTime, ' ' ) )	  and (substring( PupilIdentifiers/DOB, 6, 2 ) &gt;= 1 and substring( PupilIdentifiers/DOB, 6, 2 ) &lt; 4) ] )"/>
				</td>
				<td class="clsNumber">
					<xsl:value-of select="count(/Message/Pupils/PupilsOnRoll/PupilOnRoll[ floor(($AgeCalcDate - translate(PupilIdentifiers/DOB, '-','')) div 10000) = 4 and PupilIdentifiers/Sex='F' and contains( $true, concat( ' ', PupilStatus/PartTime, ' ' ) ) 	  and (substring( PupilIdentifiers/DOB, 6, 2 ) &gt;= 1 and substring( PupilIdentifiers/DOB, 6, 2 ) &lt; 4) ] )"/>
				</td>
				<td class="clsNumber">
					<xsl:value-of select="count(/Message/Pupils/PupilsOnRoll/PupilOnRoll[ floor(($AgeCalcDate - translate(PupilIdentifiers/DOB, '-','')) div 10000) = 4 and (PupilIdentifiers/Sex='M' or PupilIdentifiers/Sex='F') and contains( $true, concat( ' ', PupilStatus/PartTime, ' ' ) )	  and (substring( PupilIdentifiers/DOB, 6, 2 ) &gt;= 1 and substring( PupilIdentifiers/DOB, 6, 2 ) &lt; 4) ] )"/>
				</td>
				<td class="clsNumber">
					<xsl:value-of select="count(/Message/Pupils/PupilsOnRoll/PupilOnRoll[ floor(($AgeCalcDate - translate(PupilIdentifiers/DOB, '-','')) div 10000) = 4  and (substring( PupilIdentifiers/DOB, 6, 2 ) &gt;= 1 and substring( PupilIdentifiers/DOB, 6, 2 ) &lt; 4) ] )"/>
				</td>
			</tr>
			<tr>
				<td class="clsHeading">4 (0 - 4 months)</td>
				<td class="clsSubhead">
					<xsl:value-of select="$dt01Apr"/>
					<xsl:value-of select="$AcademicYear - 4"/> - <xsl:value-of select="$dt31Aug"/>
					<xsl:value-of select="$AcademicYear - 4"/>
				</td>
				<td class="clsNumber">
					<xsl:value-of select="count(/Message/Pupils/PupilsOnRoll/PupilOnRoll[ floor(($AgeCalcDate - translate(PupilIdentifiers/DOB, '-','')) div 10000) = 4 and PupilIdentifiers/Sex='M' and contains( $false, concat( ' ', PupilStatus/PartTime, ' ' ) ) and (substring( PupilIdentifiers/DOB, 6, 2 ) &gt; 3 and substring( PupilIdentifiers/DOB, 6, 2 ) &lt; 9) ] )"/>
				</td>
				<td class="clsNumber">
					<xsl:value-of select="count(/Message/Pupils/PupilsOnRoll/PupilOnRoll[ floor(($AgeCalcDate - translate(PupilIdentifiers/DOB, '-','')) div 10000) = 4 and PupilIdentifiers/Sex='F' and contains( $false, concat( ' ', PupilStatus/PartTime, ' ' ) )  and (substring( PupilIdentifiers/DOB, 6, 2 ) &gt; 3 and substring( PupilIdentifiers/DOB, 6, 2 ) &lt; 9) ] )"/>
				</td>
				<td class="clsNumber">
					<xsl:value-of select="count(/Message/Pupils/PupilsOnRoll/PupilOnRoll[ floor(($AgeCalcDate - translate(PupilIdentifiers/DOB, '-','')) div 10000) = 4 and (PupilIdentifiers/Sex='M' or PupilIdentifiers/Sex='F') and contains( $false, concat( ' ', PupilStatus/PartTime, ' ' ) ) and (substring( PupilIdentifiers/DOB, 6, 2 ) &gt; 3 and substring( PupilIdentifiers/DOB, 6, 2 ) &lt; 9) ] )"/>
				</td>
				<td class="clsNumber">
					<xsl:value-of select="count(/Message/Pupils/PupilsOnRoll/PupilOnRoll[ floor(($AgeCalcDate - translate(PupilIdentifiers/DOB, '-','')) div 10000) = 4 and PupilIdentifiers/Sex='M' and contains( $true, concat( ' ', PupilStatus/PartTime, ' ' ) )   and (substring( PupilIdentifiers/DOB, 6, 2 ) &gt; 3 and substring( PupilIdentifiers/DOB, 6, 2 ) &lt; 9) ] )"/>
				</td>
				<td class="clsNumber">
					<xsl:value-of select="count(/Message/Pupils/PupilsOnRoll/PupilOnRoll[ floor(($AgeCalcDate - translate(PupilIdentifiers/DOB, '-','')) div 10000) = 4 and PupilIdentifiers/Sex='F' and contains( $true, concat( ' ', PupilStatus/PartTime, ' ' ) )	  and (substring( PupilIdentifiers/DOB, 6, 2 ) &gt; 3 and substring( PupilIdentifiers/DOB, 6, 2 ) &lt; 9) ] )"/>
				</td>
				<td class="clsNumber">
					<xsl:value-of select="count(/Message/Pupils/PupilsOnRoll/PupilOnRoll[ floor(($AgeCalcDate - translate(PupilIdentifiers/DOB, '-','')) div 10000) = 4 and (PupilIdentifiers/Sex='M' or PupilIdentifiers/Sex='F') and contains( $true, concat( ' ', PupilStatus/PartTime, ' ' ) )   and (substring( PupilIdentifiers/DOB, 6, 2 ) &gt; 3 and substring( PupilIdentifiers/DOB, 6, 2 ) &lt; 9) ] )"/>
				</td>
				<td class="clsNumber">
					<xsl:value-of select="count(/Message/Pupils/PupilsOnRoll/PupilOnRoll[ floor(($AgeCalcDate - translate(PupilIdentifiers/DOB, '-','')) div 10000) = 4 and (substring( PupilIdentifiers/DOB, 6, 2 ) &gt; 3 and substring( PupilIdentifiers/DOB, 6, 2 ) &lt; 9) ] )"/>
				</td>
			</tr>
			<tr>
				<td class="clsHeading">3 (8 - 11 months)</td>
				<td class="clsSubhead">
					<xsl:value-of select="$dt01Sep"/>
					<xsl:value-of select="$AcademicYear - 4"/> - <xsl:value-of select="$dt31Dec"/>
					<xsl:value-of select="$AcademicYear - 4"/>
				</td>
				<td class="clsNumber">
					<xsl:value-of select="count(/Message/Pupils/PupilsOnRoll/PupilOnRoll[ floor(($AgeCalcDate - translate(PupilIdentifiers/DOB, '-','')) div 10000) = 3 and PupilIdentifiers/Sex='M' and contains( $false, concat( ' ', PupilStatus/PartTime, ' ' ) ) and (substring( PupilIdentifiers/DOB, 6, 2 ) &gt; 8 and substring( PupilIdentifiers/DOB, 6, 2 ) &lt;= 12) ] )"/>
				</td>
				<td class="clsNumber">
					<xsl:value-of select="count(/Message/Pupils/PupilsOnRoll/PupilOnRoll[ floor(($AgeCalcDate - translate(PupilIdentifiers/DOB, '-','')) div 10000) = 3 and PupilIdentifiers/Sex='F' and contains( $false, concat( ' ', PupilStatus/PartTime, ' ' ) )  and (substring( PupilIdentifiers/DOB, 6, 2 ) &gt; 8 and substring( PupilIdentifiers/DOB, 6, 2 ) &lt;= 12) ] )"/>
				</td>
				<td class="clsNumber">
					<xsl:value-of select="count(/Message/Pupils/PupilsOnRoll/PupilOnRoll[ floor(($AgeCalcDate - translate(PupilIdentifiers/DOB, '-','')) div 10000) = 3 and (PupilIdentifiers/Sex='M' or PupilIdentifiers/Sex='F') and contains( $false, concat( ' ', PupilStatus/PartTime, ' ' ) ) and (substring( PupilIdentifiers/DOB, 6, 2 ) &gt; 8 and substring( PupilIdentifiers/DOB, 6, 2 ) &lt;= 12) ] )"/>
				</td>
				<td class="clsNumber">
					<xsl:value-of select="count(/Message/Pupils/PupilsOnRoll/PupilOnRoll[ floor(($AgeCalcDate - translate(PupilIdentifiers/DOB, '-','')) div 10000) = 3 and PupilIdentifiers/Sex='M' and contains( $true, concat( ' ', PupilStatus/PartTime, ' ' ) )	  and (substring( PupilIdentifiers/DOB, 6, 2 ) &gt; 8 and substring( PupilIdentifiers/DOB, 6, 2 ) &lt;= 12) ] )"/>
				</td>
				<td class="clsNumber">
					<xsl:value-of select="count(/Message/Pupils/PupilsOnRoll/PupilOnRoll[ floor(($AgeCalcDate - translate(PupilIdentifiers/DOB, '-','')) div 10000) = 3 and PupilIdentifiers/Sex='F' and contains( $true, concat( ' ', PupilStatus/PartTime, ' ' ) )	  and (substring( PupilIdentifiers/DOB, 6, 2 ) &gt; 8 and substring( PupilIdentifiers/DOB, 6, 2 ) &lt;= 12) ] )"/>
				</td>
				<td class="clsNumber">
					<xsl:value-of select="count(/Message/Pupils/PupilsOnRoll/PupilOnRoll[ floor(($AgeCalcDate - translate(PupilIdentifiers/DOB, '-','')) div 10000) = 3 and (PupilIdentifiers/Sex='M' or PupilIdentifiers/Sex='F') and contains( $true, concat( ' ', PupilStatus/PartTime, ' ' ) )	  and (substring( PupilIdentifiers/DOB, 6, 2 ) &gt; 8 and substring( PupilIdentifiers/DOB, 6, 2 ) &lt;= 12) ] )"/>
				</td>
				<td class="clsNumber">
					<xsl:value-of select="count(/Message/Pupils/PupilsOnRoll/PupilOnRoll[ floor(($AgeCalcDate - translate(PupilIdentifiers/DOB, '-','')) div 10000) = 3  and (substring( PupilIdentifiers/DOB, 6, 2 ) &gt; 8 and substring( PupilIdentifiers/DOB, 6, 2 ) &lt;= 12) ] )"/>
				</td>
			</tr>
			<tr>
				<td class="clsHeading">3 (5 - 7 months)</td>
				<td class="clsSubhead">
					<xsl:value-of select="$dt01Jan"/>
					<xsl:value-of select="$AcademicYear - 3"/> - <xsl:value-of select="$dt31Mar"/>
					<xsl:value-of select="$AcademicYear - 3"/>
				</td>
				<td class="clsNumber">
					<xsl:value-of select="count(/Message/Pupils/PupilsOnRoll/PupilOnRoll[ floor(($AgeCalcDate - translate(PupilIdentifiers/DOB, '-','')) div 10000) = 3 and PupilIdentifiers/Sex='M' and contains( $false, concat( ' ', PupilStatus/PartTime, ' ' ) ) and (substring( PupilIdentifiers/DOB, 6, 2 ) &gt;= 1 and substring( PupilIdentifiers/DOB, 6, 2 ) &lt; 4) ] )"/>
				</td>
				<td class="clsNumber">
					<xsl:value-of select="count(/Message/Pupils/PupilsOnRoll/PupilOnRoll[ floor(($AgeCalcDate - translate(PupilIdentifiers/DOB, '-','')) div 10000) = 3 and PupilIdentifiers/Sex='F' and contains( $false, concat( ' ', PupilStatus/PartTime, ' ' ) )  and (substring( PupilIdentifiers/DOB, 6, 2 ) &gt;= 1 and substring( PupilIdentifiers/DOB, 6, 2 ) &lt; 4) ] )"/>
				</td>
				<td class="clsNumber">
					<xsl:value-of select="count(/Message/Pupils/PupilsOnRoll/PupilOnRoll[ floor(($AgeCalcDate - translate(PupilIdentifiers/DOB, '-','')) div 10000) = 3 and (PupilIdentifiers/Sex='M' or PupilIdentifiers/Sex='F') and contains( $false, concat( ' ', PupilStatus/PartTime, ' ' ) ) and (substring( PupilIdentifiers/DOB, 6, 2 ) &gt;= 1 and substring( PupilIdentifiers/DOB, 6, 2 ) &lt; 4) ] )"/>
				</td>
				<td class="clsNumber">
					<xsl:value-of select="count(/Message/Pupils/PupilsOnRoll/PupilOnRoll[ floor(($AgeCalcDate - translate(PupilIdentifiers/DOB, '-','')) div 10000) = 3 and PupilIdentifiers/Sex='M' and contains( $true, concat( ' ', PupilStatus/PartTime, ' ' ) )	  and (substring( PupilIdentifiers/DOB, 6, 2 ) &gt;= 1 and substring( PupilIdentifiers/DOB, 6, 2 ) &lt; 4) ] )"/>
				</td>
				<td class="clsNumber">
					<xsl:value-of select="count(/Message/Pupils/PupilsOnRoll/PupilOnRoll[ floor(($AgeCalcDate - translate(PupilIdentifiers/DOB, '-','')) div 10000) = 3 and PupilIdentifiers/Sex='F' and contains( $true, concat( ' ', PupilStatus/PartTime, ' ' ) ) 	  and (substring( PupilIdentifiers/DOB, 6, 2 ) &gt;= 1 and substring( PupilIdentifiers/DOB, 6, 2 ) &lt; 4) ] )"/>
				</td>
				<td class="clsNumber">
					<xsl:value-of select="count(/Message/Pupils/PupilsOnRoll/PupilOnRoll[ floor(($AgeCalcDate - translate(PupilIdentifiers/DOB, '-','')) div 10000) = 3 and (PupilIdentifiers/Sex='M' or PupilIdentifiers/Sex='F') and contains( $true, concat( ' ', PupilStatus/PartTime, ' ' ) )	  and (substring( PupilIdentifiers/DOB, 6, 2 ) &gt;= 1 and substring( PupilIdentifiers/DOB, 6, 2 ) &lt; 4) ] )"/>
				</td>
				<td class="clsNumber">
					<xsl:value-of select="count(/Message/Pupils/PupilsOnRoll/PupilOnRoll[ floor(($AgeCalcDate - translate(PupilIdentifiers/DOB, '-','')) div 10000) = 3 and (substring( PupilIdentifiers/DOB, 6, 2 ) &gt;= 1 and substring( PupilIdentifiers/DOB, 6, 2 ) &lt; 4) ] )"/>
				</td>
			</tr>
			<tr>
				<td class="clsHeading">3 (0 - 4 months)</td>
				<td class="clsSubhead">
					<xsl:value-of select="$dt01Apr"/>
					<xsl:value-of select="$AcademicYear - 3"/> - <xsl:value-of select="$dt31Aug"/>
					<xsl:value-of select="$AcademicYear - 3"/>
				</td>
				<td class="clsNumber">
					<xsl:value-of select="count(/Message/Pupils/PupilsOnRoll/PupilOnRoll[ floor(($AgeCalcDate - translate(PupilIdentifiers/DOB, '-','')) div 10000) = 3 and PupilIdentifiers/Sex='M' and contains( $false, concat( ' ', PupilStatus/PartTime, ' ' ) ) and (substring( PupilIdentifiers/DOB, 6, 2 ) &gt; 3 and substring( PupilIdentifiers/DOB, 6, 2 ) &lt; 9) ] )"/>
				</td>
				<td class="clsNumber">
					<xsl:value-of select="count(/Message/Pupils/PupilsOnRoll/PupilOnRoll[ floor(($AgeCalcDate - translate(PupilIdentifiers/DOB, '-','')) div 10000) = 3 and PupilIdentifiers/Sex='F' and contains( $false, concat( ' ', PupilStatus/PartTime, ' ' ) )  and (substring( PupilIdentifiers/DOB, 6, 2 ) &gt; 3 and substring( PupilIdentifiers/DOB, 6, 2 ) &lt; 9) ] )"/>
				</td>
				<td class="clsNumber">
					<xsl:value-of select="count(/Message/Pupils/PupilsOnRoll/PupilOnRoll[ floor(($AgeCalcDate - translate(PupilIdentifiers/DOB, '-','')) div 10000) = 3 and (PupilIdentifiers/Sex='M' or PupilIdentifiers/Sex='F') and contains( $false, concat( ' ', PupilStatus/PartTime, ' ' ) ) and (substring( PupilIdentifiers/DOB, 6, 2 ) &gt; 3 and substring( PupilIdentifiers/DOB, 6, 2 ) &lt; 9) ] )"/>
				</td>
				<td class="clsNumber">
					<xsl:value-of select="count(/Message/Pupils/PupilsOnRoll/PupilOnRoll[ floor(($AgeCalcDate - translate(PupilIdentifiers/DOB, '-','')) div 10000) = 3 and PupilIdentifiers/Sex='M' and contains( $true, concat( ' ', PupilStatus/PartTime, ' ' ) )   and (substring( PupilIdentifiers/DOB, 6, 2 ) &gt; 3 and substring( PupilIdentifiers/DOB, 6, 2 ) &lt; 9) ] )"/>
				</td>
				<td class="clsNumber">
					<xsl:value-of select="count(/Message/Pupils/PupilsOnRoll/PupilOnRoll[ floor(($AgeCalcDate - translate(PupilIdentifiers/DOB, '-','')) div 10000) = 3 and PupilIdentifiers/Sex='F' and contains( $true, concat( ' ', PupilStatus/PartTime, ' ' ) )	  and (substring( PupilIdentifiers/DOB, 6, 2 ) &gt; 3 and substring( PupilIdentifiers/DOB, 6, 2 ) &lt; 9) ] )"/>
				</td>
				<td class="clsNumber">
					<xsl:value-of select="count(/Message/Pupils/PupilsOnRoll/PupilOnRoll[ floor(($AgeCalcDate - translate(PupilIdentifiers/DOB, '-','')) div 10000) = 3 and (PupilIdentifiers/Sex='M' or PupilIdentifiers/Sex='F') and contains( $true, concat( ' ', PupilStatus/PartTime, ' ' ) )   and (substring( PupilIdentifiers/DOB, 6, 2 ) &gt; 3 and substring( PupilIdentifiers/DOB, 6, 2 ) &lt; 9) ] )"/>
				</td>
				<td class="clsNumber">
					<xsl:value-of select="count(/Message/Pupils/PupilsOnRoll/PupilOnRoll[ floor(($AgeCalcDate - translate(PupilIdentifiers/DOB, '-','')) div 10000) = 3  and (substring( PupilIdentifiers/DOB, 6, 2 ) &gt; 3 and substring( PupilIdentifiers/DOB, 6, 2 ) &lt; 9) ] )"/>
				</td>
			</tr>
			<tr>
				<td class="clsHeading">2 or under</td>
				<td class="clsSubhead">
					<xsl:value-of select="$dt01Sep"/>
					<xsl:value-of select="$AcademicYear - 3"/> or later</td>
				<td class="clsNumber">
					<xsl:value-of select="count(/Message/Pupils/PupilsOnRoll/PupilOnRoll[ floor(($AgeCalcDate - translate(PupilIdentifiers/DOB, '-','')) div 10000) &lt;= 2 and PupilIdentifiers/Sex='M' and contains( $false, concat( ' ', PupilStatus/PartTime, ' ' ) ) ] )"/>
				</td>
				<td class="clsNumber">
					<xsl:value-of select="count(/Message/Pupils/PupilsOnRoll/PupilOnRoll[ floor(($AgeCalcDate - translate(PupilIdentifiers/DOB, '-','')) div 10000) &lt;= 2 and PupilIdentifiers/Sex='F' and contains( $false, concat( ' ', PupilStatus/PartTime, ' ' ) ) ] )"/>
				</td>
				<td class="clsNumber">
					<xsl:value-of select="count(/Message/Pupils/PupilsOnRoll/PupilOnRoll[ floor(($AgeCalcDate - translate(PupilIdentifiers/DOB, '-','')) div 10000) &lt;= 2 and (PupilIdentifiers/Sex='M' or PupilIdentifiers/Sex='F') and contains( $false, concat( ' ', PupilStatus/PartTime, ' ' ) ) ] )"/>
				</td>
				<td class="clsNumber">
					<xsl:value-of select="count(/Message/Pupils/PupilsOnRoll/PupilOnRoll[ floor(($AgeCalcDate - translate(PupilIdentifiers/DOB, '-','')) div 10000) &lt;= 2 and PupilIdentifiers/Sex='M' and contains( $true, concat( ' ', PupilStatus/PartTime, ' ' ) ) ] )"/>
				</td>
				<td class="clsNumber">
					<xsl:value-of select="count(/Message/Pupils/PupilsOnRoll/PupilOnRoll[ floor(($AgeCalcDate - translate(PupilIdentifiers/DOB, '-','')) div 10000) &lt;= 2 and PupilIdentifiers/Sex='F' and contains( $true, concat( ' ', PupilStatus/PartTime, ' ' ) ) ] )"/>
				</td>
				<td class="clsNumber">
					<xsl:value-of select="count(/Message/Pupils/PupilsOnRoll/PupilOnRoll[ floor(($AgeCalcDate - translate(PupilIdentifiers/DOB, '-','')) div 10000) &lt;= 2 and (PupilIdentifiers/Sex='M' or PupilIdentifiers/Sex='F') and contains( $true, concat( ' ', PupilStatus/PartTime, ' ' ) ) ] )"/>
				</td>
				<td class="clsNumber">
					<xsl:value-of select="count(/Message/Pupils/PupilsOnRoll/PupilOnRoll[ floor(($AgeCalcDate - translate(PupilIdentifiers/DOB, '-','')) div 10000) &lt;= 2 ] )"/>
				</td>
			</tr>
			<tr>
				<td class="clsHeading" colspan="2">Total number of pupils</td>
				<td class="clsTotal">
					<xsl:value-of select="count(/Message/Pupils/PupilsOnRoll/PupilOnRoll[ PupilIdentifiers/Sex='M' and contains( $false, concat( ' ', PupilStatus/PartTime, ' ' ) ) ] )"/>
				</td>
				<td class="clsTotal">
					<xsl:value-of select="count(/Message/Pupils/PupilsOnRoll/PupilOnRoll[ PupilIdentifiers/Sex='F' and contains( $false, concat( ' ', PupilStatus/PartTime, ' ' ) ) ] )"/>
				</td>
				<td class="clsTotal">
					<xsl:value-of select="$b10"/>
				</td>
				<td class="clsTotal">
					<xsl:value-of select="count(/Message/Pupils/PupilsOnRoll/PupilOnRoll[ PupilIdentifiers/Sex='M' and contains( $true, concat( ' ', PupilStatus/PartTime, ' ' ) ) ] )"/>
				</td>
				<td class="clsTotal">
					<xsl:value-of select="count(/Message/Pupils/PupilsOnRoll/PupilOnRoll[ PupilIdentifiers/Sex='F' and contains( $true, concat( ' ', PupilStatus/PartTime, ' ' ) ) ] )"/>
				</td>
				<td class="clsTotal">
					<xsl:value-of select="$b13"/>
				</td>
				<td class="clsTotal">
					<xsl:value-of select="$b10 + $b13"/>
				</td>
			</tr>
			<tr>
				<td class="clsHeading">Aged 16 and over</td>
				<td class="clsSubHead">
					<xsl:value-of select="$dt31Aug"/>
					<xsl:value-of select="$AcademicYear - 16"/> or earlier</td>
				<td class="clsNumber">
					<xsl:value-of select="count(/Message/Pupils/PupilsOnRoll/PupilOnRoll[ floor(($AgeCalcDate - translate(PupilIdentifiers/DOB, '-','')) div 10000) &gt;= 16 and PupilIdentifiers/Sex='M' and contains( $false, concat( ' ', PupilStatus/PartTime, ' ' ) ) ] )"/>
				</td>
				<td class="clsNumber">
					<xsl:value-of select="count(/Message/Pupils/PupilsOnRoll/PupilOnRoll[ floor(($AgeCalcDate - translate(PupilIdentifiers/DOB, '-','')) div 10000) &gt;= 16 and PupilIdentifiers/Sex='F' and contains( $false, concat( ' ', PupilStatus/PartTime, ' ' ) ) ] )"/>
				</td>
				<td class="clsNumber">
					<xsl:value-of select="count(/Message/Pupils/PupilsOnRoll/PupilOnRoll[ floor(($AgeCalcDate - translate(PupilIdentifiers/DOB, '-','')) div 10000) &gt;= 16 and (PupilIdentifiers/Sex='M' or PupilIdentifiers/Sex='F') and contains( $false, concat( ' ', PupilStatus/PartTime, ' ' ) ) ] )"/>
				</td>
				<td class="clsNumber">
					<xsl:value-of select="count(/Message/Pupils/PupilsOnRoll/PupilOnRoll[ floor(($AgeCalcDate - translate(PupilIdentifiers/DOB, '-','')) div 10000) &gt;= 16 and PupilIdentifiers/Sex='M' and contains( $true, concat( ' ', PupilStatus/PartTime, ' ' ) ) ] )"/>
				</td>
				<td class="clsNumber">
					<xsl:value-of select="count(/Message/Pupils/PupilsOnRoll/PupilOnRoll[ floor(($AgeCalcDate - translate(PupilIdentifiers/DOB, '-','')) div 10000) &gt;= 16 and PupilIdentifiers/Sex='F' and contains( $true, concat( ' ', PupilStatus/PartTime, ' ' ) ) ] )"/>
				</td>
				<td class="clsNumber">
					<xsl:value-of select="count(/Message/Pupils/PupilsOnRoll/PupilOnRoll[ floor(($AgeCalcDate - translate(PupilIdentifiers/DOB, '-','')) div 10000) &gt;= 16 and (PupilIdentifiers/Sex='M' or PupilIdentifiers/Sex='F') and contains( $true, concat( ' ', PupilStatus/PartTime, ' ' ) ) ] )"/>
				</td>
				<td class="clsNumber">
					<xsl:value-of select="count(/Message/Pupils/PupilsOnRoll/PupilOnRoll[ floor(($AgeCalcDate - translate(PupilIdentifiers/DOB, '-','')) div 10000) &gt;= 16 ] )"/>
				</td>
			</tr>
			<tr>
				<td class="clsHeading">Aged 11 to 15</td>
				<td class="clsSubHead">
					<xsl:value-of select="$dt01Sep"/>
					<xsl:value-of select="$AcademicYear - 16"/> - <xsl:value-of select="$dt31Aug"/>
					<xsl:value-of select="$AcademicYear - 11"/>
				</td>
				<td class="clsNumber">
					<xsl:value-of select="count(/Message/Pupils/PupilsOnRoll/PupilOnRoll[ floor(($AgeCalcDate - translate(PupilIdentifiers/DOB, '-','')) div 10000) &gt;= 11 and floor(($AgeCalcDate - translate(PupilIdentifiers/DOB, '-','')) div 10000) &lt;= 15 and PupilIdentifiers/Sex='M' and contains( $false, concat( ' ', PupilStatus/PartTime, ' ' ) ) ] )"/>
				</td>
				<td class="clsNumber">
					<xsl:value-of select="count(/Message/Pupils/PupilsOnRoll/PupilOnRoll[ floor(($AgeCalcDate - translate(PupilIdentifiers/DOB, '-','')) div 10000) &gt;= 11 and floor(($AgeCalcDate - translate(PupilIdentifiers/DOB, '-','')) div 10000) &lt;= 15 and PupilIdentifiers/Sex='F' and contains( $false, concat( ' ', PupilStatus/PartTime, ' ' ) ) ] )"/>
				</td>
				<td class="clsNumber">
					<xsl:value-of select="count(/Message/Pupils/PupilsOnRoll/PupilOnRoll[ floor(($AgeCalcDate - translate(PupilIdentifiers/DOB, '-','')) div 10000) &gt;= 11 and floor(($AgeCalcDate - translate(PupilIdentifiers/DOB, '-','')) div 10000) &lt;= 15 and (PupilIdentifiers/Sex='M' or PupilIdentifiers/Sex='F') and contains( $false, concat( ' ', PupilStatus/PartTime, ' ' ) ) ] )"/>
				</td>
				<td class="clsNumber">
					<xsl:value-of select="count(/Message/Pupils/PupilsOnRoll/PupilOnRoll[ floor(($AgeCalcDate - translate(PupilIdentifiers/DOB, '-','')) div 10000) &gt;= 11 and floor(($AgeCalcDate - translate(PupilIdentifiers/DOB, '-','')) div 10000) &lt;= 15 and PupilIdentifiers/Sex='M' and contains( $true, concat( ' ', PupilStatus/PartTime, ' ' ) ) ] )"/>
				</td>
				<td class="clsNumber">
					<xsl:value-of select="count(/Message/Pupils/PupilsOnRoll/PupilOnRoll[ floor(($AgeCalcDate - translate(PupilIdentifiers/DOB, '-','')) div 10000) &gt;= 11 and floor(($AgeCalcDate - translate(PupilIdentifiers/DOB, '-','')) div 10000) &lt;= 15 and PupilIdentifiers/Sex='F' and contains( $true, concat( ' ', PupilStatus/PartTime, ' ' ) ) ] )"/>
				</td>
				<td class="clsNumber">
					<xsl:value-of select="count(/Message/Pupils/PupilsOnRoll/PupilOnRoll[ floor(($AgeCalcDate - translate(PupilIdentifiers/DOB, '-','')) div 10000) &gt;= 11 and floor(($AgeCalcDate - translate(PupilIdentifiers/DOB, '-','')) div 10000) &lt;= 15 and (PupilIdentifiers/Sex='M' or PupilIdentifiers/Sex='F') and contains( $true, concat( ' ', PupilStatus/PartTime, ' ' ) ) ] )"/>
				</td>
				<td class="clsNumber">
					<xsl:value-of select="count(/Message/Pupils/PupilsOnRoll/PupilOnRoll[ floor(($AgeCalcDate - translate(PupilIdentifiers/DOB, '-','')) div 10000) &gt;= 11 and floor(($AgeCalcDate - translate(PupilIdentifiers/DOB, '-','')) div 10000) &lt;= 15 ] )"/>
				</td>
			</tr>
			<tr>
				<td class="clsHeading">Aged 5 to 10</td>
				<td class="clsSubHead">
					<xsl:value-of select="$dt01Sep"/>
					<xsl:value-of select="$AcademicYear - 11"/> - <xsl:value-of select="$dt31Aug"/>
					<xsl:value-of select="$AcademicYear - 5"/>
				</td>
				<td class="clsNumber">
					<xsl:value-of select="count(/Message/Pupils/PupilsOnRoll/PupilOnRoll[ floor(($AgeCalcDate - translate(PupilIdentifiers/DOB, '-','')) div 10000) &gt;= 5 and floor(($AgeCalcDate - translate(PupilIdentifiers/DOB, '-','')) div 10000) &lt;= 10 and PupilIdentifiers/Sex='M' and contains( $false, concat( ' ', PupilStatus/PartTime, ' ' ) ) ] )"/>
				</td>
				<td class="clsNumber">
					<xsl:value-of select="count(/Message/Pupils/PupilsOnRoll/PupilOnRoll[ floor(($AgeCalcDate - translate(PupilIdentifiers/DOB, '-','')) div 10000) &gt;= 5 and floor(($AgeCalcDate - translate(PupilIdentifiers/DOB, '-','')) div 10000) &lt;= 10 and PupilIdentifiers/Sex='F' and contains( $false, concat( ' ', PupilStatus/PartTime, ' ' ) ) ] )"/>
				</td>
				<td class="clsNumber">
					<xsl:value-of select="count(/Message/Pupils/PupilsOnRoll/PupilOnRoll[ floor(($AgeCalcDate - translate(PupilIdentifiers/DOB, '-','')) div 10000) &gt;= 5 and floor(($AgeCalcDate - translate(PupilIdentifiers/DOB, '-','')) div 10000) &lt;= 10 and (PupilIdentifiers/Sex='M' or PupilIdentifiers/Sex='F') and contains( $false, concat( ' ', PupilStatus/PartTime, ' ' ) ) ] )"/>
				</td>
				<td class="clsNumber">
					<xsl:value-of select="count(/Message/Pupils/PupilsOnRoll/PupilOnRoll[ floor(($AgeCalcDate - translate(PupilIdentifiers/DOB, '-','')) div 10000) &gt;= 5 and floor(($AgeCalcDate - translate(PupilIdentifiers/DOB, '-','')) div 10000) &lt;= 10 and PupilIdentifiers/Sex='M' and contains( $true, concat( ' ', PupilStatus/PartTime, ' ' ) ) ] )"/>
				</td>
				<td class="clsNumber">
					<xsl:value-of select="count(/Message/Pupils/PupilsOnRoll/PupilOnRoll[ floor(($AgeCalcDate - translate(PupilIdentifiers/DOB, '-','')) div 10000) &gt;= 5 and floor(($AgeCalcDate - translate(PupilIdentifiers/DOB, '-','')) div 10000) &lt;= 10 and PupilIdentifiers/Sex='F' and contains( $true, concat( ' ', PupilStatus/PartTime, ' ' ) ) ] )"/>
				</td>
				<td class="clsNumber">
					<xsl:value-of select="count(/Message/Pupils/PupilsOnRoll/PupilOnRoll[ floor(($AgeCalcDate - translate(PupilIdentifiers/DOB, '-','')) div 10000) &gt;= 5 and floor(($AgeCalcDate - translate(PupilIdentifiers/DOB, '-','')) div 10000) &lt;= 10 and (PupilIdentifiers/Sex='M' or PupilIdentifiers/Sex='F') and contains( $true, concat( ' ', PupilStatus/PartTime, ' ' ) ) ] )"/>
				</td>
				<td class="clsNumber">
					<xsl:value-of select="count(/Message/Pupils/PupilsOnRoll/PupilOnRoll[ floor(($AgeCalcDate - translate(PupilIdentifiers/DOB, '-','')) div 10000) &gt;= 5 and floor(($AgeCalcDate - translate(PupilIdentifiers/DOB, '-','')) div 10000) &lt;= 10 ] )"/>
				</td>
			</tr>
			<tr>
				<td class="clsHeading">Aged under 5</td>
				<td class="clsSubHead">
					<xsl:value-of select="$dt01Sep"/>
					<xsl:value-of select="$AcademicYear - 5"/> and later</td>
				<td class="clsNumber">
					<xsl:value-of select="count(/Message/Pupils/PupilsOnRoll/PupilOnRoll[ floor(($AgeCalcDate - translate(PupilIdentifiers/DOB, '-','')) div 10000) &lt; 5 and PupilIdentifiers/Sex='M' and contains( $false, concat( ' ', PupilStatus/PartTime, ' ' ) ) ] )"/>
				</td>
				<td class="clsNumber">
					<xsl:value-of select="count(/Message/Pupils/PupilsOnRoll/PupilOnRoll[ floor(($AgeCalcDate - translate(PupilIdentifiers/DOB, '-','')) div 10000) &lt; 5 and PupilIdentifiers/Sex='F' and contains( $false, concat( ' ', PupilStatus/PartTime, ' ' ) ) ] )"/>
				</td>
				<td class="clsNumber">
					<xsl:value-of select="count(/Message/Pupils/PupilsOnRoll/PupilOnRoll[ floor(($AgeCalcDate - translate(PupilIdentifiers/DOB, '-','')) div 10000) &lt; 5 and (PupilIdentifiers/Sex='M' or PupilIdentifiers/Sex='F') and contains( $false, concat( ' ', PupilStatus/PartTime, ' ' ) ) ] )"/>
				</td>
				<td class="clsNumber">
					<xsl:value-of select="count(/Message/Pupils/PupilsOnRoll/PupilOnRoll[ floor(($AgeCalcDate - translate(PupilIdentifiers/DOB, '-','')) div 10000) &lt; 5 and PupilIdentifiers/Sex='M' and contains( $true, concat( ' ', PupilStatus/PartTime, ' ' ) ) ] )"/>
				</td>
				<td class="clsNumber">
					<xsl:value-of select="count(/Message/Pupils/PupilsOnRoll/PupilOnRoll[ floor(($AgeCalcDate - translate(PupilIdentifiers/DOB, '-','')) div 10000) &lt; 5 and PupilIdentifiers/Sex='F' and contains( $true, concat( ' ', PupilStatus/PartTime, ' ' ) ) ] )"/>
				</td>
				<td class="clsNumber">
					<xsl:value-of select="count(/Message/Pupils/PupilsOnRoll/PupilOnRoll[ floor(($AgeCalcDate - translate(PupilIdentifiers/DOB, '-','')) div 10000) &lt; 5 and (PupilIdentifiers/Sex='M' or PupilIdentifiers/Sex='F') and contains( $true, concat( ' ', PupilStatus/PartTime, ' ' ) ) ] )"/>
				</td>
				<td class="clsNumber">
					<xsl:value-of select="count(/Message/Pupils/PupilsOnRoll/PupilOnRoll[ floor(($AgeCalcDate - translate(PupilIdentifiers/DOB, '-','')) div 10000) &lt; 5 ] )"/>
				</td>
			</tr>
		</table>
		<br/>
		
		
		<h2>Table 3: Pupils on roll in each national curriculum year group by enrolment status [ALL schools]</h2>
		<table class="summaryreport" border="1">
			<tr>
				<th rowspan="2">NC year group</th>
				<th rowspan="2">Total number of pupils</th>
				<th colspan="5">Total number of pupils with enrolment status:</th>
			</tr>
			<tr>
				<th>'C' current <br/> (single registration <br/> at this school)</th>
				<th>'M' current main <br/> (dual registration)</th>
				<th>'S' current subsidiary <br/> (dual registration)</th>
				<th>'F' FE college</th>
				<th>'O' other provider</th>
			</tr>
			<tr>
				<td class="clsHeading">14</td>
				<td class="clsNumber">
					<xsl:value-of select="count(/Message/Pupils/PupilsOnRoll/PupilOnRoll[PupilStatus/NCyearActual = '14'] )"/>
				</td>
				<td class="clsNumber">
					<xsl:value-of select="count(/Message/Pupils/PupilsOnRoll/PupilOnRoll[PupilStatus/NCyearActual = '14' and PupilStatus/EnrolStatus = 'C'] )"/>
				</td>
				<td class="clsNumber">
					<xsl:value-of select="count(/Message/Pupils/PupilsOnRoll/PupilOnRoll[PupilStatus/NCyearActual = '14' and PupilStatus/EnrolStatus = 'M'] )"/>
				</td>
				<td class="clsNumber">
					<xsl:value-of select="count(/Message/Pupils/PupilsOnRoll/PupilOnRoll[PupilStatus/NCyearActual = '14' and PupilStatus/EnrolStatus = 'S'] )"/>
				</td>
				<td class="clsNumber">
					<xsl:value-of select="count(/Message/Pupils/PupilsOnRoll/PupilOnRoll[PupilStatus/NCyearActual = '14' and PupilStatus/EnrolStatus = 'F'] )"/>
				</td>
				<td class="clsNumber">
					<xsl:value-of select="count(/Message/Pupils/PupilsOnRoll/PupilOnRoll[PupilStatus/NCyearActual = '14' and PupilStatus/EnrolStatus = 'O'] )"/>
				</td>
			</tr>
			<tr>
				<td class="clsHeading">13</td>
				<td class="clsNumber">
					<xsl:value-of select="count(/Message/Pupils/PupilsOnRoll/PupilOnRoll[PupilStatus/NCyearActual = '13'] )"/>
				</td>
				<td class="clsNumber">
					<xsl:value-of select="count(/Message/Pupils/PupilsOnRoll/PupilOnRoll[PupilStatus/NCyearActual = '13' and PupilStatus/EnrolStatus = 'C'] )"/>
				</td>
				<td class="clsNumber">
					<xsl:value-of select="count(/Message/Pupils/PupilsOnRoll/PupilOnRoll[PupilStatus/NCyearActual = '13' and PupilStatus/EnrolStatus = 'M'] )"/>
				</td>
				<td class="clsNumber">
					<xsl:value-of select="count(/Message/Pupils/PupilsOnRoll/PupilOnRoll[PupilStatus/NCyearActual = '13' and PupilStatus/EnrolStatus = 'S'] )"/>
				</td>
				<td class="clsNumber">
					<xsl:value-of select="count(/Message/Pupils/PupilsOnRoll/PupilOnRoll[PupilStatus/NCyearActual = '13' and PupilStatus/EnrolStatus = 'F'] )"/>
				</td>
				<td class="clsNumber">
					<xsl:value-of select="count(/Message/Pupils/PupilsOnRoll/PupilOnRoll[PupilStatus/NCyearActual = '13' and PupilStatus/EnrolStatus = 'O'] )"/>
				</td>
			</tr>
			<tr>
				<td class="clsHeading">12</td>
				<td class="clsNumber">
					<xsl:value-of select="count(/Message/Pupils/PupilsOnRoll/PupilOnRoll[PupilStatus/NCyearActual = '12'] )"/>
				</td>
				<td class="clsNumber">
					<xsl:value-of select="count(/Message/Pupils/PupilsOnRoll/PupilOnRoll[PupilStatus/NCyearActual = '12' and PupilStatus/EnrolStatus = 'C'] )"/>
				</td>
				<td class="clsNumber">
					<xsl:value-of select="count(/Message/Pupils/PupilsOnRoll/PupilOnRoll[PupilStatus/NCyearActual = '12' and PupilStatus/EnrolStatus = 'M'] )"/>
				</td>
				<td class="clsNumber">
					<xsl:value-of select="count(/Message/Pupils/PupilsOnRoll/PupilOnRoll[PupilStatus/NCyearActual = '12' and PupilStatus/EnrolStatus = 'S'] )"/>
				</td>
				<td class="clsNumber">
					<xsl:value-of select="count(/Message/Pupils/PupilsOnRoll/PupilOnRoll[PupilStatus/NCyearActual = '12' and PupilStatus/EnrolStatus = 'F'] )"/>
				</td>
				<td class="clsNumber">
					<xsl:value-of select="count(/Message/Pupils/PupilsOnRoll/PupilOnRoll[PupilStatus/NCyearActual = '12' and PupilStatus/EnrolStatus = 'O'] )"/>
				</td>
			</tr>
			<tr>
				<td class="clsHeading">11</td>
				<td class="clsNumber">
					<xsl:value-of select="count(/Message/Pupils/PupilsOnRoll/PupilOnRoll[PupilStatus/NCyearActual = '11'] )"/>
				</td>
				<td class="clsNumber">
					<xsl:value-of select="count(/Message/Pupils/PupilsOnRoll/PupilOnRoll[PupilStatus/NCyearActual = '11' and PupilStatus/EnrolStatus = 'C'] )"/>
				</td>
				<td class="clsNumber">
					<xsl:value-of select="count(/Message/Pupils/PupilsOnRoll/PupilOnRoll[PupilStatus/NCyearActual = '11' and PupilStatus/EnrolStatus = 'M'] )"/>
				</td>
				<td class="clsNumber">
					<xsl:value-of select="count(/Message/Pupils/PupilsOnRoll/PupilOnRoll[PupilStatus/NCyearActual = '11' and PupilStatus/EnrolStatus = 'S'] )"/>
				</td>
				<td class="clsNumber">
					<xsl:value-of select="count(/Message/Pupils/PupilsOnRoll/PupilOnRoll[PupilStatus/NCyearActual = '11' and PupilStatus/EnrolStatus = 'F'] )"/>
				</td>
				<td class="clsNumber">
					<xsl:value-of select="count(/Message/Pupils/PupilsOnRoll/PupilOnRoll[PupilStatus/NCyearActual = '11' and PupilStatus/EnrolStatus = 'O'] )"/>
				</td>
			</tr>
			<tr>
				<td class="clsHeading">10</td>
				<td class="clsNumber">
					<xsl:value-of select="count(/Message/Pupils/PupilsOnRoll/PupilOnRoll[PupilStatus/NCyearActual = '10'] )"/>
				</td>
				<td class="clsNumber">
					<xsl:value-of select="count(/Message/Pupils/PupilsOnRoll/PupilOnRoll[PupilStatus/NCyearActual = '10' and PupilStatus/EnrolStatus = 'C'] )"/>
				</td>
				<td class="clsNumber">
					<xsl:value-of select="count(/Message/Pupils/PupilsOnRoll/PupilOnRoll[PupilStatus/NCyearActual = '10' and PupilStatus/EnrolStatus = 'M'] )"/>
				</td>
				<td class="clsNumber">
					<xsl:value-of select="count(/Message/Pupils/PupilsOnRoll/PupilOnRoll[PupilStatus/NCyearActual = '10' and PupilStatus/EnrolStatus = 'S'] )"/>
				</td>
				<td class="clsNumber">
					<xsl:value-of select="count(/Message/Pupils/PupilsOnRoll/PupilOnRoll[PupilStatus/NCyearActual = '10' and PupilStatus/EnrolStatus = 'F'] )"/>
				</td>
				<td class="clsNumber">
					<xsl:value-of select="count(/Message/Pupils/PupilsOnRoll/PupilOnRoll[PupilStatus/NCyearActual = '10' and PupilStatus/EnrolStatus = 'O'] )"/>
				</td>
			</tr>
			<tr>
				<td class="clsHeading">9</td>
				<td class="clsNumber">
					<xsl:value-of select="count(/Message/Pupils/PupilsOnRoll/PupilOnRoll[PupilStatus/NCyearActual = '9'] )"/>
				</td>
				<td class="clsNumber">
					<xsl:value-of select="count(/Message/Pupils/PupilsOnRoll/PupilOnRoll[PupilStatus/NCyearActual = '9' and PupilStatus/EnrolStatus = 'C'] )"/>
				</td>
				<td class="clsNumber">
					<xsl:value-of select="count(/Message/Pupils/PupilsOnRoll/PupilOnRoll[PupilStatus/NCyearActual = '9' and PupilStatus/EnrolStatus = 'M'] )"/>
				</td>
				<td class="clsNumber">
					<xsl:value-of select="count(/Message/Pupils/PupilsOnRoll/PupilOnRoll[PupilStatus/NCyearActual = '9' and PupilStatus/EnrolStatus = 'S'] )"/>
				</td>
				<td class="clsNumber">
					<xsl:value-of select="count(/Message/Pupils/PupilsOnRoll/PupilOnRoll[PupilStatus/NCyearActual = '9' and PupilStatus/EnrolStatus = 'F'] )"/>
				</td>
				<td class="clsNumber">
					<xsl:value-of select="count(/Message/Pupils/PupilsOnRoll/PupilOnRoll[PupilStatus/NCyearActual = '9' and PupilStatus/EnrolStatus = 'O'] )"/>
				</td>
			</tr>
			<tr>
				<td class="clsHeading">8</td>
				<td class="clsNumber">
					<xsl:value-of select="count(/Message/Pupils/PupilsOnRoll/PupilOnRoll[PupilStatus/NCyearActual = '8'] )"/>
				</td>
				<td class="clsNumber">
					<xsl:value-of select="count(/Message/Pupils/PupilsOnRoll/PupilOnRoll[PupilStatus/NCyearActual = '8' and PupilStatus/EnrolStatus = 'C'] )"/>
				</td>
				<td class="clsNumber">
					<xsl:value-of select="count(/Message/Pupils/PupilsOnRoll/PupilOnRoll[PupilStatus/NCyearActual = '8' and PupilStatus/EnrolStatus = 'M'] )"/>
				</td>
				<td class="clsNumber">
					<xsl:value-of select="count(/Message/Pupils/PupilsOnRoll/PupilOnRoll[PupilStatus/NCyearActual = '8' and PupilStatus/EnrolStatus = 'S'] )"/>
				</td>
				<td class="clsNumber">
					<xsl:value-of select="count(/Message/Pupils/PupilsOnRoll/PupilOnRoll[PupilStatus/NCyearActual = '8' and PupilStatus/EnrolStatus = 'F'] )"/>
				</td>
				<td class="clsNumber">
					<xsl:value-of select="count(/Message/Pupils/PupilsOnRoll/PupilOnRoll[PupilStatus/NCyearActual = '8' and PupilStatus/EnrolStatus = 'O'] )"/>
				</td>
			</tr>
			<tr>
				<td class="clsHeading">7</td>
				<td class="clsNumber">
					<xsl:value-of select="count(/Message/Pupils/PupilsOnRoll/PupilOnRoll[PupilStatus/NCyearActual = '7'] )"/>
				</td>
				<td class="clsNumber">
					<xsl:value-of select="count(/Message/Pupils/PupilsOnRoll/PupilOnRoll[PupilStatus/NCyearActual = '7' and PupilStatus/EnrolStatus = 'C'] )"/>
				</td>
				<td class="clsNumber">
					<xsl:value-of select="count(/Message/Pupils/PupilsOnRoll/PupilOnRoll[PupilStatus/NCyearActual = '7' and PupilStatus/EnrolStatus = 'M'] )"/>
				</td>
				<td class="clsNumber">
					<xsl:value-of select="count(/Message/Pupils/PupilsOnRoll/PupilOnRoll[PupilStatus/NCyearActual = '7' and PupilStatus/EnrolStatus = 'S'] )"/>
				</td>
				<td class="clsNumber">
					<xsl:value-of select="count(/Message/Pupils/PupilsOnRoll/PupilOnRoll[PupilStatus/NCyearActual = '7' and PupilStatus/EnrolStatus = 'F'] )"/>
				</td>
				<td class="clsNumber">
					<xsl:value-of select="count(/Message/Pupils/PupilsOnRoll/PupilOnRoll[PupilStatus/NCyearActual = '7' and PupilStatus/EnrolStatus = 'O'] )"/>
				</td>
			</tr>
			<tr>
				<td class="clsHeading">6</td>
				<td class="clsNumber">
					<xsl:value-of select="count(/Message/Pupils/PupilsOnRoll/PupilOnRoll[PupilStatus/NCyearActual = '6'] )"/>
				</td>
				<td class="clsNumber">
					<xsl:value-of select="count(/Message/Pupils/PupilsOnRoll/PupilOnRoll[PupilStatus/NCyearActual = '6' and PupilStatus/EnrolStatus = 'C'] )"/>
				</td>
				<td class="clsNumber">
					<xsl:value-of select="count(/Message/Pupils/PupilsOnRoll/PupilOnRoll[PupilStatus/NCyearActual = '6' and PupilStatus/EnrolStatus = 'M'] )"/>
				</td>
				<td class="clsNumber">
					<xsl:value-of select="count(/Message/Pupils/PupilsOnRoll/PupilOnRoll[PupilStatus/NCyearActual = '6' and PupilStatus/EnrolStatus = 'S'] )"/>
				</td>
				<td class="clsNumber">
					<xsl:value-of select="count(/Message/Pupils/PupilsOnRoll/PupilOnRoll[PupilStatus/NCyearActual = '6' and PupilStatus/EnrolStatus = 'F'] )"/>
				</td>
				<td class="clsNumber">
					<xsl:value-of select="count(/Message/Pupils/PupilsOnRoll/PupilOnRoll[PupilStatus/NCyearActual = '6' and PupilStatus/EnrolStatus = 'O'] )"/>
				</td>
			</tr>
			<tr>
				<td class="clsHeading">5</td>
				<td class="clsNumber">
					<xsl:value-of select="count(/Message/Pupils/PupilsOnRoll/PupilOnRoll[PupilStatus/NCyearActual = '5'] )"/>
				</td>
				<td class="clsNumber">
					<xsl:value-of select="count(/Message/Pupils/PupilsOnRoll/PupilOnRoll[PupilStatus/NCyearActual = '5' and PupilStatus/EnrolStatus = 'C'] )"/>
				</td>
				<td class="clsNumber">
					<xsl:value-of select="count(/Message/Pupils/PupilsOnRoll/PupilOnRoll[PupilStatus/NCyearActual = '5' and PupilStatus/EnrolStatus = 'M'] )"/>
				</td>
				<td class="clsNumber">
					<xsl:value-of select="count(/Message/Pupils/PupilsOnRoll/PupilOnRoll[PupilStatus/NCyearActual = '5' and PupilStatus/EnrolStatus = 'S'] )"/>
				</td>
				<td class="clsNumber">
					<xsl:value-of select="count(/Message/Pupils/PupilsOnRoll/PupilOnRoll[PupilStatus/NCyearActual = '5' and PupilStatus/EnrolStatus = 'F'] )"/>
				</td>
				<td class="clsNumber">
					<xsl:value-of select="count(/Message/Pupils/PupilsOnRoll/PupilOnRoll[PupilStatus/NCyearActual = '5' and PupilStatus/EnrolStatus = 'O'] )"/>
				</td>
			</tr>
			<tr>
				<td class="clsHeading">4</td>
				<td class="clsNumber">
					<xsl:value-of select="count(/Message/Pupils/PupilsOnRoll/PupilOnRoll[PupilStatus/NCyearActual = '4'] )"/>
				</td>
				<td class="clsNumber">
					<xsl:value-of select="count(/Message/Pupils/PupilsOnRoll/PupilOnRoll[PupilStatus/NCyearActual = '4' and PupilStatus/EnrolStatus = 'C'] )"/>
				</td>
				<td class="clsNumber">
					<xsl:value-of select="count(/Message/Pupils/PupilsOnRoll/PupilOnRoll[PupilStatus/NCyearActual = '4' and PupilStatus/EnrolStatus = 'M'] )"/>
				</td>
				<td class="clsNumber">
					<xsl:value-of select="count(/Message/Pupils/PupilsOnRoll/PupilOnRoll[PupilStatus/NCyearActual = '4' and PupilStatus/EnrolStatus = 'S'] )"/>
				</td>
				<td class="clsNumber">
					<xsl:value-of select="count(/Message/Pupils/PupilsOnRoll/PupilOnRoll[PupilStatus/NCyearActual = '4' and PupilStatus/EnrolStatus = 'F'] )"/>
				</td>
				<td class="clsNumber">
					<xsl:value-of select="count(/Message/Pupils/PupilsOnRoll/PupilOnRoll[PupilStatus/NCyearActual = '4' and PupilStatus/EnrolStatus = 'O'] )"/>
				</td>
			</tr>
			<tr>
				<td class="clsHeading">3</td>
				<td class="clsNumber">
					<xsl:value-of select="count(/Message/Pupils/PupilsOnRoll/PupilOnRoll[PupilStatus/NCyearActual = '3'] )"/>
				</td>
				<td class="clsNumber">
					<xsl:value-of select="count(/Message/Pupils/PupilsOnRoll/PupilOnRoll[PupilStatus/NCyearActual = '3' and PupilStatus/EnrolStatus = 'C'] )"/>
				</td>
				<td class="clsNumber">
					<xsl:value-of select="count(/Message/Pupils/PupilsOnRoll/PupilOnRoll[PupilStatus/NCyearActual = '3' and PupilStatus/EnrolStatus = 'M'] )"/>
				</td>
				<td class="clsNumber">
					<xsl:value-of select="count(/Message/Pupils/PupilsOnRoll/PupilOnRoll[PupilStatus/NCyearActual = '3' and PupilStatus/EnrolStatus = 'S'] )"/>
				</td>
				<td class="clsNumber">
					<xsl:value-of select="count(/Message/Pupils/PupilsOnRoll/PupilOnRoll[PupilStatus/NCyearActual = '3' and PupilStatus/EnrolStatus = 'F'] )"/>
				</td>
				<td class="clsNumber">
					<xsl:value-of select="count(/Message/Pupils/PupilsOnRoll/PupilOnRoll[PupilStatus/NCyearActual = '3' and PupilStatus/EnrolStatus = 'O'] )"/>
				</td>
			</tr>
			<tr>
				<td class="clsHeading">2</td>
				<td class="clsNumber">
					<xsl:value-of select="count(/Message/Pupils/PupilsOnRoll/PupilOnRoll[PupilStatus/NCyearActual = '2'] )"/>
				</td>
				<td class="clsNumber">
					<xsl:value-of select="count(/Message/Pupils/PupilsOnRoll/PupilOnRoll[PupilStatus/NCyearActual = '2' and PupilStatus/EnrolStatus = 'C'] )"/>
				</td>
				<td class="clsNumber">
					<xsl:value-of select="count(/Message/Pupils/PupilsOnRoll/PupilOnRoll[PupilStatus/NCyearActual = '2' and PupilStatus/EnrolStatus = 'M'] )"/>
				</td>
				<td class="clsNumber">
					<xsl:value-of select="count(/Message/Pupils/PupilsOnRoll/PupilOnRoll[PupilStatus/NCyearActual = '2' and PupilStatus/EnrolStatus = 'S'] )"/>
				</td>
				<td class="clsNumber">
					<xsl:value-of select="count(/Message/Pupils/PupilsOnRoll/PupilOnRoll[PupilStatus/NCyearActual = '2' and PupilStatus/EnrolStatus = 'F'] )"/>
				</td>
				<td class="clsNumber">
					<xsl:value-of select="count(/Message/Pupils/PupilsOnRoll/PupilOnRoll[PupilStatus/NCyearActual = '2' and PupilStatus/EnrolStatus = 'O'] )"/>
				</td>
			</tr>
			<tr>
				<td class="clsHeading">1</td>
				<td class="clsNumber">
					<xsl:value-of select="count(/Message/Pupils/PupilsOnRoll/PupilOnRoll[PupilStatus/NCyearActual = '1'] )"/>
				</td>
				<td class="clsNumber">
					<xsl:value-of select="count(/Message/Pupils/PupilsOnRoll/PupilOnRoll[PupilStatus/NCyearActual = '1' and PupilStatus/EnrolStatus = 'C'] )"/>
				</td>
				<td class="clsNumber">
					<xsl:value-of select="count(/Message/Pupils/PupilsOnRoll/PupilOnRoll[PupilStatus/NCyearActual = '1' and PupilStatus/EnrolStatus = 'M'] )"/>
				</td>
				<td class="clsNumber">
					<xsl:value-of select="count(/Message/Pupils/PupilsOnRoll/PupilOnRoll[PupilStatus/NCyearActual = '1' and PupilStatus/EnrolStatus = 'S'] )"/>
				</td>
				<td class="clsNumber">
					<xsl:value-of select="count(/Message/Pupils/PupilsOnRoll/PupilOnRoll[PupilStatus/NCyearActual = '1' and PupilStatus/EnrolStatus = 'F'] )"/>
				</td>
				<td class="clsNumber">
					<xsl:value-of select="count(/Message/Pupils/PupilsOnRoll/PupilOnRoll[PupilStatus/NCyearActual = '1' and PupilStatus/EnrolStatus = 'O'] )"/>
				</td>
			</tr>
			<tr>
				<td class="clsHeading">R</td>
				<td class="clsNumber">
					<xsl:value-of select="count(/Message/Pupils/PupilsOnRoll/PupilOnRoll[PupilStatus/NCyearActual = 'R'] )"/>
				</td>
				<td class="clsNumber">
					<xsl:value-of select="count(/Message/Pupils/PupilsOnRoll/PupilOnRoll[PupilStatus/NCyearActual = 'R' and PupilStatus/EnrolStatus = 'C'] )"/>
				</td>
				<td class="clsNumber">
					<xsl:value-of select="count(/Message/Pupils/PupilsOnRoll/PupilOnRoll[PupilStatus/NCyearActual = 'R' and PupilStatus/EnrolStatus = 'M'] )"/>
				</td>
				<td class="clsNumber">
					<xsl:value-of select="count(/Message/Pupils/PupilsOnRoll/PupilOnRoll[PupilStatus/NCyearActual = 'R' and PupilStatus/EnrolStatus = 'S'] )"/>
				</td>
				<td class="clsNumber">
					<xsl:value-of select="count(/Message/Pupils/PupilsOnRoll/PupilOnRoll[PupilStatus/NCyearActual = 'R' and PupilStatus/EnrolStatus = 'F'] )"/>
				</td>
				<td class="clsNumber">
					<xsl:value-of select="count(/Message/Pupils/PupilsOnRoll/PupilOnRoll[PupilStatus/NCyearActual = 'R' and PupilStatus/EnrolStatus = 'O'] )"/>
				</td>
			</tr>
			<tr>
				<td class="clsHeading">N2</td>
				<td class="clsNumber">
					<xsl:value-of select="count(/Message/Pupils/PupilsOnRoll/PupilOnRoll[PupilStatus/NCyearActual = 'N2'] )"/>
				</td>
				<td class="clsNumber">
					<xsl:value-of select="count(/Message/Pupils/PupilsOnRoll/PupilOnRoll[PupilStatus/NCyearActual = 'N2' and PupilStatus/EnrolStatus = 'C'] )"/>
				</td>
				<td class="clsNumber">
					<xsl:value-of select="count(/Message/Pupils/PupilsOnRoll/PupilOnRoll[PupilStatus/NCyearActual = 'N2' and PupilStatus/EnrolStatus = 'M'] )"/>
				</td>
				<td class="clsNumber">
					<xsl:value-of select="count(/Message/Pupils/PupilsOnRoll/PupilOnRoll[PupilStatus/NCyearActual = 'N2' and PupilStatus/EnrolStatus = 'S'] )"/>
				</td>
				<td class="clsNumber">
					<xsl:value-of select="count(/Message/Pupils/PupilsOnRoll/PupilOnRoll[PupilStatus/NCyearActual = 'N2' and PupilStatus/EnrolStatus = 'F'] )"/>
				</td>
				<td class="clsNumber">
					<xsl:value-of select="count(/Message/Pupils/PupilsOnRoll/PupilOnRoll[PupilStatus/NCyearActual = 'N2' and PupilStatus/EnrolStatus = 'O'] )"/>
				</td>
			</tr>
			<tr>
				<td class="clsHeading">N1</td>
				<td class="clsNumber">
					<xsl:value-of select="count(/Message/Pupils/PupilsOnRoll/PupilOnRoll[PupilStatus/NCyearActual = 'N1'] )"/>
				</td>
				<td class="clsNumber">
					<xsl:value-of select="count(/Message/Pupils/PupilsOnRoll/PupilOnRoll[PupilStatus/NCyearActual = 'N1' and PupilStatus/EnrolStatus = 'C'] )"/>
				</td>
				<td class="clsNumber">
					<xsl:value-of select="count(/Message/Pupils/PupilsOnRoll/PupilOnRoll[PupilStatus/NCyearActual = 'N1' and PupilStatus/EnrolStatus = 'M'] )"/>
				</td>
				<td class="clsNumber">
					<xsl:value-of select="count(/Message/Pupils/PupilsOnRoll/PupilOnRoll[PupilStatus/NCyearActual = 'N1' and PupilStatus/EnrolStatus = 'S'] )"/>
				</td>
				<td class="clsNumber">
					<xsl:value-of select="count(/Message/Pupils/PupilsOnRoll/PupilOnRoll[PupilStatus/NCyearActual = 'N1' and PupilStatus/EnrolStatus = 'F'] )"/>
				</td>
				<td class="clsNumber">
					<xsl:value-of select="count(/Message/Pupils/PupilsOnRoll/PupilOnRoll[PupilStatus/NCyearActual = 'N1' and PupilStatus/EnrolStatus = 'O'] )"/>
				</td>
			</tr>
			<tr>
				<td class="clsHeading">E2</td>
				<td class="clsNumber">
					<xsl:value-of select="count(/Message/Pupils/PupilsOnRoll/PupilOnRoll[PupilStatus/NCyearActual = 'E2'] )"/>
				</td>
				<td class="clsNumber">
					<xsl:value-of select="count(/Message/Pupils/PupilsOnRoll/PupilOnRoll[PupilStatus/NCyearActual = 'E2' and PupilStatus/EnrolStatus = 'C'] )"/>
				</td>
				<td class="clsNumber">
					<xsl:value-of select="count(/Message/Pupils/PupilsOnRoll/PupilOnRoll[PupilStatus/NCyearActual = 'E2' and PupilStatus/EnrolStatus = 'M'] )"/>
				</td>
				<td class="clsNumber">
					<xsl:value-of select="count(/Message/Pupils/PupilsOnRoll/PupilOnRoll[PupilStatus/NCyearActual = 'E2' and PupilStatus/EnrolStatus = 'S'] )"/>
				</td>
				<td class="clsNumber">
					<xsl:value-of select="count(/Message/Pupils/PupilsOnRoll/PupilOnRoll[PupilStatus/NCyearActual = 'E2' and PupilStatus/EnrolStatus = 'F'] )"/>
				</td>
				<td class="clsNumber">
					<xsl:value-of select="count(/Message/Pupils/PupilsOnRoll/PupilOnRoll[PupilStatus/NCyearActual = 'E2' and PupilStatus/EnrolStatus = 'O'] )"/>
				</td>
			</tr>
			<tr>
				<td class="clsHeading">E1</td>
				<td class="clsNumber">
					<xsl:value-of select="count(/Message/Pupils/PupilsOnRoll/PupilOnRoll[PupilStatus/NCyearActual = 'E1'] )"/>
				</td>
				<td class="clsNumber">
					<xsl:value-of select="count(/Message/Pupils/PupilsOnRoll/PupilOnRoll[PupilStatus/NCyearActual = 'E1' and PupilStatus/EnrolStatus = 'C'] )"/>
				</td>
				<td class="clsNumber">
					<xsl:value-of select="count(/Message/Pupils/PupilsOnRoll/PupilOnRoll[PupilStatus/NCyearActual = 'E1' and PupilStatus/EnrolStatus = 'M'] )"/>
				</td>
				<td class="clsNumber">
					<xsl:value-of select="count(/Message/Pupils/PupilsOnRoll/PupilOnRoll[PupilStatus/NCyearActual = 'E1' and PupilStatus/EnrolStatus = 'S'] )"/>
				</td>
				<td class="clsNumber">
					<xsl:value-of select="count(/Message/Pupils/PupilsOnRoll/PupilOnRoll[PupilStatus/NCyearActual = 'E1' and PupilStatus/EnrolStatus = 'F'] )"/>
				</td>
				<td class="clsNumber">
					<xsl:value-of select="count(/Message/Pupils/PupilsOnRoll/PupilOnRoll[PupilStatus/NCyearActual = 'E1' and PupilStatus/EnrolStatus = 'O'] )"/>
				</td>
			</tr>
			<tr>
				<td class="clsHeading">X (NC year group not applicable)</td>
				<td class="clsNumber">
					<xsl:value-of select="count(/Message/Pupils/PupilsOnRoll/PupilOnRoll[PupilStatus/NCyearActual = 'X'] )"/>
				</td>
				<td class="clsNumber">
					<xsl:value-of select="count(/Message/Pupils/PupilsOnRoll/PupilOnRoll[PupilStatus/NCyearActual = 'X' and PupilStatus/EnrolStatus = 'C'] )"/>
				</td>
				<td class="clsNumber">
					<xsl:value-of select="count(/Message/Pupils/PupilsOnRoll/PupilOnRoll[PupilStatus/NCyearActual = 'X' and PupilStatus/EnrolStatus = 'M'] )"/>
				</td>
				<td class="clsNumber">
					<xsl:value-of select="count(/Message/Pupils/PupilsOnRoll/PupilOnRoll[PupilStatus/NCyearActual = 'X' and PupilStatus/EnrolStatus = 'S'] )"/>
				</td>
				<td class="clsNumber">
					<xsl:value-of select="count(/Message/Pupils/PupilsOnRoll/PupilOnRoll[PupilStatus/NCyearActual = 'X' and PupilStatus/EnrolStatus = 'F'] )"/>
				</td>
				<td class="clsNumber">
					<xsl:value-of select="count(/Message/Pupils/PupilsOnRoll/PupilOnRoll[PupilStatus/NCyearActual = 'X' and PupilStatus/EnrolStatus = 'O'] )"/>
				</td>
			</tr>
			<tr>
				<td class="clsHeading">Total</td>
				<td class="clsTotal">
					<xsl:value-of select="$b16"/>
				</td>
				<td class="clsTotal">
					<xsl:value-of select="count(/Message/Pupils/PupilsOnRoll/PupilOnRoll[contains( ' 14 13 12 11 10 9 8 7 6 5 4 3 2 1 R N2 N1 E1 E2 X ', concat( ' ', PupilStatus/NCyearActual, ' ' ) ) and PupilStatus/EnrolStatus = 'C'] )"/>
				</td>
				<td class="clsTotal">
					<xsl:value-of select="count(/Message/Pupils/PupilsOnRoll/PupilOnRoll[contains( ' 14 13 12 11 10 9 8 7 6 5 4 3 2 1 R N2 N1 E1 E2 X ', concat( ' ', PupilStatus/NCyearActual, ' ' ) ) and PupilStatus/EnrolStatus = 'M'] )"/>
				</td>
				<td class="clsTotal">
					<xsl:value-of select="count(/Message/Pupils/PupilsOnRoll/PupilOnRoll[contains( ' 14 13 12 11 10 9 8 7 6 5 4 3 2 1 R N2 N1 E1 E2 X ', concat( ' ', PupilStatus/NCyearActual, ' ' ) ) and PupilStatus/EnrolStatus = 'S'] )"/>
				</td>
				<td class="clsTotal">
					<xsl:value-of select="count(/Message/Pupils/PupilsOnRoll/PupilOnRoll[contains( ' 14 13 12 11 10 9 8 7 6 5 4 3 2 1 R N2 N1 E1 E2 X ', concat( ' ', PupilStatus/NCyearActual, ' ' ) ) and PupilStatus/EnrolStatus = 'F'] )"/>
				</td>
				<td class="clsTotal">
					<xsl:value-of select="count(/Message/Pupils/PupilsOnRoll/PupilOnRoll[contains( ' 14 13 12 11 10 9 8 7 6 5 4 3 2 1 R N2 N1 E1 E2 X ', concat( ' ', PupilStatus/NCyearActual, ' ' ) ) and PupilStatus/EnrolStatus = 'O'] )"/>
				</td>
			</tr>
			<xsl:if test="$b16 != $b10 + $b13">
				<tr>
					<td class="clsHeading">Warning</td>
					<td class="clsTotal" colspan="2">
					Total number of pupils in this table differs from that indicated in table 2.
				</td>
				</tr>
			</xsl:if>
		</table>
		<br/>
		
		
		<h2>Table 4: Pupils on roll by their first language [ALL schools]</h2>
		<table class="summaryreport" border="1">
			<tr>
				<th>Language Code</th>
				<th>Description</th>
				<th>Number of Pupils</th>
			</tr>
			<xsl:for-each select="//PupilCharacteristics/Language[ not(. = '')  ]">
				<xsl:sort select="."/>
				<xsl:choose>
					<xsl:when test=". = preceding::Language [ not(. = '')  ]"/>
					<xsl:when test="count(/Message/Pupils/PupilsOnRoll/PupilOnRoll/PupilCharacteristics/Language[. = current() and not(. = '') ] ) = 0"/>
					<xsl:otherwise>
						<tr>
							<td class="clsHeading">
								<xsl:value-of select="."/>
							</td>
							<td class="clsSubhead">
								<xsl:value-of select="document('./SchoolCensus23-24-SchoolSummaryReferenceLists.xsl') /xsl:stylesheet/Language[LanguageCode = current() ]/LanguageDescription"/>
							</td>
							<td class="clsNumber">
								<xsl:value-of select="count(/Message/Pupils/PupilsOnRoll/PupilOnRoll/PupilCharacteristics/Language[. = current() and not(. = '') ] )"/>
							</td>
						</tr>
					</xsl:otherwise>
				</xsl:choose>
			</xsl:for-each>
			<xsl:if test="$b19total != $b10 + $b13">
				<tr>
					<td class="clsHeading">Warning</td>
					<td class="clsTotal" colspan="2">
					Total number of pupils in this table differs from that indicated in table 2.
				</td>
				</tr>
			</xsl:if>
		</table>
		<br/>
		<!--	Table 5 removed 30/07/2020 ahead of Aut 20 collection-->
		<!--		<h2>Table 5: Pupils on roll by enrolment status [ALL schools]</h2>
		<table class="summaryreport" border="1">
			<tr>
				<th>Enrolment status</th>
				<th>Number of pupils</th>
			</tr>
			<tr>
				<td class="clsHeading">Current (single registration at this school) (C)</td>
				<td class="clsNumber">
					<xsl:value-of select="count(/Message/Pupils/PupilsOnRoll/PupilOnRoll[PupilStatus/EnrolStatus = 'C' ] )"/>
				</td>
			</tr>
			<tr>
				<td class="clsHeading">Current main (dual registration) (M)</td>
				<td class="clsNumber">
					<xsl:value-of select="count(/Message/Pupils/PupilsOnRoll/PupilOnRoll[PupilStatus/EnrolStatus = 'M' ] )"/>
				</td>
			</tr>
			<tr>
				<td class="clsHeading">Current subsidiary (dual registration) (S)</td>
				<td class="clsNumber">
					<xsl:value-of select="count(/Message/Pupils/PupilsOnRoll/PupilOnRoll[PupilStatus/EnrolStatus = 'S' ] )"/>
				</td>
			</tr>
			<tr>
				<td class="clsHeading">Number of dually registered pupils (Total M and Total S)</td>
				<td class="clsNumber">
					<xsl:value-of select="count(/Message/Pupils/PupilsOnRoll/PupilOnRoll[contains( ' M S ' , concat( ' ', PupilStatus/EnrolStatus, ' ' ) ) ] )"/>
				</td>
			</tr>	
-->
		<!--Change in sequence June 2015.-->
		<!--			<xsl:choose>
				<xsl:when test="$phase = 'PR'">
					<tr>
						<td class="clsHeading">FE College (F)</td>
						<td class="clsNumber">
							<xsl:value-of select="count(/Message/Pupils/PupilsOnRoll/PupilOnRoll[PupilStatus/EnrolStatus = 'F' ] )"/>
						</td>
					</tr>
					<tr>
						<td class="clsHeading">Other provider (O)</td>
						<td class="clsNumber">
							<xsl:value-of select="count(/Message/Pupils/PupilsOnRoll/PupilOnRoll[PupilStatus/EnrolStatus = 'O' ] )"/>
						</td>
					</tr>
					<tr>
						<td class="clsHeading">Total number of pupils in F and O</td>
						<td class="clsNumber">
							<xsl:value-of select="count(/Message/Pupils/PupilsOnRoll/PupilOnRoll[contains( ' F O ' , concat( ' ', PupilStatus/EnrolStatus, ' ' ) ) ] )"/>
						</td>
					</tr>
					<tr>
						<td class="clsHeading">Total number of pupils</td>
						<td class="clsNumber">
							<xsl:value-of select="count(/Message/Pupils/PupilsOnRoll/PupilOnRoll[contains( ' C M S F O ' , concat( ' ', PupilStatus/EnrolStatus, ' ' ) ) ] )"/>
						</td>
					</tr>
				</xsl:when>
				<xsl:otherwise>
					<tr>
						<td class="clsHeading">Total number of pupils excluding F and O</td>
						<td class="clsNumber">
							<xsl:value-of select="count(/Message/Pupils/PupilsOnRoll/PupilOnRoll[contains( ' C M S ' , concat( ' ', PupilStatus/EnrolStatus, ' ' ) ) ] )"/>
						</td>
					</tr>
					<tr>
						<td class="clsHeading">Total number of pupils</td>
						<td class="clsNumber">
							<xsl:value-of select="count(/Message/Pupils/PupilsOnRoll/PupilOnRoll[contains( ' C M S F O ' , concat( ' ', PupilStatus/EnrolStatus, ' ' ) ) ] )"/>
						</td>
					</tr>
				</xsl:otherwise>
			</xsl:choose>
			<xsl:if test="$b28 != $b10 + $b13">
				<tr>
					<td class="clsHeading">Warning</td>
					<td class="clsTotal" colspan="2">
					Total number of pupils in this table differs from that indicated in table 2.
				</td>
				</tr>
			</xsl:if>
		</table>
		<br/>	-->
		
		
		<h2>Table 5: Specific types of pupils on roll [ALL schools]</h2>
		<table border="1" class="summaryreport">
			<tr>
				<th>Pupils on roll:</th>
				<th>Number of pupils</th>
			</tr>
			<tr>
				<td class="clsHeading">Boarders</td>
				<td class="clsNumber">
					<xsl:value-of select="count(/Message/Pupils/PupilsOnRoll/PupilOnRoll[ contains(' B 6 7 ', concat(' ', PupilStatus/Boarder, ' ') ) ] )"/>
				</td>
			</tr>
			<tr>
				<td class="clsHeading">Service children</td>
				<td class="clsNumber">
					<xsl:value-of select="count(/Message/Pupils/PupilsOnRoll/PupilOnRoll[ PupilCharacteristics/ServiceChild = 'Y' ] )"/>
				</td>
			</tr>
			<tr>
				<td class="clsHeading">Pupils for whom the school receives top-up funding</td>
				<td class="clsNumber">
					<xsl:value-of select="count(/Message/Pupils/PupilsOnRoll/PupilOnRoll[ contains( $true, concat( ' ', PupilCharacteristics/TopUpFunding, ' ' ) ) ] )"/>
				</td>
			</tr>
			<tr>
				<td class="clsHeading">Post looked after arrangements - includes children ceased to be looked after through adoption, special guardianship, residence order or child arrangement order</td>
				<td class="clsNumber">
					<xsl:value-of select="count(/Message/Pupils/PupilsOnRoll/PupilOnRoll[ contains( ' A G C O R ' , concat( ' ', PupilCharacteristics/PLAA, ' ' ) ) ] )"/>
				</td>
			</tr>
			<tr>
				<td class="clsHeading">Eligible for free school meals on census day</td>
				<td class="clsNumber">
					<xsl:value-of select="count(/Message/Pupils/PupilsOnRoll/PupilOnRoll[ 
						PupilCharacteristics/FSMeligibility/FSMperiod[
							translate(./FSMstartDate, '-','' ) &lt;= $ReferenceDate 
							and (string-length(./FSMendDate)=0 
										or translate(./FSMendDate, '-', '') = $ReferenceDate) 
							] ] )"/>
				</td>
			</tr>
			<tr>
				<td class="clsHeading">Unique pupils with any period of eligibility for free school meals reported in the current census (includes those eligible on census day)</td>
				<td class="clsNumber">
					<xsl:value-of select="count(/Message/Pupils/PupilsOnRoll/PupilOnRoll[PupilCharacteristics/FSMeligibility/FSMperiod/FSMstartDate] )"/>
				</td>
			</tr>
			<!--The next row is conditional, and applies to non-PRUs in spring-->
			<xsl:if test="$term = 'SPR' and $phase != 'PR'">
				<tr>
					<td class="clsHeading">Pupils who took free school meals on census day</td>
					<td class="clsNumber">
						<xsl:choose>
							<xsl:when test="/Message/School/Miscellaneous/FreeMealsTaken = '' 
								or not (/Message/School/Miscellaneous/FreeMealsTaken) ">0</xsl:when>
							<xsl:otherwise>
								<xsl:value-of select="/Message/School/Miscellaneous/FreeMealsTaken"/>
							</xsl:otherwise>
						</xsl:choose>
					</td>
				</tr>
			</xsl:if>
		</table>
		<br/>
		
		
		<h2>Table 6: Funded and extended childcare hours for pupils on roll aged 2, 3 and 4 years [Not for: Non-maintained special school and city technology college] </h2>
		<!-- 31 August for autumn, 31 December for spring, 31 March for summer-->
		<xsl:variable name="measuredate">
			<xsl:choose>
				<xsl:when test="$term = 'AUT' ">
					<xsl:value-of select=" '31 August 2023' "/>
				</xsl:when>
				<xsl:when test="$term = 'SPR' ">
					<xsl:value-of select=" '31 December 2023' "/>
				</xsl:when>
				<xsl:when test="$term = 'SUM' ">
					<xsl:value-of select=" '31 March 2024' "/>
				</xsl:when>
			</xsl:choose>
		</xsl:variable>
		<xsl:variable name="measuredate2" select=" '31 August 2023' "/>
		<xsl:variable name="rising3date">
			<xsl:choose>
				<xsl:when test="$term = 'SPR' ">
					<xsl:value-of select=" '31 December 2023' "/>
				</xsl:when>
				<xsl:when test="$term = 'SUM' ">
					<xsl:value-of select=" '31 March 2024' "/>
				</xsl:when>
			</xsl:choose>
		</xsl:variable>
		<!--Age: 2 years at measurement date-->
		<xsl:variable name="tyominbd">
			<xsl:choose>
				<xsl:when test="$term = 'AUT' ">
					<xsl:value-of select=" '2020-09-01' "/>
				</xsl:when>
				<xsl:when test="$term = 'SPR' ">
					<xsl:value-of select=" '2021-01-01' "/>
				</xsl:when>
				<xsl:when test="$term = 'SUM' ">
					<xsl:value-of select=" '2021-04-01' "/>
				</xsl:when>
			</xsl:choose>
		</xsl:variable>
		<xsl:variable name="tyomaxbd">
			<xsl:choose>
				<xsl:when test="$term = 'AUT' ">
					<xsl:value-of select=" '2021-08-31' "/>
				</xsl:when>
				<xsl:when test="$term = 'SPR' ">
					<xsl:value-of select=" '2021-12-31' "/>
				</xsl:when>
				<xsl:when test="$term = 'SUM' ">
					<xsl:value-of select=" '2022-03-31' "/>
				</xsl:when>
			</xsl:choose>
		</xsl:variable>
		<!--Age: 3 with recent birthday (spring/summer) / unused (Autumn)-->
		<xsl:variable name="rtyominbd" select=" '2020-09-01' "/>
		<xsl:variable name="rtyomaxbd">
			<xsl:choose>
				<xsl:when test="$term = 'SPR' ">
					<xsl:value-of select=" '2020-12-31' "/>
				</xsl:when>
				<xsl:when test="$term = 'SUM' ">
					<xsl:value-of select=" '2021-03-31' "/>
				</xsl:when>
			</xsl:choose>
		</xsl:variable>
		<!--Age: 3 years at measurement date (autumn) / non-rising threes (spring/summer)-->
		<xsl:variable name="ntyominbd" select=" '2019-09-01' "/>
		<xsl:variable name="ntyomaxbd" select=" '2020-08-31' "/>
		<!--Age: 4 years at measurement date-->
		<xsl:variable name="fyominbd">
			<xsl:choose>
				<xsl:when test="$term = 'AUT' ">
					<xsl:value-of select=" '2018-09-01' "/>
				</xsl:when>
				<xsl:when test="$term = 'SPR' ">
					<xsl:value-of select=" '2018-09-01' "/>
				</xsl:when>
				<xsl:when test="$term = 'SUM' ">
					<xsl:value-of select=" '2019-04-01' "/>
				</xsl:when>
			</xsl:choose>		
		</xsl:variable>
		<xsl:variable name="fyomaxbd" select=" '2019-08-31' "/>
		<xsl:choose>
			<xsl:when test="/Message/School/SchoolCharacteristics/SchoolType = '47'
											or ($phase = 'SP' 
											and /Message/School/SchoolCharacteristics/Governance = 'NM')"/>
			<xsl:otherwise>
				<table class="summaryreport" border="1">
					<tr>
						<th rowspan="2">Age</th>
						<th colspan="8">Number of pupils with:</th>
					</tr>
					<tr>
						<th>zero <br/>funded <br/>hours</th>
						<th>funded <br/>hours <br/>greater<br/>than zero<br/>but less<br/>than 15</th>
						<th>funded <br/>hours equal <br/>to 15</th>
						<!--th>funded <br/>hours <br/>greater <br/>than 15<br/>but less <br/>than 25</th>
						<th>funded <br/>hours equal <br/>to 25</th-->
						<th>zero<br/>extended<br/>childcare<br/>hours</th>
						<th>extended<br/>hours<br/>greater<br/>than zero<br/>but less<br/>than 15</th>
						<th>extended<br/>hours<br/>equal<br/>to 15</th>
					</tr>
					<tr>
						<td class="clsHeading">Aged 2 years at <xsl:value-of select="$measuredate"/>
							<br/>(pupils born between <xsl:value-of select="$tyominbd"/> and <xsl:value-of select="$tyomaxbd"/>)</td>
						<td class="clsNumber">
							<xsl:value-of select="count(/Message/Pupils/PupilsOnRoll/PupilOnRoll[ translate(PupilIdentifiers/DOB, '-', '') &gt;= translate($tyominbd, '-', '')
								and translate(PupilIdentifiers/DOB, '-', '') &lt;= translate($tyomaxbd, '-', '')
								and (PupilCharacteristics/FundedHours=0 or not(PupilCharacteristics/FundedHours) ) ] ) "/>
						</td>
						<td class="clsNumber">
							<xsl:value-of select="count(/Message/Pupils/PupilsOnRoll/PupilOnRoll[ translate(PupilIdentifiers/DOB, '-', '') &gt;= translate($tyominbd, '-', '')
								and translate(PupilIdentifiers/DOB, '-', '') &lt;= translate($tyomaxbd, '-', '')
								and PupilCharacteristics/FundedHours &gt; 0 
								and PupilCharacteristics/FundedHours &lt; 15] ) "/>
						</td>
						<td class="clsNumber">
							<xsl:value-of select="count(/Message/Pupils/PupilsOnRoll/PupilOnRoll[ translate(PupilIdentifiers/DOB, '-', '') &gt;= translate($tyominbd, '-', '')
								and translate(PupilIdentifiers/DOB, '-', '') &lt;= translate($tyomaxbd, '-', '')
								and PupilCharacteristics/FundedHours = 15 ] ) "/>
						</td>
						<td class="clsEmpty" colspan="3">
							N/a
						</td>
					</tr>
					<!--The conditional processing does not seem to work here - commenting it out to ensure it doesn't get output-->
					<!--Added following section back in as it is needed for Spr18.  Amended to force it to work on Spr18, may need to review for other terms though - ACN 02/11/2017 -->
					<xsl:if test="$term = 'SPR' or $term = 'SUM'">
						<tr>
							<!--<td class="clsHeading">Aged 2 years at 31 August 2017 but 3 by <xsl:value-of select="$measuredate" /><br/>(pupils born between 01/09/2013 and 31/03/2014) (Rising 3s)</td>-->
							<!--Above replaced with following line for Spr18 ACN 02/11/17-->
							<td class="clsHeading">Aged 2 years at <xsl:value-of select="$measuredate2"/> but 3 by <xsl:value-of select="$rising3date"/>
								<br/>(pupils born between <xsl:value-of select="$rtyominbd"/> and <xsl:value-of select="$rtyomaxbd"/>) </td>
							<td class="clsNumber">
								<xsl:value-of select="count(/Message/Pupils/PupilsOnRoll/PupilOnRoll[ translate(PupilIdentifiers/DOB, '-', '') &gt;= translate($rtyominbd, '-', '')
									and translate(PupilIdentifiers/DOB, '-', '') &lt;= translate($rtyomaxbd, '-', '')
									and (PupilCharacteristics/FundedHours=0 or not(PupilCharacteristics/FundedHours) ) ] ) "/>
							</td>
							<td class="clsNumber">
								<xsl:value-of select="count(/Message/Pupils/PupilsOnRoll/PupilOnRoll[ translate(PupilIdentifiers/DOB, '-', '') &gt;= translate($rtyominbd, '-', '')
									and translate(PupilIdentifiers/DOB, '-', '') &lt;= translate($rtyomaxbd, '-', '')
									and PupilCharacteristics/FundedHours &gt; 0 
									and PupilCharacteristics/FundedHours &lt; 15] ) "/>
							</td>
							<td class="clsNumber">
								<xsl:value-of select="count(/Message/Pupils/PupilsOnRoll/PupilOnRoll[ translate(PupilIdentifiers/DOB, '-', '') &gt;= translate($rtyominbd, '-', '')
									and translate(PupilIdentifiers/DOB, '-', '') &lt;= translate($rtyomaxbd, '-', '')
									and PupilCharacteristics/FundedHours = 15] ) "/>
							</td>
							<!-- next 3 TD's added for Spr 18. ACN 2/11/17-->
							<td class="clsNumber">
								<xsl:value-of select="count(/Message/Pupils/PupilsOnRoll/PupilOnRoll[ translate(PupilIdentifiers/DOB, '-', '') &gt;= translate($rtyominbd, '-', '')
									and translate(PupilIdentifiers/DOB, '-', '') &lt;= translate($rtyomaxbd, '-', '')
									and PupilCharacteristics/ExtendedHours=0 ] ) "/>
							</td>
							<td class="clsNumber">
								<xsl:value-of select="count(/Message/Pupils/PupilsOnRoll/PupilOnRoll[ translate(PupilIdentifiers/DOB, '-', '') &gt;= translate($rtyominbd, '-', '')
									and translate(PupilIdentifiers/DOB, '-', '') &lt;= translate($rtyomaxbd, '-', '')
									and PupilCharacteristics/ExtendedHours &gt; 0
									and PupilCharacteristics/ExtendedHours &lt; 15 ] )"/>
							</td>
							<td class="clsNumber">
								<xsl:value-of select="count(/Message/Pupils/PupilsOnRoll/PupilOnRoll[ translate(PupilIdentifiers/DOB, '-', '') &gt;= translate($rtyominbd, '-', '')
									and translate(PupilIdentifiers/DOB, '-', '') &lt;= translate($rtyomaxbd, '-', '')
									and PupilCharacteristics/ExtendedHours = 15] ) "/>
							</td>
						</tr>
					</xsl:if>
					<tr>
						<td class="clsHeading">Aged 3 years at <xsl:value-of select="$measuredate2"/>
							<br/>(pupils born between <xsl:value-of select="$ntyominbd"/> and <xsl:value-of select="$ntyomaxbd"/>)</td>
						<td class="clsNumber">
							<xsl:value-of select="count(/Message/Pupils/PupilsOnRoll/PupilOnRoll[ translate(PupilIdentifiers/DOB, '-', '') &gt;= translate($ntyominbd, '-', '')
																								and translate(PupilIdentifiers/DOB, '-', '') &lt;= translate($ntyomaxbd, '-', '')
																								and (PupilCharacteristics/FundedHours=0 or not(PupilCharacteristics/FundedHours) ) ] ) "/>
						</td>
						<td class="clsNumber">
							<xsl:value-of select="count(/Message/Pupils/PupilsOnRoll/PupilOnRoll[ translate(PupilIdentifiers/DOB, '-', '') &gt;= translate($ntyominbd, '-', '')
																								and translate(PupilIdentifiers/DOB, '-', '') &lt;= translate($ntyomaxbd, '-', '')
																								and PupilCharacteristics/FundedHours &gt; 0
																								and PupilCharacteristics/FundedHours &lt; 15 ] )"/>
						</td>
						<td class="clsNumber">
							<xsl:value-of select="count(/Message/Pupils/PupilsOnRoll/PupilOnRoll[ translate(PupilIdentifiers/DOB, '-', '') &gt;= translate($ntyominbd, '-', '')
																								and translate(PupilIdentifiers/DOB, '-', '') &lt;= translate($ntyomaxbd, '-', '')
																								and PupilCharacteristics/FundedHours = 15] ) "/>
						</td>
						<td class="clsNumber">
							<xsl:value-of select="count(/Message/Pupils/PupilsOnRoll/PupilOnRoll[ translate(PupilIdentifiers/DOB, '-', '') &gt;= translate($ntyominbd, '-', '')
																								and translate(PupilIdentifiers/DOB, '-', '') &lt;= translate($ntyomaxbd, '-', '')
																								and PupilCharacteristics/ExtendedHours=0 ] ) "/>
						</td>
						<td class="clsNumber">
							<xsl:value-of select="count(/Message/Pupils/PupilsOnRoll/PupilOnRoll[ translate(PupilIdentifiers/DOB, '-', '') &gt;= translate($ntyominbd, '-', '')
																								and translate(PupilIdentifiers/DOB, '-', '') &lt;= translate($ntyomaxbd, '-', '')
																								and PupilCharacteristics/ExtendedHours &gt; 0
																								and PupilCharacteristics/ExtendedHours &lt; 15 ] )"/>
						</td>
						<td class="clsNumber">
							<xsl:value-of select="count(/Message/Pupils/PupilsOnRoll/PupilOnRoll[ translate(PupilIdentifiers/DOB, '-', '') &gt;= translate($ntyominbd, '-', '')
																								and translate(PupilIdentifiers/DOB, '-', '') &lt;= translate($ntyomaxbd, '-', '')
																								and PupilCharacteristics/ExtendedHours = 15] ) "/>
						</td>
					</tr>
					<tr>
						<td class="clsHeading">Aged 4 years at <xsl:value-of select="$measuredate2"/>
							<br/>(pupils born between <xsl:value-of select="$fyominbd"/> and <xsl:value-of select="$fyomaxbd"/>) who are in nursery provision</td>
						<td class="clsNumber">
							<xsl:value-of select="count(/Message/Pupils/PupilsOnRoll/PupilOnRoll[ translate(PupilIdentifiers/DOB, '-', '') &gt;= translate($fyominbd, '-', '')
																								and translate(PupilIdentifiers/DOB, '-', '') &lt;= translate($fyomaxbd, '-', '')
																								and PupilCharacteristics/FundedHours = 0 
																								and contains(' E1 E2 N1 N2 ', concat( ' ', PupilStatus/NCyearActual, ' ' )) ] ) "/>
						</td>
						<td class="clsNumber">
							<xsl:value-of select="count(/Message/Pupils/PupilsOnRoll/PupilOnRoll[ translate(PupilIdentifiers/DOB, '-', '') &gt;= translate($fyominbd, '-', '')
								and translate(PupilIdentifiers/DOB, '-', '') &lt;= translate($fyomaxbd, '-', '')
								and PupilCharacteristics/FundedHours &gt; 0
								and PupilCharacteristics/FundedHours &lt; 15 
								and contains(' E1 E2 N1 N2 ', concat( ' ', PupilStatus/NCyearActual, ' ' )) ])"/>
						</td>
						<td class="clsNumber">
							<xsl:value-of select="count(/Message/Pupils/PupilsOnRoll/PupilOnRoll[ translate(PupilIdentifiers/DOB, '-', '') &gt;= translate($fyominbd, '-', '')
								and translate(PupilIdentifiers/DOB, '-', '') &lt;= translate($fyomaxbd, '-', '')
								and PupilCharacteristics/FundedHours = 15
								and contains(' E1 E2 N1 N2 ', concat( ' ', PupilStatus/NCyearActual, ' ' ))] ) "/>
						</td>
						<!--td class="clsNumber">
							<xsl:value-of select="count(/Message/Pupils/PupilsOnRoll/PupilOnRoll[ translate(PupilIdentifiers/DOB, '-', '') &gt;= translate($fyominbd, '-', '')
								and translate(PupilIdentifiers/DOB, '-', '') &lt;= translate($fyomaxbd, '-', '')
								and PupilCharacteristics/FundedHours &gt; 15
								and PupilCharacteristics/FundedHours &lt; 25 ] )"/>
						</td>
						<td class="clsNumber">
							<xsl:value-of select="count(/Message/Pupils/PupilsOnRoll/PupilOnRoll[ translate(PupilIdentifiers/DOB, '-', '') &gt;= translate($fyominbd, '-', '')
								and translate(PupilIdentifiers/DOB, '-', '') &lt;= translate($fyomaxbd, '-', '')
								and PupilCharacteristics/FundedHours = 25] ) "/>
						</td-->
						<td class="clsNumber">
							<xsl:value-of select="count(/Message/Pupils/PupilsOnRoll/PupilOnRoll[ translate(PupilIdentifiers/DOB, '-', '') &gt;= translate($fyominbd, '-', '')
								and translate(PupilIdentifiers/DOB, '-', '') &lt;= translate($fyomaxbd, '-', '')
								and PupilCharacteristics/ExtendedHours = 0 
								and contains(' E1 E2 N1 N2 ', concat( ' ', PupilStatus/NCyearActual, ' ' ))] ) "/>
						</td>
						<td class="clsNumber">
							<xsl:value-of select="count(/Message/Pupils/PupilsOnRoll/PupilOnRoll[ translate(PupilIdentifiers/DOB, '-', '') &gt;= translate($fyominbd, '-', '')
								and translate(PupilIdentifiers/DOB, '-', '') &lt;= translate($fyomaxbd, '-', '')
								and PupilCharacteristics/ExtendedHours &gt; 0
								and PupilCharacteristics/ExtendedHours &lt; 15 
								and contains(' E1 E2 N1 N2 ', concat( ' ', PupilStatus/NCyearActual, ' ' ))] )"/>
						</td>
						<td class="clsNumber">
							<xsl:value-of select="count(/Message/Pupils/PupilsOnRoll/PupilOnRoll[ translate(PupilIdentifiers/DOB, '-', '') &gt;= translate($fyominbd, '-', '')
								and translate(PupilIdentifiers/DOB, '-', '') &lt;= translate($fyomaxbd, '-', '')
								and PupilCharacteristics/ExtendedHours = 15
								and contains(' E1 E2 N1 N2 ', concat( ' ', PupilStatus/NCyearActual, ' ' ))] ) "/>
						</td>
					</tr>
				</table>
			</xsl:otherwise>
		</xsl:choose>
		
		
		<h2>Table 7: Early years pupil premium - nursery schools [For: Schools with phase 'NS' only] [used for funding]</h2>
		<xsl:choose>
			<xsl:when test="$term != 'SPR'">
				<p class="clsFootnote">This table does not apply to the <xsl:value-of select="$thiscensus"/> census, as early years pupil premium data is only collected in the spring census.</p>
			</xsl:when>
			<xsl:when test="$phase != 'NS'">
				<p class="clsFootnote">This table only applies to Nursery schools.</p>
			</xsl:when>
			<xsl:otherwise>
				<table class="summaryreport" border="1">
					<tr>
						<th rowspan="2">NC year group</th>
						<th rowspan="2">Number<br/>of pupils<br/>on roll</th>
						<th colspan="2">of which</th>
					</tr>
					<tr>
						<th>Are in <br/>receipt of <br/>early years<br/>pupil <br/>premium<br/>funding</th>
						<th>Are not in <br/>receipt of <br/>early years <br/>pupil<br/>premium<br/>funding</th>
					</tr>
					<tr>
						<td class="clsHeading">E1</td>
						<td class="clsNumber">
							<xsl:value-of select="count($EYPPNS[PupilStatus/NCyearActual='E1' 
								and contains(' Y N ', concat(' ', PupilCharacteristics/EYPPR, ' ') ) ] )"/>
						</td>
						<td class="clsNumber">
							<xsl:value-of select="count($EYPPNS[PupilStatus/NCyearActual='E1' 
								and PupilCharacteristics/EYPPR = 'Y' ] )"/>
						</td>
						<td class="clsNumber">
							<xsl:value-of select="count($EYPPNS[PupilStatus/NCyearActual='E1' 
								and PupilCharacteristics/EYPPR = 'N' ] )"/>
						</td>
					</tr>
					<tr>
						<td class="clsHeading">E2</td>
						<td class="clsNumber">
							<xsl:value-of select="count($EYPPNS[PupilStatus/NCyearActual='E2' 
								and contains(' Y N ', concat(' ', PupilCharacteristics/EYPPR, ' ') ) ] )"/>
						</td>
						<td class="clsNumber">
							<xsl:value-of select="count($EYPPNS[PupilStatus/NCyearActual='E2' 
								and PupilCharacteristics/EYPPR = 'Y' ] )"/>
						</td>
						<td class="clsNumber">
							<xsl:value-of select="count($EYPPNS[PupilStatus/NCyearActual='E2' 
								and PupilCharacteristics/EYPPR = 'N' ] )"/>
						</td>
					</tr>
					<tr>
						<td class="clsHeading">N1</td>
						<td class="clsNumber">
							<xsl:value-of select="count($EYPPNS[PupilStatus/NCyearActual='N1' 
								and contains(' Y N ', concat(' ', PupilCharacteristics/EYPPR, ' ') ) ] )"/>
						</td>
						<td class="clsNumber">
							<xsl:value-of select="count($EYPPNS[PupilStatus/NCyearActual='N1' 
								and PupilCharacteristics/EYPPR = 'Y' ] )"/>
						</td>
						<td class="clsNumber">
							<xsl:value-of select="count($EYPPNS[PupilStatus/NCyearActual='N1' 
								and PupilCharacteristics/EYPPR = 'N' ] )"/>
						</td>
					</tr>
					<tr>
						<td class="clsHeading">N2</td>
						<td class="clsNumber">
							<xsl:value-of select="count($EYPPNS[PupilStatus/NCyearActual='N2' 
								and contains(' Y N ', concat(' ', PupilCharacteristics/EYPPR, ' ') ) ] )"/>
						</td>
						<td class="clsNumber">
							<xsl:value-of select="count($EYPPNS[PupilStatus/NCyearActual='N2' 
								and PupilCharacteristics/EYPPR = 'Y' ] )"/>
						</td>
						<td class="clsNumber">
							<xsl:value-of select="count($EYPPNS[PupilStatus/NCyearActual='N2' 
								and PupilCharacteristics/EYPPR = 'N' ] )"/>
						</td>
					</tr>
					<tr>
						<td class="clsHeading">Reception</td>
						<td class="clsNumber">
							<xsl:value-of select="count($EYPPNS[PupilStatus/NCyearActual='R' 
								and contains(' Y N ', concat(' ', PupilCharacteristics/EYPPR, ' ') ) ] )"/>
						</td>
						<td class="clsNumber">
							<xsl:value-of select="count($EYPPNS[PupilStatus/NCyearActual='R' 
								and PupilCharacteristics/EYPPR = 'Y' ] )"/>
						</td>
						<td class="clsNumber">
							<xsl:value-of select="count($EYPPNS[PupilStatus/NCyearActual='R' 
								and PupilCharacteristics/EYPPR = 'N' ] )"/>
						</td>
					</tr>
					<tr>
						<td class="clsHeading">Total pupils</td>
						<td class="clsNumber">
							<xsl:value-of select="count($EYPPNS) "/>
						</td>
						<td class="clsNumber">
							<xsl:value-of select="count($EYPPNS[PupilCharacteristics/EYPPR = 'Y']) "/>
						</td>
						<td class="clsNumber">
							<xsl:value-of select="count($EYPPNS[PupilCharacteristics/EYPPR = 'N']) "/>
						</td>
					</tr>
				</table>
			</xsl:otherwise>
		</xsl:choose>
		<br/>
		
		
		<h2>Table 8: Early years pupil premium [Not for: Nursery] [used for funding]</h2>
		<xsl:choose>
			<xsl:when test="$term != 'SPR'">
				<p class="clsFootnote">This table does not apply to the <xsl:value-of select="$thiscensus"/> census, as pupil premium data is only collected in the spring census.</p>
			</xsl:when>
			<xsl:when test="$phase = 'NS'">
				<p class="clsFootnote">Table 8 does not apply to schools with phase of NS (nursery).</p>
			</xsl:when>			
			<xsl:otherwise>
				<table class="summaryreport" border="1">
					<tr>
						<th rowspan="2">NC year group</th>
						<th rowspan="2">Number of<br/>pupils on<br/>roll</th>
						<th colspan="2">of which</th>
					</tr>
					<tr>
						<th>Are in receipt<br/>of early years<br/>pupil <br/>premium<br/>funding</th>
						<th>Are not in<br/>receipt of<br/>early years<br/>pupil<br/>premium<br/>funding</th>
					</tr>
					<tr>
						<td class="clsHeading">E1</td>
						<td class="clsNumber">
							<xsl:value-of select="count($EYPPOTH[PupilStatus/NCyearActual='E1' ] )"/>
							<!--								and contains(' Y N ', concat(' ', PupilCharacteristics/EYPPR, ' ') ) ] )"/>	-->
						</td>
						<td class="clsNumber">
							<xsl:value-of select="count($EYPPOTH[PupilStatus/NCyearActual='E1' 
								and PupilCharacteristics/EYPPR = 'Y' ] )"/>
						</td>
						<td class="clsNumber">
							<xsl:value-of select="count($EYPPOTH[PupilStatus/NCyearActual='E1' 
								and PupilCharacteristics/EYPPR = 'N' ] )"/>
						</td>
					</tr>
					<tr>
						<td class="clsHeading">E2</td>
						<td class="clsNumber">
							<xsl:value-of select="count($EYPPOTH[PupilStatus/NCyearActual='E2'] )"/>
							<!--							and contains(' Y N ', concat(' ', PupilCharacteristics/EYPPR, ' ') ) ] )"/>  -->
						</td>
						<td class="clsNumber">
							<xsl:value-of select="count($EYPPOTH[PupilStatus/NCyearActual='E2' 
								and PupilCharacteristics/EYPPR = 'Y' ] )"/>
						</td>
						<td class="clsNumber">
							<xsl:value-of select="count($EYPPOTH[PupilStatus/NCyearActual='E2' 
								and PupilCharacteristics/EYPPR = 'N' ] )"/>
						</td>
					</tr>
					<tr>
						<td class="clsHeading">N1</td>
						<td class="clsNumber">
							<xsl:value-of select="count($EYPPOTH[PupilStatus/NCyearActual='N1'] )"/>
							<!--								and contains(' Y N ', concat(' ', PupilCharacteristics/EYPPR, ' ') ) ] )"/>	-->
						</td>
						<td class="clsNumber">
							<xsl:value-of select="count($EYPPOTH[PupilStatus/NCyearActual='N1' 
								and PupilCharacteristics/EYPPR = 'Y' ] )"/>
						</td>
						<td class="clsNumber">
							<xsl:value-of select="count($EYPPOTH[PupilStatus/NCyearActual='N1' 
								and PupilCharacteristics/EYPPR = 'N' ] )"/>
						</td>
					</tr>
					<tr>
						<td class="clsHeading">N2</td>
						<td class="clsNumber">
							<xsl:value-of select="count($EYPPOTH[PupilStatus/NCyearActual='N2'] )"/>
							<!--								and contains(' Y N ', concat(' ', PupilCharacteristics/EYPPR, ' ') ) ] )"/>	-->
						</td>
						<td class="clsNumber">
							<xsl:value-of select="count($EYPPOTH[PupilStatus/NCyearActual='N2' 
								and PupilCharacteristics/EYPPR = 'Y' ] )"/>
						</td>
						<td class="clsNumber">
							<xsl:value-of select="count($EYPPOTH[PupilStatus/NCyearActual='N2' 
								and PupilCharacteristics/EYPPR = 'N' ] )"/>
						</td>
					</tr>
					<tr>
						<td class="clsHeading">Reception</td>
						<td class="clsNumber">
							<xsl:value-of select="count($EYPPOTH4YrOlds[PupilStatus/NCyearActual='R'] )"/>
							<!--								and contains(' Y N ', concat(' ', PupilCharacteristics/EYPPR, ' ') ) ] )"/>	-->
						</td>
						<td class="clsNumber">
							<xsl:value-of select="count($EYPPOTH4YrOlds[PupilStatus/NCyearActual='R' 
								and PupilCharacteristics/EYPPR = 'Y' ] )"/>
						</td>
						<td class="clsNumber">
							<xsl:value-of select="count($EYPPOTH4YrOlds[PupilStatus/NCyearActual='R' 
								and PupilCharacteristics/EYPPR = 'N' ] )"/>
						</td>
					</tr>
					<tr>
						<td class="clsHeading">Year X</td>
						<td class="clsNumber">
							<xsl:value-of select="count($EYPPOTH4YrOlds[PupilStatus/NCyearActual='X'] )"/>
						</td>
						<td class="clsNumber">
							<xsl:value-of select="count($EYPPOTH4YrOlds[PupilStatus/NCyearActual='X' 
								and PupilCharacteristics/EYPPR = 'Y' ] )"/>
						</td>
						<td class="clsNumber">
							<xsl:value-of select="count($EYPPOTH4YrOlds[PupilStatus/NCyearActual='X' 
								and PupilCharacteristics/EYPPR = 'N' ] )"/>
						</td>
					</tr>
					<tr>
						<td class="clsHeading">Total pupils</td>
						<td class="clsNumber">
							<xsl:value-of select="count($EYPPOTH[contains(' E1 E2 N1 N2 ', concat(' ', PupilStatus/NCyearActual, ' '))]) 
												+ count($EYPPOTH4YrOlds[PupilStatus/NCyearActual = 'R'])
												+ count($EYPPOTH4YrOlds[PupilStatus/NCyearActual = 'X']) "/>
						</td>
						<td class="clsNumber">
						<!--	<xsl:value-of select="count($EYPPOTH[PupilCharacteristics/EYPPR = 'Y']) "/>	-->
							<xsl:value-of select="count($EYPPOTH[PupilCharacteristics/EYPPR = 'Y' and contains(' E1 E2 N1 N2 ', concat(' ', PupilStatus/NCyearActual, ' ')) ]) 
											    + count($EYPPOTH4YrOlds[PupilCharacteristics/EYPPR = 'Y' and PupilStatus/NCyearActual='R']) 
											    + count($EYPPOTH4YrOlds[PupilCharacteristics/EYPPR = 'Y' and PupilStatus/NCyearActual='X' ]) "/> 
						</td>
						<td class="clsNumber">
						<!--	<xsl:value-of select="count($EYPPOTH[PupilCharacteristics/EYPPR = 'N']) "/>	-->
							<xsl:value-of select="count($EYPPOTH[PupilCharacteristics/EYPPR = 'N' and PupilStatus/NCyearActual='E1' ]) 
												+ count($EYPPOTH[PupilCharacteristics/EYPPR = 'N' and PupilStatus/NCyearActual='E2' ])
												+ count($EYPPOTH[PupilCharacteristics/EYPPR = 'N' and PupilStatus/NCyearActual='N1']) 
												+ count($EYPPOTH[PupilCharacteristics/EYPPR = 'N' and PupilStatus/NCyearActual='N2' ])
												+ count($EYPPOTH4YrOlds[PupilCharacteristics/EYPPR = 'N' and PupilStatus/NCyearActual='R']) 
												+ count($EYPPOTH4YrOlds[PupilCharacteristics/EYPPR = 'N' and PupilStatus/NCyearActual='X' ]) "/> 
						</td>
					</tr>
				</table>
			</xsl:otherwise>
		</xsl:choose>
		<br/>
		
		<h2>Table 9: School childcare [ALL schools]</h2>
		<xsl:choose>
			<xsl:when test="$term != 'SPR'">
				<p class="clsFootnote">This table does not apply to the <xsl:value-of select="$thiscensus"/> census, as school childcare data is only collected in the spring census.</p>
			</xsl:when>
			<xsl:otherwise>
				<table class="summaryreport" border="1">
					<tr>
						<th>Type of <br/>childcare</th>
						<th>Pupils<br/>from<br/>other<br/>schools</th>
						<th>Signposting<br/>off-site<br/>provision</th>
						<th>Childcare<br/>weeks<br/>open</th>
						<th>Childcare<br/>provider</th>
						<th>Number<br/>of<br/>places</th>
					</tr>
					<xsl:for-each select="/Message/School/Miscellaneous/Childcare">
						<xsl:choose>
							<xsl:when test="TypeOfChildcare = 'B' ">
								<tr>
									<td class="clsHeading">Before school</td>
									<td class="clsNumber">
										<xsl:if test="OnSite = 'Y' ">
											<xsl:value-of select="OtherSchools"/>
										</xsl:if>
										<br/>
									</td>
									<td class="clsNumber">
										<xsl:if test="OnSite = 'Y' 
											or OnSite = 'N' ">
											<xsl:value-of select="ChildcareSignposting"/>
										</xsl:if>
										<br/>
									</td>
									<td class="clsNumber">
										<xsl:if test="OnSite = 'Y' ">
											<xsl:value-of select="ChildcareWksOpen"/>
										</xsl:if>
										<br/>
									</td>
									<td class="clsNumber">
										<xsl:if test="OnSite = 'Y' ">
											<xsl:value-of select="ChildcareProvider"/>
										</xsl:if>
										<br/>
									</td>
									<td class="clsNumber">
										<xsl:value-of select="NoOfChildcarePlaces"/>
										<br/>
									</td>
								</tr>
							</xsl:when>
							<xsl:when test="TypeOfChildcare = 'A' ">
								<tr>
									<td class="clsHeading">After school</td>
									<td class="clsNumber">
										<xsl:if test="OnSite = 'Y' ">
											<xsl:value-of select="OtherSchools"/>
										</xsl:if>
										<br/>
									</td>
									<td class="clsNumber">
										<xsl:if test="OnSite = 'Y' 
											or OnSite = 'N' ">
											<xsl:value-of select="ChildcareSignposting"/>
										</xsl:if>
										<br/>
									</td>
									<td class="clsNumber">
										<xsl:if test="OnSite = 'Y' ">
											<xsl:value-of select="ChildcareWksOpen"/>
										</xsl:if>
										<br/>
									</td>
									<td class="clsNumber">
										<xsl:if test="OnSite = 'Y' ">
											<xsl:value-of select="ChildcareProvider"/>
										</xsl:if>
										<br/>
									</td>
									<td class="clsNumber">
										<xsl:value-of select="NoOfChildcarePlaces"/>
										<br/>
									</td>
								</tr>
							</xsl:when>
							<xsl:when test="TypeOfChildcare = 'H' ">
								<tr>
									<td class="clsHeading">Holiday</td>
									<td class="clsNumber">
										<xsl:if test="OnSite = 'Y' ">
											<xsl:value-of select="OtherSchools"/>
										</xsl:if>
									</td>
									<td class="clsNumber">
										<xsl:if test="OnSite = 'Y' 
											or OnSite = 'N' ">
											<xsl:value-of select="ChildcareSignposting"/>
										</xsl:if>
										<br/>
									</td>
									<td class="clsNumber">
										<xsl:if test="OnSite = 'Y' ">
											<xsl:value-of select="ChildcareWksOpen"/>
										</xsl:if>
										<br/>
									</td>
									<td class="clsNumber">
										<xsl:if test="OnSite = 'Y' ">
											<xsl:value-of select="ChildcareProvider"/>
										</xsl:if>
										<br/>
									</td>
									<td class="clsNumber">
										<xsl:value-of select="NoOfChildcarePlaces"/>
										<br/>
									</td>
								</tr>
							</xsl:when>
							<xsl:when test="TypeOfChildcare = 'U' ">
								<tr>
									<td class="clsHeading">Under fives</td>
									<td class="clsNumber">
										<xsl:if test="OnSite = 'Y' ">
											<xsl:value-of select="OtherSchools"/>
										</xsl:if>
									</td>
									<td class="clsNumber">
										<xsl:if test="OnSite = 'Y' 
											or OnSite = 'N' ">
											<xsl:value-of select="ChildcareSignposting"/>
										</xsl:if>
										<br/>
									</td>
									<td class="clsNumber">
										<xsl:if test="OnSite = 'Y' ">
											<xsl:value-of select="ChildcareWksOpen"/>
										</xsl:if>
										<br/>
									</td>
									<td class="clsNumber">
										<xsl:if test="OnSite = 'Y' ">
											<xsl:value-of select="ChildcareProvider"/>
										</xsl:if>
										<br/>
									</td>
									<td class="clsNumber">
										<xsl:value-of select="NoOfChildcarePlaces"/>
										<br/>
									</td>
								</tr>
							</xsl:when>
						</xsl:choose>
					</xsl:for-each>
				</table>
			</xsl:otherwise>
		</xsl:choose>
		<br/>
		
		
		<h2>Table 10: Pupils on roll with SEN provision [ALL schools]</h2>
		<table class="summaryreport" border="1">
			<tr>
				<th>SEN Provision</th>
				<th>Number of pupils</th>
			</tr>
			<tr>
				<td class="clsHeading">SEN Provision - education, health and care plan (code E)</td>
				<td class="clsNumber">
					<xsl:value-of select="count(/Message/Pupils/PupilsOnRoll/PupilOnRoll[SpecialEducationalNeeds/SENprovision='E'] )"/>
				</td>
			</tr>
			<tr>
				<td class="clsHeading">SEN Provision - SEN support (code K)</td>
				<td class="clsNumber">
					<xsl:value-of select="count(/Message/Pupils/PupilsOnRoll/PupilOnRoll[SpecialEducationalNeeds/SENprovision='K'] )"/>
				</td>
			</tr>
			<tr>
				<td class="clsHeading">Total number of pupils with SEN (codes E, and K) </td>
				<td class="clsNumber">
					<xsl:value-of select="count(/Message/Pupils/PupilsOnRoll/PupilOnRoll[contains($SENtypes, concat(' ', SpecialEducationalNeeds/SENprovision, ' ') ) ] )"/>
				</td>
			</tr>
			<tr>
				<td class="clsHeading">No special educational needs (code N)</td>
				<td class="clsNumber">
					<xsl:value-of select="count(/Message/Pupils/PupilsOnRoll/PupilOnRoll[SpecialEducationalNeeds/SENprovision='N'] )"/>
				</td>
			</tr>
.			<tr>
				<td class="clsHeading">Total pupils on roll</td>
				<td class="clsTotal">
					<xsl:value-of select="$b16"/>
				</td>
			</tr>
			<xsl:if test="$b16 != $b10 + $b13">
				<tr>
					<td class="clsHeading">Warning</td>
					<td class="clsTotal" colspan="2">
					Total number of pupils in this table differs from that indicated in table 2.
				</td>
				</tr>
			</xsl:if>
			<xsl:choose>
				<!--The next two rows exclude SP and PR phases-->
				<xsl:when test="contains( ' SP PR ', concat(' ', $phase, ' ' ) )"/>
				<xsl:otherwise>
					<tr>
						<td class="clsHeading">Number of SEN Pupils in a mainstream school who are members of a special provision (SEN Unit). * Should be less than or equal to the total number of pupils with SEN (codes E and K)</td>
						<td class="clsNumber">
							<xsl:value-of select="count(/Message/Pupils/PupilsOnRoll/PupilOnRoll[contains( $true , concat( ' ', SpecialEducationalNeeds/SENunitIndicator, ' ' ) ) ] )"/>
						</td>
					</tr>
					<tr>
						<td class="clsHeading">Number of SEN Pupils in a mainstream school who are members of a special provision (resourced provision). * Should be less than or equal to the total number of pupils with SEN (codes E and K)</td>
						<td class="clsNumber">
							<xsl:value-of select="count(/Message/Pupils/PupilsOnRoll/PupilOnRoll[contains( $true , concat( ' ', SpecialEducationalNeeds/ResourcedProvisionIndicator, ' ' ) ) ] )"/>
						</td>
					</tr>
				</xsl:otherwise>
			</xsl:choose>
		</table>
		<br/>
		
		
		<h2>Table 11: SEN need type for pupils on roll with SEN (SEN provision E or K) [ALL schools]</h2>
		<xsl:choose>
			<!-- New test added 2013-06-26 IK. This table does not apply to nursery, middle deemed Secondary or Secondary schools, show the relevant footnote -->
			<xsl:when test="$term != 'SPR'">
				<p class="clsFootnote">This table does not apply to the <xsl:value-of select="$thiscensus"/> census, as SEN need type is only collected in the spring census.</p>
			</xsl:when>
			<xsl:otherwise>
				<table border="1" class="summaryreport">
					<tr>
						<th>Code</th>
						<th>Description</th>
						<th>Primary Need</th>
						<th>Secondary Need</th>
					</tr>
					<tr>
						<td class="clsHeading">SPLD</td>
						<td class="clsHeading">Specific Learning Difficulty</td>
						<td class="clsNumber">
							<xsl:value-of select="count(/Message/Pupils/PupilsOnRoll/PupilOnRoll/SpecialEducationalNeeds[contains( $SENtypes, concat( ' ', SENprovision, ' ' ) ) ]/SENneeds/SENneed[SENtypeRank='1' and SENtype='SPLD'] )"/>
						</td>
						<td class="clsNumber">
							<xsl:value-of select="count(/Message/Pupils/PupilsOnRoll/PupilOnRoll/SpecialEducationalNeeds[contains( $SENtypes, concat( ' ', SENprovision, ' ' ) ) ]/SENneeds/SENneed[SENtypeRank='2' and SENtype='SPLD'] )"/>
						</td>
					</tr>
					<tr>
						<td class="clsHeading">MLD</td>
						<td class="clsHeading">Moderate Learning Difficulty</td>
						<td class="clsNumber">
							<xsl:value-of select="count(/Message/Pupils/PupilsOnRoll/PupilOnRoll/SpecialEducationalNeeds[contains( $SENtypes, concat( ' ', SENprovision, ' ' ) ) ]/SENneeds/SENneed[SENtypeRank='1' and SENtype='MLD'] )"/>
						</td>
						<td class="clsNumber">
							<xsl:value-of select="count(/Message/Pupils/PupilsOnRoll/PupilOnRoll/SpecialEducationalNeeds[contains( $SENtypes, concat( ' ', SENprovision, ' ' ) ) ]/SENneeds/SENneed[SENtypeRank='2' and SENtype='MLD'] )"/>
						</td>
					</tr>
					<tr>
						<td class="clsHeading">SLD</td>
						<td class="clsHeading">Severe Learning Difficulty</td>
						<td class="clsNumber">
							<xsl:value-of select="count(/Message/Pupils/PupilsOnRoll/PupilOnRoll/SpecialEducationalNeeds[contains( $SENtypes, concat( ' ', SENprovision, ' ' ) ) ]/SENneeds/SENneed[SENtypeRank='1' and SENtype='SLD'] )"/>
						</td>
						<td class="clsNumber">
							<xsl:value-of select="count(/Message/Pupils/PupilsOnRoll/PupilOnRoll/SpecialEducationalNeeds[contains( $SENtypes, concat( ' ', SENprovision, ' ' ) ) ]/SENneeds/SENneed[SENtypeRank='2' and SENtype='SLD'] )"/>
						</td>
					</tr>
					<tr>
						<td class="clsHeading">PMLD</td>
						<td class="clsHeading">Profound and Multiple Learning Difficulty</td>
						<td class="clsNumber">
							<xsl:value-of select="count(/Message/Pupils/PupilsOnRoll/PupilOnRoll/SpecialEducationalNeeds[contains( $SENtypes, concat( ' ', SENprovision, ' ' ) ) ]/SENneeds/SENneed[SENtypeRank='1' and SENtype='PMLD'] )"/>
						</td>
						<td class="clsNumber">
							<xsl:value-of select="count(/Message/Pupils/PupilsOnRoll/PupilOnRoll/SpecialEducationalNeeds[contains( $SENtypes, concat( ' ', SENprovision, ' ' ) ) ]/SENneeds/SENneed[SENtypeRank='2' and SENtype='PMLD'] )"/>
						</td>
					</tr>
					<tr>
						<td class="clsHeading">SEMH</td>
						<td class="clsHeading">Social, emotional and mental health</td>
						<td class="clsNumber">
							<xsl:value-of select="count(/Message/Pupils/PupilsOnRoll/PupilOnRoll/SpecialEducationalNeeds[contains( $SENtypes, concat( ' ', SENprovision, ' ' ) ) ]/SENneeds/SENneed[SENtypeRank='1' and SENtype='SEMH'] )"/>
						</td>
						<td class="clsNumber">
							<xsl:value-of select="count(/Message/Pupils/PupilsOnRoll/PupilOnRoll/SpecialEducationalNeeds[contains( $SENtypes, concat( ' ', SENprovision, ' ' ) ) ]/SENneeds/SENneed[SENtypeRank='2' and SENtype='SEMH'] )"/>
						</td>
					</tr>
					<tr>
						<td class="clsHeading">SLCN</td>
						<td class="clsHeading">Speech, Language and Communication Needs</td>
						<td class="clsNumber">
							<xsl:value-of select="count(/Message/Pupils/PupilsOnRoll/PupilOnRoll/SpecialEducationalNeeds[contains( $SENtypes, concat( ' ', SENprovision, ' ' ) ) ]/SENneeds/SENneed[SENtypeRank='1' and SENtype='SLCN'] )"/>
						</td>
						<td class="clsNumber">
							<xsl:value-of select="count(/Message/Pupils/PupilsOnRoll/PupilOnRoll/SpecialEducationalNeeds[contains( $SENtypes, concat( ' ', SENprovision, ' ' ) ) ]/SENneeds/SENneed[SENtypeRank='2' and SENtype='SLCN'] )"/>
						</td>
					</tr>
					<tr>
						<td class="clsHeading">MSI</td>
						<td class="clsHeading">Multi-Sensory Impairment</td>
						<td class="clsNumber">
							<xsl:value-of select="count(/Message/Pupils/PupilsOnRoll/PupilOnRoll/SpecialEducationalNeeds[contains( $SENtypes, concat( ' ', SENprovision, ' ' ) ) ]/SENneeds/SENneed[SENtypeRank='1' and SENtype='MSI'] )"/>
						</td>
						<td class="clsNumber">
							<xsl:value-of select="count(/Message/Pupils/PupilsOnRoll/PupilOnRoll/SpecialEducationalNeeds[contains( $SENtypes, concat( ' ', SENprovision, ' ' ) ) ]/SENneeds/SENneed[SENtypeRank='2' and SENtype='MSI'] )"/>
						</td>
					</tr>
					<tr>
						<td class="clsHeading">HI</td>
						<td class="clsHeading">Hearing Impairment</td>
						<td class="clsNumber">
							<xsl:value-of select="count(/Message/Pupils/PupilsOnRoll/PupilOnRoll/SpecialEducationalNeeds[contains( $SENtypes, concat( ' ', SENprovision, ' ' ) ) ]/SENneeds/SENneed[SENtypeRank='1' and SENtype='HI'] )"/>
						</td>
						<td class="clsNumber">
							<xsl:value-of select="count(/Message/Pupils/PupilsOnRoll/PupilOnRoll/SpecialEducationalNeeds[contains( $SENtypes, concat( ' ', SENprovision, ' ' ) ) ]/SENneeds/SENneed[SENtypeRank='2' and SENtype='HI'] )"/>
						</td>
					</tr>
					<tr>
						<td class="clsHeading">VI</td>
						<td class="clsHeading">Vision Impairment</td>
						<td class="clsNumber">
							<xsl:value-of select="count(/Message/Pupils/PupilsOnRoll/PupilOnRoll/SpecialEducationalNeeds[contains( $SENtypes, concat( ' ', SENprovision, ' ' ) ) ]/SENneeds/SENneed[SENtypeRank='1' and SENtype='VI'] )"/>
						</td>
						<td class="clsNumber">
							<xsl:value-of select="count(/Message/Pupils/PupilsOnRoll/PupilOnRoll/SpecialEducationalNeeds[contains( $SENtypes, concat( ' ', SENprovision, ' ' ) ) ]/SENneeds/SENneed[SENtypeRank='2' and SENtype='VI'] )"/>
						</td>
					</tr>
					<tr>
						<td class="clsHeading">PD</td>
						<td class="clsHeading">Physical Disability</td>
						<td class="clsNumber">
							<xsl:value-of select="count(/Message/Pupils/PupilsOnRoll/PupilOnRoll/SpecialEducationalNeeds[contains( $SENtypes, concat( ' ', SENprovision, ' ' ) ) ]/SENneeds/SENneed[SENtypeRank='1' and SENtype='PD'] )"/>
						</td>
						<td class="clsNumber">
							<xsl:value-of select="count(/Message/Pupils/PupilsOnRoll/PupilOnRoll/SpecialEducationalNeeds[contains( $SENtypes, concat( ' ', SENprovision, ' ' ) ) ]/SENneeds/SENneed[SENtypeRank='2' and SENtype='PD'] )"/>
						</td>
					</tr>
					<tr>
						<td class="clsHeading">ASD</td>
						<td class="clsHeading">Autistic Spectrum Disorder</td>
						<td class="clsNumber">
							<xsl:value-of select="count(/Message/Pupils/PupilsOnRoll/PupilOnRoll/SpecialEducationalNeeds[contains( $SENtypes, concat( ' ', SENprovision, ' ' ) ) ]/SENneeds/SENneed[SENtypeRank='1' and SENtype='ASD'] )"/>
						</td>
						<td class="clsNumber">
							<xsl:value-of select="count(/Message/Pupils/PupilsOnRoll/PupilOnRoll/SpecialEducationalNeeds[contains( $SENtypes, concat( ' ', SENprovision, ' ' ) ) ]/SENneeds/SENneed[SENtypeRank='2' and SENtype='ASD'] )"/>
						</td>
					</tr>
					<tr>
						<!--This row new for Spring 2014-->
						<td class="clsHeading">NSA</td>
						<td class="clsHeading">SEN support but no specialist assessment of type of need</td>
						<td class="clsNumber">
							<xsl:value-of select="count(/Message/Pupils/PupilsOnRoll/PupilOnRoll/SpecialEducationalNeeds[contains( $SENtypes, concat( ' ', SENprovision, ' ' ) ) ]/SENneeds/SENneed[SENtypeRank='1' and SENtype='NSA'] )"/>
						</td>
						<td class="clsNumber">
							<xsl:value-of select="count(/Message/Pupils/PupilsOnRoll/PupilOnRoll/SpecialEducationalNeeds[contains( $SENtypes, concat( ' ', SENprovision, ' ' ) ) ]/SENneeds/SENneed[SENtypeRank='2' and SENtype='NSA'] )"/>
						</td>
					</tr>
					<tr>
						<td class="clsHeading">OTH</td>
						<td class="clsHeading">Other Difficulty / Disability</td>
						<td class="clsNumber">
							<xsl:value-of select="count(/Message/Pupils/PupilsOnRoll/PupilOnRoll/SpecialEducationalNeeds[contains( $SENtypes, concat( ' ', SENprovision, ' ' ) ) ]/SENneeds/SENneed[SENtypeRank='1' and SENtype='OTH'] )"/>
						</td>
						<td class="clsNumber">
							<xsl:value-of select="count(/Message/Pupils/PupilsOnRoll/PupilOnRoll/SpecialEducationalNeeds[contains( $SENtypes, concat( ' ', SENprovision, ' ' ) ) ]/SENneeds/SENneed[SENtypeRank='2' and SENtype='OTH'] )"/>
						</td>
					</tr>
				</table>
			</xsl:otherwise>
		</xsl:choose>
		<br/>
		
		
		<xsl:if test="$term='AUT'">
			<h2>Table 12: Number of suspensions and permanent exclusions by SEN provision in the 2023 spring and summer terms (terms 3, 4, 5 and 6) [Not for: Nursery school]</h2>
			<xsl:variable name="t0lower" select="20220901"/>
			<xsl:variable name="t0upper" select="20221231"/>
			<xsl:variable name="t1lower" select="20230101"/>
			<xsl:variable name="t1upper" select="20230409"/>
			<xsl:variable name="t2lower" select="20230410"/>
			<xsl:variable name="t2upper" select="20230731"/>
			<xsl:choose>
				<xsl:when test="/Message/School/SchoolCharacteristics/Phase = 'NS'">
					<p class="clsFootnote">Table 12 does not apply to schools with phase of NS (nursery).</p>
				</xsl:when>
				<xsl:otherwise>
					<table class="summaryreport" border="1">
						<tr>
							<th colspan="2"/>
							<!--<th colspan="2">Autumn term (01 September 2019 - 31 December 2019)</th> -->
							<th colspan="2">Spring term (01 January 2023 - 09 April 2023)</th>
							<th colspan="2">Summer term (10 April 2023 - 31 July 2023)</th>
						</tr>
						<tr>
							<th colspan="2"/>
							<!--<th>Number of fixed exclusions</th>
							<th>Number of permanent exclusions</th>	-->
							<th>Number of suspensions</th>
							<th>Number of permanent exclusions</th>
							<th>Number of suspensions</th>
							<th>Number of permanent exclusions</th>
						</tr>
						<xsl:choose>
							<xsl:when test=" count(//TermlyExclusion ) &gt; 0 ">
								<tr>
									<td class="clsHeading" colspan="2"> </td>
									<td class="clsNumber">
										<xsl:value-of select="count(//TermlyExclusion[Category='SUSP' 
											and translate(StartDate, '-', '') &gt;= $t1lower
											and translate(StartDate, '-', '') &lt;= $t1upper
											] )"/>
									</td>
									<td class="clsNumber">
										<xsl:value-of select="count(//TermlyExclusion[Category='PERM' 
											and translate(StartDate, '-', '') &gt;= $t1lower
											and translate(StartDate, '-', '') &lt;= $t1upper
											] )"/>
									</td>
									<td class="clsNumber">
										<xsl:value-of select="count(//TermlyExclusion[Category='SUSP' 
											and translate(StartDate, '-', '') &gt;= $t2lower
											and translate(StartDate, '-', '') &lt;= $t2upper
											] )"/>
									</td>
									<td class="clsNumber">
										<xsl:value-of select="count(//TermlyExclusion[Category='PERM' 
											and translate(StartDate, '-', '') &gt;= $t2lower
											and translate(StartDate, '-', '') &lt;= $t2upper
											] )"/>
									</td>
								</tr>
							</xsl:when>
							<xsl:otherwise>
								<td class="clsHeading" colspan="5">No exclusions recorded</td>
							</xsl:otherwise>
						</xsl:choose>
						<tr>
							<th colspan="2">SEN Provision</th>
							<!--<th>Number of fixed exclusions</th>
							<th>Number of permanent exclusions</th>	-->
							<th>Number of suspensions</th>
							<th>Number of permanent exclusions</th>
							<th>Number of suspensions</th>
							<th>Number of permanent exclusions</th>
						</tr>
						<tr>
							<td class="clsHeading" colspan="2">Pupils with SEN provision E - education, health and care plan</td>
							<!--<td class="clsNumber">
								<xsl:value-of select="count(//TermlyExclusion[Category='FIXD' 
									and translate(StartDate, '-', '') &gt;= $t0lower
									and translate(StartDate, '-', '') &lt;= $t0upper
									and SENprovision = 'E'] )"/>
							</td>
							<td class="clsNumber">
								<xsl:value-of select="count(//TermlyExclusion[Category='PERM' 
									and translate(StartDate, '-', '') &gt;= $t0lower
									and translate(StartDate, '-', '') &lt;= $t0upper
									and SENprovision = 'E'] )"/>
							</td>	-->
							<td class="clsNumber">
								<xsl:value-of select="count(//TermlyExclusion[Category='SUSP' 
									and translate(StartDate, '-', '') &gt;= $t1lower
									and translate(StartDate, '-', '') &lt;= $t1upper
									and SENprovision = 'E'] )"/>
							</td>
							<td class="clsNumber">
								<xsl:value-of select="count(//TermlyExclusion[Category='PERM' 
									and translate(StartDate, '-', '') &gt;= $t1lower
									and translate(StartDate, '-', '') &lt;= $t1upper
									and SENprovision = 'E'] )"/>
							</td>
							<td class="clsNumber">
								<xsl:value-of select="count(//TermlyExclusion[Category='SUSP' 
									and translate(StartDate, '-', '') &gt;= $t2lower
									and translate(StartDate, '-', '') &lt;= $t2upper
									and SENprovision = 'E'] )"/>
							</td>
							<td class="clsNumber">
								<xsl:value-of select="count(//TermlyExclusion[Category='PERM' 
									and translate(StartDate, '-', '') &gt;= $t2lower
									and translate(StartDate, '-', '') &lt;= $t2upper
									and SENprovision = 'E'] )"/>
							</td>
						</tr>
						<tr>
							<td class="clsHeading" colspan="2">Pupils with SEN provision K - SEN support</td>
							<!--<td class="clsNumber">
								<xsl:value-of select="count(//TermlyExclusion[Category='FIXD' 
									and translate(StartDate, '-', '') &gt;= $t0lower
									and translate(StartDate, '-', '') &lt;= $t0upper
									and SENprovision = 'K'] )"/>
							</td>
							<td class="clsNumber">
								<xsl:value-of select="count(//TermlyExclusion[Category='PERM' 
									and translate(StartDate, '-', '') &gt;= $t0lower
									and translate(StartDate, '-', '') &lt;= $t0upper
									and SENprovision = 'K'] )"/>
							</td>	-->
							<td class="clsNumber">
								<xsl:value-of select="count(//TermlyExclusion[Category='SUSP' 
									and translate(StartDate, '-', '') &gt;= $t1lower
									and translate(StartDate, '-', '') &lt;= $t1upper
									and SENprovision = 'K'] )"/>
							</td>
							<td class="clsNumber">
								<xsl:value-of select="count(//TermlyExclusion[Category='PERM' 
									and translate(StartDate, '-', '') &gt;= $t1lower
									and translate(StartDate, '-', '') &lt;= $t1upper
									and SENprovision = 'K'] )"/>
							</td>
							<td class="clsNumber">
								<xsl:value-of select="count(//TermlyExclusion[Category='SUSP' 
									and translate(StartDate, '-', '') &gt;= $t2lower
									and translate(StartDate, '-', '') &lt;= $t2upper
									and SENprovision = 'K'] )"/>
							</td>
							<td class="clsNumber">
								<xsl:value-of select="count(//TermlyExclusion[Category='PERM' 
									and translate(StartDate, '-', '') &gt;= $t2lower
									and translate(StartDate, '-', '') &lt;= $t2upper
									and SENprovision = 'K'] )"/>
							</td>
						</tr>
						<tr>
							<td class="clsHeading" colspan="2">Pupils with no SEN provision (code N)</td>
							<!--<td class="clsNumber">
								<xsl:value-of select="count(//TermlyExclusion[Category='FIXD' 
									and translate(StartDate, '-', '') &gt;= $t0lower
									and translate(StartDate, '-', '') &lt;= $t0upper
									and SENprovision = 'N'] )"/>
							</td>
							<td class="clsNumber">
								<xsl:value-of select="count(//TermlyExclusion[Category='PERM' 
									and translate(StartDate, '-', '') &gt;= $t0lower
									and translate(StartDate, '-', '') &lt;= $t0upper
									and SENprovision = 'N'] )"/>
							</td>	-->
							<td class="clsNumber">
								<xsl:value-of select="count(//TermlyExclusion[Category='SUSP' 
									and translate(StartDate, '-', '') &gt;= $t1lower
									and translate(StartDate, '-', '') &lt;= $t1upper
									and SENprovision = 'N'] )"/>
							</td>
							<td class="clsNumber">
								<xsl:value-of select="count(//TermlyExclusion[Category='PERM' 
									and translate(StartDate, '-', '') &gt;= $t1lower
									and translate(StartDate, '-', '') &lt;= $t1upper
									and SENprovision = 'N'] )"/>
							</td>
							<td class="clsNumber">
								<xsl:value-of select="count(//TermlyExclusion[Category='SUSP' 
									and translate(StartDate, '-', '') &gt;= $t2lower
									and translate(StartDate, '-', '') &lt;= $t2upper
									and SENprovision = 'N'] )"/>
							</td>
							<td class="clsNumber">
								<xsl:value-of select="count(//TermlyExclusion[Category='PERM' 
									and translate(StartDate, '-', '') &gt;= $t2lower
									and translate(StartDate, '-', '') &lt;= $t2upper
									and SENprovision = 'N'] )"/>
							</td>
						</tr>
					</table>
				</xsl:otherwise>
			</xsl:choose>
		</xsl:if>
		<br/>
		<xsl:if test="$term='SPR'">
			<h2>Table 12: Number of suspensions and permanent exclusions by SEN provision in the 2023 summer and autumn terms (terms 5, 6, 1 and 2) [Not for: Nursery school]</h2>
			<xsl:variable name="t1lower" select="20230410"/>
			<xsl:variable name="t1upper" select="20230731"/>
			<xsl:variable name="t2lower" select="20230801"/>
			<xsl:variable name="t2upper" select="20231231"/>
			<xsl:choose>
				<xsl:when test="/Message/School/SchoolCharacteristics/Phase = 'NS'">
					<p class="clsFootnote">Table 12 does not apply to schools with phase of NS (nursery).</p>
				</xsl:when>
				<xsl:otherwise>
					<table class="summaryreport" border="1">
						<tr>
							<th colspan="2"/>
							<th colspan="2">Summer term (10 April 2023 - 31 July 2023)</th>
							<th colspan="2">Autumn term (1 August 2023 - 31 December 2023)</th>
						</tr>
						<tr>
							<!--							<th colspan="2">Reason for exclusion</th>	-->
							<th colspan="2"/>
							<th>Number of suspensions</th>
							<th>Number of permanent exclusions</th>
							<th>Number of suspensions</th>
							<th>Number of permanent exclusions</th>
						</tr>
						<xsl:choose>
							<xsl:when test=" count(//TermlyExclusion ) &gt; 0 ">
								<tr>
									<td class="clsHeading" colspan="2"> </td>
									<td class="clsNumber">
										<xsl:value-of select="count(//TermlyExclusion[Category='SUSP' 
											and translate(StartDate, '-', '') &gt;= $t1lower
											and translate(StartDate, '-', '') &lt;= $t1upper
											] )"/>
									</td>
									<td class="clsNumber">
										<xsl:value-of select="count(//TermlyExclusion[Category='PERM' 
											and translate(StartDate, '-', '') &gt;= $t1lower
											and translate(StartDate, '-', '') &lt;= $t1upper
											] )"/>
									</td>
									<td class="clsNumber">
										<xsl:value-of select="count(//TermlyExclusion[Category='SUSP' 
											and translate(StartDate, '-', '') &gt;= $t2lower
											and translate(StartDate, '-', '') &lt;= $t2upper
											] )"/>
									</td>
									<td class="clsNumber">
										<xsl:value-of select="count(//TermlyExclusion[Category='PERM' 
											and translate(StartDate, '-', '') &gt;= $t2lower
											and translate(StartDate, '-', '') &lt;= $t2upper
											] )"/>
									</td>
								</tr>
							</xsl:when>
							<xsl:otherwise>
								<td class="clsHeading" colspan="5">No exclusions recorded</td>
							</xsl:otherwise>
						</xsl:choose>
						<!--						<xsl:choose>
							<xsl:when test=" count(//TermlyExclusion/Reason ) &gt; 0 ">
								<xsl:for-each select="//TermlyExclusion/Reason ">
									<xsl:sort select="."/>
									<xsl:choose>
										<xsl:when test=". = preceding::TermlyExclusion/Reason "/>
										<xsl:otherwise>
											<tr>
												<td class="clsHeading">
													<xsl:value-of select="."/>
												</td>
												<td class="clsSubhead">
													<xsl:value-of select="document('./SchoolCensus23-24-SchoolSummaryReferenceLists.xsl') /xsl:stylesheet/Exclusion[ExclusionCode = current() ]/ExclusionDescription"/>
												</td>
												<td class="clsNumber">
													<xsl:value-of select="count(//TermlyExclusion/Reason[. = current() 
														and translate(../StartDate, '-', '') &gt;= $t1lower
														and translate(../StartDate, '-', '') &lt;= $t1upper
														and ../Category = 'FIXD'  ] ) "/>
												</td>
												<td class="clsNumber">
													<xsl:value-of select="count(//TermlyExclusion/Reason[. = current() 
														and translate(../StartDate, '-', '') &gt;= $t1lower
														and translate(../StartDate, '-', '') &lt;= $t1upper
														and ../Category = 'PERM'  ] ) "/>
												</td>
												<td class="clsNumber">
													<xsl:value-of select="count(//TermlyExclusion/Reason[. = current() 
														and translate(../StartDate, '-', '') &gt;= $t2lower
														and translate(../StartDate, '-', '') &lt;= $t2upper
														and ../Category = 'FIXD'  ] ) "/>
												</td>
												<td class="clsNumber">
													<xsl:value-of select="count(//TermlyExclusion/Reason[. = current() 
														and translate(../StartDate, '-', '') &gt;= $t2lower
														and translate(../StartDate, '-', '') &lt;= $t2upper
														and ../Category = 'PERM'  ] ) "/>
												</td>
											</tr>
										</xsl:otherwise>
									</xsl:choose>
								</xsl:for-each>
							</xsl:when>	
							<xsl:otherwise>
								<td class="clsHeading" colspan="5">No exclusions recorded</td>
							</xsl:otherwise>
						</xsl:choose>
-->
						<tr>
							<th colspan="2">SEN Provision of excluded pupil</th>
							<th>Number of suspensions</th>
							<th>Number of permanent exclusions</th>
							<th>Number of suspensions</th>
							<th>Number of permanent exclusions</th>
						</tr>
						<tr>
							<td class="clsHeading" colspan="2">Pupils with SEN provision E - education, health and care plan</td>
							<td class="clsNumber">
								<xsl:value-of select="count(//TermlyExclusion[Category='SUSP' 
									and translate(StartDate, '-', '') &gt;= $t1lower
									and translate(StartDate, '-', '') &lt;= $t1upper
									and SENprovision = 'E'] )"/>
							</td>
							<td class="clsNumber">
								<xsl:value-of select="count(//TermlyExclusion[Category='PERM' 
									and translate(StartDate, '-', '') &gt;= $t1lower
									and translate(StartDate, '-', '') &lt;= $t1upper
									and SENprovision = 'E'] )"/>
							</td>
							<td class="clsNumber">
								<xsl:value-of select="count(//TermlyExclusion[Category='SUSP' 
									and translate(StartDate, '-', '') &gt;= $t2lower
									and translate(StartDate, '-', '') &lt;= $t2upper
									and SENprovision = 'E'] )"/>
							</td>
							<td class="clsNumber">
								<xsl:value-of select="count(//TermlyExclusion[Category='PERM' 
									and translate(StartDate, '-', '') &gt;= $t2lower
									and translate(StartDate, '-', '') &lt;= $t2upper
									and SENprovision = 'E'] )"/>
							</td>
						</tr>
						<tr>
							<td class="clsHeading" colspan="2">Pupils with SEN provision K - SEN support</td>
							<td class="clsNumber">
								<xsl:value-of select="count(//TermlyExclusion[Category='SUSP' 
									and translate(StartDate, '-', '') &gt;= $t1lower
									and translate(StartDate, '-', '') &lt;= $t1upper
									and SENprovision = 'K'] )"/>
							</td>
							<td class="clsNumber">
								<xsl:value-of select="count(//TermlyExclusion[Category='PERM' 
									and translate(StartDate, '-', '') &gt;= $t1lower
									and translate(StartDate, '-', '') &lt;= $t1upper
									and SENprovision = 'K'] )"/>
							</td>
							<td class="clsNumber">
								<xsl:value-of select="count(//TermlyExclusion[Category='SUSP' 
									and translate(StartDate, '-', '') &gt;= $t2lower
									and translate(StartDate, '-', '') &lt;= $t2upper
									and SENprovision = 'K'] )"/>
							</td>
							<td class="clsNumber">
								<xsl:value-of select="count(//TermlyExclusion[Category='PERM' 
									and translate(StartDate, '-', '') &gt;= $t2lower
									and translate(StartDate, '-', '') &lt;= $t2upper
									and SENprovision = 'K'] )"/>
							</td>
						</tr>
						<tr>
							<td class="clsHeading" colspan="2">Pupils with no SEN provision (code N)</td>
							<td class="clsNumber">
								<xsl:value-of select="count(//TermlyExclusion[Category='SUSP' 
									and translate(StartDate, '-', '') &gt;= $t1lower
									and translate(StartDate, '-', '') &lt;= $t1upper
									and SENprovision = 'N'] )"/>
							</td>
							<td class="clsNumber">
								<xsl:value-of select="count(//TermlyExclusion[Category='PERM' 
									and translate(StartDate, '-', '') &gt;= $t1lower
									and translate(StartDate, '-', '') &lt;= $t1upper
									and SENprovision = 'N'] )"/>
							</td>
							<td class="clsNumber">
								<xsl:value-of select="count(//TermlyExclusion[Category='SUSP' 
									and translate(StartDate, '-', '') &gt;= $t2lower
									and translate(StartDate, '-', '') &lt;= $t2upper
									and SENprovision = 'N'] )"/>
							</td>
							<td class="clsNumber">
								<xsl:value-of select="count(//TermlyExclusion[Category='PERM' 
									and translate(StartDate, '-', '') &gt;= $t2lower
									and translate(StartDate, '-', '') &lt;= $t2upper
									and SENprovision = 'N'] )"/>
							</td>
						</tr>
					</table>
				</xsl:otherwise>
			</xsl:choose>
		</xsl:if>
		<br/>
		<xsl:if test="$term='SUM'">
			<h2>Table 12: Number of suspensions and permanent exclusions by SEN provision in the 2023 autumn and 2024 spring terms (terms 1, 2, 3 and 4) [Not for: Nursery school]</h2>
			<xsl:variable name="t1lower" select="20230801"/>
			<xsl:variable name="t1upper" select="20231231"/>
			<xsl:variable name="t2lower" select="20240101"/>
			<xsl:variable name="t2upper" select="20240331"/>
			<xsl:choose>
				<xsl:when test="/Message/School/SchoolCharacteristics/Phase = 'NS'">
					<p class="clsFootnote">Table 12 does not apply to schools with phase of NS (nursery).</p>
				</xsl:when>
				<xsl:otherwise>
					<table class="summaryreport" border="1">
						<tr>
							<th colspan="2"/>
							<th colspan="2">Autumn term (01 September 2023 - 31 December 2023)</th>
							<th colspan="2">Spring term (01 January 2024 - 31 March 2024)</th>
						</tr>
						<tr>
							<th colspan="2"/>
							<th>Number of suspensions</th>
							<th>Number of permanent exclusions</th>
							<th>Number of suspensions</th>
							<th>Number of permanent exclusions</th>
						</tr>
						<xsl:choose>
							<xsl:when test=" count(//TermlyExclusion ) &gt; 0 ">
								<tr>
									<td class="clsHeading" colspan="2"> </td>
									<td class="clsNumber">
										<xsl:value-of select="count(//TermlyExclusion[Category='SUSP' 
											and translate(StartDate, '-', '') &gt;= $t1lower
											and translate(StartDate, '-', '') &lt;= $t1upper
											] )"/>
									</td>
									<td class="clsNumber">
										<xsl:value-of select="count(//TermlyExclusion[Category='PERM' 
											and translate(StartDate, '-', '') &gt;= $t1lower
											and translate(StartDate, '-', '') &lt;= $t1upper
											] )"/>
									</td>
									<td class="clsNumber">
										<xsl:value-of select="count(//TermlyExclusion[Category='SUSP' 
											and translate(StartDate, '-', '') &gt;= $t2lower
											and translate(StartDate, '-', '') &lt;= $t2upper
											] )"/>
									</td>
									<td class="clsNumber">
										<xsl:value-of select="count(//TermlyExclusion[Category='PERM' 
											and translate(StartDate, '-', '') &gt;= $t2lower
											and translate(StartDate, '-', '') &lt;= $t2upper
											] )"/>
									</td>
								</tr>
							</xsl:when>
							<xsl:otherwise>
								<td class="clsHeading" colspan="5">No suspensions or permanent exclusions recorded</td>
							</xsl:otherwise>
						</xsl:choose>
						<tr>
							<th colspan="2">SEN Provision</th>
							<th>Number of suspensions</th>
							<th>Number of permanent exclusions</th>
							<th>Number of suspensions</th>
							<th>Number of permanent exclusions</th>
						</tr>
						<tr>
							<td class="clsHeading" colspan="2">Pupils with SEN provision E - education, health and care plan</td>
							<td class="clsNumber">
								<xsl:value-of select="count(//TermlyExclusion[Category='SUSP' 
									and translate(StartDate, '-', '') &gt;= $t1lower
									and translate(StartDate, '-', '') &lt;= $t1upper
									and SENprovision = 'E'] )"/>
							</td>
							<td class="clsNumber">
								<xsl:value-of select="count(//TermlyExclusion[Category='PERM' 
									and translate(StartDate, '-', '') &gt;= $t1lower
									and translate(StartDate, '-', '') &lt;= $t1upper
									and SENprovision = 'E'] )"/>
							</td>
							<td class="clsNumber">
								<xsl:value-of select="count(//TermlyExclusion[Category='SUSP' 
									and translate(StartDate, '-', '') &gt;= $t2lower
									and translate(StartDate, '-', '') &lt;= $t2upper
									and SENprovision = 'E'] )"/>
							</td>
							<td class="clsNumber">
								<xsl:value-of select="count(//TermlyExclusion[Category='PERM' 
									and translate(StartDate, '-', '') &gt;= $t2lower
									and translate(StartDate, '-', '') &lt;= $t2upper
									and SENprovision = 'E'] )"/>
							</td>
						</tr>
						<tr>
							<td class="clsHeading" colspan="2">Pupils with SEN provision K - SEN support</td>
							<td class="clsNumber">
								<xsl:value-of select="count(//TermlyExclusion[Category='SUSP' 
									and translate(StartDate, '-', '') &gt;= $t1lower
									and translate(StartDate, '-', '') &lt;= $t1upper
									and SENprovision = 'K'] )"/>
							</td>
							<td class="clsNumber">
								<xsl:value-of select="count(//TermlyExclusion[Category='PERM' 
									and translate(StartDate, '-', '') &gt;= $t1lower
									and translate(StartDate, '-', '') &lt;= $t1upper
									and SENprovision = 'K'] )"/>
							</td>
							<td class="clsNumber">
								<xsl:value-of select="count(//TermlyExclusion[Category='SUSP' 
									and translate(StartDate, '-', '') &gt;= $t2lower
									and translate(StartDate, '-', '') &lt;= $t2upper
									and SENprovision = 'K'] )"/>
							</td>
							<td class="clsNumber">
								<xsl:value-of select="count(//TermlyExclusion[Category='PERM' 
									and translate(StartDate, '-', '') &gt;= $t2lower
									and translate(StartDate, '-', '') &lt;= $t2upper
									and SENprovision = 'K'] )"/>
							</td>
						</tr>
						<tr>
							<td class="clsHeading" colspan="2">Pupils with no SEN provision (code N)</td>
							<td class="clsNumber">
								<xsl:value-of select="count(//TermlyExclusion[Category='SUSP' 
									and translate(StartDate, '-', '') &gt;= $t1lower
									and translate(StartDate, '-', '') &lt;= $t1upper
									and SENprovision = 'N'] )"/>
							</td>
							<td class="clsNumber">
								<xsl:value-of select="count(//TermlyExclusion[Category='PERM' 
									and translate(StartDate, '-', '') &gt;= $t1lower
									and translate(StartDate, '-', '') &lt;= $t1upper
									and SENprovision = 'N'] )"/>
							</td>
							<td class="clsNumber">
								<xsl:value-of select="count(//TermlyExclusion[Category='SUSP' 
									and translate(StartDate, '-', '') &gt;= $t2lower
									and translate(StartDate, '-', '') &lt;= $t2upper
									and SENprovision = 'N'] )"/>
							</td>
							<td class="clsNumber">
								<xsl:value-of select="count(//TermlyExclusion[Category='PERM' 
									and translate(StartDate, '-', '') &gt;= $t2lower
									and translate(StartDate, '-', '') &lt;= $t2upper
									and SENprovision = 'N'] )"/>
							</td>
						</tr>
					</table>
				</xsl:otherwise>
			</xsl:choose>
		</xsl:if>
		<br/>
		
		
		<!-- Table 13 removed for Autumn 2020 collection as attendance data wasn't collected due to COVID-19 related school closures -->
		<!-- code to do that was added after the variables-->		
		<h2>Table 13: Attendance information for the <xsl:value-of select="$prevcensus"/> term (<xsl:value-of select="$prevterms"/>) for all pupils aged between 5 and 15 years as at  <xsl:value-of select="$AgeAsAtHeadertext"/> [Not for: Nursery school]</h2>
		<xsl:variable name="TotalSessionsPossibleOn" select="sum($OnRoll5_15/Attendance/TermlyAttendance/SessionsPossible[. &gt; 0] ) "/>
		<xsl:variable name="TotalSessionsPossibleOff" select="sum($OffRoll5_15/Attendance/TermlyAttendance/SessionsPossible[. &gt; 0] ) "/>
		<xsl:variable name="TotalSessionsPossible" select="$TotalSessionsPossibleOn + $TotalSessionsPossibleOff"/>
		<xsl:variable name="NumberOnRoll" select="count($OnRoll5_15/Attendance/TermlyAttendance/SessionsPossible[. &gt; 0] ) "/>
		<xsl:variable name="NumberOffRoll" select="count($OffRoll5_15/Attendance/TermlyAttendance/SessionsPossible[. &gt; 0] ) "/>
		<xsl:variable name="NumberOnOffRoll" select=" $NumberOnRoll +$NumberOffRoll"/>
		<xsl:variable name="AtLeastOneAbsenceOn" select="count($OnRoll5_15/Attendance/TermlyAttendance
				[SessionsPossible &gt; 0 
					and (SessionsAuthorised &gt; 0 
								or SessionsUnauthorised &gt; 0 
								or (sum(SessionDetails/SessionDetail/Sessions[. &gt; 0 and contains( ' I M R S T H E C G U O N ', concat(' ', ../AttendanceReason, ' ') ) ] ) ) &gt; 0 ) ] ) "/>
		<xsl:variable name="AtLeastOneAbsenceOff" select="count($OffRoll5_15/Attendance/TermlyAttendance
				[SessionsPossible &gt; 0 
					and (SessionsAuthorised &gt; 0 
								or SessionsUnauthorised &gt; 0 
								or (sum(SessionDetails/SessionDetail/Sessions[. &gt; 0 and contains( ' I M R S T H E C G U O N ', concat(' ', ../AttendanceReason, ' ') ) ] ) ) &gt; 0 ) ] ) "/>
		<xsl:variable name="AtLeastOneAbsence" select="$AtLeastOneAbsenceOn + $AtLeastOneAbsenceOff"/>
		<xsl:variable name="TotalSessionsAuthorisedOn" select="sum($OnRoll5_15/Attendance/TermlyAttendance/SessionsAuthorised
			[ . &gt; 0 and ../SessionsPossible &gt; 0 ] ) 
		+ sum($OnRoll5_15/Attendance/TermlyAttendance/SessionDetails/SessionDetail/Sessions
			[ . &gt; 0 and contains( ' I M R S T H E C ', concat(' ', ../AttendanceReason, ' ') ) and ../../../SessionsPossible &gt; 0 ] )"/>
		<xsl:variable name="TotalSessionsAuthorisedOff" select="sum($OffRoll5_15/Attendance/TermlyAttendance/SessionsAuthorised
			[ . &gt; 0 and ../SessionsPossible &gt; 0 ] ) 
		+ sum($OffRoll5_15/Attendance/TermlyAttendance/SessionDetails/SessionDetail/Sessions
			[ . &gt; 0 and contains( ' I M R S T H E C ', concat(' ', ../AttendanceReason, ' ') ) and ../../../SessionsPossible &gt; 0 ] )"/>
		<xsl:variable name="TotalSessionsAuthorised" select="$TotalSessionsAuthorisedOn + $TotalSessionsAuthorisedOff"/>
		<xsl:variable name="TotalSessionsUnauthorisedOn" select="sum($OnRoll5_15/Attendance/TermlyAttendance/SessionsUnauthorised
			[ . &gt; 0 and ../SessionsPossible &gt; 0 ] ) 
		+ sum($OnRoll5_15/Attendance/TermlyAttendance/SessionDetails/SessionDetail/Sessions
			[ . &gt; 0 and contains( ' G U O N ', concat(' ', ../AttendanceReason, ' ') ) and ../../../SessionsPossible &gt; 0 ] )"/>
		<xsl:variable name="TotalSessionsUnauthorisedOff" select="sum($OffRoll5_15/Attendance/TermlyAttendance/SessionsUnauthorised
			[ . &gt; 0 and ../SessionsPossible &gt; 0 ] ) 
		+ sum($OffRoll5_15/Attendance/TermlyAttendance/SessionDetails/SessionDetail/Sessions
			[ . &gt; 0 and contains( ' G U O N ', concat(' ', ../AttendanceReason, ' ') ) and ../../../SessionsPossible &gt; 0 ] )"/>
		<xsl:variable name="TotalSessionsUnauthorised" select=" $TotalSessionsUnauthorisedOn +$TotalSessionsUnauthorisedOff"/>
		<!--These two used for persistent absence calculations.  Note that absence is only calculated on the first half term for autumn-->
		<xsl:variable name="OverTenPCAbsenceOn" select="count(//PupilOnRoll
										[ ( ($AttendanceAcademicYear - substring( PupilIdentifiers/DOB, 1, 4 ) - (substring( PupilIdentifiers/DOB, 6, 2 ) &gt; $August) ) &gt;=5
											and ($AttendanceAcademicYear - substring( PupilIdentifiers/DOB, 1, 4 ) - (substring( PupilIdentifiers/DOB, 6, 2 ) &gt; $August) ) &lt;=15
											and Attendance/TermlyAttendance/SessionsPossible &gt; 0
											and (PupilStatus/Boarder='N' or string-length(PupilStatus/Boarder) = 0 )
											and ((sum(Attendance/TermlyAttendance/SessionDetails/SessionDetail/Sessions
												[. &gt; 0 and contains( ' I M R S T H E C G U O N ', concat(' ', ../AttendanceReason, ' ') )] ) ) &gt;= Attendance/TermlyAttendance/SessionsPossible * 0.1
										or Attendance/TermlyAttendance/SessionsAuthorised &gt;= Attendance/TermlyAttendance/SessionsPossible * 0.1
										or Attendance/TermlyAttendance/SessionsUnauthorised &gt;= Attendance/TermlyAttendance/SessionsPossible * 0.1
										or Attendance/TermlyAttendance/SessionsAuthorised + Attendance/TermlyAttendance/SessionsUnauthorised &gt;= Attendance/TermlyAttendance/SessionsPossible * 0.1 ) ) ] )"/>
		<xsl:variable name="OverTenPCAbsenceOff" select="count(//PupilNoLongerOnRoll
										[ ( ($AttendanceAcademicYear - substring( PupilIdentifiers/DOB, 1, 4 ) - (substring( PupilIdentifiers/DOB, 6, 2 ) &gt; $August) ) &gt;=5
											and ($AttendanceAcademicYear - substring( PupilIdentifiers/DOB, 1, 4 ) - (substring( PupilIdentifiers/DOB, 6, 2 ) &gt; $August) ) &lt;=15
											and Attendance/TermlyAttendance/SessionsPossible &gt; 0
											and (PupilStatus/Boarder='N' or string-length(PupilStatus/Boarder) = 0 )
											and ((sum(Attendance/TermlyAttendance/SessionDetails/SessionDetail/Sessions
												[. &gt; 0 and contains( ' I M R S T H E C G U O N ', concat(' ', ../AttendanceReason, ' ') )] ) ) &gt;= Attendance/TermlyAttendance/SessionsPossible * 0.1
										or Attendance/TermlyAttendance/SessionsAuthorised &gt;= Attendance/TermlyAttendance/SessionsPossible * 0.1 
										or Attendance/TermlyAttendance/SessionsUnauthorised &gt;= Attendance/TermlyAttendance/SessionsPossible * 0.1 
										or Attendance/TermlyAttendance/SessionsAuthorised + Attendance/TermlyAttendance/SessionsUnauthorised &gt;= Attendance/TermlyAttendance/SessionsPossible * 0.1 ) ) ] )"/>
		<xsl:choose>
			<!--This table does not apply to nursery schools-->
			<xsl:when test="contains( ' NS ', concat(' ', /Message/School/SchoolCharacteristics/Phase, ' ' ) ) ">
				<p class="clsFootnote">Table 13 does not apply to schools with phase of NS (nursery).</p>
			</xsl:when>
			<xsl:when test="$term = 'SPR' or $term = 'SUM' ">
				<table class="summaryreport" border="1">
					<tr>
						<td class="clsHeading">Number of pupils on roll for at least one session in the <xsl:value-of select="$prevcensus"/> term</td>
						<td class="clsNumber">
							<xsl:value-of select="$NumberOnOffRoll"/>
						</td>
					</tr>
					<tr>
						<td class="clsHeading">Number of pupils with at least one absence in the <xsl:value-of select="$prevcensus"/> term</td>
						<td class="clsNumber">
							<xsl:value-of select="$AtLeastOneAbsence"/>
						</td>
					</tr>
					<tr>
						<td class="clsHeading">Percentage of pupils with at least one absence in the <xsl:value-of select="$prevcensus"/> term</td>
						<td class="clsNumber">
							<xsl:call-template name="HandlePercentage">
								<xsl:with-param name="Numerator" select="$AtLeastOneAbsence"/>
								<xsl:with-param name="Denominator" select="$NumberOnOffRoll"/>
							</xsl:call-template>
						</td>
					</tr>
					<tr>
						<td class="clsHeading">Total sessions possible for all pupils</td>
						<td class="clsNumber">
							<xsl:value-of select="$TotalSessionsPossible"/>
						</td>
					</tr>
					<tr>
						<td class="clsHeading">Total Sessions missed due to authorised absence for all pupils</td>
						<td class="clsNumber">
							<xsl:value-of select="$TotalSessionsAuthorised"/>
						</td>
					</tr>
					<tr>
						<td class="clsHeading">Total Sessions missed due to unauthorised absence for all pupils</td>
						<td class="clsNumber">
							<xsl:value-of select="$TotalSessionsUnauthorised"/>
						</td>
					</tr>
					<tr>
						<td class="clsHeading">Total Sessions missed due to overall (authorised plus unauthorised) absence for all pupils</td>
						<td class="clsNumber">
							<xsl:value-of select="$TotalSessionsAuthorised + $TotalSessionsUnauthorised"/>
						</td>
					</tr>
					<tr>
						<td class="clsHeading">Authorised absence as percentage of total sessions possible</td>
						<td class="clsNumber">
							<xsl:call-template name="HandlePercentage">
								<xsl:with-param name="Numerator" select="$TotalSessionsAuthorised"/>
								<xsl:with-param name="Denominator" select="$TotalSessionsPossible"/>
							</xsl:call-template>
						</td>
					</tr>
					<tr>
						<td class="clsHeading">Unauthorised absence as percentage of total sessions possible</td>
						<td class="clsNumber">
							<xsl:call-template name="HandlePercentage">
								<xsl:with-param name="Numerator" select="$TotalSessionsUnauthorised"/>
								<xsl:with-param name="Denominator" select="$TotalSessionsPossible"/>
							</xsl:call-template>
						</td>
					</tr>
					<tr>
						<td class="clsHeading">Overall (authorised plus unauthorised) absence  as percentage of total sessions possible</td>
						<td class="clsNumber">
							<xsl:call-template name="HandlePercentage">
								<xsl:with-param name="Numerator" select="$TotalSessionsAuthorised + $TotalSessionsUnauthorised"/>
								<xsl:with-param name="Denominator" select="$TotalSessionsPossible"/>
							</xsl:call-template>
						</td>
					</tr>
					<tr>
						<td class="clsHeading">Number of pupils whose overall absence rate is greater than or equal to 10 per cent and are therefore identified as a persistent absentee in this term </td>
						<td class="clsNumber">
							<xsl:value-of select="$OverTenPCAbsenceOff + $OverTenPCAbsenceOn"/>
						</td>
					</tr>
					<tr>
						<td class="clsHeading">Percentage of pupils whose overall absence rate is greater than or equal to 10 per cent and are therefore identified as a persistent absentee in this term</td>
						<td class="clsNumber">
							<xsl:call-template name="HandlePercentage">
								<xsl:with-param name="Numerator" select="$OverTenPCAbsenceOff + $OverTenPCAbsenceOn"/>
								<xsl:with-param name="Denominator" select="$NumberOnOffRoll"/>
							</xsl:call-template>
						</td>
					</tr>
				</table>
				<br/>
				<!--h4>Warning Messages</h4>
				<table class="summaryreport" border="1">
					<tr>
						<td class="clsHeading">Overall (authorised plus unauthorised) absence rate in term is high (i.e. greater than 5%)</td>
						<td class="clsHeading">
							<xsl:choose>
								<xsl:when test="($TotalSessionsAuthorised + $TotalSessionsUnauthorised) div $TotalSessionsPossible &gt; 0.05">
									True - check</xsl:when>
								<xsl:otherwise>False - OK</xsl:otherwise>
							</xsl:choose>
						</td>
					</tr>
				</table-->
			</xsl:when>
			<xsl:otherwise>
				<xsl:variable name="TotalSessionsPossibleOn2ndHalfTerm" select="sum($OnRoll5_15/Attendance/SummerHalfTerm2Attendance/SessionsPossible[number(.) = .] ) "/>
				<xsl:variable name="TotalSessionsPossibleOff2ndHalfTerm" select="sum($OffRoll5_15/Attendance/SummerHalfTerm2Attendance/SessionsPossible[number(.) = .] ) "/>
				<xsl:variable name="TotalSessionsPossible2ndHalfTerm" select="$TotalSessionsPossibleOn2ndHalfTerm+$TotalSessionsPossibleOff2ndHalfTerm"/>
				<xsl:variable name="AtLeastOneAbsenceOn2ndHalfTerm" select="count($OnRoll5_15/Attendance/SummerHalfTerm2Attendance
						[SessionsPossible &gt; 0 
							and (SessionsAuthorised &gt; 0 
										or SessionsUnauthorised &gt; 0 
										or (sum(SessionDetails/SessionDetail/Sessions[. &gt; 0 and contains( ' I M R S T H E C G U O N ', concat(' ', ../AttendanceReason, ' ') ) ] ) ) &gt; 0 ) ] ) "/>
				<xsl:variable name="AtLeastOneAbsenceOff2ndHalfTerm" select="count($OffRoll5_15/Attendance/SummerHalfTerm2Attendance
						[SessionsPossible &gt; 0 
							and (SessionsAuthorised &gt; 0 
										or SessionsUnauthorised &gt; 0 
										or (sum(SessionDetails/SessionDetail/Sessions[. &gt; 0 and contains( ' I M R S T H E C G U O N ', concat(' ', ../AttendanceReason, ' ') ) ] ) ) &gt; 0 ) ] ) "/>
				<xsl:variable name="AtLeastOneAbsence2ndHalfTerm" select="$AtLeastOneAbsenceOn2ndHalfTerm + $AtLeastOneAbsenceOff2ndHalfTerm"/>
				<xsl:variable name="NumberOnRoll2ndHalfTerm" select="count($OnRoll5_15/Attendance/SummerHalfTerm2Attendance/SessionsPossible[. &gt; 0] ) "/>
				<xsl:variable name="NumberOffRoll2ndHalfTerm" select="count($OffRoll5_15/Attendance/SummerHalfTerm2Attendance/SessionsPossible[. &gt; 0] ) "/>
				<xsl:variable name="NumberOnOffRoll2ndHalfTerm" select=" $NumberOnRoll2ndHalfTerm +$NumberOffRoll2ndHalfTerm"/>
				<xsl:variable name="TotalSessionsAuthorisedOn2ndHalfTerm" select="sum($OnRoll5_15/Attendance/SummerHalfTerm2Attendance/SessionsAuthorised
					[ . &gt; 0 and ../SessionsPossible &gt; 0 ] ) 
				+ sum($OnRoll5_15/Attendance/SummerHalfTerm2Attendance/SessionDetails/SessionDetail/Sessions
					[ . &gt; 0 and contains( ' I M R S T H E C ', concat(' ', ../AttendanceReason, ' ') ) and ../../../SessionsPossible &gt; 0 ] )"/>
				<xsl:variable name="TotalSessionsAuthorisedOff2ndHalfTerm" select="sum($OffRoll5_15/Attendance/SummerHalfTerm2Attendance/SessionsAuthorised
					[ . &gt; 0 and ../SessionsPossible &gt; 0 ] ) 
				+ sum($OffRoll5_15/Attendance/SummerHalfTerm2Attendance/SessionDetails/SessionDetail/Sessions
					[ . &gt; 0 and contains( ' I M R S T H E C ', concat(' ', ../AttendanceReason, ' ') ) and ../../../SessionsPossible &gt; 0 ] )"/>
				<xsl:variable name="TotalSessionsAuthorised2ndHalfTerm" select="$TotalSessionsAuthorisedOn2ndHalfTerm + $TotalSessionsAuthorisedOff2ndHalfTerm"/>
				<xsl:variable name="TotalSessionsUnauthorisedOn2ndHalfTerm" select="sum($OnRoll5_15/Attendance/SummerHalfTerm2Attendance/SessionsUnauthorised
					[ . &gt; 0 and ../SessionsPossible &gt; 0 ] ) 
				+ sum($OnRoll5_15/Attendance/SummerHalfTerm2Attendance/SessionDetails/SessionDetail/Sessions
					[ . &gt; 0 and contains( ' G U O N ', concat(' ', ../AttendanceReason, ' ') ) and ../../../SessionsPossible &gt; 0 ] )"/>
				<xsl:variable name="TotalSessionsUnauthorisedOff2ndHalfTerm" select="sum($OffRoll5_15/Attendance/SummerHalfTerm2Attendance/SessionsUnauthorised
					[ . &gt; 0 and ../SessionsPossible &gt; 0 ] ) 
				+ sum($OffRoll5_15/Attendance/SummerHalfTerm2Attendance/SessionDetails/SessionDetail/Sessions
					[ . &gt; 0 and contains( ' G U O N ', concat(' ', ../AttendanceReason, ' ') ) and ../../../SessionsPossible &gt; 0 ] )"/>
				<xsl:variable name="TotalSessionsUnauthorised2ndHalfTerm" select=" $TotalSessionsUnauthorisedOn2ndHalfTerm + $TotalSessionsUnauthorisedOff2ndHalfTerm"/>
				<xsl:variable name="AtLeastOneAbsenceOnFullTerm" select="count($OnRoll5_15/Attendance
					[ ( TermlyAttendance/SessionsPossible &gt; 0 
						or SummerHalfTerm2Attendance/SessionsPossible &gt; 0 ) 
					and (sum(TermlyAttendance/SessionDetails/SessionDetail/Sessions
						[. &gt; 0 and contains( ' I M R S T H E C G U O N ', concat(' ', ../AttendanceReason, ' ') )] )  &gt; 0 
					or TermlyAttendance[SessionsAuthorised &gt; 0] 
					or TermlyAttendance[SessionsUnauthorised &gt; 0] 
					or sum(SummerHalfTerm2Attendance/SessionDetails/SessionDetail/Sessions
						[. &gt; 0 and contains( ' I M R S T H E C G U O N ', concat(' ', ../AttendanceReason, ' ') )] ) &gt; 0 
					or SummerHalfTerm2Attendance[SessionsAuthorised &gt; 0] 
					or SummerHalfTerm2Attendance[SessionsUnauthorised &gt; 0] ) ] ) "/>
				<xsl:variable name="AtLeastOneAbsenceOffFullTerm" select="count($OffRoll5_15/Attendance
					[ ( TermlyAttendance/SessionsPossible &gt; 0 
						or SummerHalfTerm2Attendance/SessionsPossible &gt; 0 ) 
					and (sum(TermlyAttendance/SessionDetails/SessionDetail/Sessions
						[. &gt; 0 and contains( ' I M R S T H E C G U O N ', concat(' ', ../AttendanceReason, ' ') )] )  &gt; 0 
					or TermlyAttendance[SessionsAuthorised &gt; 0] 
					or TermlyAttendance[SessionsUnauthorised &gt; 0] 
					or sum(SummerHalfTerm2Attendance/SessionDetails/SessionDetail/Sessions
						[. &gt; 0 and contains( ' I M R S T H E C G U O N ', concat(' ', ../AttendanceReason, ' ') )] ) &gt; 0 
					or SummerHalfTerm2Attendance[SessionsAuthorised &gt; 0] 
					or SummerHalfTerm2Attendance[SessionsUnauthorised &gt; 0] ) ] )"/>
				<xsl:variable name="NumberOnRollFullTerm" select="count($OnRoll5_15/Attendance[TermlyAttendance/SessionsPossible &gt; 0 or SummerHalfTerm2Attendance/SessionsPossible &gt; 0 ] ) "/>
				<xsl:variable name="NumberOffRollFullTerm" select="count($OffRoll5_15/Attendance[TermlyAttendance/SessionsPossible &gt; 0 or SummerHalfTerm2Attendance/SessionsPossible &gt; 0 ] ) "/>
				<xsl:variable name="NumberOnOffRollFullTerm" select=" $NumberOnRollFullTerm +$NumberOffRollFullTerm"/>
				<table class="summaryreport" border="1">
					<tr>
						<th/>
						<th class="clsHeading">Summer <br/>First Half<br/>Term<br/>(10 April<br/>to 28 May<br/>
							<xsl:value-of select="$etyear"/>)</th>
						<th class="clsHeading">Summer <br/>Second<br/>Half Term<br/>(29 May<br/>to 31 July<br/>
							<xsl:value-of select="$etyear"/>)</th>
						<th class="clsHeading">Total<br/>Summer<br/>Term<br/>(10 April<br/>to 31 July<br/>
							<xsl:value-of select="$etyear"/>)</th>
					</tr>
					<tr>
						<td class="clsHeading">Number of pupils on roll for at least one session in the <xsl:value-of select="$prevcensus"/> term</td>
						<td class="clsNumber">
							<xsl:value-of select="$NumberOnOffRoll "/>
						</td>
						<td class="clsNumber">
							<xsl:value-of select="$NumberOnOffRoll2ndHalfTerm "/>
						</td>
						<td class="clsNumber">
							<xsl:value-of select="$NumberOnRollFullTerm + $NumberOffRollFullTerm"/>
						</td>
					</tr>
					<tr>
						<td class="clsHeading">Number of pupils with at least one absence in the <xsl:value-of select="$prevcensus"/> term</td>
						<td class="clsNumber">
							<xsl:value-of select="$AtLeastOneAbsence"/>
						</td>
						<td class="clsNumber">
							<xsl:value-of select="$AtLeastOneAbsence2ndHalfTerm"/>
						</td>
						<td class="clsNumber">
							<xsl:value-of select="$AtLeastOneAbsenceOnFullTerm + $AtLeastOneAbsenceOffFullTerm"/>
						</td>
					</tr>
					<tr>
						<td class="clsHeading">Percentage of pupils with at least one absence in the <xsl:value-of select="$prevcensus"/> term</td>
						<td class="clsNumber">
							<xsl:call-template name="HandlePercentage">
								<xsl:with-param name="Numerator" select="$AtLeastOneAbsence"/>
								<xsl:with-param name="Denominator" select="$NumberOnOffRoll"/>
							</xsl:call-template>
						</td>
						<td class="clsNumber">
							<xsl:call-template name="HandlePercentage">
								<xsl:with-param name="Numerator" select="$AtLeastOneAbsence2ndHalfTerm"/>
								<xsl:with-param name="Denominator" select="$NumberOnOffRoll2ndHalfTerm"/>
							</xsl:call-template>
						</td>
						<td class="clsNumber">
							<xsl:call-template name="HandlePercentage">
								<xsl:with-param name="Numerator" select="$AtLeastOneAbsenceOnFullTerm + $AtLeastOneAbsenceOffFullTerm"/>
								<xsl:with-param name="Denominator" select="$NumberOnRollFullTerm + $NumberOffRollFullTerm"/>
							</xsl:call-template>
						</td>
					</tr>
					<tr>
						<td class="clsHeading">Total sessions possible for all pupils</td>
						<td class="clsNumber">
							<xsl:value-of select="$TotalSessionsPossible"/>
						</td>
						<td class="clsNumber">
							<xsl:value-of select="$TotalSessionsPossible2ndHalfTerm"/>
						</td>
						<td class="clsNumber">
							<xsl:value-of select="$TotalSessionsPossible + $TotalSessionsPossible2ndHalfTerm"/>
						</td>
					</tr>
					<tr>
						<td class="clsHeading">Total Sessions missed due to Authorised Absence for all pupils</td>
						<td class="clsNumber">
							<xsl:value-of select="$TotalSessionsAuthorised"/>
						</td>
						<td class="clsNumber">
							<xsl:value-of select="$TotalSessionsAuthorised2ndHalfTerm"/>
						</td>
						<td class="clsNumber">
							<xsl:value-of select="$TotalSessionsAuthorised + $TotalSessionsAuthorised2ndHalfTerm"/>
						</td>
					</tr>
					<tr>
						<td class="clsHeading">Total Sessions missed due to Unauthorised Absence for all pupils</td>
						<td class="clsNumber">
							<xsl:value-of select="$TotalSessionsUnauthorised"/>
						</td>
						<td class="clsNumber">
							<xsl:value-of select="$TotalSessionsUnauthorised2ndHalfTerm"/>
						</td>
						<td class="clsNumber">
							<xsl:value-of select="$TotalSessionsUnauthorised + $TotalSessionsUnauthorised2ndHalfTerm"/>
						</td>
					</tr>
					<tr>
						<td class="clsHeading">Total Sessions missed due to Overall (Authorised plus Unauthorised) Absence for all pupils</td>
						<td class="clsNumber">
							<xsl:value-of select="$TotalSessionsAuthorised + $TotalSessionsUnauthorised"/>
						</td>
						<td class="clsNumber">
							<xsl:value-of select="$TotalSessionsAuthorised2ndHalfTerm + $TotalSessionsUnauthorised2ndHalfTerm"/>
						</td>
						<td class="clsNumber">
							<xsl:value-of select="$TotalSessionsAuthorised + $TotalSessionsUnauthorised + $TotalSessionsAuthorised2ndHalfTerm + $TotalSessionsUnauthorised2ndHalfTerm"/>
						</td>
					</tr>
					<tr>
						<td class="clsHeading">Authorised absence as percentage of total sessions possible</td>
						<td class="clsNumber">
							<xsl:call-template name="HandlePercentage">
								<xsl:with-param name="Numerator" select="$TotalSessionsAuthorised"/>
								<xsl:with-param name="Denominator" select="$TotalSessionsPossible"/>
							</xsl:call-template>
						</td>
						<td class="clsNumber">
							<xsl:call-template name="HandlePercentage">
								<xsl:with-param name="Numerator" select="$TotalSessionsAuthorised2ndHalfTerm"/>
								<xsl:with-param name="Denominator" select="$TotalSessionsPossible2ndHalfTerm"/>
							</xsl:call-template>
						</td>
						<td class="clsNumber">
							<xsl:call-template name="HandlePercentage">
								<xsl:with-param name="Numerator" select="$TotalSessionsAuthorised + $TotalSessionsAuthorised2ndHalfTerm"/>
								<xsl:with-param name="Denominator" select="$TotalSessionsPossible + $TotalSessionsPossible2ndHalfTerm"/>
							</xsl:call-template>
						</td>
					</tr>
					<tr>
						<td class="clsHeading">Unauthorised absence as percentage of total sessions possible</td>
						<td class="clsNumber">
							<xsl:call-template name="HandlePercentage">
								<xsl:with-param name="Numerator" select="$TotalSessionsUnauthorised"/>
								<xsl:with-param name="Denominator" select="$TotalSessionsPossible"/>
							</xsl:call-template>
						</td>
						<td class="clsNumber">
							<xsl:call-template name="HandlePercentage">
								<xsl:with-param name="Numerator" select="$TotalSessionsUnauthorised2ndHalfTerm"/>
								<xsl:with-param name="Denominator" select="$TotalSessionsPossible2ndHalfTerm"/>
							</xsl:call-template>
						</td>
						<td class="clsNumber">
							<xsl:call-template name="HandlePercentage">
								<xsl:with-param name="Numerator" select="$TotalSessionsUnauthorised + $TotalSessionsUnauthorised2ndHalfTerm"/>
								<xsl:with-param name="Denominator" select="$TotalSessionsPossible + $TotalSessionsPossible2ndHalfTerm"/>
							</xsl:call-template>
						</td>
					</tr>
					<tr>
						<td class="clsHeading">Overall (Authorised plus Unauthorised) absence as percentage of total sessions possible</td>
						<td class="clsNumber">
							<xsl:call-template name="HandlePercentage">
								<xsl:with-param name="Numerator" select="$TotalSessionsAuthorised + $TotalSessionsUnauthorised"/>
								<xsl:with-param name="Denominator" select="$TotalSessionsPossible"/>
							</xsl:call-template>
						</td>
						<td class="clsNumber">
							<xsl:call-template name="HandlePercentage">
								<xsl:with-param name="Numerator" select="$TotalSessionsAuthorised2ndHalfTerm + $TotalSessionsUnauthorised2ndHalfTerm"/>
								<xsl:with-param name="Denominator" select="$TotalSessionsPossible2ndHalfTerm"/>
							</xsl:call-template>
						</td>
						<td class="clsNumber">
							<xsl:call-template name="HandlePercentage">
								<xsl:with-param name="Numerator" select="$TotalSessionsAuthorised + $TotalSessionsUnauthorised + $TotalSessionsAuthorised2ndHalfTerm + $TotalSessionsUnauthorised2ndHalfTerm"/>
								<xsl:with-param name="Denominator" select="$TotalSessionsPossible + $TotalSessionsPossible2ndHalfTerm"/>
							</xsl:call-template>
						</td>
					</tr>
					<tr>
						<td class="clsHeading">Number of pupils whose overall absence rate is greater than or equal to 10 per cent and are therefore identified as a persistent absentee in this term</td>
						<td class="clsNumber">
							<xsl:value-of select="$OverTenPCAbsenceOff + $OverTenPCAbsenceOn"/>
						</td>
						<td class="clsEmpty" colspan="2"/>
					</tr>
					<tr>
						<td class="clsHeading">Percentage of pupils whose overall absence rate is greater than or equal to 10 per cent and are therefore identified as a persistent absentee in this term</td>
						<td class="clsNumber">
							<xsl:call-template name="HandlePercentage">
								<xsl:with-param name="Numerator" select="$OverTenPCAbsenceOff + $OverTenPCAbsenceOn"/>
								<xsl:with-param name="Denominator" select="$NumberOnOffRoll"/>
							</xsl:call-template>
						</td>
						<td class="clsEmpty" colspan="2"/>
					</tr>
				</table>
				<br/>
			</xsl:otherwise>
		</xsl:choose>
		<p class="clsFootnote">Attendance information is not collected for boarding pupils.  Information in table 13 includes those pupils on roll on census day and those who are no longer at the school but who attended at least one session during the term covered.</p>
		<br/>
		
		
		<!--Table 14 is not required for Nursery or Special schools-->
		<h2>Table 14: Attendance information for the <xsl:value-of select="$prevcensus"/> term (<xsl:value-of select="$prevterms"/>) for all pupils aged 4 years as at <xsl:value-of select="$AgeAsAtHeadertext"/> [not for: nursery schools]</h2>
		<!--Set up variables for attendance of four year-olds-->
		<xsl:variable name="TotalSessionsPossibleOn4yo" select="sum($OnRoll4/Attendance/TermlyAttendance/SessionsPossible[. &gt; 0] ) "/>
		<xsl:variable name="TotalSessionsPossibleOff4yo" select="sum($OffRoll4/Attendance/TermlyAttendance/SessionsPossible[. &gt; 0] ) "/>
		<xsl:variable name="TotalSessionsPossible4yo" select="$TotalSessionsPossibleOn4yo + $TotalSessionsPossibleOff4yo"/>
		<xsl:variable name="NumberOnRoll4yo" select="count($OnRoll4/Attendance/TermlyAttendance/SessionsPossible[. &gt; 0] ) "/>
		<xsl:variable name="NumberOffRoll4yo" select="count($OffRoll4/Attendance/TermlyAttendance/SessionsPossible[. &gt; 0] ) "/>
		<xsl:variable name="NumberOnOffRoll4yo" select="$NumberOnRoll4yo + $NumberOffRoll4yo"/>
		<xsl:variable name="AtLeastOneAbsenceOn4yo" select="count($OnRoll4/Attendance/TermlyAttendance
				[SessionsPossible &gt; 0 
					and (SessionsAuthorised &gt; 0 
								or SessionsUnauthorised &gt; 0 
								or (sum(SessionDetails/SessionDetail/Sessions[. &gt; 0 and contains( ' I M R S T H E C G U O N ', concat(' ', ../AttendanceReason, ' ') ) ] ) ) &gt; 0 ) ] ) "/>
		<xsl:variable name="AtLeastOneAbsenceOff4yo" select="count($OffRoll4/Attendance/TermlyAttendance
				[SessionsPossible &gt; 0 
					and (SessionsAuthorised &gt; 0 
								or SessionsUnauthorised &gt; 0 
								or (sum(SessionDetails/SessionDetail/Sessions[. &gt; 0 and contains( ' I M R S T H E C G U O N ', concat(' ', ../AttendanceReason, ' ') ) ] ) ) &gt; 0 ) ] ) "/>
		<xsl:variable name="AtLeastOneAbsence4yo" select="$AtLeastOneAbsenceOn4yo + $AtLeastOneAbsenceOff4yo"/>
		<xsl:variable name="TotalSessionsAuthorisedOn4yo" select="sum($OnRoll4/Attendance/TermlyAttendance/SessionsAuthorised
			[ . &gt; 0 and ../SessionsPossible &gt; 0 ] ) 
		+ sum($OnRoll4/Attendance/TermlyAttendance/SessionDetails/SessionDetail/Sessions
			[ . &gt; 0 and contains( ' I M R S T H E C ', concat(' ', ../AttendanceReason, ' ') ) and ../../../SessionsPossible &gt; 0 ] )"/>
		<xsl:variable name="TotalSessionsAuthorisedOff4yo" select="sum($OffRoll4/Attendance/TermlyAttendance/SessionsAuthorised
			[ . &gt; 0 and ../SessionsPossible &gt; 0 ] ) 
		+ sum($OffRoll4/Attendance/TermlyAttendance/SessionDetails/SessionDetail/Sessions
			[ . &gt; 0 and contains( ' I M R S T H E C ', concat(' ', ../AttendanceReason, ' ') ) and ../../../SessionsPossible &gt; 0 ] )"/>
		<xsl:variable name="TotalSessionsAuthorised4yo" select="$TotalSessionsAuthorisedOn4yo + $TotalSessionsAuthorisedOff4yo"/>
		<xsl:variable name="TotalSessionsUnauthorisedOn4yo" select="sum($OnRoll4/Attendance/TermlyAttendance/SessionsUnauthorised
			[ . &gt; 0 and ../SessionsPossible &gt; 0 ] ) 
		+ sum($OnRoll4/Attendance/TermlyAttendance/SessionDetails/SessionDetail/Sessions
			[ . &gt; 0 and contains( ' G U O N ', concat(' ', ../AttendanceReason, ' ') ) and ../../../SessionsPossible &gt; 0 ] )"/>
		<xsl:variable name="TotalSessionsUnauthorisedOff4yo" select="sum($OffRoll4/Attendance/TermlyAttendance/SessionsUnauthorised
			[ . &gt; 0 and ../SessionsPossible &gt; 0 ] ) 
		+ sum($OffRoll4/Attendance/TermlyAttendance/SessionDetails/SessionDetail/Sessions
			[ . &gt; 0 and contains( ' G U O N ', concat(' ', ../AttendanceReason, ' ') ) and ../../../SessionsPossible &gt; 0 ] )"/>
		<xsl:variable name="TotalSessionsUnauthorised4yo" select="$TotalSessionsUnauthorisedOn4yo + $TotalSessionsUnauthorisedOff4yo"/>
		<xsl:choose>
			<xsl:when test="contains( ' NS ', concat(' ', $phase, ' ' ) ) "/>
			<xsl:when test="$term = 'SPR' or $term = 'SUM' ">
				<table class="summaryreport" border="1">
					<tr>
						<td class="clsHeading">Number of 4 year old pupils on roll for at least one session in the <xsl:value-of select="$prevcensus"/> term</td>
						<td class="clsNumber">
							<xsl:value-of select="$NumberOnRoll4yo + $NumberOffRoll4yo"/>
						</td>
					</tr>
					<tr>
						<td class="clsHeading">Number of 4 year old pupils with at least one absence in the <xsl:value-of select="$prevcensus"/> term</td>
						<td class="clsNumber">
							<xsl:value-of select="$AtLeastOneAbsence4yo"/>
						</td>
					</tr>
					<tr>
						<td class="clsHeading">Percentage of 4 year old pupils with at least one absence in the <xsl:value-of select="$prevcensus"/> term</td>
						<td class="clsNumber">
							<xsl:call-template name="HandlePercentage">
								<xsl:with-param name="Numerator" select="$AtLeastOneAbsence4yo"/>
								<xsl:with-param name="Denominator" select="$NumberOnOffRoll4yo"/>
							</xsl:call-template>
						</td>
					</tr>
					<tr>
						<td class="clsHeading">Total sessions possible for all 4 year old pupils</td>
						<td class="clsNumber">
							<xsl:value-of select="$TotalSessionsPossible4yo"/>
						</td>
					</tr>
					<tr>
						<td class="clsHeading">Total sessions missed due to overall absence for all 4 year old pupils</td>
						<td class="clsNumber">
							<xsl:value-of select="$TotalSessionsAuthorised4yo + $TotalSessionsUnauthorised4yo "/>
						</td>
					</tr>
					<tr>
						<td class="clsHeading">Overall absence as percentage of total sessions possible</td>
						<td class="clsNumber">
							<xsl:call-template name="HandlePercentage">
								<xsl:with-param name="Numerator" select="$TotalSessionsAuthorised4yo + $TotalSessionsUnauthorised4yo"/>
								<xsl:with-param name="Denominator" select="$TotalSessionsPossible4yo"/>
							</xsl:call-template>
						</td>
					</tr>
				</table>
			</xsl:when>
			<xsl:when test="$term = 'AUT' ">
				<xsl:variable name="TotalSessionsPossibleOn2ndHalfTerm4yo" select="sum($OnRoll4/Attendance/SummerHalfTerm2Attendance/SessionsPossible[number(.) = .] ) "/>
				<xsl:variable name="TotalSessionsPossibleOff2ndHalfTerm4yo" select="sum($OffRoll4/Attendance/SummerHalfTerm2Attendance/SessionsPossible[number(.) = .] ) "/>
				<xsl:variable name="TotalSessionsPossible2ndHalfTerm4yo" select="$TotalSessionsPossibleOn2ndHalfTerm4yo + $TotalSessionsPossibleOff2ndHalfTerm4yo"/>
				<xsl:variable name="AtLeastOneAbsenceOn2ndHalfTerm4yo" select="count($OnRoll4/Attendance/SummerHalfTerm2Attendance
						[SessionsPossible &gt; 0 
							and (SessionsAuthorised &gt; 0 
										or SessionsUnauthorised &gt; 0 
										or (sum(SessionDetails/SessionDetail/Sessions[. &gt; 0 and contains( ' I M R S T H E C G U O N ', concat(' ', ../AttendanceReason, ' ') ) ] ) ) &gt; 0 ) ] ) "/>
				<xsl:variable name="AtLeastOneAbsenceOff2ndHalfTerm4yo" select="count($OffRoll4/Attendance/SummerHalfTerm2Attendance
						[SessionsPossible &gt; 0 
							and (SessionsAuthorised &gt; 0 
										or SessionsUnauthorised &gt; 0 
										or (sum(SessionDetails/SessionDetail/Sessions[. &gt; 0 and contains( ' I M R S T H E C G U O N ', concat(' ', ../AttendanceReason, ' ') ) ] ) ) &gt; 0 ) ] ) "/>
				<xsl:variable name="AtLeastOneAbsence2ndHalfTerm4yo" select="$AtLeastOneAbsenceOn2ndHalfTerm4yo + $AtLeastOneAbsenceOff2ndHalfTerm4yo"/>
				<xsl:variable name="NumberOnRoll2ndHalfTerm4yo" select="count($OnRoll4/Attendance/SummerHalfTerm2Attendance/SessionsPossible[. &gt; 0] ) "/>
				<xsl:variable name="NumberOffRoll2ndHalfTerm4yo" select="count($OffRoll4/Attendance/SummerHalfTerm2Attendance/SessionsPossible[. &gt; 0] ) "/>
				<xsl:variable name="NumberOnOffRoll2ndHalfTerm4yo" select="$NumberOnRoll2ndHalfTerm4yo + $NumberOffRoll2ndHalfTerm4yo"/>
				<xsl:variable name="TotalSessionsAuthorisedOn2ndHalfTerm4yo" select="sum($OnRoll4/Attendance/SummerHalfTerm2Attendance/SessionsAuthorised
					[ . &gt; 0 and ../SessionsPossible &gt; 0 ] ) 
				+ sum($OnRoll4/Attendance/SummerHalfTerm2Attendance/SessionDetails/SessionDetail/Sessions
					[ . &gt; 0 and contains( ' I M R S T H E C ', concat(' ', ../AttendanceReason, ' ') ) and ../../../SessionsPossible &gt; 0 ] )"/>
				<xsl:variable name="TotalSessionsAuthorisedOff2ndHalfTerm4yo" select="sum($OffRoll4/Attendance/SummerHalfTerm2Attendance/SessionsAuthorised
					[ . &gt; 0 and ../SessionsPossible &gt; 0 ] ) 
				+ sum($OffRoll4/Attendance/SummerHalfTerm2Attendance/SessionDetails/SessionDetail/Sessions
					[ . &gt; 0 and contains( ' I M R S T H E C ', concat(' ', ../AttendanceReason, ' ') ) and ../../../SessionsPossible &gt; 0 ] )"/>
				<xsl:variable name="TotalSessionsAuthorised2ndHalfTerm4yo" select="$TotalSessionsAuthorisedOn2ndHalfTerm4yo + $TotalSessionsAuthorisedOff2ndHalfTerm4yo"/>
				<xsl:variable name="TotalSessionsUnauthorisedOn2ndHalfTerm4yo" select="sum($OnRoll4/Attendance/SummerHalfTerm2Attendance/SessionsUnauthorised
					[ . &gt; 0 and ../SessionsPossible &gt; 0 ] ) 
				+ sum($OnRoll4/Attendance/SummerHalfTerm2Attendance/SessionDetails/SessionDetail/Sessions
					[ . &gt; 0 and contains( ' G U O N ', concat(' ', ../AttendanceReason, ' ') ) and ../../../SessionsPossible &gt; 0 ] )"/>
				<xsl:variable name="TotalSessionsUnauthorisedOff2ndHalfTerm4yo" select="sum($OffRoll4/Attendance/SummerHalfTerm2Attendance/SessionsUnauthorised
					[ . &gt; 0 and ../SessionsPossible &gt; 0 ] ) 
				+ sum($OffRoll4/Attendance/SummerHalfTerm2Attendance/SessionDetails/SessionDetail/Sessions
					[ . &gt; 0 and contains( ' G U O N ', concat(' ', ../AttendanceReason, ' ') ) and ../../../SessionsPossible &gt; 0 ] )"/>
				<xsl:variable name="TotalSessionsUnauthorised2ndHalfTerm4yo" select="$TotalSessionsUnauthorisedOn2ndHalfTerm4yo + $TotalSessionsUnauthorisedOff2ndHalfTerm4yo"/>
				<xsl:variable name="AtLeastOneAbsenceOnFullTerm4yo" select="count($OnRoll4/Attendance
					[ ( TermlyAttendance/SessionsPossible &gt; 0 
						or SummerHalfTerm2Attendance/SessionsPossible &gt; 0 ) 
					and (sum(TermlyAttendance/SessionDetails/SessionDetail/Sessions
						[. &gt; 0 and contains( ' I M R S T H E C G U O N ', concat(' ', ../AttendanceReason, ' ') )] )  &gt; 0 
					or TermlyAttendance[SessionsAuthorised &gt; 0] 
					or TermlyAttendance[SessionsUnauthorised &gt; 0] 
					or sum(SummerHalfTerm2Attendance/SessionDetails/SessionDetail/Sessions
						[. &gt; 0 and contains( ' I M R S T H E C G U O N ', concat(' ', ../AttendanceReason, ' ') )] ) &gt; 0 
					or SummerHalfTerm2Attendance[SessionsAuthorised &gt; 0] 
					or SummerHalfTerm2Attendance[SessionsUnauthorised &gt; 0] ) ] ) "/>
				<xsl:variable name="AtLeastOneAbsenceOffFullTerm4yo" select="count($OffRoll4/Attendance
					[ ( TermlyAttendance/SessionsPossible &gt; 0 
						or SummerHalfTerm2Attendance/SessionsPossible &gt; 0 ) 
					and (sum(TermlyAttendance/SessionDetails/SessionDetail/Sessions
						[. &gt; 0 and contains( ' I M R S T H E C G U O N ', concat(' ', ../AttendanceReason, ' ') )] )  &gt; 0 
					or TermlyAttendance[SessionsAuthorised &gt; 0] 
					or TermlyAttendance[SessionsUnauthorised &gt; 0] 
					or sum(SummerHalfTerm2Attendance/SessionDetails/SessionDetail/Sessions
						[. &gt; 0 and contains( ' I M R S T H E C G U O N ', concat(' ', ../AttendanceReason, ' ') )] ) &gt; 0 
					or SummerHalfTerm2Attendance[SessionsAuthorised &gt; 0] 
					or SummerHalfTerm2Attendance[SessionsUnauthorised &gt; 0] ) ] )"/>
				<xsl:variable name="NumberOnRollFullTerm4yo" select="count($OnRoll4/Attendance[TermlyAttendance/SessionsPossible &gt; 0 or SummerHalfTerm2Attendance/SessionsPossible &gt; 0 ] ) "/>
				<xsl:variable name="NumberOffRollFullTerm4yo" select="count($OffRoll4/Attendance[TermlyAttendance/SessionsPossible &gt; 0 or SummerHalfTerm2Attendance/SessionsPossible &gt; 0 ] ) "/>
				<xsl:variable name="NumberOnOffRollFullTerm4yo" select=" $NumberOnRollFullTerm4yo +$NumberOffRollFullTerm4yo"/>
				<table class="summaryreport" border="1">
					<tr>
						<th class="clsHeading"/>
						<th class="clsHeading">Summer <br/>First Half<br/>Term<br/>(10 April<br/>to 28 May<br/>2023)</th>
						<th class="clsHeading">Summer <br/>Second<br/>Half Term<br/>(29 May<br/>to 31 July<br/>2023)</th>
						<th class="clsHeading">Total<br/>Summer<br/>Term<br/>(10 April<br/>to 31 July<br/>2023)</th>
					</tr>
					<tr>
						<td class="clsHeading">Number of 4 year old pupils on roll for at least one session in the <xsl:value-of select="$prevcensus"/> term</td>
						<td class="clsNumber">
							<xsl:value-of select="$NumberOnOffRoll4yo "/>
						</td>
						<td class="clsNumber">
							<xsl:value-of select="$NumberOnOffRoll2ndHalfTerm4yo"/>
						</td>
						<td class="clsNumber">
							<xsl:value-of select="$NumberOnRollFullTerm4yo + $NumberOffRollFullTerm4yo"/>
						</td>
					</tr>
					<tr>
						<td class="clsHeading">Number of 4 year old pupils with at least one absence in the <xsl:value-of select="$prevcensus"/> term</td>
						<td class="clsNumber">
							<xsl:value-of select="$AtLeastOneAbsence4yo"/>
						</td>
						<td class="clsNumber">
							<xsl:value-of select="$AtLeastOneAbsence2ndHalfTerm4yo"/>
						</td>
						<td class="clsNumber">
							<xsl:value-of select="$AtLeastOneAbsenceOnFullTerm4yo + $AtLeastOneAbsenceOffFullTerm4yo"/>
						</td>
					</tr>
					<tr>
						<td class="clsHeading">Percentage of 4 year old pupils with at least one absence in the <xsl:value-of select="$prevcensus"/> term</td>
						<td class="clsNumber">
							<xsl:call-template name="HandlePercentage">
								<xsl:with-param name="Numerator" select="$AtLeastOneAbsence4yo"/>
								<xsl:with-param name="Denominator" select="$NumberOnOffRoll4yo"/>
							</xsl:call-template>
						</td>
						<td class="clsNumber">
							<xsl:call-template name="HandlePercentage">
								<xsl:with-param name="Numerator" select="$AtLeastOneAbsence2ndHalfTerm4yo"/>
								<xsl:with-param name="Denominator" select="$NumberOnOffRoll2ndHalfTerm4yo"/>
							</xsl:call-template>
						</td>
						<td class="clsNumber">
							<xsl:call-template name="HandlePercentage">
								<xsl:with-param name="Numerator" select="$AtLeastOneAbsence4yo + $AtLeastOneAbsence2ndHalfTerm4yo"/>
								<xsl:with-param name="Denominator" select="$NumberOnOffRoll4yo + $NumberOnOffRoll2ndHalfTerm4yo"/>
							</xsl:call-template>
						</td>
					</tr>
					<tr>
						<td class="clsHeading">Total sessions possible for all 4 year old pupils</td>
						<td class="clsNumber">
							<xsl:value-of select="$TotalSessionsPossible4yo"/>
						</td>
						<td class="clsNumber">
							<xsl:value-of select="$TotalSessionsPossible2ndHalfTerm4yo"/>
						</td>
						<td class="clsNumber">
							<xsl:value-of select="$TotalSessionsPossible4yo + $TotalSessionsPossible2ndHalfTerm4yo"/>
						</td>
					</tr>
					<tr>
						<td class="clsHeading">Total sessions missed due to overall absence for all 4 year old pupils</td>
						<td class="clsNumber">
							<xsl:value-of select="$TotalSessionsAuthorised4yo + $TotalSessionsUnauthorised4yo"/>
						</td>
						<td class="clsNumber">
							<xsl:value-of select="$TotalSessionsAuthorised2ndHalfTerm4yo + $TotalSessionsUnauthorised2ndHalfTerm4yo"/>
						</td>
						<td class="clsNumber">
							<xsl:value-of select="$TotalSessionsAuthorised4yo + $TotalSessionsAuthorised2ndHalfTerm4yo + $TotalSessionsUnauthorised4yo + $TotalSessionsUnauthorised2ndHalfTerm4yo"/>
						</td>
					</tr>
					<tr>
						<td class="clsHeading">Overall absence as percentage of total sessions possible</td>
						<td class="clsNumber">
							<xsl:call-template name="HandlePercentage">
								<xsl:with-param name="Numerator" select="$TotalSessionsAuthorised4yo + $TotalSessionsUnauthorised4yo"/>
								<xsl:with-param name="Denominator" select="$TotalSessionsPossible4yo"/>
							</xsl:call-template>
						</td>
						<td class="clsNumber">
							<xsl:call-template name="HandlePercentage">
								<xsl:with-param name="Numerator" select="$TotalSessionsAuthorised2ndHalfTerm4yo + $TotalSessionsUnauthorised2ndHalfTerm4yo"/>
								<xsl:with-param name="Denominator" select="$TotalSessionsPossible2ndHalfTerm4yo"/>
							</xsl:call-template>
						</td>
						<td class="clsNumber">
							<xsl:call-template name="HandlePercentage">
								<xsl:with-param name="Numerator" select="$TotalSessionsAuthorised4yo + $TotalSessionsAuthorised2ndHalfTerm4yo + $TotalSessionsUnauthorised4yo + $TotalSessionsUnauthorised2ndHalfTerm4yo"/>
								<xsl:with-param name="Denominator" select="$TotalSessionsPossible4yo + $TotalSessionsPossible2ndHalfTerm4yo"/>
							</xsl:call-template>
						</td>
					</tr>
				</table>
			</xsl:when>
		</xsl:choose>
		<br/>
		<xsl:choose>
			<xsl:when test="$AcademicYear = '2020' and $term = 'AUT' ">
			</xsl:when>
			<xsl:otherwise>
				<p class="clsFootnote">Attendance information is not collected for boarding pupils.  Information in table 14 includes those pupils on roll on census day and those who are no longer at the school but who attended at least one session during the term covered.</p>
				<p class="clsFootnote">Schools cannot 'authorise' or 'unauthorise' the absence of pupils who are not of compulsory school age.</p>
				<p class="clsFootnote">However, for ease schools can use the attendance module and therefore may use these codes to record the absence of pupils aged 4. Therefore, the 'unauthorised' absence codes (‘G’, ‘U’, ‘O’ and ‘N’) are also included in the business rules for completeness. Regardless of which codes are returned in the census for pupils aged 4, they will be treated as 'absence' by the department.</p>
				<br/>
			</xsl:otherwise>
		</xsl:choose>


		<xsl:choose>
			<xsl:when test="$term = 'AUT'"><h2>Table 15: Attendance by reason for the 2023 summer term (terms 5 and 6) for all pupils aged between 4 and 15 years as at 31/08/2022 [Not for: Nursery school]</h2></xsl:when>
			<xsl:when test="$term = 'SPR'"><h2>Table 15: Attendance by reason for the 2023 autumn term (terms 1 and 2) for all pupils aged between 4 and 15 years as at 31/08/2023 [Not for: Nursery school]</h2></xsl:when>
			<xsl:when test="$term = 'SUM'"><h2>Table 15: Attendance by reason for the 2024 spring term (terms 3 and 4) for all pupils aged between 4 and 15 years as at 31/08/2023 [Not for: Nursery school]</h2></xsl:when>
		</xsl:choose>
		<xsl:variable name="AM1stHalf4yrOld" select="
				sum($OnRoll4/Attendance/TermlyAttendance[sum(SessionDetails/SessionDetail/Sessions[. &gt; 0 and contains( ' / ', concat(' ', ../AttendanceReason, ' ') ) ] ) &gt; 0 ]
					/SessionDetails/SessionDetail/Sessions[contains( ' / ', concat(' ', ../AttendanceReason, ' ') ) ] ) 
				+
				sum($OffRoll4/Attendance/TermlyAttendance[sum(SessionDetails/SessionDetail/Sessions[. &gt; 0 and contains( ' / ', concat(' ', ../AttendanceReason, ' ') ) ] ) &gt; 0 ]
					/SessionDetails/SessionDetail/Sessions[contains( ' / ', concat(' ', ../AttendanceReason, ' ') ) ] ) 
					"/>
		<xsl:variable name="AM2ndHalf4yrOld" select="
				sum($OnRoll4/Attendance/SummerHalfTerm2Attendance[sum(SessionDetails/SessionDetail/Sessions[. &gt; 0 and contains( ' / ', concat(' ', ../AttendanceReason, ' ') ) ] ) &gt; 0 ]
					/SessionDetails/SessionDetail/Sessions[contains( ' / ', concat(' ', ../AttendanceReason, ' ') ) ] ) 
				+
				sum($OffRoll4/Attendance/SummerHalfTerm2Attendance[sum(SessionDetails/SessionDetail/Sessions[. &gt; 0 and contains( ' / ', concat(' ', ../AttendanceReason, ' ') ) ] ) &gt; 0 ]
					/SessionDetails/SessionDetail/Sessions[contains( ' / ', concat(' ', ../AttendanceReason, ' ') ) ] ) 	
					"/>
		<xsl:variable name="AMTotal4yrOld" select="$AM1stHalf4yrOld + $AM2ndHalf4yrOld"/>
		<xsl:variable name="AM1stHalf5to15" select="
				sum($OnRoll5_15/Attendance/TermlyAttendance[sum(SessionDetails/SessionDetail/Sessions[. &gt; 0 and contains( ' / ', concat(' ', ../AttendanceReason, ' ') ) ] ) &gt; 0 ]
					/SessionDetails/SessionDetail/Sessions[contains( ' / ', concat(' ', ../AttendanceReason, ' ') ) ] ) 
				+
				sum($OffRoll5_15/Attendance/TermlyAttendance[sum(SessionDetails/SessionDetail/Sessions[. &gt; 0 and contains( ' / ', concat(' ', ../AttendanceReason, ' ') ) ] ) &gt; 0 ]
					/SessionDetails/SessionDetail/Sessions[contains( ' / ', concat(' ', ../AttendanceReason, ' ') ) ] ) 	
					"/>
		<xsl:variable name="AM2ndHalf5to15" select="
				sum($OnRoll5_15/Attendance/SummerHalfTerm2Attendance[sum(SessionDetails/SessionDetail/Sessions[. &gt; 0 and contains( ' / ', concat(' ', ../AttendanceReason, ' ') ) ] ) &gt; 0 ]
					/SessionDetails/SessionDetail/Sessions[contains( ' / ', concat(' ', ../AttendanceReason, ' ') ) ] ) 
				+
				sum($OffRoll5_15/Attendance/SummerHalfTerm2Attendance[sum(SessionDetails/SessionDetail/Sessions[. &gt; 0 and contains( ' / ', concat(' ', ../AttendanceReason, ' ') ) ] ) &gt; 0 ]
					/SessionDetails/SessionDetail/Sessions[contains( ' / ', concat(' ', ../AttendanceReason, ' ') ) ] ) 
					"/>
		<xsl:variable name="AMTotal5to15" select="$AM1stHalf5to15 + $AM2ndHalf5to15"/>
		<xsl:variable name="PM1stHalf4yrOld" select="
				sum($OnRoll4/Attendance/TermlyAttendance[sum(SessionDetails/SessionDetail/Sessions[. &gt; 0 and contains( ' \ ', concat(' ', ../AttendanceReason, ' ') ) ] ) &gt; 0 ]
					/SessionDetails/SessionDetail/Sessions[contains( ' \ ', concat(' ', ../AttendanceReason, ' ') ) ] ) 
				+
				sum($OffRoll4/Attendance/TermlyAttendance[sum(SessionDetails/SessionDetail/Sessions[. &gt; 0 and contains( ' \ ', concat(' ', ../AttendanceReason, ' ') ) ] ) &gt; 0 ]
					/SessionDetails/SessionDetail/Sessions[contains( ' \ ', concat(' ', ../AttendanceReason, ' ') ) ] ) 
					"/>
		<xsl:variable name="PM2ndHalf4yrOld" select="
				sum($OnRoll4/Attendance/SummerHalfTerm2Attendance[sum(SessionDetails/SessionDetail/Sessions[. &gt; 0 and contains( ' \ ', concat(' ', ../AttendanceReason, ' ') ) ] ) &gt; 0 ]
					/SessionDetails/SessionDetail/Sessions[contains( ' \ ', concat(' ', ../AttendanceReason, ' ') ) ] ) 
				+
				sum($OffRoll4/Attendance/SummerHalfTerm2Attendance[sum(SessionDetails/SessionDetail/Sessions[. &gt; 0 and contains( ' \ ', concat(' ', ../AttendanceReason, ' ') ) ] ) &gt; 0 ]
					/SessionDetails/SessionDetail/Sessions[contains( ' \ ', concat(' ', ../AttendanceReason, ' ') ) ] ) 	
					"/>
		<xsl:variable name="PMTotal4yrOld" select="$PM1stHalf4yrOld + $PM2ndHalf4yrOld"/>
		<xsl:variable name="PM1stHalf5to15" select="
				sum($OnRoll5_15/Attendance/TermlyAttendance[sum(SessionDetails/SessionDetail/Sessions[. &gt; 0 and contains( ' \ ', concat(' ', ../AttendanceReason, ' ') ) ] ) &gt; 0 ]
					/SessionDetails/SessionDetail/Sessions[contains( ' \ ', concat(' ', ../AttendanceReason, ' ') ) ] ) 
				+
				sum($OffRoll5_15/Attendance/TermlyAttendance[sum(SessionDetails/SessionDetail/Sessions[. &gt; 0 and contains( ' \ ', concat(' ', ../AttendanceReason, ' ') ) ] ) &gt; 0 ]
					/SessionDetails/SessionDetail/Sessions[contains( ' \ ', concat(' ', ../AttendanceReason, ' ') ) ] ) 	
					"/>
		<xsl:variable name="PM2ndHalf5to15" select="
				sum($OnRoll5_15/Attendance/SummerHalfTerm2Attendance[sum(SessionDetails/SessionDetail/Sessions[. &gt; 0 and contains( ' \ ', concat(' ', ../AttendanceReason, ' ') ) ] ) &gt; 0 ]
					/SessionDetails/SessionDetail/Sessions[contains( ' \ ', concat(' ', ../AttendanceReason, ' ') ) ] ) 
				+
				sum($OffRoll5_15/Attendance/SummerHalfTerm2Attendance[sum(SessionDetails/SessionDetail/Sessions[. &gt; 0 and contains( ' \ ', concat(' ', ../AttendanceReason, ' ') ) ] ) &gt; 0 ]
					/SessionDetails/SessionDetail/Sessions[contains( ' \ ', concat(' ', ../AttendanceReason, ' ') ) ] ) 
					"/>
		<xsl:variable name="PMTotal5to15" select="$PM1stHalf5to15 + $PM2ndHalf5to15"/>
		<xsl:variable name="B1stHalf4yrOld" select="
			sum($OnRoll4/Attendance/TermlyAttendance[sum(SessionDetails/SessionDetail/Sessions[. &gt; 0 and contains( ' B ', concat(' ', ../AttendanceReason, ' ') ) ] ) &gt; 0 ]
				/SessionDetails/SessionDetail/Sessions[contains( ' B ', concat(' ', ../AttendanceReason, ' ') ) ] ) 
			+
			sum($OffRoll4/Attendance/TermlyAttendance[sum(SessionDetails/SessionDetail/Sessions[. &gt; 0 and contains( ' B ', concat(' ', ../AttendanceReason, ' ') ) ] ) &gt; 0 ]
				/SessionDetails/SessionDetail/Sessions[contains( ' B ', concat(' ', ../AttendanceReason, ' ') ) ] ) 
				"/>
		<xsl:variable name="B2ndHalf4yrOld" select="
			sum($OnRoll4/Attendance/SummerHalfTerm2Attendance [sum(SessionDetails/SessionDetail/Sessions[. &gt; 0 and contains( ' B ', concat(' ', ../AttendanceReason, ' ') ) ] ) &gt; 0 ]
				/SessionDetails/SessionDetail/Sessions[contains( ' B ', concat(' ', ../AttendanceReason, ' ') ) ] ) 
			+
			sum($OffRoll4/Attendance/SummerHalfTerm2Attendance [sum(SessionDetails/SessionDetail/Sessions[. &gt; 0 and contains( ' B ', concat(' ', ../AttendanceReason, ' ') ) ] ) &gt; 0 ]
				/SessionDetails/SessionDetail/Sessions[contains( ' B ', concat(' ', ../AttendanceReason, ' ') ) ] ) 				
				"/>
		<xsl:variable name="BTotal4yrOld" select="$B1stHalf4yrOld + $B2ndHalf4yrOld"/>
		<xsl:variable name="B1stHalf5to15" select="
			sum($OnRoll5_15/Attendance/TermlyAttendance[sum(SessionDetails/SessionDetail/Sessions[. &gt; 0 and contains( ' B ', concat(' ', ../AttendanceReason, ' ') ) ] ) &gt; 0 ]
				/SessionDetails/SessionDetail/Sessions[contains( ' B ', concat(' ', ../AttendanceReason, ' ') ) ] ) 
			+
			sum($OffRoll5_15/Attendance/TermlyAttendance[sum(SessionDetails/SessionDetail/Sessions[. &gt; 0 and contains( ' B ', concat(' ', ../AttendanceReason, ' ') ) ] ) &gt; 0 ]
				/SessionDetails/SessionDetail/Sessions[contains( ' B ', concat(' ', ../AttendanceReason, ' ') ) ] ) 
				"/>
		<xsl:variable name="B2ndHalf5to15" select="
			sum($OnRoll5_15/Attendance/SummerHalfTerm2Attendance[sum(SessionDetails/SessionDetail/Sessions[. &gt; 0 and contains( ' B ', concat(' ', ../AttendanceReason, ' ') ) ] ) &gt; 0 ]
				/SessionDetails/SessionDetail/Sessions[contains( ' B ', concat(' ', ../AttendanceReason, ' ') ) ] ) 
			+
			sum($OffRoll5_15/Attendance/SummerHalfTerm2Attendance[sum(SessionDetails/SessionDetail/Sessions[. &gt; 0 and contains( ' B ', concat(' ', ../AttendanceReason, ' ') ) ] ) &gt; 0 ]
				/SessionDetails/SessionDetail/Sessions[contains( ' B ', concat(' ', ../AttendanceReason, ' ') ) ] ) 
				"/>
		<xsl:variable name="BTotal5to15" select="$B1stHalf5to15 + $B2ndHalf5to15"/>
		<xsl:variable name="C1stHalf4yrOld" select="
			sum($OnRoll4/Attendance/TermlyAttendance[sum(SessionDetails/SessionDetail/Sessions[. &gt; 0 and contains( ' C ', concat(' ', ../AttendanceReason, ' ') ) ] ) &gt; 0 ]
				/SessionDetails/SessionDetail/Sessions[contains( ' C ', concat(' ', ../AttendanceReason, ' ') ) ] ) 
			+
			sum($OffRoll4/Attendance/TermlyAttendance[sum(SessionDetails/SessionDetail/Sessions[. &gt; 0 and contains( ' C ', concat(' ', ../AttendanceReason, ' ') ) ] ) &gt; 0 ]
				/SessionDetails/SessionDetail/Sessions[contains( ' C ', concat(' ', ../AttendanceReason, ' ') ) ] ) 
				"/>
		<xsl:variable name="C2ndHalf4yrOld" select="
			sum($OnRoll4/Attendance/SummerHalfTerm2Attendance [sum(SessionDetails/SessionDetail/Sessions[. &gt; 0 and contains( ' C ', concat(' ', ../AttendanceReason, ' ') ) ] ) &gt; 0 ]
				/SessionDetails/SessionDetail/Sessions[contains( ' C ', concat(' ', ../AttendanceReason, ' ') ) ] ) 
			+
			sum($OffRoll4/Attendance/SummerHalfTerm2Attendance [sum(SessionDetails/SessionDetail/Sessions[. &gt; 0 and contains( ' C ', concat(' ', ../AttendanceReason, ' ') ) ] ) &gt; 0 ]
				/SessionDetails/SessionDetail/Sessions[contains( ' C ', concat(' ', ../AttendanceReason, ' ') ) ] ) 				
				"/>
		<xsl:variable name="CTotal4yrOld" select="$C1stHalf4yrOld + $C2ndHalf4yrOld"/>
		<xsl:variable name="C1stHalf5to15" select="
			sum($OnRoll5_15/Attendance/TermlyAttendance[sum(SessionDetails/SessionDetail/Sessions[. &gt; 0 and contains( ' C ', concat(' ', ../AttendanceReason, ' ') ) ] ) &gt; 0 ]
				/SessionDetails/SessionDetail/Sessions[contains( ' C ', concat(' ', ../AttendanceReason, ' ') ) ] ) 
			+
			sum($OffRoll5_15/Attendance/TermlyAttendance[sum(SessionDetails/SessionDetail/Sessions[. &gt; 0 and contains( ' C ', concat(' ', ../AttendanceReason, ' ') ) ] ) &gt; 0 ]
				/SessionDetails/SessionDetail/Sessions[contains( ' C ', concat(' ', ../AttendanceReason, ' ') ) ] ) 
				"/>
		<xsl:variable name="C2ndHalf5to15" select="
			sum($OnRoll5_15/Attendance/SummerHalfTerm2Attendance[sum(SessionDetails/SessionDetail/Sessions[. &gt; 0 and contains( ' C ', concat(' ', ../AttendanceReason, ' ') ) ] ) &gt; 0 ]
				/SessionDetails/SessionDetail/Sessions[contains( ' C ', concat(' ', ../AttendanceReason, ' ') ) ] ) 
			+
			sum($OffRoll5_15/Attendance/SummerHalfTerm2Attendance[sum(SessionDetails/SessionDetail/Sessions[. &gt; 0 and contains( ' C ', concat(' ', ../AttendanceReason, ' ') ) ] ) &gt; 0 ]
				/SessionDetails/SessionDetail/Sessions[contains( ' C ', concat(' ', ../AttendanceReason, ' ') ) ] ) 
				"/>
		<xsl:variable name="CTotal5to15" select="$C1stHalf5to15 + $C2ndHalf5to15"/>
		<xsl:variable name="D1stHalf4yrOld" select="
			sum($OnRoll4/Attendance/TermlyAttendance[sum(SessionDetails/SessionDetail/Sessions[. &gt; 0 and contains( ' D ', concat(' ', ../AttendanceReason, ' ') ) ] ) &gt; 0 ]
				/SessionDetails/SessionDetail/Sessions[contains( ' D ', concat(' ', ../AttendanceReason, ' ') ) ] ) 
			+
			sum($OffRoll4/Attendance/TermlyAttendance[sum(SessionDetails/SessionDetail/Sessions[. &gt; 0 and contains( ' D ', concat(' ', ../AttendanceReason, ' ') ) ] ) &gt; 0 ]
				/SessionDetails/SessionDetail/Sessions[contains( ' D ', concat(' ', ../AttendanceReason, ' ') ) ] ) 
				"/>
		<xsl:variable name="D2ndHalf4yrOld" select="
			sum($OnRoll4/Attendance/SummerHalfTerm2Attendance [sum(SessionDetails/SessionDetail/Sessions[. &gt; 0 and contains( ' D ', concat(' ', ../AttendanceReason, ' ') ) ] ) &gt; 0 ]
				/SessionDetails/SessionDetail/Sessions[contains( ' D ', concat(' ', ../AttendanceReason, ' ') ) ] ) 
			+
			sum($OffRoll4/Attendance/SummerHalfTerm2Attendance [sum(SessionDetails/SessionDetail/Sessions[. &gt; 0 and contains( ' D ', concat(' ', ../AttendanceReason, ' ') ) ] ) &gt; 0 ]
				/SessionDetails/SessionDetail/Sessions[contains( ' D ', concat(' ', ../AttendanceReason, ' ') ) ] ) 				
				"/>
		<xsl:variable name="DTotal4yrOld" select="$D1stHalf4yrOld + $D2ndHalf4yrOld"/>
		<xsl:variable name="D1stHalf5to15" select="
			sum($OnRoll5_15/Attendance/TermlyAttendance[sum(SessionDetails/SessionDetail/Sessions[. &gt; 0 and contains( ' D ', concat(' ', ../AttendanceReason, ' ') ) ] ) &gt; 0 ]
				/SessionDetails/SessionDetail/Sessions[contains( ' D ', concat(' ', ../AttendanceReason, ' ') ) ] ) 
			+
			sum($OffRoll5_15/Attendance/TermlyAttendance[sum(SessionDetails/SessionDetail/Sessions[. &gt; 0 and contains( ' D ', concat(' ', ../AttendanceReason, ' ') ) ] ) &gt; 0 ]
				/SessionDetails/SessionDetail/Sessions[contains( ' D ', concat(' ', ../AttendanceReason, ' ') ) ] ) 
				"/>
		<xsl:variable name="D2ndHalf5to15" select="
			sum($OnRoll5_15/Attendance/SummerHalfTerm2Attendance[sum(SessionDetails/SessionDetail/Sessions[. &gt; 0 and contains( ' D ', concat(' ', ../AttendanceReason, ' ') ) ] ) &gt; 0 ]
				/SessionDetails/SessionDetail/Sessions[contains( ' D ', concat(' ', ../AttendanceReason, ' ') ) ] ) 
			+
			sum($OffRoll5_15/Attendance/SummerHalfTerm2Attendance[sum(SessionDetails/SessionDetail/Sessions[. &gt; 0 and contains( ' D ', concat(' ', ../AttendanceReason, ' ') ) ] ) &gt; 0 ]
				/SessionDetails/SessionDetail/Sessions[contains( ' D ', concat(' ', ../AttendanceReason, ' ') ) ] ) 
				"/>
		<xsl:variable name="DTotal5to15" select="$D1stHalf5to15 + $D2ndHalf5to15"/>
		<xsl:variable name="E1stHalf4yrOld" select="
			sum($OnRoll4/Attendance/TermlyAttendance[sum(SessionDetails/SessionDetail/Sessions[. &gt; 0 and contains( ' E ', concat(' ', ../AttendanceReason, ' ') ) ] ) &gt; 0 ]
				/SessionDetails/SessionDetail/Sessions[contains( ' E ', concat(' ', ../AttendanceReason, ' ') ) ] ) 
			+
			sum($OffRoll4/Attendance/TermlyAttendance[sum(SessionDetails/SessionDetail/Sessions[. &gt; 0 and contains( ' E ', concat(' ', ../AttendanceReason, ' ') ) ] ) &gt; 0 ]
				/SessionDetails/SessionDetail/Sessions[contains( ' E ', concat(' ', ../AttendanceReason, ' ') ) ] ) 
				"/>
		<xsl:variable name="E2ndHalf4yrOld" select="
			sum($OnRoll4/Attendance/SummerHalfTerm2Attendance [sum(SessionDetails/SessionDetail/Sessions[. &gt; 0 and contains( ' E ', concat(' ', ../AttendanceReason, ' ') ) ] ) &gt; 0 ]
				/SessionDetails/SessionDetail/Sessions[contains( ' E ', concat(' ', ../AttendanceReason, ' ') ) ] ) 
			+
			sum($OffRoll4/Attendance/SummerHalfTerm2Attendance [sum(SessionDetails/SessionDetail/Sessions[. &gt; 0 and contains( ' E ', concat(' ', ../AttendanceReason, ' ') ) ] ) &gt; 0 ]
				/SessionDetails/SessionDetail/Sessions[contains( ' E ', concat(' ', ../AttendanceReason, ' ') ) ] ) 				
				"/>
		<xsl:variable name="ETotal4yrOld" select="$E1stHalf4yrOld + $E2ndHalf4yrOld"/>
		<xsl:variable name="E1stHalf5to15" select="
			sum($OnRoll5_15/Attendance/TermlyAttendance[sum(SessionDetails/SessionDetail/Sessions[. &gt; 0 and contains( ' E ', concat(' ', ../AttendanceReason, ' ') ) ] ) &gt; 0 ]
				/SessionDetails/SessionDetail/Sessions[contains( ' E ', concat(' ', ../AttendanceReason, ' ') ) ] ) 
			+
			sum($OffRoll5_15/Attendance/TermlyAttendance[sum(SessionDetails/SessionDetail/Sessions[. &gt; 0 and contains( ' E ', concat(' ', ../AttendanceReason, ' ') ) ] ) &gt; 0 ]
				/SessionDetails/SessionDetail/Sessions[contains( ' E ', concat(' ', ../AttendanceReason, ' ') ) ] ) 
				"/>
		<xsl:variable name="E2ndHalf5to15" select="
			sum($OnRoll5_15/Attendance/SummerHalfTerm2Attendance[sum(SessionDetails/SessionDetail/Sessions[. &gt; 0 and contains( ' E ', concat(' ', ../AttendanceReason, ' ') ) ] ) &gt; 0 ]
				/SessionDetails/SessionDetail/Sessions[contains( ' E ', concat(' ', ../AttendanceReason, ' ') ) ] ) 
			+
			sum($OffRoll5_15/Attendance/SummerHalfTerm2Attendance[sum(SessionDetails/SessionDetail/Sessions[. &gt; 0 and contains( ' E ', concat(' ', ../AttendanceReason, ' ') ) ] ) &gt; 0 ]
				/SessionDetails/SessionDetail/Sessions[contains( ' E ', concat(' ', ../AttendanceReason, ' ') ) ] ) 
				"/>
		<xsl:variable name="ETotal5to15" select="$E1stHalf5to15 + $E2ndHalf5to15"/>
		<xsl:variable name="G1stHalf4yrOld" select="
			sum($OnRoll4/Attendance/TermlyAttendance[sum(SessionDetails/SessionDetail/Sessions[. &gt; 0 and contains( ' G ', concat(' ', ../AttendanceReason, ' ') ) ] ) &gt; 0 ]
				/SessionDetails/SessionDetail/Sessions[contains( ' G ', concat(' ', ../AttendanceReason, ' ') ) ] ) 
			+
			sum($OffRoll4/Attendance/TermlyAttendance[sum(SessionDetails/SessionDetail/Sessions[. &gt; 0 and contains( ' G ', concat(' ', ../AttendanceReason, ' ') ) ] ) &gt; 0 ]
				/SessionDetails/SessionDetail/Sessions[contains( ' G ', concat(' ', ../AttendanceReason, ' ') ) ] ) 
				"/>
		<xsl:variable name="G2ndHalf4yrOld" select="
			sum($OnRoll4/Attendance/SummerHalfTerm2Attendance [sum(SessionDetails/SessionDetail/Sessions[. &gt; 0 and contains( ' G ', concat(' ', ../AttendanceReason, ' ') ) ] ) &gt; 0 ]
				/SessionDetails/SessionDetail/Sessions[contains( ' G ', concat(' ', ../AttendanceReason, ' ') ) ] ) 
			+
			sum($OffRoll4/Attendance/SummerHalfTerm2Attendance [sum(SessionDetails/SessionDetail/Sessions[. &gt; 0 and contains( ' G ', concat(' ', ../AttendanceReason, ' ') ) ] ) &gt; 0 ]
				/SessionDetails/SessionDetail/Sessions[contains( ' G ', concat(' ', ../AttendanceReason, ' ') ) ] ) 				
				"/>
		<xsl:variable name="GTotal4yrOld" select="$G1stHalf4yrOld + $G2ndHalf4yrOld"/>
		<xsl:variable name="G1stHalf5to15" select="
			sum($OnRoll5_15/Attendance/TermlyAttendance[sum(SessionDetails/SessionDetail/Sessions[. &gt; 0 and contains( ' G ', concat(' ', ../AttendanceReason, ' ') ) ] ) &gt; 0 ]
				/SessionDetails/SessionDetail/Sessions[contains( ' G ', concat(' ', ../AttendanceReason, ' ') ) ] ) 
			+
			sum($OffRoll5_15/Attendance/TermlyAttendance[sum(SessionDetails/SessionDetail/Sessions[. &gt; 0 and contains( ' G ', concat(' ', ../AttendanceReason, ' ') ) ] ) &gt; 0 ]
				/SessionDetails/SessionDetail/Sessions[contains( ' G ', concat(' ', ../AttendanceReason, ' ') ) ] ) 
				"/>
		<xsl:variable name="G2ndHalf5to15" select="
			sum($OnRoll5_15/Attendance/SummerHalfTerm2Attendance[sum(SessionDetails/SessionDetail/Sessions[. &gt; 0 and contains( ' G ', concat(' ', ../AttendanceReason, ' ') ) ] ) &gt; 0 ]
				/SessionDetails/SessionDetail/Sessions[contains( ' G ', concat(' ', ../AttendanceReason, ' ') ) ] ) 
			+
			sum($OffRoll5_15/Attendance/SummerHalfTerm2Attendance[sum(SessionDetails/SessionDetail/Sessions[. &gt; 0 and contains( ' G ', concat(' ', ../AttendanceReason, ' ') ) ] ) &gt; 0 ]
				/SessionDetails/SessionDetail/Sessions[contains( ' G ', concat(' ', ../AttendanceReason, ' ') ) ] ) 
				"/>
		<xsl:variable name="GTotal5to15" select="$G1stHalf5to15 + $G2ndHalf5to15"/>
		<xsl:variable name="H1stHalf4yrOld" select="
			sum($OnRoll4/Attendance/TermlyAttendance[sum(SessionDetails/SessionDetail/Sessions[. &gt; 0 and contains( ' H ', concat(' ', ../AttendanceReason, ' ') ) ] ) &gt; 0 ]
				/SessionDetails/SessionDetail/Sessions[contains( ' H ', concat(' ', ../AttendanceReason, ' ') ) ] ) 
			+
			sum($OffRoll4/Attendance/TermlyAttendance[sum(SessionDetails/SessionDetail/Sessions[. &gt; 0 and contains( ' H ', concat(' ', ../AttendanceReason, ' ') ) ] ) &gt; 0 ]
				/SessionDetails/SessionDetail/Sessions[contains( ' H ', concat(' ', ../AttendanceReason, ' ') ) ] ) 
				"/>
		<xsl:variable name="H2ndHalf4yrOld" select="
			sum($OnRoll4/Attendance/SummerHalfTerm2Attendance [sum(SessionDetails/SessionDetail/Sessions[. &gt; 0 and contains( ' H ', concat(' ', ../AttendanceReason, ' ') ) ] ) &gt; 0 ]
				/SessionDetails/SessionDetail/Sessions[contains( ' H ', concat(' ', ../AttendanceReason, ' ') ) ] ) 
			+
			sum($OffRoll4/Attendance/SummerHalfTerm2Attendance [sum(SessionDetails/SessionDetail/Sessions[. &gt; 0 and contains( ' H ', concat(' ', ../AttendanceReason, ' ') ) ] ) &gt; 0 ]
				/SessionDetails/SessionDetail/Sessions[contains( ' H ', concat(' ', ../AttendanceReason, ' ') ) ] ) 				
				"/>
		<xsl:variable name="HTotal4yrOld" select="$H1stHalf4yrOld + $H2ndHalf4yrOld"/>
		<xsl:variable name="H1stHalf5to15" select="
			sum($OnRoll5_15/Attendance/TermlyAttendance[sum(SessionDetails/SessionDetail/Sessions[. &gt; 0 and contains( ' H ', concat(' ', ../AttendanceReason, ' ') ) ] ) &gt; 0 ]
				/SessionDetails/SessionDetail/Sessions[contains( ' H ', concat(' ', ../AttendanceReason, ' ') ) ] ) 
			+
			sum($OffRoll5_15/Attendance/TermlyAttendance[sum(SessionDetails/SessionDetail/Sessions[. &gt; 0 and contains( ' H ', concat(' ', ../AttendanceReason, ' ') ) ] ) &gt; 0 ]
				/SessionDetails/SessionDetail/Sessions[contains( ' H ', concat(' ', ../AttendanceReason, ' ') ) ] ) 
				"/>
		<xsl:variable name="H2ndHalf5to15" select="
			sum($OnRoll5_15/Attendance/SummerHalfTerm2Attendance[sum(SessionDetails/SessionDetail/Sessions[. &gt; 0 and contains( ' H ', concat(' ', ../AttendanceReason, ' ') ) ] ) &gt; 0 ]
				/SessionDetails/SessionDetail/Sessions[contains( ' H ', concat(' ', ../AttendanceReason, ' ') ) ] ) 
			+
			sum($OffRoll5_15/Attendance/SummerHalfTerm2Attendance[sum(SessionDetails/SessionDetail/Sessions[. &gt; 0 and contains( ' H ', concat(' ', ../AttendanceReason, ' ') ) ] ) &gt; 0 ]
				/SessionDetails/SessionDetail/Sessions[contains( ' H ', concat(' ', ../AttendanceReason, ' ') ) ] ) 
				"/>
		<xsl:variable name="HTotal5to15" select="$H1stHalf5to15 + $H2ndHalf5to15"/>
		<xsl:variable name="I1stHalf4yrOld" select="
			sum($OnRoll4/Attendance/TermlyAttendance[sum(SessionDetails/SessionDetail/Sessions[. &gt; 0 and contains( ' I ', concat(' ', ../AttendanceReason, ' ') ) ] ) &gt; 0 ]
				/SessionDetails/SessionDetail/Sessions[contains( ' I ', concat(' ', ../AttendanceReason, ' ') ) ] ) 
			+
			sum($OffRoll4/Attendance/TermlyAttendance[sum(SessionDetails/SessionDetail/Sessions[. &gt; 0 and contains( ' I ', concat(' ', ../AttendanceReason, ' ') ) ] ) &gt; 0 ]
				/SessionDetails/SessionDetail/Sessions[contains( ' I ', concat(' ', ../AttendanceReason, ' ') ) ] ) 
				"/>
		<xsl:variable name="I2ndHalf4yrOld" select="
			sum($OnRoll4/Attendance/SummerHalfTerm2Attendance [sum(SessionDetails/SessionDetail/Sessions[. &gt; 0 and contains( ' I ', concat(' ', ../AttendanceReason, ' ') ) ] ) &gt; 0 ]
				/SessionDetails/SessionDetail/Sessions[contains( ' I ', concat(' ', ../AttendanceReason, ' ') ) ] ) 
			+
			sum($OffRoll4/Attendance/SummerHalfTerm2Attendance [sum(SessionDetails/SessionDetail/Sessions[. &gt; 0 and contains( ' I ', concat(' ', ../AttendanceReason, ' ') ) ] ) &gt; 0 ]
				/SessionDetails/SessionDetail/Sessions[contains( ' I ', concat(' ', ../AttendanceReason, ' ') ) ] ) 				
				"/>
		<xsl:variable name="ITotal4yrOld" select="$I1stHalf4yrOld + $I2ndHalf4yrOld"/>
		<xsl:variable name="I1stHalf5to15" select="
			sum($OnRoll5_15/Attendance/TermlyAttendance[sum(SessionDetails/SessionDetail/Sessions[. &gt; 0 and contains( ' I ', concat(' ', ../AttendanceReason, ' ') ) ] ) &gt; 0 ]
				/SessionDetails/SessionDetail/Sessions[contains( ' I ', concat(' ', ../AttendanceReason, ' ') ) ] ) 
			+
			sum($OffRoll5_15/Attendance/TermlyAttendance[sum(SessionDetails/SessionDetail/Sessions[. &gt; 0 and contains( ' I ', concat(' ', ../AttendanceReason, ' ') ) ] ) &gt; 0 ]
				/SessionDetails/SessionDetail/Sessions[contains( ' I ', concat(' ', ../AttendanceReason, ' ') ) ] ) 
				"/>
		<xsl:variable name="I2ndHalf5to15" select="
			sum($OnRoll5_15/Attendance/SummerHalfTerm2Attendance[sum(SessionDetails/SessionDetail/Sessions[. &gt; 0 and contains( ' I ', concat(' ', ../AttendanceReason, ' ') ) ] ) &gt; 0 ]
				/SessionDetails/SessionDetail/Sessions[contains( ' I ', concat(' ', ../AttendanceReason, ' ') ) ] ) 
			+
			sum($OffRoll5_15/Attendance/SummerHalfTerm2Attendance[sum(SessionDetails/SessionDetail/Sessions[. &gt; 0 and contains( ' I ', concat(' ', ../AttendanceReason, ' ') ) ] ) &gt; 0 ]
				/SessionDetails/SessionDetail/Sessions[contains( ' I ', concat(' ', ../AttendanceReason, ' ') ) ] ) 
				"/>
		<xsl:variable name="ITotal5to15" select="$I1stHalf5to15 + $I2ndHalf5to15"/>
		<xsl:variable name="J1stHalf4yrOld" select="
			sum($OnRoll4/Attendance/TermlyAttendance[sum(SessionDetails/SessionDetail/Sessions[. &gt; 0 and contains( ' J ', concat(' ', ../AttendanceReason, ' ') ) ] ) &gt; 0 ]
				/SessionDetails/SessionDetail/Sessions[contains( ' J ', concat(' ', ../AttendanceReason, ' ') ) ] ) 
			+
			sum($OffRoll4/Attendance/TermlyAttendance[sum(SessionDetails/SessionDetail/Sessions[. &gt; 0 and contains( ' J ', concat(' ', ../AttendanceReason, ' ') ) ] ) &gt; 0 ]
				/SessionDetails/SessionDetail/Sessions[contains( ' J ', concat(' ', ../AttendanceReason, ' ') ) ] ) 
				"/>
		<xsl:variable name="J2ndHalf4yrOld" select="
			sum($OnRoll4/Attendance/SummerHalfTerm2Attendance [sum(SessionDetails/SessionDetail/Sessions[. &gt; 0 and contains( ' J ', concat(' ', ../AttendanceReason, ' ') ) ] ) &gt; 0 ]
				/SessionDetails/SessionDetail/Sessions[contains( ' J ', concat(' ', ../AttendanceReason, ' ') ) ] ) 
			+
			sum($OffRoll4/Attendance/SummerHalfTerm2Attendance [sum(SessionDetails/SessionDetail/Sessions[. &gt; 0 and contains( ' J ', concat(' ', ../AttendanceReason, ' ') ) ] ) &gt; 0 ]
				/SessionDetails/SessionDetail/Sessions[contains( ' J ', concat(' ', ../AttendanceReason, ' ') ) ] ) 				
				"/>
		<xsl:variable name="JTotal4yrOld" select="$J1stHalf4yrOld + $J2ndHalf4yrOld"/>
		<xsl:variable name="J1stHalf5to15" select="
			sum($OnRoll5_15/Attendance/TermlyAttendance[sum(SessionDetails/SessionDetail/Sessions[. &gt; 0 and contains( ' J ', concat(' ', ../AttendanceReason, ' ') ) ] ) &gt; 0 ]
				/SessionDetails/SessionDetail/Sessions[contains( ' J ', concat(' ', ../AttendanceReason, ' ') ) ] ) 
			+
			sum($OffRoll5_15/Attendance/TermlyAttendance[sum(SessionDetails/SessionDetail/Sessions[. &gt; 0 and contains( ' J ', concat(' ', ../AttendanceReason, ' ') ) ] ) &gt; 0 ]
				/SessionDetails/SessionDetail/Sessions[contains( ' J ', concat(' ', ../AttendanceReason, ' ') ) ] ) 
				"/>
		<xsl:variable name="J2ndHalf5to15" select="
			sum($OnRoll5_15/Attendance/SummerHalfTerm2Attendance[sum(SessionDetails/SessionDetail/Sessions[. &gt; 0 and contains( ' J ', concat(' ', ../AttendanceReason, ' ') ) ] ) &gt; 0 ]
				/SessionDetails/SessionDetail/Sessions[contains( ' J ', concat(' ', ../AttendanceReason, ' ') ) ] ) 
			+
			sum($OffRoll5_15/Attendance/SummerHalfTerm2Attendance[sum(SessionDetails/SessionDetail/Sessions[. &gt; 0 and contains( ' J ', concat(' ', ../AttendanceReason, ' ') ) ] ) &gt; 0 ]
				/SessionDetails/SessionDetail/Sessions[contains( ' J ', concat(' ', ../AttendanceReason, ' ') ) ] ) 
				"/>
		<xsl:variable name="JTotal5to15" select="$J1stHalf5to15 + $J2ndHalf5to15"/>
		<xsl:variable name="L1stHalf4yrOld" select="
			sum($OnRoll4/Attendance/TermlyAttendance[sum(SessionDetails/SessionDetail/Sessions[. &gt; 0 and contains( ' L ', concat(' ', ../AttendanceReason, ' ') ) ] ) &gt; 0 ]
				/SessionDetails/SessionDetail/Sessions[contains( ' L ', concat(' ', ../AttendanceReason, ' ') ) ] ) 
			+
			sum($OffRoll4/Attendance/TermlyAttendance[sum(SessionDetails/SessionDetail/Sessions[. &gt; 0 and contains( ' L ', concat(' ', ../AttendanceReason, ' ') ) ] ) &gt; 0 ]
				/SessionDetails/SessionDetail/Sessions[contains( ' L ', concat(' ', ../AttendanceReason, ' ') ) ] ) 
				"/>
		<xsl:variable name="L2ndHalf4yrOld" select="
			sum($OnRoll4/Attendance/SummerHalfTerm2Attendance [sum(SessionDetails/SessionDetail/Sessions[. &gt; 0 and contains( ' L ', concat(' ', ../AttendanceReason, ' ') ) ] ) &gt; 0 ]
				/SessionDetails/SessionDetail/Sessions[contains( ' L ', concat(' ', ../AttendanceReason, ' ') ) ] ) 
			+
			sum($OffRoll4/Attendance/SummerHalfTerm2Attendance [sum(SessionDetails/SessionDetail/Sessions[. &gt; 0 and contains( ' L ', concat(' ', ../AttendanceReason, ' ') ) ] ) &gt; 0 ]
				/SessionDetails/SessionDetail/Sessions[contains( ' L ', concat(' ', ../AttendanceReason, ' ') ) ] ) 				
				"/>
		<xsl:variable name="LTotal4yrOld" select="$L1stHalf4yrOld + $L2ndHalf4yrOld"/>
		<xsl:variable name="L1stHalf5to15" select="
			sum($OnRoll5_15/Attendance/TermlyAttendance[sum(SessionDetails/SessionDetail/Sessions[. &gt; 0 and contains( ' L ', concat(' ', ../AttendanceReason, ' ') ) ] ) &gt; 0 ]
				/SessionDetails/SessionDetail/Sessions[contains( ' L ', concat(' ', ../AttendanceReason, ' ') ) ] ) 
			+
			sum($OffRoll5_15/Attendance/TermlyAttendance[sum(SessionDetails/SessionDetail/Sessions[. &gt; 0 and contains( ' L ', concat(' ', ../AttendanceReason, ' ') ) ] ) &gt; 0 ]
				/SessionDetails/SessionDetail/Sessions[contains( ' L ', concat(' ', ../AttendanceReason, ' ') ) ] ) 
				"/>
		<xsl:variable name="L2ndHalf5to15" select="
			sum($OnRoll5_15/Attendance/SummerHalfTerm2Attendance[sum(SessionDetails/SessionDetail/Sessions[. &gt; 0 and contains( ' L ', concat(' ', ../AttendanceReason, ' ') ) ] ) &gt; 0 ]
				/SessionDetails/SessionDetail/Sessions[contains( ' L ', concat(' ', ../AttendanceReason, ' ') ) ] ) 
			+
			sum($OffRoll5_15/Attendance/SummerHalfTerm2Attendance[sum(SessionDetails/SessionDetail/Sessions[. &gt; 0 and contains( ' L ', concat(' ', ../AttendanceReason, ' ') ) ] ) &gt; 0 ]
				/SessionDetails/SessionDetail/Sessions[contains( ' L ', concat(' ', ../AttendanceReason, ' ') ) ] ) 
				"/>
		<xsl:variable name="LTotal5to15" select="$L1stHalf5to15 + $L2ndHalf5to15"/>
		<xsl:variable name="M1stHalf4yrOld" select="
			sum($OnRoll4/Attendance/TermlyAttendance[sum(SessionDetails/SessionDetail/Sessions[. &gt; 0 and contains( ' M ', concat(' ', ../AttendanceReason, ' ') ) ] ) &gt; 0 ]
				/SessionDetails/SessionDetail/Sessions[contains( ' M ', concat(' ', ../AttendanceReason, ' ') ) ] ) 
			+
			sum($OffRoll4/Attendance/TermlyAttendance[sum(SessionDetails/SessionDetail/Sessions[. &gt; 0 and contains( ' M ', concat(' ', ../AttendanceReason, ' ') ) ] ) &gt; 0 ]
				/SessionDetails/SessionDetail/Sessions[contains( ' M ', concat(' ', ../AttendanceReason, ' ') ) ] ) 
				"/>
		<xsl:variable name="M2ndHalf4yrOld" select="
			sum($OnRoll4/Attendance/SummerHalfTerm2Attendance [sum(SessionDetails/SessionDetail/Sessions[. &gt; 0 and contains( ' M ', concat(' ', ../AttendanceReason, ' ') ) ] ) &gt; 0 ]
				/SessionDetails/SessionDetail/Sessions[contains( ' M ', concat(' ', ../AttendanceReason, ' ') ) ] ) 
			+
			sum($OffRoll4/Attendance/SummerHalfTerm2Attendance [sum(SessionDetails/SessionDetail/Sessions[. &gt; 0 and contains( ' M ', concat(' ', ../AttendanceReason, ' ') ) ] ) &gt; 0 ]
				/SessionDetails/SessionDetail/Sessions[contains( ' M ', concat(' ', ../AttendanceReason, ' ') ) ] ) 				
				"/>
		<xsl:variable name="MTotal4yrOld" select="$M1stHalf4yrOld + $M2ndHalf4yrOld"/>
		<xsl:variable name="M1stHalf5to15" select="
			sum($OnRoll5_15/Attendance/TermlyAttendance[sum(SessionDetails/SessionDetail/Sessions[. &gt; 0 and contains( ' M ', concat(' ', ../AttendanceReason, ' ') ) ] ) &gt; 0 ]
				/SessionDetails/SessionDetail/Sessions[contains( ' M ', concat(' ', ../AttendanceReason, ' ') ) ] ) 
			+
			sum($OffRoll5_15/Attendance/TermlyAttendance[sum(SessionDetails/SessionDetail/Sessions[. &gt; 0 and contains( ' M ', concat(' ', ../AttendanceReason, ' ') ) ] ) &gt; 0 ]
				/SessionDetails/SessionDetail/Sessions[contains( ' M ', concat(' ', ../AttendanceReason, ' ') ) ] ) 
				"/>
		<xsl:variable name="M2ndHalf5to15" select="
			sum($OnRoll5_15/Attendance/SummerHalfTerm2Attendance[sum(SessionDetails/SessionDetail/Sessions[. &gt; 0 and contains( ' M ', concat(' ', ../AttendanceReason, ' ') ) ] ) &gt; 0 ]
				/SessionDetails/SessionDetail/Sessions[contains( ' M ', concat(' ', ../AttendanceReason, ' ') ) ] ) 
			+
			sum($OffRoll5_15/Attendance/SummerHalfTerm2Attendance[sum(SessionDetails/SessionDetail/Sessions[. &gt; 0 and contains( ' M ', concat(' ', ../AttendanceReason, ' ') ) ] ) &gt; 0 ]
				/SessionDetails/SessionDetail/Sessions[contains( ' M ', concat(' ', ../AttendanceReason, ' ') ) ] ) 
				"/>
		<xsl:variable name="MTotal5to15" select="$M1stHalf5to15 + $M2ndHalf5to15"/>
		<xsl:variable name="N1stHalf4yrOld" select="
			sum($OnRoll4/Attendance/TermlyAttendance[sum(SessionDetails/SessionDetail/Sessions[. &gt; 0 and contains( ' N ', concat(' ', ../AttendanceReason, ' ') ) ] ) &gt; 0 ]
				/SessionDetails/SessionDetail/Sessions[contains( ' N ', concat(' ', ../AttendanceReason, ' ') ) ] ) 
			+
			sum($OffRoll4/Attendance/TermlyAttendance[sum(SessionDetails/SessionDetail/Sessions[. &gt; 0 and contains( ' N ', concat(' ', ../AttendanceReason, ' ') ) ] ) &gt; 0 ]
				/SessionDetails/SessionDetail/Sessions[contains( ' N ', concat(' ', ../AttendanceReason, ' ') ) ] ) 
				"/>
		<xsl:variable name="N2ndHalf4yrOld" select="
			sum($OnRoll4/Attendance/SummerHalfTerm2Attendance [sum(SessionDetails/SessionDetail/Sessions[. &gt; 0 and contains( ' N ', concat(' ', ../AttendanceReason, ' ') ) ] ) &gt; 0 ]
				/SessionDetails/SessionDetail/Sessions[contains( ' N ', concat(' ', ../AttendanceReason, ' ') ) ] ) 
			+
			sum($OffRoll4/Attendance/SummerHalfTerm2Attendance [sum(SessionDetails/SessionDetail/Sessions[. &gt; 0 and contains( ' N ', concat(' ', ../AttendanceReason, ' ') ) ] ) &gt; 0 ]
				/SessionDetails/SessionDetail/Sessions[contains( ' N ', concat(' ', ../AttendanceReason, ' ') ) ] ) 				
				"/>
		<xsl:variable name="NTotal4yrOld" select="$N1stHalf4yrOld + $N2ndHalf4yrOld"/>
		<xsl:variable name="N1stHalf5to15" select="
			sum($OnRoll5_15/Attendance/TermlyAttendance[sum(SessionDetails/SessionDetail/Sessions[. &gt; 0 and contains( ' N ', concat(' ', ../AttendanceReason, ' ') ) ] ) &gt; 0 ]
				/SessionDetails/SessionDetail/Sessions[contains( ' N ', concat(' ', ../AttendanceReason, ' ') ) ] ) 
			+
			sum($OffRoll5_15/Attendance/TermlyAttendance[sum(SessionDetails/SessionDetail/Sessions[. &gt; 0 and contains( ' N ', concat(' ', ../AttendanceReason, ' ') ) ] ) &gt; 0 ]
				/SessionDetails/SessionDetail/Sessions[contains( ' N ', concat(' ', ../AttendanceReason, ' ') ) ] ) 
				"/>
		<xsl:variable name="N2ndHalf5to15" select="
			sum($OnRoll5_15/Attendance/SummerHalfTerm2Attendance[sum(SessionDetails/SessionDetail/Sessions[. &gt; 0 and contains( ' N ', concat(' ', ../AttendanceReason, ' ') ) ] ) &gt; 0 ]
				/SessionDetails/SessionDetail/Sessions[contains( ' N ', concat(' ', ../AttendanceReason, ' ') ) ] ) 
			+
			sum($OffRoll5_15/Attendance/SummerHalfTerm2Attendance[sum(SessionDetails/SessionDetail/Sessions[. &gt; 0 and contains( ' N ', concat(' ', ../AttendanceReason, ' ') ) ] ) &gt; 0 ]
				/SessionDetails/SessionDetail/Sessions[contains( ' N ', concat(' ', ../AttendanceReason, ' ') ) ] ) 
				"/>
		<xsl:variable name="NTotal5to15" select="$N1stHalf5to15 + $N2ndHalf5to15"/>
		<xsl:variable name="O1stHalf4yrOld" select="
			sum($OnRoll4/Attendance/TermlyAttendance[sum(SessionDetails/SessionDetail/Sessions[. &gt; 0 and contains( ' O ', concat(' ', ../AttendanceReason, ' ') ) ] ) &gt; 0 ]
				/SessionDetails/SessionDetail/Sessions[contains( ' O ', concat(' ', ../AttendanceReason, ' ') ) ] ) 
			+
			sum($OffRoll4/Attendance/TermlyAttendance[sum(SessionDetails/SessionDetail/Sessions[. &gt; 0 and contains( ' O ', concat(' ', ../AttendanceReason, ' ') ) ] ) &gt; 0 ]
				/SessionDetails/SessionDetail/Sessions[contains( ' O ', concat(' ', ../AttendanceReason, ' ') ) ] ) 
				"/>
		<xsl:variable name="O2ndHalf4yrOld" select="
			sum($OnRoll4/Attendance/SummerHalfTerm2Attendance [sum(SessionDetails/SessionDetail/Sessions[. &gt; 0 and contains( ' O ', concat(' ', ../AttendanceReason, ' ') ) ] ) &gt; 0 ]
				/SessionDetails/SessionDetail/Sessions[contains( ' O ', concat(' ', ../AttendanceReason, ' ') ) ] ) 
			+
			sum($OffRoll4/Attendance/SummerHalfTerm2Attendance [sum(SessionDetails/SessionDetail/Sessions[. &gt; 0 and contains( ' O ', concat(' ', ../AttendanceReason, ' ') ) ] ) &gt; 0 ]
				/SessionDetails/SessionDetail/Sessions[contains( ' O ', concat(' ', ../AttendanceReason, ' ') ) ] ) 				
				"/>
		<xsl:variable name="OTotal4yrOld" select="$O1stHalf4yrOld + $O2ndHalf4yrOld"/>
		<xsl:variable name="O1stHalf5to15" select="
			sum($OnRoll5_15/Attendance/TermlyAttendance[sum(SessionDetails/SessionDetail/Sessions[. &gt; 0 and contains( ' O ', concat(' ', ../AttendanceReason, ' ') ) ] ) &gt; 0 ]
				/SessionDetails/SessionDetail/Sessions[contains( ' O ', concat(' ', ../AttendanceReason, ' ') ) ] ) 
			+
			sum($OffRoll5_15/Attendance/TermlyAttendance[sum(SessionDetails/SessionDetail/Sessions[. &gt; 0 and contains( ' O ', concat(' ', ../AttendanceReason, ' ') ) ] ) &gt; 0 ]
				/SessionDetails/SessionDetail/Sessions[contains( ' O ', concat(' ', ../AttendanceReason, ' ') ) ] ) 
				"/>
		<xsl:variable name="O2ndHalf5to15" select="
			sum($OnRoll5_15/Attendance/SummerHalfTerm2Attendance[sum(SessionDetails/SessionDetail/Sessions[. &gt; 0 and contains( ' O ', concat(' ', ../AttendanceReason, ' ') ) ] ) &gt; 0 ]
				/SessionDetails/SessionDetail/Sessions[contains( ' O ', concat(' ', ../AttendanceReason, ' ') ) ] ) 
			+
			sum($OffRoll5_15/Attendance/SummerHalfTerm2Attendance[sum(SessionDetails/SessionDetail/Sessions[. &gt; 0 and contains( ' O ', concat(' ', ../AttendanceReason, ' ') ) ] ) &gt; 0 ]
				/SessionDetails/SessionDetail/Sessions[contains( ' O ', concat(' ', ../AttendanceReason, ' ') ) ] ) 
				"/>
		<xsl:variable name="OTotal5to15" select="$O1stHalf5to15 + $O2ndHalf5to15"/>
		<xsl:variable name="P1stHalf4yrOld" select="
			sum($OnRoll4/Attendance/TermlyAttendance[sum(SessionDetails/SessionDetail/Sessions[. &gt; 0 and contains( ' P ', concat(' ', ../AttendanceReason, ' ') ) ] ) &gt; 0 ]
				/SessionDetails/SessionDetail/Sessions[contains( ' P ', concat(' ', ../AttendanceReason, ' ') ) ] ) 
			+
			sum($OffRoll4/Attendance/TermlyAttendance[sum(SessionDetails/SessionDetail/Sessions[. &gt; 0 and contains( ' P ', concat(' ', ../AttendanceReason, ' ') ) ] ) &gt; 0 ]
				/SessionDetails/SessionDetail/Sessions[contains( ' P ', concat(' ', ../AttendanceReason, ' ') ) ] ) 
				"/>
		<xsl:variable name="P2ndHalf4yrOld" select="
			sum($OnRoll4/Attendance/SummerHalfTerm2Attendance [sum(SessionDetails/SessionDetail/Sessions[. &gt; 0 and contains( ' P ', concat(' ', ../AttendanceReason, ' ') ) ] ) &gt; 0 ]
				/SessionDetails/SessionDetail/Sessions[contains( ' P ', concat(' ', ../AttendanceReason, ' ') ) ] ) 
			+
			sum($OffRoll4/Attendance/SummerHalfTerm2Attendance [sum(SessionDetails/SessionDetail/Sessions[. &gt; 0 and contains( ' P ', concat(' ', ../AttendanceReason, ' ') ) ] ) &gt; 0 ]
				/SessionDetails/SessionDetail/Sessions[contains( ' P ', concat(' ', ../AttendanceReason, ' ') ) ] ) 				
				"/>
		<xsl:variable name="PTotal4yrOld" select="$P1stHalf4yrOld + $P2ndHalf4yrOld"/>
		<xsl:variable name="P1stHalf5to15" select="
			sum($OnRoll5_15/Attendance/TermlyAttendance[sum(SessionDetails/SessionDetail/Sessions[. &gt; 0 and contains( ' P ', concat(' ', ../AttendanceReason, ' ') ) ] ) &gt; 0 ]
				/SessionDetails/SessionDetail/Sessions[contains( ' P ', concat(' ', ../AttendanceReason, ' ') ) ] ) 
			+
			sum($OffRoll5_15/Attendance/TermlyAttendance[sum(SessionDetails/SessionDetail/Sessions[. &gt; 0 and contains( ' P ', concat(' ', ../AttendanceReason, ' ') ) ] ) &gt; 0 ]
				/SessionDetails/SessionDetail/Sessions[contains( ' P ', concat(' ', ../AttendanceReason, ' ') ) ] ) 
				"/>
		<xsl:variable name="P2ndHalf5to15" select="
			sum($OnRoll5_15/Attendance/SummerHalfTerm2Attendance[sum(SessionDetails/SessionDetail/Sessions[. &gt; 0 and contains( ' P ', concat(' ', ../AttendanceReason, ' ') ) ] ) &gt; 0 ]
				/SessionDetails/SessionDetail/Sessions[contains( ' P ', concat(' ', ../AttendanceReason, ' ') ) ] ) 
			+
			sum($OffRoll5_15/Attendance/SummerHalfTerm2Attendance[sum(SessionDetails/SessionDetail/Sessions[. &gt; 0 and contains( ' P ', concat(' ', ../AttendanceReason, ' ') ) ] ) &gt; 0 ]
				/SessionDetails/SessionDetail/Sessions[contains( ' P ', concat(' ', ../AttendanceReason, ' ') ) ] ) 
				"/>
		<xsl:variable name="PTotal5to15" select="$P1stHalf5to15 + $P2ndHalf5to15"/>
		<xsl:variable name="R1stHalf4yrOld" select="
			sum($OnRoll4/Attendance/TermlyAttendance[sum(SessionDetails/SessionDetail/Sessions[. &gt; 0 and contains( ' R ', concat(' ', ../AttendanceReason, ' ') ) ] ) &gt; 0 ]
				/SessionDetails/SessionDetail/Sessions[contains( ' R ', concat(' ', ../AttendanceReason, ' ') ) ] ) 
			+
			sum($OffRoll4/Attendance/TermlyAttendance[sum(SessionDetails/SessionDetail/Sessions[. &gt; 0 and contains( ' R ', concat(' ', ../AttendanceReason, ' ') ) ] ) &gt; 0 ]
				/SessionDetails/SessionDetail/Sessions[contains( ' R ', concat(' ', ../AttendanceReason, ' ') ) ] ) 
				"/>
		<xsl:variable name="R2ndHalf4yrOld" select="
			sum($OnRoll4/Attendance/SummerHalfTerm2Attendance [sum(SessionDetails/SessionDetail/Sessions[. &gt; 0 and contains( ' R ', concat(' ', ../AttendanceReason, ' ') ) ] ) &gt; 0 ]
				/SessionDetails/SessionDetail/Sessions[contains( ' R ', concat(' ', ../AttendanceReason, ' ') ) ] ) 
			+
			sum($OffRoll4/Attendance/SummerHalfTerm2Attendance [sum(SessionDetails/SessionDetail/Sessions[. &gt; 0 and contains( ' R ', concat(' ', ../AttendanceReason, ' ') ) ] ) &gt; 0 ]
				/SessionDetails/SessionDetail/Sessions[contains( ' R ', concat(' ', ../AttendanceReason, ' ') ) ] ) 				
				"/>
		<xsl:variable name="RTotal4yrOld" select="$R1stHalf4yrOld + $R2ndHalf4yrOld"/>
		<xsl:variable name="R1stHalf5to15" select="
			sum($OnRoll5_15/Attendance/TermlyAttendance[sum(SessionDetails/SessionDetail/Sessions[. &gt; 0 and contains( ' R ', concat(' ', ../AttendanceReason, ' ') ) ] ) &gt; 0 ]
				/SessionDetails/SessionDetail/Sessions[contains( ' R ', concat(' ', ../AttendanceReason, ' ') ) ] ) 
			+
			sum($OffRoll5_15/Attendance/TermlyAttendance[sum(SessionDetails/SessionDetail/Sessions[. &gt; 0 and contains( ' R ', concat(' ', ../AttendanceReason, ' ') ) ] ) &gt; 0 ]
				/SessionDetails/SessionDetail/Sessions[contains( ' R ', concat(' ', ../AttendanceReason, ' ') ) ] ) 
				"/>
		<xsl:variable name="R2ndHalf5to15" select="
			sum($OnRoll5_15/Attendance/SummerHalfTerm2Attendance[sum(SessionDetails/SessionDetail/Sessions[. &gt; 0 and contains( ' R ', concat(' ', ../AttendanceReason, ' ') ) ] ) &gt; 0 ]
				/SessionDetails/SessionDetail/Sessions[contains( ' R ', concat(' ', ../AttendanceReason, ' ') ) ] ) 
			+
			sum($OffRoll5_15/Attendance/SummerHalfTerm2Attendance[sum(SessionDetails/SessionDetail/Sessions[. &gt; 0 and contains( ' R ', concat(' ', ../AttendanceReason, ' ') ) ] ) &gt; 0 ]
				/SessionDetails/SessionDetail/Sessions[contains( ' R ', concat(' ', ../AttendanceReason, ' ') ) ] ) 
				"/>
		<xsl:variable name="RTotal5to15" select="$R1stHalf5to15 + $R2ndHalf5to15"/>
		<xsl:variable name="S1stHalf4yrOld" select="
			sum($OnRoll4/Attendance/TermlyAttendance[sum(SessionDetails/SessionDetail/Sessions[. &gt; 0 and contains( ' S ', concat(' ', ../AttendanceReason, ' ') ) ] ) &gt; 0 ]
				/SessionDetails/SessionDetail/Sessions[contains( ' S ', concat(' ', ../AttendanceReason, ' ') ) ] ) 
			+
			sum($OffRoll4/Attendance/TermlyAttendance[sum(SessionDetails/SessionDetail/Sessions[. &gt; 0 and contains( ' S ', concat(' ', ../AttendanceReason, ' ') ) ] ) &gt; 0 ]
				/SessionDetails/SessionDetail/Sessions[contains( ' S ', concat(' ', ../AttendanceReason, ' ') ) ] ) 
				"/>
		<xsl:variable name="S2ndHalf4yrOld" select="
			sum($OnRoll4/Attendance/SummerHalfTerm2Attendance [sum(SessionDetails/SessionDetail/Sessions[. &gt; 0 and contains( ' S ', concat(' ', ../AttendanceReason, ' ') ) ] ) &gt; 0 ]
				/SessionDetails/SessionDetail/Sessions[contains( ' S ', concat(' ', ../AttendanceReason, ' ') ) ] ) 
			+
			sum($OffRoll4/Attendance/SummerHalfTerm2Attendance [sum(SessionDetails/SessionDetail/Sessions[. &gt; 0 and contains( ' S ', concat(' ', ../AttendanceReason, ' ') ) ] ) &gt; 0 ]
				/SessionDetails/SessionDetail/Sessions[contains( ' S ', concat(' ', ../AttendanceReason, ' ') ) ] ) 				
				"/>
		<xsl:variable name="STotal4yrOld" select="$S1stHalf4yrOld + $S2ndHalf4yrOld"/>
		<xsl:variable name="S1stHalf5to15" select="
			sum($OnRoll5_15/Attendance/TermlyAttendance[sum(SessionDetails/SessionDetail/Sessions[. &gt; 0 and contains( ' S ', concat(' ', ../AttendanceReason, ' ') ) ] ) &gt; 0 ]
				/SessionDetails/SessionDetail/Sessions[contains( ' S ', concat(' ', ../AttendanceReason, ' ') ) ] ) 
			+
			sum($OffRoll5_15/Attendance/TermlyAttendance[sum(SessionDetails/SessionDetail/Sessions[. &gt; 0 and contains( ' S ', concat(' ', ../AttendanceReason, ' ') ) ] ) &gt; 0 ]
				/SessionDetails/SessionDetail/Sessions[contains( ' S ', concat(' ', ../AttendanceReason, ' ') ) ] ) 
				"/>
		<xsl:variable name="S2ndHalf5to15" select="
			sum($OnRoll5_15/Attendance/SummerHalfTerm2Attendance[sum(SessionDetails/SessionDetail/Sessions[. &gt; 0 and contains( ' S ', concat(' ', ../AttendanceReason, ' ') ) ] ) &gt; 0 ]
				/SessionDetails/SessionDetail/Sessions[contains( ' S ', concat(' ', ../AttendanceReason, ' ') ) ] ) 
			+
			sum($OffRoll5_15/Attendance/SummerHalfTerm2Attendance[sum(SessionDetails/SessionDetail/Sessions[. &gt; 0 and contains( ' S ', concat(' ', ../AttendanceReason, ' ') ) ] ) &gt; 0 ]
				/SessionDetails/SessionDetail/Sessions[contains( ' S ', concat(' ', ../AttendanceReason, ' ') ) ] ) 
				"/>
		<xsl:variable name="STotal5to15" select="$S1stHalf5to15 + $S2ndHalf5to15"/>
		<xsl:variable name="T1stHalf4yrOld" select="
			sum($OnRoll4/Attendance/TermlyAttendance[sum(SessionDetails/SessionDetail/Sessions[. &gt; 0 and contains( ' T ', concat(' ', ../AttendanceReason, ' ') ) ] ) &gt; 0 ]
				/SessionDetails/SessionDetail/Sessions[contains( ' T ', concat(' ', ../AttendanceReason, ' ') ) ] ) 
			+
			sum($OffRoll4/Attendance/TermlyAttendance[sum(SessionDetails/SessionDetail/Sessions[. &gt; 0 and contains( ' T ', concat(' ', ../AttendanceReason, ' ') ) ] ) &gt; 0 ]
				/SessionDetails/SessionDetail/Sessions[contains( ' T ', concat(' ', ../AttendanceReason, ' ') ) ] ) 
				"/>
		<xsl:variable name="T2ndHalf4yrOld" select="
			sum($OnRoll4/Attendance/SummerHalfTerm2Attendance [sum(SessionDetails/SessionDetail/Sessions[. &gt; 0 and contains( ' T ', concat(' ', ../AttendanceReason, ' ') ) ] ) &gt; 0 ]
				/SessionDetails/SessionDetail/Sessions[contains( ' T ', concat(' ', ../AttendanceReason, ' ') ) ] ) 
			+
			sum($OffRoll4/Attendance/SummerHalfTerm2Attendance [sum(SessionDetails/SessionDetail/Sessions[. &gt; 0 and contains( ' T ', concat(' ', ../AttendanceReason, ' ') ) ] ) &gt; 0 ]
				/SessionDetails/SessionDetail/Sessions[contains( ' T ', concat(' ', ../AttendanceReason, ' ') ) ] ) 				
				"/>
		<xsl:variable name="TTotal4yrOld" select="$T1stHalf4yrOld + $T2ndHalf4yrOld"/>
		<xsl:variable name="T1stHalf5to15" select="
			sum($OnRoll5_15/Attendance/TermlyAttendance[sum(SessionDetails/SessionDetail/Sessions[. &gt; 0 and contains( ' T ', concat(' ', ../AttendanceReason, ' ') ) ] ) &gt; 0 ]
				/SessionDetails/SessionDetail/Sessions[contains( ' T ', concat(' ', ../AttendanceReason, ' ') ) ] ) 
			+
			sum($OffRoll5_15/Attendance/TermlyAttendance[sum(SessionDetails/SessionDetail/Sessions[. &gt; 0 and contains( ' T ', concat(' ', ../AttendanceReason, ' ') ) ] ) &gt; 0 ]
				/SessionDetails/SessionDetail/Sessions[contains( ' T ', concat(' ', ../AttendanceReason, ' ') ) ] ) 
				"/>
		<xsl:variable name="T2ndHalf5to15" select="
			sum($OnRoll5_15/Attendance/SummerHalfTerm2Attendance[sum(SessionDetails/SessionDetail/Sessions[. &gt; 0 and contains( ' T ', concat(' ', ../AttendanceReason, ' ') ) ] ) &gt; 0 ]
				/SessionDetails/SessionDetail/Sessions[contains( ' T ', concat(' ', ../AttendanceReason, ' ') ) ] ) 
			+
			sum($OffRoll5_15/Attendance/SummerHalfTerm2Attendance[sum(SessionDetails/SessionDetail/Sessions[. &gt; 0 and contains( ' T ', concat(' ', ../AttendanceReason, ' ') ) ] ) &gt; 0 ]
				/SessionDetails/SessionDetail/Sessions[contains( ' T ', concat(' ', ../AttendanceReason, ' ') ) ] ) 
				"/>
		<xsl:variable name="TTotal5to15" select="$T1stHalf5to15 + $T2ndHalf5to15"/>
		<xsl:variable name="U1stHalf4yrOld" select="
			sum($OnRoll4/Attendance/TermlyAttendance[sum(SessionDetails/SessionDetail/Sessions[. &gt; 0 and contains( ' U ', concat(' ', ../AttendanceReason, ' ') ) ] ) &gt; 0 ]
				/SessionDetails/SessionDetail/Sessions[contains( ' U ', concat(' ', ../AttendanceReason, ' ') ) ] ) 
			+
			sum($OffRoll4/Attendance/TermlyAttendance[sum(SessionDetails/SessionDetail/Sessions[. &gt; 0 and contains( ' U ', concat(' ', ../AttendanceReason, ' ') ) ] ) &gt; 0 ]
				/SessionDetails/SessionDetail/Sessions[contains( ' U ', concat(' ', ../AttendanceReason, ' ') ) ] ) 
				"/>
		<xsl:variable name="U2ndHalf4yrOld" select="
			sum($OnRoll4/Attendance/SummerHalfTerm2Attendance [sum(SessionDetails/SessionDetail/Sessions[. &gt; 0 and contains( ' U ', concat(' ', ../AttendanceReason, ' ') ) ] ) &gt; 0 ]
				/SessionDetails/SessionDetail/Sessions[contains( ' U ', concat(' ', ../AttendanceReason, ' ') ) ] ) 
			+
			sum($OffRoll4/Attendance/SummerHalfTerm2Attendance [sum(SessionDetails/SessionDetail/Sessions[. &gt; 0 and contains( ' U ', concat(' ', ../AttendanceReason, ' ') ) ] ) &gt; 0 ]
				/SessionDetails/SessionDetail/Sessions[contains( ' U ', concat(' ', ../AttendanceReason, ' ') ) ] ) 				
				"/>
		<xsl:variable name="UTotal4yrOld" select="$U1stHalf4yrOld + $U2ndHalf4yrOld"/>
		<xsl:variable name="U1stHalf5to15" select="
			sum($OnRoll5_15/Attendance/TermlyAttendance[sum(SessionDetails/SessionDetail/Sessions[. &gt; 0 and contains( ' U ', concat(' ', ../AttendanceReason, ' ') ) ] ) &gt; 0 ]
				/SessionDetails/SessionDetail/Sessions[contains( ' U ', concat(' ', ../AttendanceReason, ' ') ) ] ) 
			+
			sum($OffRoll5_15/Attendance/TermlyAttendance[sum(SessionDetails/SessionDetail/Sessions[. &gt; 0 and contains( ' U ', concat(' ', ../AttendanceReason, ' ') ) ] ) &gt; 0 ]
				/SessionDetails/SessionDetail/Sessions[contains( ' U ', concat(' ', ../AttendanceReason, ' ') ) ] ) 
				"/>
		<xsl:variable name="U2ndHalf5to15" select="
			sum($OnRoll5_15/Attendance/SummerHalfTerm2Attendance[sum(SessionDetails/SessionDetail/Sessions[. &gt; 0 and contains( ' U ', concat(' ', ../AttendanceReason, ' ') ) ] ) &gt; 0 ]
				/SessionDetails/SessionDetail/Sessions[contains( ' U ', concat(' ', ../AttendanceReason, ' ') ) ] ) 
			+
			sum($OffRoll5_15/Attendance/SummerHalfTerm2Attendance[sum(SessionDetails/SessionDetail/Sessions[. &gt; 0 and contains( ' U ', concat(' ', ../AttendanceReason, ' ') ) ] ) &gt; 0 ]
				/SessionDetails/SessionDetail/Sessions[contains( ' U ', concat(' ', ../AttendanceReason, ' ') ) ] ) 
				"/>
		<xsl:variable name="UTotal5to15" select="$U1stHalf5to15 + $U2ndHalf5to15"/>
		<xsl:variable name="V1stHalf4yrOld" select="
			sum($OnRoll4/Attendance/TermlyAttendance[sum(SessionDetails/SessionDetail/Sessions[. &gt; 0 and contains( ' V ', concat(' ', ../AttendanceReason, ' ') ) ] ) &gt; 0 ]
				/SessionDetails/SessionDetail/Sessions[contains( ' V ', concat(' ', ../AttendanceReason, ' ') ) ] ) 
			+
			sum($OffRoll4/Attendance/TermlyAttendance[sum(SessionDetails/SessionDetail/Sessions[. &gt; 0 and contains( ' V ', concat(' ', ../AttendanceReason, ' ') ) ] ) &gt; 0 ]
				/SessionDetails/SessionDetail/Sessions[contains( ' V ', concat(' ', ../AttendanceReason, ' ') ) ] ) 
				"/>
		<xsl:variable name="V2ndHalf4yrOld" select="
			sum($OnRoll4/Attendance/SummerHalfTerm2Attendance [sum(SessionDetails/SessionDetail/Sessions[. &gt; 0 and contains( ' V ', concat(' ', ../AttendanceReason, ' ') ) ] ) &gt; 0 ]
				/SessionDetails/SessionDetail/Sessions[contains( ' V ', concat(' ', ../AttendanceReason, ' ') ) ] ) 
			+
			sum($OffRoll4/Attendance/SummerHalfTerm2Attendance [sum(SessionDetails/SessionDetail/Sessions[. &gt; 0 and contains( ' V ', concat(' ', ../AttendanceReason, ' ') ) ] ) &gt; 0 ]
				/SessionDetails/SessionDetail/Sessions[contains( ' V ', concat(' ', ../AttendanceReason, ' ') ) ] ) 				
				"/>
		<xsl:variable name="VTotal4yrOld" select="$V1stHalf4yrOld + $V2ndHalf4yrOld"/>
		<xsl:variable name="V1stHalf5to15" select="
			sum($OnRoll5_15/Attendance/TermlyAttendance[sum(SessionDetails/SessionDetail/Sessions[. &gt; 0 and contains( ' V ', concat(' ', ../AttendanceReason, ' ') ) ] ) &gt; 0 ]
				/SessionDetails/SessionDetail/Sessions[contains( ' V ', concat(' ', ../AttendanceReason, ' ') ) ] ) 
			+
			sum($OffRoll5_15/Attendance/TermlyAttendance[sum(SessionDetails/SessionDetail/Sessions[. &gt; 0 and contains( ' V ', concat(' ', ../AttendanceReason, ' ') ) ] ) &gt; 0 ]
				/SessionDetails/SessionDetail/Sessions[contains( ' V ', concat(' ', ../AttendanceReason, ' ') ) ] ) 
				"/>
		<xsl:variable name="V2ndHalf5to15" select="
			sum($OnRoll5_15/Attendance/SummerHalfTerm2Attendance[sum(SessionDetails/SessionDetail/Sessions[. &gt; 0 and contains( ' V ', concat(' ', ../AttendanceReason, ' ') ) ] ) &gt; 0 ]
				/SessionDetails/SessionDetail/Sessions[contains( ' V ', concat(' ', ../AttendanceReason, ' ') ) ] ) 
			+
			sum($OffRoll5_15/Attendance/SummerHalfTerm2Attendance[sum(SessionDetails/SessionDetail/Sessions[. &gt; 0 and contains( ' V ', concat(' ', ../AttendanceReason, ' ') ) ] ) &gt; 0 ]
				/SessionDetails/SessionDetail/Sessions[contains( ' V ', concat(' ', ../AttendanceReason, ' ') ) ] ) 
				"/>
		<xsl:variable name="VTotal5to15" select="$V1stHalf5to15 + $V2ndHalf5to15"/>
		<xsl:variable name="W1stHalf4yrOld" select="
			sum($OnRoll4/Attendance/TermlyAttendance[sum(SessionDetails/SessionDetail/Sessions[. &gt; 0 and contains( ' W ', concat(' ', ../AttendanceReason, ' ') ) ] ) &gt; 0 ]
				/SessionDetails/SessionDetail/Sessions[contains( ' W ', concat(' ', ../AttendanceReason, ' ') ) ] ) 
			+
			sum($OffRoll4/Attendance/TermlyAttendance[sum(SessionDetails/SessionDetail/Sessions[. &gt; 0 and contains( ' W ', concat(' ', ../AttendanceReason, ' ') ) ] ) &gt; 0 ]
				/SessionDetails/SessionDetail/Sessions[contains( ' W ', concat(' ', ../AttendanceReason, ' ') ) ] ) 
				"/>
		<xsl:variable name="W2ndHalf4yrOld" select="
			sum($OnRoll4/Attendance/SummerHalfTerm2Attendance [sum(SessionDetails/SessionDetail/Sessions[. &gt; 0 and contains( ' W ', concat(' ', ../AttendanceReason, ' ') ) ] ) &gt; 0 ]
				/SessionDetails/SessionDetail/Sessions[contains( ' W ', concat(' ', ../AttendanceReason, ' ') ) ] ) 
			+
			sum($OffRoll4/Attendance/SummerHalfTerm2Attendance [sum(SessionDetails/SessionDetail/Sessions[. &gt; 0 and contains( ' W ', concat(' ', ../AttendanceReason, ' ') ) ] ) &gt; 0 ]
				/SessionDetails/SessionDetail/Sessions[contains( ' W ', concat(' ', ../AttendanceReason, ' ') ) ] ) 				
				"/>
		<xsl:variable name="WTotal4yrOld" select="$W1stHalf4yrOld + $W2ndHalf4yrOld"/>
		<xsl:variable name="W1stHalf5to15" select="
			sum($OnRoll5_15/Attendance/TermlyAttendance[sum(SessionDetails/SessionDetail/Sessions[. &gt; 0 and contains( ' W ', concat(' ', ../AttendanceReason, ' ') ) ] ) &gt; 0 ]
				/SessionDetails/SessionDetail/Sessions[contains( ' W ', concat(' ', ../AttendanceReason, ' ') ) ] ) 
			+
			sum($OffRoll5_15/Attendance/TermlyAttendance[sum(SessionDetails/SessionDetail/Sessions[. &gt; 0 and contains( ' W ', concat(' ', ../AttendanceReason, ' ') ) ] ) &gt; 0 ]
				/SessionDetails/SessionDetail/Sessions[contains( ' W ', concat(' ', ../AttendanceReason, ' ') ) ] ) 
				"/>
		<xsl:variable name="W2ndHalf5to15" select="
			sum($OnRoll5_15/Attendance/SummerHalfTerm2Attendance[sum(SessionDetails/SessionDetail/Sessions[. &gt; 0 and contains( ' W ', concat(' ', ../AttendanceReason, ' ') ) ] ) &gt; 0 ]
				/SessionDetails/SessionDetail/Sessions[contains( ' W ', concat(' ', ../AttendanceReason, ' ') ) ] ) 
			+
			sum($OffRoll5_15/Attendance/SummerHalfTerm2Attendance[sum(SessionDetails/SessionDetail/Sessions[. &gt; 0 and contains( ' W ', concat(' ', ../AttendanceReason, ' ') ) ] ) &gt; 0 ]
				/SessionDetails/SessionDetail/Sessions[contains( ' W ', concat(' ', ../AttendanceReason, ' ') ) ] ) 
				"/>
		<xsl:variable name="WTotal5to15" select="$W1stHalf5to15 + $W2ndHalf5to15"/>
		<xsl:variable name="X1stHalf4yrOld" select="
			sum($OnRoll4/Attendance/TermlyAttendance[sum(SessionDetails/SessionDetail/Sessions[. &gt; 0 and contains( ' X ', concat(' ', ../AttendanceReason, ' ') ) ] ) &gt; 0 ]
				/SessionDetails/SessionDetail/Sessions[contains( ' X ', concat(' ', ../AttendanceReason, ' ') ) ] ) 
			+
			sum($OffRoll4/Attendance/TermlyAttendance[sum(SessionDetails/SessionDetail/Sessions[. &gt; 0 and contains( ' X ', concat(' ', ../AttendanceReason, ' ') ) ] ) &gt; 0 ]
				/SessionDetails/SessionDetail/Sessions[contains( ' X ', concat(' ', ../AttendanceReason, ' ') ) ] ) 
				"/>
		<xsl:variable name="X2ndHalf4yrOld" select="
			sum($OnRoll4/Attendance/SummerHalfTerm2Attendance [sum(SessionDetails/SessionDetail/Sessions[. &gt; 0 and contains( ' X ', concat(' ', ../AttendanceReason, ' ') ) ] ) &gt; 0 ]
				/SessionDetails/SessionDetail/Sessions[contains( ' X ', concat(' ', ../AttendanceReason, ' ') ) ] ) 
			+
			sum($OffRoll4/Attendance/SummerHalfTerm2Attendance [sum(SessionDetails/SessionDetail/Sessions[. &gt; 0 and contains( ' X ', concat(' ', ../AttendanceReason, ' ') ) ] ) &gt; 0 ]
				/SessionDetails/SessionDetail/Sessions[contains( ' X ', concat(' ', ../AttendanceReason, ' ') ) ] ) 				
				"/>
		<xsl:variable name="XTotal4yrOld" select="$X1stHalf4yrOld + $X2ndHalf4yrOld"/>
		<xsl:variable name="X1stHalf5to15" select="
			sum($OnRoll5_15/Attendance/TermlyAttendance[sum(SessionDetails/SessionDetail/Sessions[. &gt; 0 and contains( ' X ', concat(' ', ../AttendanceReason, ' ') ) ] ) &gt; 0 ]
				/SessionDetails/SessionDetail/Sessions[contains( ' X ', concat(' ', ../AttendanceReason, ' ') ) ] ) 
			+
			sum($OffRoll5_15/Attendance/TermlyAttendance[sum(SessionDetails/SessionDetail/Sessions[. &gt; 0 and contains( ' X ', concat(' ', ../AttendanceReason, ' ') ) ] ) &gt; 0 ]
				/SessionDetails/SessionDetail/Sessions[contains( ' X ', concat(' ', ../AttendanceReason, ' ') ) ] ) 
				"/>
		<xsl:variable name="X2ndHalf5to15" select="
			sum($OnRoll5_15/Attendance/SummerHalfTerm2Attendance[sum(SessionDetails/SessionDetail/Sessions[. &gt; 0 and contains( ' X ', concat(' ', ../AttendanceReason, ' ') ) ] ) &gt; 0 ]
				/SessionDetails/SessionDetail/Sessions[contains( ' X ', concat(' ', ../AttendanceReason, ' ') ) ] ) 
			+
			sum($OffRoll5_15/Attendance/SummerHalfTerm2Attendance[sum(SessionDetails/SessionDetail/Sessions[. &gt; 0 and contains( ' X ', concat(' ', ../AttendanceReason, ' ') ) ] ) &gt; 0 ]
				/SessionDetails/SessionDetail/Sessions[contains( ' X ', concat(' ', ../AttendanceReason, ' ') ) ] ) 
				"/>
		<xsl:variable name="XTotal5to15" select="$X1stHalf5to15 + $X2ndHalf5to15"/>
		<xsl:variable name="Y1stHalf4yrOld" select="
			sum($OnRoll4/Attendance/TermlyAttendance[sum(SessionDetails/SessionDetail/Sessions[. &gt; 0 and contains( ' Y ', concat(' ', ../AttendanceReason, ' ') ) ] ) &gt; 0 ]
				/SessionDetails/SessionDetail/Sessions[contains( ' Y ', concat(' ', ../AttendanceReason, ' ') ) ] ) 
			+
			sum($OffRoll4/Attendance/TermlyAttendance[sum(SessionDetails/SessionDetail/Sessions[. &gt; 0 and contains( ' Y ', concat(' ', ../AttendanceReason, ' ') ) ] ) &gt; 0 ]
				/SessionDetails/SessionDetail/Sessions[contains( ' Y ', concat(' ', ../AttendanceReason, ' ') ) ] ) 
				"/>
		<xsl:variable name="Y2ndHalf4yrOld" select="
			sum($OnRoll4/Attendance/SummerHalfTerm2Attendance [sum(SessionDetails/SessionDetail/Sessions[. &gt; 0 and contains( ' Y ', concat(' ', ../AttendanceReason, ' ') ) ] ) &gt; 0 ]
				/SessionDetails/SessionDetail/Sessions[contains( ' Y ', concat(' ', ../AttendanceReason, ' ') ) ] ) 
			+
			sum($OffRoll4/Attendance/SummerHalfTerm2Attendance [sum(SessionDetails/SessionDetail/Sessions[. &gt; 0 and contains( ' Y ', concat(' ', ../AttendanceReason, ' ') ) ] ) &gt; 0 ]
				/SessionDetails/SessionDetail/Sessions[contains( ' Y ', concat(' ', ../AttendanceReason, ' ') ) ] ) 				
				"/>
		<xsl:variable name="YTotal4yrOld" select="$Y1stHalf4yrOld + $Y2ndHalf4yrOld"/>
		<xsl:variable name="Y1stHalf5to15" select="
			sum($OnRoll5_15/Attendance/TermlyAttendance[sum(SessionDetails/SessionDetail/Sessions[. &gt; 0 and contains( ' Y ', concat(' ', ../AttendanceReason, ' ') ) ] ) &gt; 0 ]
				/SessionDetails/SessionDetail/Sessions[contains( ' Y ', concat(' ', ../AttendanceReason, ' ') ) ] ) 
			+
			sum($OffRoll5_15/Attendance/TermlyAttendance[sum(SessionDetails/SessionDetail/Sessions[. &gt; 0 and contains( ' Y ', concat(' ', ../AttendanceReason, ' ') ) ] ) &gt; 0 ]
				/SessionDetails/SessionDetail/Sessions[contains( ' Y ', concat(' ', ../AttendanceReason, ' ') ) ] ) 
				"/>
		<xsl:variable name="Y2ndHalf5to15" select="
			sum($OnRoll5_15/Attendance/SummerHalfTerm2Attendance[sum(SessionDetails/SessionDetail/Sessions[. &gt; 0 and contains( ' Y ', concat(' ', ../AttendanceReason, ' ') ) ] ) &gt; 0 ]
				/SessionDetails/SessionDetail/Sessions[contains( ' Y ', concat(' ', ../AttendanceReason, ' ') ) ] ) 
			+
			sum($OffRoll5_15/Attendance/SummerHalfTerm2Attendance[sum(SessionDetails/SessionDetail/Sessions[. &gt; 0 and contains( ' Y ', concat(' ', ../AttendanceReason, ' ') ) ] ) &gt; 0 ]
				/SessionDetails/SessionDetail/Sessions[contains( ' Y ', concat(' ', ../AttendanceReason, ' ') ) ] ) 
				"/>
		<xsl:variable name="YTotal5to15" select="$Y1stHalf5to15 + $Y2ndHalf5to15"/>		

		<xsl:choose>
			<xsl:when test="$phase = 'NS'"/>
			<xsl:when test="$term = 'AUT'">
				<table class="summaryreport" border="1">
					<tr>
						<th colspan="1"/>
						<th colspan="3">Pupils aged 4 as at 31/08/2022</th>
						<th colspan="3">Pupils aged between 5 and 15 as at 31/08/2022</th>
					</tr>
					<tr>
						<th>Attendance reason</th>
						<th>Summer first half term (10 April to 28 May 2023)</th>
						<th>Summer second half term (29 May to 31 July 2023)</th>
						<th>Total summer term (10 April to 31 July 2023)</th>
						<th>Summer first half term (10 April to 28 May 2023)</th>
						<th>Summer second half term (29 May to 31 July 2023)</th>
						<th>Total summer term (10 April to 31 July 2023)</th>
					</tr>
					<tr>
						<td class="clsHeading">
						/ - <xsl:value-of select="document('./SchoolCensus23-24-SchoolSummaryReferenceLists.xsl') /xsl:stylesheet/Attendance[AttendanceCode = '/' ]/AttendanceDescription"/>
						</td>
						<td class="clsNumber">
							<xsl:value-of select="$AM1stHalf4yrOld"/>
						</td>
						<td class="clsNumber">
							<xsl:value-of select="$AM2ndHalf4yrOld"/>
						</td>
						<td class="clsNumber">
							<xsl:value-of select="$AMTotal4yrOld"/>
						</td>
						<td class="clsNumber">
							<xsl:value-of select="$AM1stHalf5to15"/>
						</td>
						<td class="clsNumber">
							<xsl:value-of select="$AM2ndHalf5to15"/>
						</td>
						<td class="clsNumber">
							<xsl:value-of select="$AMTotal5to15"/>
						</td>
					</tr>
					<tr>
						<td class="clsHeading">
						\ - <xsl:value-of select="document('./SchoolCensus23-24-SchoolSummaryReferenceLists.xsl') /xsl:stylesheet/Attendance[AttendanceCode = '\' ]/AttendanceDescription"/>
						</td>
						<td class="clsNumber">
							<xsl:value-of select="$PM1stHalf4yrOld"/>
						</td>
						<td class="clsNumber">
							<xsl:value-of select="$PM2ndHalf4yrOld"/>
						</td>
						<td class="clsNumber">
							<xsl:value-of select="$PMTotal4yrOld"/>
						</td>
						<td class="clsNumber">
							<xsl:value-of select="$PM1stHalf5to15"/>
						</td>
						<td class="clsNumber">
							<xsl:value-of select="$PM2ndHalf5to15"/>
						</td>
						<td class="clsNumber">
							<xsl:value-of select="$PMTotal5to15"/>
						</td>
					</tr>
					<tr>
						<td class="clsHeading">
						B - <xsl:value-of select="document('./SchoolCensus23-24-SchoolSummaryReferenceLists.xsl') /xsl:stylesheet/Attendance[AttendanceCode = 'B' ]/AttendanceDescription"/>
						</td>
						<td class="clsNumber">
							<xsl:value-of select="$B1stHalf4yrOld"/>
						</td>
						<td class="clsNumber">
							<xsl:value-of select="$B2ndHalf4yrOld"/>
						</td>
						<td class="clsNumber">
							<xsl:value-of select="$BTotal4yrOld"/>
						</td>
						<td class="clsNumber">
							<xsl:value-of select="$B1stHalf5to15"/>
						</td>
						<td class="clsNumber">
							<xsl:value-of select="$B2ndHalf5to15"/>
						</td>
						<td class="clsNumber">
							<xsl:value-of select="$BTotal5to15"/>
						</td>
					</tr>
					<tr>
						<td class="clsHeading">
						C - <xsl:value-of select="document('./SchoolCensus23-24-SchoolSummaryReferenceLists.xsl') /xsl:stylesheet/Attendance[AttendanceCode = 'C' ]/AttendanceDescription"/>
						</td>
						<td class="clsNumber">
							<xsl:value-of select="$C1stHalf4yrOld"/>
						</td>
						<td class="clsNumber">
							<xsl:value-of select="$C2ndHalf4yrOld"/>
						</td>
						<td class="clsNumber">
							<xsl:value-of select="$CTotal4yrOld"/>
						</td>
						<td class="clsNumber">
							<xsl:value-of select="$C1stHalf5to15"/>
						</td>
						<td class="clsNumber">
							<xsl:value-of select="$C2ndHalf5to15"/>
						</td>
						<td class="clsNumber">
							<xsl:value-of select="$CTotal5to15"/>
						</td>
					</tr>
					<tr>
						<td class="clsHeading">
						D - <xsl:value-of select="document('./SchoolCensus23-24-SchoolSummaryReferenceLists.xsl') /xsl:stylesheet/Attendance[AttendanceCode = 'D' ]/AttendanceDescription"/>
						</td>
						<td class="clsNumber">
							<xsl:value-of select="$D1stHalf4yrOld"/>
						</td>
						<td class="clsNumber">
							<xsl:value-of select="$D2ndHalf4yrOld"/>
						</td>
						<td class="clsNumber">
							<xsl:value-of select="$DTotal4yrOld"/>
						</td>
						<td class="clsNumber">
							<xsl:value-of select="$D1stHalf5to15"/>
						</td>
						<td class="clsNumber">
							<xsl:value-of select="$D2ndHalf5to15"/>
						</td>
						<td class="clsNumber">
							<xsl:value-of select="$DTotal5to15"/>
						</td>
					</tr>
					<tr>
						<td class="clsHeading">
						E - <xsl:value-of select="document('./SchoolCensus23-24-SchoolSummaryReferenceLists.xsl') /xsl:stylesheet/Attendance[AttendanceCode = 'E' ]/AttendanceDescription"/>
						</td>
						<td class="clsNumber">
							<xsl:value-of select="$E1stHalf4yrOld"/>
						</td>
						<td class="clsNumber">
							<xsl:value-of select="$E2ndHalf4yrOld"/>
						</td>
						<td class="clsNumber">
							<xsl:value-of select="$ETotal4yrOld"/>
						</td>
						<td class="clsNumber">
							<xsl:value-of select="$E1stHalf5to15"/>
						</td>
						<td class="clsNumber">
							<xsl:value-of select="$E2ndHalf5to15"/>
						</td>
						<td class="clsNumber">
							<xsl:value-of select="$ETotal5to15"/>
						</td>
					</tr>
					<tr>
						<td class="clsHeading">
						G - <xsl:value-of select="document('./SchoolCensus23-24-SchoolSummaryReferenceLists.xsl') /xsl:stylesheet/Attendance[AttendanceCode = 'G' ]/AttendanceDescription"/>
						</td>
						<td class="clsNumber">
							<xsl:value-of select="$G1stHalf4yrOld"/>
						</td>
						<td class="clsNumber">
							<xsl:value-of select="$G2ndHalf4yrOld"/>
						</td>
						<td class="clsNumber">
							<xsl:value-of select="$GTotal4yrOld"/>
						</td>
						<td class="clsNumber">
							<xsl:value-of select="$G1stHalf5to15"/>
						</td>
						<td class="clsNumber">
							<xsl:value-of select="$G2ndHalf5to15"/>
						</td>
						<td class="clsNumber">
							<xsl:value-of select="$GTotal5to15"/>
						</td>
					</tr>
					<tr>
						<td class="clsHeading">
						H - <xsl:value-of select="document('./SchoolCensus23-24-SchoolSummaryReferenceLists.xsl') /xsl:stylesheet/Attendance[AttendanceCode = 'H' ]/AttendanceDescription"/>
						</td>
						<td class="clsNumber">
							<xsl:value-of select="$H1stHalf4yrOld"/>
						</td>
						<td class="clsNumber">
							<xsl:value-of select="$H2ndHalf4yrOld"/>
						</td>
						<td class="clsNumber">
							<xsl:value-of select="$HTotal4yrOld"/>
						</td>
						<td class="clsNumber">
							<xsl:value-of select="$H1stHalf5to15"/>
						</td>
						<td class="clsNumber">
							<xsl:value-of select="$H2ndHalf5to15"/>
						</td>
						<td class="clsNumber">
							<xsl:value-of select="$HTotal5to15"/>
						</td>
					</tr>
					<tr>
						<td class="clsHeading">
						I - <xsl:value-of select="document('./SchoolCensus23-24-SchoolSummaryReferenceLists.xsl') /xsl:stylesheet/Attendance[AttendanceCode = 'I' ]/AttendanceDescription"/>
						</td>
						<td class="clsNumber">
							<xsl:value-of select="$I1stHalf4yrOld"/>
						</td>
						<td class="clsNumber">
							<xsl:value-of select="$I2ndHalf4yrOld"/>
						</td>
						<td class="clsNumber">
							<xsl:value-of select="$ITotal4yrOld"/>
						</td>
						<td class="clsNumber">
							<xsl:value-of select="$I1stHalf5to15"/>
						</td>
						<td class="clsNumber">
							<xsl:value-of select="$I2ndHalf5to15"/>
						</td>
						<td class="clsNumber">
							<xsl:value-of select="$ITotal5to15"/>
						</td>
					</tr>
					<tr>
						<td class="clsHeading">
						J - <xsl:value-of select="document('./SchoolCensus23-24-SchoolSummaryReferenceLists.xsl') /xsl:stylesheet/Attendance[AttendanceCode = 'J' ]/AttendanceDescription"/>
						</td>
						<td class="clsNumber">
							<xsl:value-of select="$J1stHalf4yrOld"/>
						</td>
						<td class="clsNumber">
							<xsl:value-of select="$J2ndHalf4yrOld"/>
						</td>
						<td class="clsNumber">
							<xsl:value-of select="$JTotal4yrOld"/>
						</td>
						<td class="clsNumber">
							<xsl:value-of select="$J1stHalf5to15"/>
						</td>
						<td class="clsNumber">
							<xsl:value-of select="$J2ndHalf5to15"/>
						</td>
						<td class="clsNumber">
							<xsl:value-of select="$JTotal5to15"/>
						</td>
					</tr>
					<tr>
						<td class="clsHeading">
						L - <xsl:value-of select="document('./SchoolCensus23-24-SchoolSummaryReferenceLists.xsl') /xsl:stylesheet/Attendance[AttendanceCode = 'L' ]/AttendanceDescription"/>
						</td>
						<td class="clsNumber">
							<xsl:value-of select="$L1stHalf4yrOld"/>
						</td>
						<td class="clsNumber">
							<xsl:value-of select="$L2ndHalf4yrOld"/>
						</td>
						<td class="clsNumber">
							<xsl:value-of select="$LTotal4yrOld"/>
						</td>
						<td class="clsNumber">
							<xsl:value-of select="$L1stHalf5to15"/>
						</td>
						<td class="clsNumber">
							<xsl:value-of select="$L2ndHalf5to15"/>
						</td>
						<td class="clsNumber">
							<xsl:value-of select="$LTotal5to15"/>
						</td>
					</tr>
					<tr>
						<td class="clsHeading">
						M - <xsl:value-of select="document('./SchoolCensus23-24-SchoolSummaryReferenceLists.xsl') /xsl:stylesheet/Attendance[AttendanceCode = 'M' ]/AttendanceDescription"/>
						</td>
						<td class="clsNumber">
							<xsl:value-of select="$M1stHalf4yrOld"/>
						</td>
						<td class="clsNumber">
							<xsl:value-of select="$M2ndHalf4yrOld"/>
						</td>
						<td class="clsNumber">
							<xsl:value-of select="$MTotal4yrOld"/>
						</td>
						<td class="clsNumber">
							<xsl:value-of select="$M1stHalf5to15"/>
						</td>
						<td class="clsNumber">
							<xsl:value-of select="$M2ndHalf5to15"/>
						</td>
						<td class="clsNumber">
							<xsl:value-of select="$MTotal5to15"/>
						</td>
					</tr>
					<tr>
						<td class="clsHeading">
						N - <xsl:value-of select="document('./SchoolCensus23-24-SchoolSummaryReferenceLists.xsl') /xsl:stylesheet/Attendance[AttendanceCode = 'N' ]/AttendanceDescription"/>
						</td>
						<td class="clsNumber">
							<xsl:value-of select="$N1stHalf4yrOld"/>
						</td>
						<td class="clsNumber">
							<xsl:value-of select="$N2ndHalf4yrOld"/>
						</td>
						<td class="clsNumber">
							<xsl:value-of select="$NTotal4yrOld"/>
						</td>
						<td class="clsNumber">
							<xsl:value-of select="$N1stHalf5to15"/>
						</td>
						<td class="clsNumber">
							<xsl:value-of select="$N2ndHalf5to15"/>
						</td>
						<td class="clsNumber">
							<xsl:value-of select="$NTotal5to15"/>
						</td>
					</tr>
					<tr>
						<td class="clsHeading">
						O - <xsl:value-of select="document('./SchoolCensus23-24-SchoolSummaryReferenceLists.xsl') /xsl:stylesheet/Attendance[AttendanceCode = 'O' ]/AttendanceDescription"/>
						</td>
						<td class="clsNumber">
							<xsl:value-of select="$O1stHalf4yrOld"/>
						</td>
						<td class="clsNumber">
							<xsl:value-of select="$O2ndHalf4yrOld"/>
						</td>
						<td class="clsNumber">
							<xsl:value-of select="$OTotal4yrOld"/>
						</td>
						<td class="clsNumber">
							<xsl:value-of select="$O1stHalf5to15"/>
						</td>
						<td class="clsNumber">
							<xsl:value-of select="$O2ndHalf5to15"/>
						</td>
						<td class="clsNumber">
							<xsl:value-of select="$OTotal5to15"/>
						</td>
					</tr>
					<tr>
						<td class="clsHeading">
						P - <xsl:value-of select="document('./SchoolCensus23-24-SchoolSummaryReferenceLists.xsl') /xsl:stylesheet/Attendance[AttendanceCode = 'P' ]/AttendanceDescription"/>
						</td>
						<td class="clsNumber">
							<xsl:value-of select="$P1stHalf4yrOld"/>
						</td>
						<td class="clsNumber">
							<xsl:value-of select="$P2ndHalf4yrOld"/>
						</td>
						<td class="clsNumber">
							<xsl:value-of select="$PTotal4yrOld"/>
						</td>
						<td class="clsNumber">
							<xsl:value-of select="$P1stHalf5to15"/>
						</td>
						<td class="clsNumber">
							<xsl:value-of select="$P2ndHalf5to15"/>
						</td>
						<td class="clsNumber">
							<xsl:value-of select="$PTotal5to15"/>
						</td>
					</tr>
					<tr>
						<td class="clsHeading">
						R - <xsl:value-of select="document('./SchoolCensus23-24-SchoolSummaryReferenceLists.xsl') /xsl:stylesheet/Attendance[AttendanceCode = 'R' ]/AttendanceDescription"/>
						</td>
						<td class="clsNumber">
							<xsl:value-of select="$R1stHalf4yrOld"/>
						</td>
						<td class="clsNumber">
							<xsl:value-of select="$R2ndHalf4yrOld"/>
						</td>
						<td class="clsNumber">
							<xsl:value-of select="$RTotal4yrOld"/>
						</td>
						<td class="clsNumber">
							<xsl:value-of select="$R1stHalf5to15"/>
						</td>
						<td class="clsNumber">
							<xsl:value-of select="$R2ndHalf5to15"/>
						</td>
						<td class="clsNumber">
							<xsl:value-of select="$RTotal5to15"/>
						</td>
					</tr>
					<tr>
						<td class="clsHeading">
						S - <xsl:value-of select="document('./SchoolCensus23-24-SchoolSummaryReferenceLists.xsl') /xsl:stylesheet/Attendance[AttendanceCode = 'S' ]/AttendanceDescription"/>
						</td>
						<td class="clsNumber">
							<xsl:value-of select="$S1stHalf4yrOld"/>
						</td>
						<td class="clsNumber">
							<xsl:value-of select="$S2ndHalf4yrOld"/>
						</td>
						<td class="clsNumber">
							<xsl:value-of select="$STotal4yrOld"/>
						</td>
						<td class="clsNumber">
							<xsl:value-of select="$S1stHalf5to15"/>
						</td>
						<td class="clsNumber">
							<xsl:value-of select="$S2ndHalf5to15"/>
						</td>
						<td class="clsNumber">
							<xsl:value-of select="$STotal5to15"/>
						</td>
					</tr>
					<tr>
						<td class="clsHeading">
						T - <xsl:value-of select="document('./SchoolCensus23-24-SchoolSummaryReferenceLists.xsl') /xsl:stylesheet/Attendance[AttendanceCode = 'T' ]/AttendanceDescription"/>
						</td>
						<td class="clsNumber">
							<xsl:value-of select="$T1stHalf4yrOld"/>
						</td>
						<td class="clsNumber">
							<xsl:value-of select="$T2ndHalf4yrOld"/>
						</td>
						<td class="clsNumber">
							<xsl:value-of select="$TTotal4yrOld"/>
						</td>
						<td class="clsNumber">
							<xsl:value-of select="$T1stHalf5to15"/>
						</td>
						<td class="clsNumber">
							<xsl:value-of select="$T2ndHalf5to15"/>
						</td>
						<td class="clsNumber">
							<xsl:value-of select="$TTotal5to15"/>
						</td>
					</tr>
					<tr>
						<td class="clsHeading">
						U - <xsl:value-of select="document('./SchoolCensus23-24-SchoolSummaryReferenceLists.xsl') /xsl:stylesheet/Attendance[AttendanceCode = 'U' ]/AttendanceDescription"/>
						</td>
						<td class="clsNumber">
							<xsl:value-of select="$U1stHalf4yrOld"/>
						</td>
						<td class="clsNumber">
							<xsl:value-of select="$U2ndHalf4yrOld"/>
						</td>
						<td class="clsNumber">
							<xsl:value-of select="$UTotal4yrOld"/>
						</td>
						<td class="clsNumber">
							<xsl:value-of select="$U1stHalf5to15"/>
						</td>
						<td class="clsNumber">
							<xsl:value-of select="$U2ndHalf5to15"/>
						</td>
						<td class="clsNumber">
							<xsl:value-of select="$UTotal5to15"/>
						</td>
					</tr>
					<tr>
						<td class="clsHeading">
						V - <xsl:value-of select="document('./SchoolCensus23-24-SchoolSummaryReferenceLists.xsl') /xsl:stylesheet/Attendance[AttendanceCode = 'V' ]/AttendanceDescription"/>
						</td>
						<td class="clsNumber">
							<xsl:value-of select="$V1stHalf4yrOld"/>
						</td>
						<td class="clsNumber">
							<xsl:value-of select="$V2ndHalf4yrOld"/>
						</td>
						<td class="clsNumber">
							<xsl:value-of select="$VTotal4yrOld"/>
						</td>
						<td class="clsNumber">
							<xsl:value-of select="$V1stHalf5to15"/>
						</td>
						<td class="clsNumber">
							<xsl:value-of select="$V2ndHalf5to15"/>
						</td>
						<td class="clsNumber">
							<xsl:value-of select="$VTotal5to15"/>
						</td>
					</tr>
					<tr>
						<td class="clsHeading">
						W - <xsl:value-of select="document('./SchoolCensus23-24-SchoolSummaryReferenceLists.xsl') /xsl:stylesheet/Attendance[AttendanceCode = 'W' ]/AttendanceDescription"/>
						</td>
						<td class="clsNumber">
							<xsl:value-of select="$W1stHalf4yrOld"/>
						</td>
						<td class="clsNumber">
							<xsl:value-of select="$W2ndHalf4yrOld"/>
						</td>
						<td class="clsNumber">
							<xsl:value-of select="$WTotal4yrOld"/>
						</td>
						<td class="clsNumber">
							<xsl:value-of select="$W1stHalf5to15"/>
						</td>
						<td class="clsNumber">
							<xsl:value-of select="$W2ndHalf5to15"/>
						</td>
						<td class="clsNumber">
							<xsl:value-of select="$WTotal5to15"/>
						</td>
					</tr>
					<tr>
						<td class="clsHeading">
						X - <xsl:value-of select="document('./SchoolCensus23-24-SchoolSummaryReferenceLists.xsl') /xsl:stylesheet/Attendance[AttendanceCode = 'X' ]/AttendanceDescription"/>
						</td>
						<td class="clsNumber">
							<xsl:value-of select="$X1stHalf4yrOld"/>
						</td>
						<td class="clsNumber">
							<xsl:value-of select="$X2ndHalf4yrOld"/>
						</td>
						<td class="clsNumber">
							<xsl:value-of select="$XTotal4yrOld"/>
						</td>
						<td class="clsNumber">
							<xsl:value-of select="$X1stHalf5to15"/>
						</td>
						<td class="clsNumber">
							<xsl:value-of select="$X2ndHalf5to15"/>
						</td>
						<td class="clsNumber">
							<xsl:value-of select="$XTotal5to15"/>
						</td>
					</tr>
					<tr>
						<td class="clsHeading">
						Y - <xsl:value-of select="document('./SchoolCensus23-24-SchoolSummaryReferenceLists.xsl') /xsl:stylesheet/Attendance[AttendanceCode = 'Y' ]/AttendanceDescription"/>
						</td>
						<td class="clsNumber">
							<xsl:value-of select="$Y1stHalf4yrOld"/>
						</td>
						<td class="clsNumber">
							<xsl:value-of select="$Y2ndHalf4yrOld"/>
						</td>
						<td class="clsNumber">
							<xsl:value-of select="$YTotal4yrOld"/>
						</td>
						<td class="clsNumber">
							<xsl:value-of select="$Y1stHalf5to15"/>
						</td>
						<td class="clsNumber">
							<xsl:value-of select="$Y2ndHalf5to15"/>
						</td>
						<td class="clsNumber">
							<xsl:value-of select="$YTotal5to15"/>
						</td>
					</tr>
					<tr>
						<td class="clsHeading">
						Total of attendance sessions
					</td>
						<td class="clsNumber">
							<xsl:value-of select="$AM1stHalf4yrOld + $PM1stHalf4yrOld + $B1stHalf4yrOld + $C1stHalf4yrOld + $D1stHalf4yrOld + $E1stHalf4yrOld + $G1stHalf4yrOld + $H1stHalf4yrOld + $I1stHalf4yrOld + $J1stHalf4yrOld +  $L1stHalf4yrOld 
							+ $M1stHalf4yrOld + $N1stHalf4yrOld + $O1stHalf4yrOld + $P1stHalf4yrOld + $R1stHalf4yrOld + $S1stHalf4yrOld + $T1stHalf4yrOld + $U1stHalf4yrOld + $V1stHalf4yrOld + $W1stHalf4yrOld + $X1stHalf4yrOld + $Y1stHalf4yrOld"/>
						</td>
						<td class="clsNumber">
							<xsl:value-of select="$AM2ndHalf4yrOld + $PM2ndHalf4yrOld + $B2ndHalf4yrOld + $C2ndHalf4yrOld + $D2ndHalf4yrOld + $E2ndHalf4yrOld + $G2ndHalf4yrOld + $H2ndHalf4yrOld + $I2ndHalf4yrOld + $J2ndHalf4yrOld +  $L2ndHalf4yrOld
							+ $M2ndHalf4yrOld + $N2ndHalf4yrOld + $O2ndHalf4yrOld + $P2ndHalf4yrOld + $R2ndHalf4yrOld + $S2ndHalf4yrOld + $T2ndHalf4yrOld + $U2ndHalf4yrOld + $V2ndHalf4yrOld + $W2ndHalf4yrOld + $X2ndHalf4yrOld + $Y2ndHalf4yrOld"/>
						</td>
						<td class="clsNumber">
							<xsl:value-of select="$AMTotal4yrOld + $PMTotal4yrOld + $BTotal4yrOld + $CTotal4yrOld + $DTotal4yrOld + $ETotal4yrOld + $GTotal4yrOld + $HTotal4yrOld + $ITotal4yrOld + $JTotal4yrOld +  $LTotal4yrOld + 
											  $MTotal4yrOld + $NTotal4yrOld + $OTotal4yrOld + $PTotal4yrOld + $RTotal4yrOld + $STotal4yrOld + $TTotal4yrOld + $UTotal4yrOld + $VTotal4yrOld + $WTotal4yrOld + $XTotal4yrOld + $YTotal4yrOld"/>
						</td>
						<td class="clsNumber">
							<xsl:value-of select="$AM1stHalf5to15 + $PM1stHalf5to15 + $B1stHalf5to15 + $C1stHalf5to15 + $D1stHalf5to15 + $E1stHalf5to15 + $G1stHalf5to15 + $H1stHalf5to15 + $I1stHalf5to15 + $J1stHalf5to15 +  $L1stHalf5to15 
										+ $M1stHalf5to15 + $N1stHalf5to15 + $O1stHalf5to15 + $P1stHalf5to15 + $R1stHalf5to15 + $S1stHalf5to15 + $T1stHalf5to15 + $U1stHalf5to15 + $V1stHalf5to15 + $W1stHalf5to15+ $X1stHalf5to15 + $Y1stHalf5to15"/>
						</td>
						<td class="clsNumber">
							<xsl:value-of select="$AM2ndHalf5to15 + $PM2ndHalf5to15 + $B2ndHalf5to15 + $C2ndHalf5to15 + $D2ndHalf5to15 + $E2ndHalf5to15 + $G2ndHalf5to15 + $H2ndHalf5to15 + $I2ndHalf5to15 + $J2ndHalf5to15 +  $L2ndHalf5to15
										+ $M2ndHalf5to15 + $N2ndHalf5to15 + $O2ndHalf5to15 + $P2ndHalf5to15 + $R2ndHalf5to15 + $S2ndHalf5to15 + $T2ndHalf5to15 + $U2ndHalf5to15 + $V2ndHalf5to15 + $W2ndHalf5to15 + $X2ndHalf5to15 + $Y2ndHalf5to15"/>
						</td>
						<td class="clsNumber">
							<xsl:value-of select="$AMTotal5to15 + $PMTotal5to15 + $BTotal5to15 + $CTotal5to15 + $DTotal5to15 + $ETotal5to15 + $GTotal5to15 + $HTotal5to15 + $ITotal5to15 + $JTotal5to15 +  $LTotal5to15 + 
											  $MTotal5to15 + $NTotal5to15 + $OTotal5to15 + $PTotal5to15 + $RTotal5to15 + $STotal5to15 + $TTotal5to15 + $UTotal5to15 + $VTotal5to15 + $WTotal5to15 + $XTotal5to15 + $YTotal5to15"/>
						</td>
					</tr>
				</table>
			</xsl:when>
			<xsl:when test="$term = 'SPR'">
				<table class="summaryreport" border="1">
					<tr>
						<th colspan="1"/>
						<th colspan="1">Pupils aged 4 as at 31/08/2023</th>
						<th colspan="1">Pupils aged between 5 and 15 as at 31/08/2023</th>
					</tr>
					<tr>
						<th>Attendance reason</th>
						<th>Autumn term (01 August to 31 December 2023)</th>
						<th>Autumn term (01 August to 31 December 2023)</th>
					</tr>
					<tr>
						<td class="clsHeading">
						/ - <xsl:value-of select="document('./SchoolCensus23-24-SchoolSummaryReferenceLists.xsl') /xsl:stylesheet/Attendance[AttendanceCode = '/' ]/AttendanceDescription"/>
						</td>
						<td class="clsNumber">
							<xsl:value-of select="$AMTotal4yrOld"/>
						</td>
						<td class="clsNumber">
							<xsl:value-of select="$AMTotal5to15"/>
						</td>
					</tr>
					<tr>
						<td class="clsHeading">
						\ - <xsl:value-of select="document('./SchoolCensus23-24-SchoolSummaryReferenceLists.xsl') /xsl:stylesheet/Attendance[AttendanceCode = '\' ]/AttendanceDescription"/>
						</td>
						<td class="clsNumber">
							<xsl:value-of select="$PMTotal4yrOld"/>
						</td>
						<td class="clsNumber">
							<xsl:value-of select="$PMTotal5to15"/>
						</td>
					</tr>
					<tr>
						<td class="clsHeading">
						B - <xsl:value-of select="document('./SchoolCensus23-24-SchoolSummaryReferenceLists.xsl') /xsl:stylesheet/Attendance[AttendanceCode = 'B' ]/AttendanceDescription"/>
						</td>
						<td class="clsNumber">
							<xsl:value-of select="$BTotal4yrOld"/>
						</td>
						<td class="clsNumber">
							<xsl:value-of select="$BTotal5to15"/>
						</td>
					</tr>
					<tr>
						<td class="clsHeading">
						C - <xsl:value-of select="document('./SchoolCensus23-24-SchoolSummaryReferenceLists.xsl') /xsl:stylesheet/Attendance[AttendanceCode = 'C' ]/AttendanceDescription"/>
						</td>
						<td class="clsNumber">
							<xsl:value-of select="$CTotal4yrOld"/>
						</td>
						<td class="clsNumber">
							<xsl:value-of select="$CTotal5to15"/>
						</td>
					</tr>
					<tr>
						<td class="clsHeading">
						D - <xsl:value-of select="document('./SchoolCensus23-24-SchoolSummaryReferenceLists.xsl') /xsl:stylesheet/Attendance[AttendanceCode = 'D' ]/AttendanceDescription"/>
						</td>
						<td class="clsNumber">
							<xsl:value-of select="$DTotal4yrOld"/>
						</td>
						<td class="clsNumber">
							<xsl:value-of select="$DTotal5to15"/>
						</td>
					</tr>
					<tr>
						<td class="clsHeading">
						E - <xsl:value-of select="document('./SchoolCensus23-24-SchoolSummaryReferenceLists.xsl') /xsl:stylesheet/Attendance[AttendanceCode = 'E' ]/AttendanceDescription"/>
						</td>
						<td class="clsNumber">
							<xsl:value-of select="$ETotal4yrOld"/>
						</td>
						<td class="clsNumber">
							<xsl:value-of select="$ETotal5to15"/>
						</td>
					</tr>
					<tr>
						<td class="clsHeading">
						G - <xsl:value-of select="document('./SchoolCensus23-24-SchoolSummaryReferenceLists.xsl') /xsl:stylesheet/Attendance[AttendanceCode = 'G' ]/AttendanceDescription"/>
						</td>
						<td class="clsNumber">
							<xsl:value-of select="$GTotal4yrOld"/>
						</td>
						<td class="clsNumber">
							<xsl:value-of select="$GTotal5to15"/>
						</td>
					</tr>
					<tr>
						<td class="clsHeading">
						H - <xsl:value-of select="document('./SchoolCensus23-24-SchoolSummaryReferenceLists.xsl') /xsl:stylesheet/Attendance[AttendanceCode = 'H' ]/AttendanceDescription"/>
						</td>
						<td class="clsNumber">
							<xsl:value-of select="$HTotal4yrOld"/>
						</td>
						<td class="clsNumber">
							<xsl:value-of select="$HTotal5to15"/>
						</td>
					</tr>
					<tr>
						<td class="clsHeading">
						I - <xsl:value-of select="document('./SchoolCensus23-24-SchoolSummaryReferenceLists.xsl') /xsl:stylesheet/Attendance[AttendanceCode = 'I' ]/AttendanceDescription"/>
						</td>
						<td class="clsNumber">
							<xsl:value-of select="$ITotal4yrOld"/>
						</td>
						<td class="clsNumber">
							<xsl:value-of select="$ITotal5to15"/>
						</td>
					</tr>
					<tr>
						<td class="clsHeading">
						J - <xsl:value-of select="document('./SchoolCensus23-24-SchoolSummaryReferenceLists.xsl') /xsl:stylesheet/Attendance[AttendanceCode = 'J' ]/AttendanceDescription"/>
						</td>
						<td class="clsNumber">
							<xsl:value-of select="$JTotal4yrOld"/>
						</td>
						<td class="clsNumber">
							<xsl:value-of select="$JTotal5to15"/>
						</td>
					</tr>
					<tr>
						<td class="clsHeading">
						L - <xsl:value-of select="document('./SchoolCensus23-24-SchoolSummaryReferenceLists.xsl') /xsl:stylesheet/Attendance[AttendanceCode = 'L' ]/AttendanceDescription"/>
						</td>
						<td class="clsNumber">
							<xsl:value-of select="$LTotal4yrOld"/>
						</td>
						<td class="clsNumber">
							<xsl:value-of select="$LTotal5to15"/>
						</td>
					</tr>
					<tr>
						<td class="clsHeading">
						M - <xsl:value-of select="document('./SchoolCensus23-24-SchoolSummaryReferenceLists.xsl') /xsl:stylesheet/Attendance[AttendanceCode = 'M' ]/AttendanceDescription"/>
						</td>
						<td class="clsNumber">
							<xsl:value-of select="$MTotal4yrOld"/>
						</td>
						<td class="clsNumber">
							<xsl:value-of select="$MTotal5to15"/>
						</td>
					</tr>
					<tr>
						<td class="clsHeading">
						N - <xsl:value-of select="document('./SchoolCensus23-24-SchoolSummaryReferenceLists.xsl') /xsl:stylesheet/Attendance[AttendanceCode = 'N' ]/AttendanceDescription"/>
						</td>
						<td class="clsNumber">
							<xsl:value-of select="$NTotal4yrOld"/>
						</td>
						<td class="clsNumber">
							<xsl:value-of select="$NTotal5to15"/>
						</td>
					</tr>
					<tr>
						<td class="clsHeading">
						O - <xsl:value-of select="document('./SchoolCensus23-24-SchoolSummaryReferenceLists.xsl') /xsl:stylesheet/Attendance[AttendanceCode = 'O' ]/AttendanceDescription"/>
						</td>
						<td class="clsNumber">
							<xsl:value-of select="$OTotal4yrOld"/>
						</td>
						<td class="clsNumber">
							<xsl:value-of select="$OTotal5to15"/>
						</td>
					</tr>
					<tr>
						<td class="clsHeading">
						P - <xsl:value-of select="document('./SchoolCensus23-24-SchoolSummaryReferenceLists.xsl') /xsl:stylesheet/Attendance[AttendanceCode = 'P' ]/AttendanceDescription"/>
						</td>
						<td class="clsNumber">
							<xsl:value-of select="$PTotal4yrOld"/>
						</td>
						<td class="clsNumber">
							<xsl:value-of select="$PTotal5to15"/>
						</td>
					</tr>
					<tr>
						<td class="clsHeading">
						R - <xsl:value-of select="document('./SchoolCensus23-24-SchoolSummaryReferenceLists.xsl') /xsl:stylesheet/Attendance[AttendanceCode = 'R' ]/AttendanceDescription"/>
						</td>
						<td class="clsNumber">
							<xsl:value-of select="$RTotal4yrOld"/>
						</td>
						<td class="clsNumber">
							<xsl:value-of select="$RTotal5to15"/>
						</td>
					</tr>
					<tr>
						<td class="clsHeading">
						S - <xsl:value-of select="document('./SchoolCensus23-24-SchoolSummaryReferenceLists.xsl') /xsl:stylesheet/Attendance[AttendanceCode = 'S' ]/AttendanceDescription"/>
						</td>
						<td class="clsNumber">
							<xsl:value-of select="$STotal4yrOld"/>
						</td>
						<td class="clsNumber">
							<xsl:value-of select="$STotal5to15"/>
						</td>
					</tr>
					<tr>
						<td class="clsHeading">
						T - <xsl:value-of select="document('./SchoolCensus23-24-SchoolSummaryReferenceLists.xsl') /xsl:stylesheet/Attendance[AttendanceCode = 'T' ]/AttendanceDescription"/>
						</td>
						<td class="clsNumber">
							<xsl:value-of select="$TTotal4yrOld"/>
						</td>
						<td class="clsNumber">
							<xsl:value-of select="$TTotal5to15"/>
						</td>
					</tr>
					<tr>
						<td class="clsHeading">
						U - <xsl:value-of select="document('./SchoolCensus23-24-SchoolSummaryReferenceLists.xsl') /xsl:stylesheet/Attendance[AttendanceCode = 'U' ]/AttendanceDescription"/>
						</td>
						<td class="clsNumber">
							<xsl:value-of select="$UTotal4yrOld"/>
						</td>
						<td class="clsNumber">
							<xsl:value-of select="$UTotal5to15"/>
						</td>
					</tr>
					<tr>
						<td class="clsHeading">
						V - <xsl:value-of select="document('./SchoolCensus23-24-SchoolSummaryReferenceLists.xsl') /xsl:stylesheet/Attendance[AttendanceCode = 'V' ]/AttendanceDescription"/>
						</td>
						<td class="clsNumber">
							<xsl:value-of select="$VTotal4yrOld"/>
						</td>
						<td class="clsNumber">
							<xsl:value-of select="$VTotal5to15"/>
						</td>
					</tr>
					<tr>
						<td class="clsHeading">
						W - <xsl:value-of select="document('./SchoolCensus23-24-SchoolSummaryReferenceLists.xsl') /xsl:stylesheet/Attendance[AttendanceCode = 'W' ]/AttendanceDescription"/>
						</td>
						<td class="clsNumber">
							<xsl:value-of select="$WTotal4yrOld"/>
						</td>
						<td class="clsNumber">
							<xsl:value-of select="$WTotal5to15"/>
						</td>
					</tr>
					<tr>
						<td class="clsHeading">
						X - <xsl:value-of select="document('./SchoolCensus23-24-SchoolSummaryReferenceLists.xsl') /xsl:stylesheet/Attendance[AttendanceCode = 'X' ]/AttendanceDescription"/>
						</td>
						<td class="clsNumber">
							<xsl:value-of select="$XTotal4yrOld"/>
						</td>
						<td class="clsNumber">
							<xsl:value-of select="$XTotal5to15"/>
						</td>
					</tr>					
					<tr>
						<td class="clsHeading">
						Y - <xsl:value-of select="document('./SchoolCensus23-24-SchoolSummaryReferenceLists.xsl') /xsl:stylesheet/Attendance[AttendanceCode = 'Y' ]/AttendanceDescription"/>
						</td>
						<td class="clsNumber">
							<xsl:value-of select="$YTotal4yrOld"/>
						</td>
						<td class="clsNumber">
							<xsl:value-of select="$YTotal5to15"/>
						</td>
					</tr>
					<tr>
						<td class="clsHeading">
						Total of attendance sessions
					</td>
						<td class="clsNumber">
							<xsl:value-of select="$AMTotal4yrOld + $PMTotal4yrOld + $BTotal4yrOld + $CTotal4yrOld + $DTotal4yrOld + $ETotal4yrOld + $GTotal4yrOld + $HTotal4yrOld + $ITotal4yrOld + $JTotal4yrOld +  $LTotal4yrOld + 
											  $MTotal4yrOld + $NTotal4yrOld + $OTotal4yrOld + $PTotal4yrOld + $RTotal4yrOld + $STotal4yrOld + $TTotal4yrOld + $UTotal4yrOld + $VTotal4yrOld + $WTotal4yrOld + $YTotal4yrOld"/>
						</td>
						<td class="clsNumber">
							<xsl:value-of select="$AMTotal5to15 + $PMTotal5to15 + $BTotal5to15 + $CTotal5to15 + $DTotal5to15 + $ETotal5to15 + $GTotal5to15 + $HTotal5to15 + $ITotal5to15 + $JTotal5to15 +  $LTotal5to15 + 
											  $MTotal5to15 + $NTotal5to15 + $OTotal5to15 + $PTotal5to15 + $RTotal5to15 + $STotal5to15 + $TTotal5to15 + $UTotal5to15 + $VTotal5to15 + $WTotal5to15 + $YTotal5to15"/>
						</td>
					</tr>
				</table>
			</xsl:when>				
			<xsl:when test="$term = 'SUM'">
				<table class="summaryreport" border="1">
					<tr>
						<th colspan="1"/>
						<th colspan="1">Pupils aged 4 as at 31/08/2023</th>
						<th colspan="1">Pupils aged between 5 and 15 as at 31/08/2023</th>
					</tr>
					<tr>
						<th>Attendance reason</th>
						<th>Spring term (01 January to 31 March 2024)</th>
						<th>Spring term (01 January to 31 March 2024)</th>
					</tr>
					<tr>
						<td class="clsHeading">
						/ - <xsl:value-of select="document('./SchoolCensus23-24-SchoolSummaryReferenceLists.xsl') /xsl:stylesheet/Attendance[AttendanceCode = '/' ]/AttendanceDescription"/>
						</td>
						<td class="clsNumber">
							<xsl:value-of select="$AMTotal4yrOld"/>
						</td>
						<td class="clsNumber">
							<xsl:value-of select="$AMTotal5to15"/>
						</td>
					</tr>
					<tr>
						<td class="clsHeading">
						\ - <xsl:value-of select="document('./SchoolCensus23-24-SchoolSummaryReferenceLists.xsl') /xsl:stylesheet/Attendance[AttendanceCode = '\' ]/AttendanceDescription"/>
						</td>
						<td class="clsNumber">
							<xsl:value-of select="$PMTotal4yrOld"/>
						</td>
						<td class="clsNumber">
							<xsl:value-of select="$PMTotal5to15"/>
						</td>
					</tr>
					<tr>
						<td class="clsHeading">
						B - <xsl:value-of select="document('./SchoolCensus23-24-SchoolSummaryReferenceLists.xsl') /xsl:stylesheet/Attendance[AttendanceCode = 'B' ]/AttendanceDescription"/>
						</td>
						<td class="clsNumber">
							<xsl:value-of select="$BTotal4yrOld"/>
						</td>
						<td class="clsNumber">
							<xsl:value-of select="$BTotal5to15"/>
						</td>
					</tr>
					<tr>
						<td class="clsHeading">
						C - <xsl:value-of select="document('./SchoolCensus23-24-SchoolSummaryReferenceLists.xsl') /xsl:stylesheet/Attendance[AttendanceCode = 'C' ]/AttendanceDescription"/>
						</td>
						<td class="clsNumber">
							<xsl:value-of select="$CTotal4yrOld"/>
						</td>
						<td class="clsNumber">
							<xsl:value-of select="$CTotal5to15"/>
						</td>
					</tr>
					<tr>
						<td class="clsHeading">
						D - <xsl:value-of select="document('./SchoolCensus23-24-SchoolSummaryReferenceLists.xsl') /xsl:stylesheet/Attendance[AttendanceCode = 'D' ]/AttendanceDescription"/>
						</td>
						<td class="clsNumber">
							<xsl:value-of select="$DTotal4yrOld"/>
						</td>
						<td class="clsNumber">
							<xsl:value-of select="$DTotal5to15"/>
						</td>
					</tr>
					<tr>
						<td class="clsHeading">
						E - <xsl:value-of select="document('./SchoolCensus23-24-SchoolSummaryReferenceLists.xsl') /xsl:stylesheet/Attendance[AttendanceCode = 'E' ]/AttendanceDescription"/>
						</td>
						<td class="clsNumber">
							<xsl:value-of select="$ETotal4yrOld"/>
						</td>
						<td class="clsNumber">
							<xsl:value-of select="$ETotal5to15"/>
						</td>
					</tr>
					<tr>
						<td class="clsHeading">
						G - <xsl:value-of select="document('./SchoolCensus23-24-SchoolSummaryReferenceLists.xsl') /xsl:stylesheet/Attendance[AttendanceCode = 'G' ]/AttendanceDescription"/>
						</td>
						<td class="clsNumber">
							<xsl:value-of select="$GTotal4yrOld"/>
						</td>
						<td class="clsNumber">
							<xsl:value-of select="$GTotal5to15"/>
						</td>
					</tr>
					<tr>
						<td class="clsHeading">
						H - <xsl:value-of select="document('./SchoolCensus23-24-SchoolSummaryReferenceLists.xsl') /xsl:stylesheet/Attendance[AttendanceCode = 'H' ]/AttendanceDescription"/>
						</td>
						<td class="clsNumber">
							<xsl:value-of select="$HTotal4yrOld"/>
						</td>
						<td class="clsNumber">
							<xsl:value-of select="$HTotal5to15"/>
						</td>
					</tr>
					<tr>
						<td class="clsHeading">
						I - <xsl:value-of select="document('./SchoolCensus23-24-SchoolSummaryReferenceLists.xsl') /xsl:stylesheet/Attendance[AttendanceCode = 'I' ]/AttendanceDescription"/>
						</td>
						<td class="clsNumber">
							<xsl:value-of select="$ITotal4yrOld"/>
						</td>
						<td class="clsNumber">
							<xsl:value-of select="$ITotal5to15"/>
						</td>
					</tr>
					<tr>
						<td class="clsHeading">
						J - <xsl:value-of select="document('./SchoolCensus23-24-SchoolSummaryReferenceLists.xsl') /xsl:stylesheet/Attendance[AttendanceCode = 'J' ]/AttendanceDescription"/>
						</td>
						<td class="clsNumber">
							<xsl:value-of select="$JTotal4yrOld"/>
						</td>
						<td class="clsNumber">
							<xsl:value-of select="$JTotal5to15"/>
						</td>
					</tr>
					<tr>
						<td class="clsHeading">
						L - <xsl:value-of select="document('./SchoolCensus23-24-SchoolSummaryReferenceLists.xsl') /xsl:stylesheet/Attendance[AttendanceCode = 'L' ]/AttendanceDescription"/>
						</td>
						<td class="clsNumber">
							<xsl:value-of select="$LTotal4yrOld"/>
						</td>
						<td class="clsNumber">
							<xsl:value-of select="$LTotal5to15"/>
						</td>
					</tr>
					<tr>
						<td class="clsHeading">
						M - <xsl:value-of select="document('./SchoolCensus23-24-SchoolSummaryReferenceLists.xsl') /xsl:stylesheet/Attendance[AttendanceCode = 'M' ]/AttendanceDescription"/>
						</td>
						<td class="clsNumber">
							<xsl:value-of select="$MTotal4yrOld"/>
						</td>
						<td class="clsNumber">
							<xsl:value-of select="$MTotal5to15"/>
						</td>
					</tr>
					<tr>
						<td class="clsHeading">
						N - <xsl:value-of select="document('./SchoolCensus23-24-SchoolSummaryReferenceLists.xsl') /xsl:stylesheet/Attendance[AttendanceCode = 'N' ]/AttendanceDescription"/>
						</td>
						<td class="clsNumber">
							<xsl:value-of select="$NTotal4yrOld"/>
						</td>
						<td class="clsNumber">
							<xsl:value-of select="$NTotal5to15"/>
						</td>
					</tr>
					<tr>
						<td class="clsHeading">
						O - <xsl:value-of select="document('./SchoolCensus23-24-SchoolSummaryReferenceLists.xsl') /xsl:stylesheet/Attendance[AttendanceCode = 'O' ]/AttendanceDescription"/>
						</td>
						<td class="clsNumber">
							<xsl:value-of select="$OTotal4yrOld"/>
						</td>
						<td class="clsNumber">
							<xsl:value-of select="$OTotal5to15"/>
						</td>
					</tr>
					<tr>
						<td class="clsHeading">
						P - <xsl:value-of select="document('./SchoolCensus23-24-SchoolSummaryReferenceLists.xsl') /xsl:stylesheet/Attendance[AttendanceCode = 'P' ]/AttendanceDescription"/>
						</td>
						<td class="clsNumber">
							<xsl:value-of select="$PTotal4yrOld"/>
						</td>
						<td class="clsNumber">
							<xsl:value-of select="$PTotal5to15"/>
						</td>
					</tr>
					<tr>
						<td class="clsHeading">
						R - <xsl:value-of select="document('./SchoolCensus23-24-SchoolSummaryReferenceLists.xsl') /xsl:stylesheet/Attendance[AttendanceCode = 'R' ]/AttendanceDescription"/>
						</td>
						<td class="clsNumber">
							<xsl:value-of select="$RTotal4yrOld"/>
						</td>
						<td class="clsNumber">
							<xsl:value-of select="$RTotal5to15"/>
						</td>
					</tr>
					<tr>
						<td class="clsHeading">
						S - <xsl:value-of select="document('./SchoolCensus23-24-SchoolSummaryReferenceLists.xsl') /xsl:stylesheet/Attendance[AttendanceCode = 'S' ]/AttendanceDescription"/>
						</td>
						<td class="clsNumber">
							<xsl:value-of select="$STotal4yrOld"/>
						</td>
						<td class="clsNumber">
							<xsl:value-of select="$STotal5to15"/>
						</td>
					</tr>
					<tr>
						<td class="clsHeading">
						T - <xsl:value-of select="document('./SchoolCensus23-24-SchoolSummaryReferenceLists.xsl') /xsl:stylesheet/Attendance[AttendanceCode = 'T' ]/AttendanceDescription"/>
						</td>
						<td class="clsNumber">
							<xsl:value-of select="$TTotal4yrOld"/>
						</td>
						<td class="clsNumber">
							<xsl:value-of select="$TTotal5to15"/>
						</td>
					</tr>
					<tr>
						<td class="clsHeading">
						U - <xsl:value-of select="document('./SchoolCensus23-24-SchoolSummaryReferenceLists.xsl') /xsl:stylesheet/Attendance[AttendanceCode = 'U' ]/AttendanceDescription"/>
						</td>
						<td class="clsNumber">
							<xsl:value-of select="$UTotal4yrOld"/>
						</td>
						<td class="clsNumber">
							<xsl:value-of select="$UTotal5to15"/>
						</td>
					</tr>
					<tr>
						<td class="clsHeading">
						V - <xsl:value-of select="document('./SchoolCensus23-24-SchoolSummaryReferenceLists.xsl') /xsl:stylesheet/Attendance[AttendanceCode = 'V' ]/AttendanceDescription"/>
						</td>
						<td class="clsNumber">
							<xsl:value-of select="$VTotal4yrOld"/>
						</td>
						<td class="clsNumber">
							<xsl:value-of select="$VTotal5to15"/>
						</td>
					</tr>
					<tr>
						<td class="clsHeading">
						W - <xsl:value-of select="document('./SchoolCensus23-24-SchoolSummaryReferenceLists.xsl') /xsl:stylesheet/Attendance[AttendanceCode = 'W' ]/AttendanceDescription"/>
						</td>
						<td class="clsNumber">
							<xsl:value-of select="$WTotal4yrOld"/>
						</td>
						<td class="clsNumber">
							<xsl:value-of select="$WTotal5to15"/>
						</td>
					</tr>
					<tr>
						<td class="clsHeading">
						X - <xsl:value-of select="document('./SchoolCensus23-24-SchoolSummaryReferenceLists.xsl') /xsl:stylesheet/Attendance[AttendanceCode = 'X' ]/AttendanceDescription"/>
						</td>
						<td class="clsNumber">
							<xsl:value-of select="$XTotal4yrOld"/>
						</td>
						<td class="clsNumber">
							<xsl:value-of select="$XTotal5to15"/>
						</td>
					</tr>
					<tr>
						<td class="clsHeading">
						Y - <xsl:value-of select="document('./SchoolCensus23-24-SchoolSummaryReferenceLists.xsl') /xsl:stylesheet/Attendance[AttendanceCode = 'Y' ]/AttendanceDescription"/>
						</td>
						<td class="clsNumber">
							<xsl:value-of select="$YTotal4yrOld"/>
						</td>
						<td class="clsNumber">
							<xsl:value-of select="$YTotal5to15"/>
						</td>
					</tr>
					<tr>
						<td class="clsHeading">
						Total of attendance sessions
					</td>
						<td class="clsNumber">
							<xsl:value-of select="$AMTotal4yrOld + $PMTotal4yrOld + $BTotal4yrOld + $CTotal4yrOld + $DTotal4yrOld + $ETotal4yrOld + $GTotal4yrOld + $HTotal4yrOld + $ITotal4yrOld + $JTotal4yrOld +  $LTotal4yrOld + 
											  $MTotal4yrOld + $NTotal4yrOld + $OTotal4yrOld + $PTotal4yrOld + $RTotal4yrOld + $STotal4yrOld + $TTotal4yrOld + $UTotal4yrOld + $VTotal4yrOld + $WTotal4yrOld + $XTotal4yrOld + $YTotal4yrOld"/>
						</td>
						<td class="clsNumber">
							<xsl:value-of select="$AMTotal5to15 + $PMTotal5to15 + $BTotal5to15 + $CTotal5to15 + $DTotal5to15 + $ETotal5to15 + $GTotal5to15 + $HTotal5to15 + $ITotal5to15 + $JTotal5to15 +  $LTotal5to15 + 
											  $MTotal5to15 + $NTotal5to15 + $OTotal5to15 + $PTotal5to15 + $RTotal5to15 + $STotal5to15 + $TTotal5to15 + $UTotal5to15 + $VTotal5to15 + $WTotal5to15 + $YTotal5to15"/>
						</td>
					</tr>
				</table>
			</xsl:when>
		</xsl:choose>
		
		
		<h2>Table 16: Alternative Provisions placements for single registered pupils by reason [PRU/AP only] </h2>
		<xsl:choose>
			<xsl:when test="contains(' NS PS MP MS SS AT ', concat(' ', $phase, ' ') )">
				<p class="clsFootnote">This table only applies to schools with a phase of PRU or AP</p>
			</xsl:when>
			<xsl:otherwise>
				<xsl:variable name="APReasonOnroll" select="/Message/Pupils/PupilsOnRoll/PupilOnRoll"/>
				<xsl:variable name="APReasonOffroll" select="/Message/Pupils/PupilsNoLongerOnRoll/PupilNoLongerOnRoll[translate(PupilStatus/LeavingDate,'-','') &gt;= $APReasonMaxDate 
																													  and translate(PupilStatus/LeavingDate,'-','') &lt;= ($ReferenceDate - 1) ] "/>
				<xsl:variable name="ASPtotal" select="
						count($APReasonOnroll/APPlacementDetails/APProvisionDetail[contains( ' ASP ', concat(' ', APReason, ' ') ) ] )  
						+
						count($APReasonOffroll/APPlacementDetails/APProvisionDetail[contains( ' ASP ', concat(' ', APReason, ' ') ) ] )
							"/>
				<xsl:variable name="EHCtotal" select="					
						count($APReasonOnroll/APPlacementDetails/APProvisionDetail[contains( ' EHC ', concat(' ', APReason, ' ') ) ] )  
						+
						count($APReasonOffroll/APPlacementDetails/APProvisionDetail[contains( ' EHC ', concat(' ', APReason, ' ') ) ] )
							"/>
				<xsl:variable name="MHNtotal" select="
						count($APReasonOnroll/APPlacementDetails/APProvisionDetail[contains( ' MHN ', concat(' ', APReason, ' ') ) ] )  
						+
						count($APReasonOffroll/APPlacementDetails/APProvisionDetail[contains( ' MHN ', concat(' ', APReason, ' ') ) ] )
							"/>
				<xsl:variable name="NEWtotal" select="
						count($APReasonOnroll/APPlacementDetails/APProvisionDetail[contains( ' NEW ', concat(' ', APReason, ' ') ) ] )  
						+
						count($APReasonOffroll/APPlacementDetails/APProvisionDetail[contains( ' NEW ', concat(' ', APReason, ' ') ) ] )
							"/>
				<xsl:variable name="OTHtotal" select="
						count($APReasonOnroll/APPlacementDetails/APProvisionDetail[contains( ' OTH ', concat(' ', APReason, ' ') ) ] )  
						+
						count($APReasonOffroll/APPlacementDetails/APProvisionDetail[contains( ' OTH ', concat(' ', APReason, ' ') ) ] )
							"/>
				<xsl:variable name="PEXtotal" select="
						count($APReasonOnroll/APPlacementDetails/APProvisionDetail[contains( ' PEX ', concat(' ', APReason, ' ') ) ] )  
						+
						count($APReasonOffroll/APPlacementDetails/APProvisionDetail[contains( ' PEX ', concat(' ', APReason, ' ') ) ] )
							"/>
				<xsl:variable name="PHNtotal" select="
						count($APReasonOnroll/APPlacementDetails/APProvisionDetail[contains( ' PHN ', concat(' ', APReason, ' ') ) ] )  
						+
						count($APReasonOffroll/APPlacementDetails/APProvisionDetail[contains( ' PHN ', concat(' ', APReason, ' ') ) ] )
							"/>
				<xsl:variable name="RHEtotal" select="
						count($APReasonOnroll/APPlacementDetails/APProvisionDetail[contains( ' RHE ', concat(' ', APReason, ' ') ) ] )  
						+
						count($APReasonOffroll/APPlacementDetails/APProvisionDetail[contains( ' RHE ', concat(' ', APReason, ' ') ) ] )
							"/>
				<table class="summaryreport" border="1">
					<tr>
						<th>Alternative provision reason</th>
						<th>Number</th>
					</tr>
					<tr>
						<td class="clsHeading">
							ASP - <xsl:value-of select="document('./SchoolCensus23-24-SchoolSummaryReferenceLists.xsl') /xsl:stylesheet/APReason[APReasonCode = 'ASP' ]/APReasonDescription"/>
						</td>
						<td class="clsNumber">
							<xsl:value-of select="$ASPtotal"/>
						</td>
					</tr>
					<tr>
						<td class="clsHeading">
							EHC - <xsl:value-of select="document('./SchoolCensus23-24-SchoolSummaryReferenceLists.xsl') /xsl:stylesheet/APReason[APReasonCode = 'EHC' ]/APReasonDescription"/>
						</td>
						<td class="clsNumber">
							<xsl:value-of select="$EHCtotal"/>
						</td>
					</tr>
					<tr>
						<td class="clsHeading">
							MHN - <xsl:value-of select="document('./SchoolCensus23-24-SchoolSummaryReferenceLists.xsl') /xsl:stylesheet/APReason[APReasonCode = 'MHN' ]/APReasonDescription"/>
						</td>
						<td class="clsNumber">
							<xsl:value-of select="$MHNtotal"/>
						</td>
					</tr>
					<tr>
						<td class="clsHeading">
							NEW - <xsl:value-of select="document('./SchoolCensus23-24-SchoolSummaryReferenceLists.xsl') /xsl:stylesheet/APReason[APReasonCode = 'NEW' ]/APReasonDescription"/>
						</td>
						<td class="clsNumber">
							<xsl:value-of select="$NEWtotal"/>
						</td>
					</tr>
					<tr>
						<td class="clsHeading">
							OTH - <xsl:value-of select="document('./SchoolCensus23-24-SchoolSummaryReferenceLists.xsl') /xsl:stylesheet/APReason[APReasonCode = 'OTH' ]/APReasonDescription"/>
						</td>
						<td class="clsNumber">
							<xsl:value-of select="$OTHtotal"/>
						</td>
					</tr>
					<tr>
						<td class="clsHeading">
							PEX - <xsl:value-of select="document('./SchoolCensus23-24-SchoolSummaryReferenceLists.xsl') /xsl:stylesheet/APReason[APReasonCode = 'PEX' ]/APReasonDescription"/>
						</td>
						<td class="clsNumber">
							<xsl:value-of select="$PEXtotal"/>
						</td>
					</tr>
					<tr>
						<td class="clsHeading">
							PHN - <xsl:value-of select="document('./SchoolCensus23-24-SchoolSummaryReferenceLists.xsl') /xsl:stylesheet/APReason[APReasonCode = 'PHN' ]/APReasonDescription"/>
						</td>
						<td class="clsNumber">
							<xsl:value-of select="$PHNtotal"/>
						</td>
					</tr>
					<tr>
						<td class="clsHeading">
							RHE - <xsl:value-of select="document('./SchoolCensus23-24-SchoolSummaryReferenceLists.xsl') /xsl:stylesheet/APReason[APReasonCode = 'RHE' ]/APReasonDescription"/>
						</td>
						<td class="clsNumber">
							<xsl:value-of select="$RHEtotal"/>
						</td>
					</tr>
					<tr>
						<td class="clsHeading">
							Total of all Alternative Provision placements for single registered pupils
						</td>
						<td class="clsNumber">
							<xsl:value-of select="$ASPtotal + $EHCtotal + $MHNtotal + $NEWtotal + $OTHtotal + $PEXtotal + $PHNtotal + $RHEtotal "/>
						</td>
					</tr>
				</table>
			</xsl:otherwise>
		</xsl:choose>


		<h2>Table 17: School arranged Alternative Provision placements within the census period [Not for: Nursery schools] </h2>
		<xsl:choose>
			<xsl:when test="$phase = 'NS'"/>
			<xsl:otherwise>
				<xsl:variable name="PlacementsOnroll" select="/Message/Pupils/PupilsOnRoll/PupilOnRoll"/>
				<xsl:variable name="PlacementsOffroll" select="/Message/Pupils/PupilsNoLongerOnRoll/PupilNoLongerOnRoll"/>
				<xsl:variable name="BHSPlacementtotal" select="
						count($PlacementsOnroll/APPlacementDetails/SchoolArrangedAPDetail[PlacementReason = 'BHS' 
							  and ((translate(LeavingDate,'-','') &gt; $APReasonMaxDate and translate(LeavingDate,'-','') &lt;= ($ReferenceDate - 1) )
								   or string-length(LeavingDate) = 0) ])
						+
						count($PlacementsOffroll/APPlacementDetails/SchoolArrangedAPDetail[PlacementReason = 'BHS' 
							  and ((translate(LeavingDate,'-','') &gt; $APReasonMaxDate and translate(LeavingDate,'-','') &lt;= ($ReferenceDate - 1) )
								   or string-length(LeavingDate) = 0) ]) "/>
								   
				<xsl:variable name="SUSPlacementtotal" select="
						count($PlacementsOnroll/APPlacementDetails/SchoolArrangedAPDetail[PlacementReason = 'SUS' 
							  and ((translate(LeavingDate,'-','') &gt; $APReasonMaxDate and translate(LeavingDate,'-','') &lt;= ($ReferenceDate - 1) )
								   or string-length(LeavingDate) = 0) ])
						+
						count($PlacementsOffroll/APPlacementDetails/SchoolArrangedAPDetail[PlacementReason = 'SUS' 
							  and ((translate(LeavingDate,'-','') &gt; $APReasonMaxDate and translate(LeavingDate,'-','') &lt;= ($ReferenceDate - 1) )
								   or string-length(LeavingDate) = 0) ]) "/>						
								   
				<xsl:variable name="EXRPlacementtotal" select="
						count($PlacementsOnroll/APPlacementDetails/SchoolArrangedAPDetail[PlacementReason = 'EXR' 
							  and ((translate(LeavingDate,'-','') &gt; $APReasonMaxDate and translate(LeavingDate,'-','') &lt;= ($ReferenceDate - 1) )
								   or string-length(LeavingDate) = 0) ])
						+
						count($PlacementsOffroll/APPlacementDetails/SchoolArrangedAPDetail[PlacementReason = 'EXR' 
							  and ((translate(LeavingDate,'-','') &gt; $APReasonMaxDate and translate(LeavingDate,'-','') &lt;= ($ReferenceDate - 1) )
								   or string-length(LeavingDate) = 0) ]) "/>
								   
				<xsl:variable name="MHNPlacementtotal" select="
						count($PlacementsOnroll/APPlacementDetails/SchoolArrangedAPDetail[PlacementReason = 'MHN' 
							  and ((translate(LeavingDate,'-','') &gt; $APReasonMaxDate and translate(LeavingDate,'-','') &lt;= ($ReferenceDate - 1) )
								   or string-length(LeavingDate) = 0) ])
						+
						count($PlacementsOffroll/APPlacementDetails/SchoolArrangedAPDetail[PlacementReason = 'MHN' 
							  and ((translate(LeavingDate,'-','') &gt; $APReasonMaxDate and translate(LeavingDate,'-','') &lt;= ($ReferenceDate - 1) )
								   or string-length(LeavingDate) = 0) ]) "/>
								   
				<xsl:variable name="OTHPlacementtotal" select="
						count($PlacementsOnroll/APPlacementDetails/SchoolArrangedAPDetail[PlacementReason = 'OTH' 
							  and ((translate(LeavingDate,'-','') &gt; $APReasonMaxDate and translate(LeavingDate,'-','') &lt;= ($ReferenceDate - 1) )
								   or string-length(LeavingDate) = 0) ])
						+
						count($PlacementsOffroll/APPlacementDetails/SchoolArrangedAPDetail[PlacementReason = 'OTH' 
							  and ((translate(LeavingDate,'-','') &gt; $APReasonMaxDate and translate(LeavingDate,'-','') &lt;= ($ReferenceDate - 1) )
								   or string-length(LeavingDate) = 0) ]) "/>
								   
				<xsl:variable name="PHNPlacementtotal" select="
						count($PlacementsOnroll/APPlacementDetails/SchoolArrangedAPDetail[PlacementReason = 'PHN' 
							  and ((translate(LeavingDate,'-','') &gt; $APReasonMaxDate and translate(LeavingDate,'-','') &lt;= ($ReferenceDate - 1) )
								   or string-length(LeavingDate) = 0) ])
						+
						count($PlacementsOffroll/APPlacementDetails/SchoolArrangedAPDetail[PlacementReason = 'PHN' 
							  and ((translate(LeavingDate,'-','') &gt; $APReasonMaxDate and translate(LeavingDate,'-','') &lt;= ($ReferenceDate - 1) )
								   or string-length(LeavingDate) = 0) ]) "/>

				<xsl:variable name="Placementtotal" select="
						count($PlacementsOnroll/APPlacementDetails/SchoolArrangedAPDetail[((translate(LeavingDate,'-','') &gt; $APReasonMaxDate and translate(LeavingDate,'-','') &lt;= ($ReferenceDate - 1) )
																							 or string-length(LeavingDate) = 0) ] )  
						+
						count($PlacementsOffroll/APPlacementDetails/SchoolArrangedAPDetail[((translate(LeavingDate,'-','') &gt; $APReasonMaxDate and translate(LeavingDate,'-','') &lt;= ($ReferenceDate - 1) )
																						     or string-length(LeavingDate) = 0) ] ) "/>

				<xsl:variable name="OpenFTtotal" select="
						count($PlacementsOnroll/APPlacementDetails/SchoolArrangedAPDetail[APAttendancePattern = 'FT' and string-length(LeavingDate) = 0 ] )  
						+
						count($PlacementsOffroll/APPlacementDetails/SchoolArrangedAPDetail[APAttendancePattern = 'FT' and string-length(LeavingDate) = 0 ] ) "/>

				<xsl:variable name="OpenPTtotal" select="
						count($PlacementsOnroll/APPlacementDetails/SchoolArrangedAPDetail[APAttendancePattern = 'PT' and string-length(LeavingDate) = 0 ] )  
						+
						count($PlacementsOffroll/APPlacementDetails/SchoolArrangedAPDetail[APAttendancePattern = 'PT' and string-length(LeavingDate) = 0 ] ) "/>

				<xsl:variable name="URNPresenttotal" select="
						count($PlacementsOnroll/APPlacementDetails/SchoolArrangedAPDetail[string-length(URN) &gt; 0 and (string-length(LeavingDate) = 0 or (translate(LeavingDate,'-','') &gt; $APReasonMaxDate and translate(LeavingDate,'-','') &lt;= ($ReferenceDate - 1)) ) ] )  
						+
						count($PlacementsOffroll/APPlacementDetails/SchoolArrangedAPDetail[string-length(URN) &gt; 0 and (string-length(LeavingDate) = 0 or (translate(LeavingDate,'-','') &gt; $APReasonMaxDate and translate(LeavingDate,'-','') &lt;= ($ReferenceDate - 1)) ) ] ) "/>

				<xsl:variable name="UKPRNPresenttotal" select="
						count($PlacementsOnroll/APPlacementDetails/SchoolArrangedAPDetail[string-length(UKPRN) &gt; 0 and (string-length(LeavingDate) = 0 or (translate(LeavingDate,'-','') &gt; $APReasonMaxDate and translate(LeavingDate,'-','') &lt;= ($ReferenceDate - 1)) ) ] )  
						+
						count($PlacementsOffroll/APPlacementDetails/SchoolArrangedAPDetail[string-length(UKPRN) &gt; 0 and (string-length(LeavingDate) = 0 or (translate(LeavingDate,'-','') &gt; $APReasonMaxDate and translate(LeavingDate,'-','') &lt;= ($ReferenceDate - 1)) ) ] ) "/>

				<xsl:variable name="SettingTypePresenttotal" select="
						count($PlacementsOnroll/APPlacementDetails/SchoolArrangedAPDetail[string-length(APSettingType) &gt; 0 and (string-length(LeavingDate) = 0 or (translate(LeavingDate,'-','') &gt; $APReasonMaxDate and translate(LeavingDate,'-','') &lt;= ($ReferenceDate - 1)) ) ] )  
						+
						count($PlacementsOffroll/APPlacementDetails/SchoolArrangedAPDetail[string-length(APSettingType) &gt; 0 and (string-length(LeavingDate) = 0 or (translate(LeavingDate,'-','') &gt; $APReasonMaxDate and translate(LeavingDate,'-','') &lt;= ($ReferenceDate - 1)) ) ] ) "/>						
						
				<table class="summaryreport" border="1">
					<tr>
						<th>School arranged Alternative Provision placements</th>
						<th>Number</th>
					</tr>
					<tr>
						<td class="clsHeading">
								BHS - <xsl:value-of select="document('./SchoolCensus23-24-SchoolSummaryReferenceLists.xsl') /xsl:stylesheet/PlacementReason[PlacementReasonCode = 'BHS' ]/PlacementReasonDesc"/>
						</td>
						<td class="clsNumber">
							<xsl:value-of select="$BHSPlacementtotal"/>
						</td>
					</tr>
					<tr>
						<td class="clsHeading">
								SUS - <xsl:value-of select="document('./SchoolCensus23-24-SchoolSummaryReferenceLists.xsl') /xsl:stylesheet/PlacementReason[PlacementReasonCode = 'SUS' ]/PlacementReasonDesc"/>
						</td>
						<td class="clsNumber">
							<xsl:value-of select="$SUSPlacementtotal"/>
						</td>
					</tr>
					<tr>
						<td class="clsHeading">
								EXR - <xsl:value-of select="document('./SchoolCensus23-24-SchoolSummaryReferenceLists.xsl') /xsl:stylesheet/PlacementReason[PlacementReasonCode = 'EXR' ]/PlacementReasonDesc"/>
						</td>
						<td class="clsNumber">
							<xsl:value-of select="$EXRPlacementtotal"/>
						</td>
					</tr>
					<tr>
						<td class="clsHeading">
								MHN - <xsl:value-of select="document('./SchoolCensus23-24-SchoolSummaryReferenceLists.xsl') /xsl:stylesheet/PlacementReason[PlacementReasonCode = 'MHN' ]/PlacementReasonDesc"/>
						</td>
						<td class="clsNumber">
							<xsl:value-of select="$MHNPlacementtotal"/>
						</td>
					</tr>
					<tr>
						<td class="clsHeading">
								OTH - <xsl:value-of select="document('./SchoolCensus23-24-SchoolSummaryReferenceLists.xsl') /xsl:stylesheet/PlacementReason[PlacementReasonCode = 'OTH' ]/PlacementReasonDesc"/>
						</td>
						<td class="clsNumber">
							<xsl:value-of select="$OTHPlacementtotal"/>
						</td>
					</tr>
					<tr>
						<td class="clsHeading">
								PHN - <xsl:value-of select="document('./SchoolCensus23-24-SchoolSummaryReferenceLists.xsl') /xsl:stylesheet/PlacementReason[PlacementReasonCode = 'PHN' ]/PlacementReasonDesc"/>
						</td>
						<td class="clsNumber">
							<xsl:value-of select="$PHNPlacementtotal"/>
						</td>
					</tr>
					<tr>
						<th>Total of all school arranged Alternative Provision placements</th>
						<td class="clsNumber">
							<xsl:value-of select="$Placementtotal"/>
						</td>
					</tr>
					<tr>
						<td class="clsHeading">
								Number of open full time placements
							</td>
						<td class="clsNumber">
							<xsl:value-of select="$OpenFTtotal"/>
						</td>
					</tr>
					<tr>
						<td class="clsHeading">
								Number of open part time placements
							</td>
						<td class="clsNumber">
							<xsl:value-of select="$OpenPTtotal"/>
						</td>
					</tr>
					<tr>
						<td class="clsHeading">
								Number of placement details with URN present
							</td>
						<td class="clsNumber">
							<xsl:value-of select="$URNPresenttotal"/>
						</td>
					</tr>
					<tr>
						<td class="clsHeading">
								Number of placement details with UKPRN present
							</td>
						<td class="clsNumber">
							<xsl:value-of select="$UKPRNPresenttotal"/>
						</td>
					</tr>
					<tr>
						<td class="clsHeading">
								Number of placement details with AP setting type present
							</td>
						<td class="clsNumber">
							<xsl:value-of select="$SettingTypePresenttotal"/>
						</td>
					</tr>
				</table>
			</xsl:otherwise>
		</xsl:choose>


		<h2>Table 18: Admission appeals [Not for: Nursery school, special and PRU] [Note: Primary admissions appeals include Infant admissions appeals]</h2>
		<xsl:choose>
			<xsl:when test="$term != 'SPR'">
				<p class="clsFootnote">This table does not apply to the <xsl:value-of select="$thiscensus"/> census as primary admission appeals data is only collected in the spring census.</p>
			</xsl:when>
			<xsl:when test="$term = 'SPR' and contains(' PS MP MS SS AT ', concat(' ', $phase, ' ') ) ">
				<table class="summaryreport" border="1">
					<tr>
						<th class="clsHeading" rowspan="2">Admissions appeals</th>
						<th class="clsHeading" colspan="3">Number of</th>
					</tr>
					<tr>
						<th class="clsHeading">(A)<br/>Primary<br/>appeals</th>
						<th class="clsHeading">(B)<br/>Infant<br/>appeals</th>
						<th class="clsHeading">(C)<br/>Secondary<br/>appeals</th>
					</tr>
					<tr>
						<td class="clsHeading">Admissions appeals lodged</td>
						<td class="clsNumber">
							<xsl:call-template name="HandleEmptyNumerics">
								<xsl:with-param name="NullNode" select="/Message/School/PrimaryAdmissionsAppeals/Lodged"/>
							</xsl:call-template>
						</td>
						<td class="clsNumber">
							<xsl:call-template name="HandleEmptyNumerics">
								<xsl:with-param name="NullNode" select="/Message/School/InfantAdmissionsAppeals/Lodged"/>
							</xsl:call-template>
						</td>
						<td class="clsNumber">
							<xsl:call-template name="HandleEmptyNumerics">
								<xsl:with-param name="NullNode" select="/Message/School/SecondaryAdmissionsAppeals/Lodged"/>
							</xsl:call-template>
						</td>
					</tr>
					<tr>
						<td class="clsHeading">Admissions appeals withdrawn</td>
						<td class="clsNumber">
							<xsl:call-template name="HandleEmptyNumerics">
								<xsl:with-param name="NullNode" select="/Message/School/PrimaryAdmissionsAppeals/Withdrawn"/>
							</xsl:call-template>
						</td>
						<td class="clsNumber">
							<xsl:call-template name="HandleEmptyNumerics">
								<xsl:with-param name="NullNode" select="/Message/School/InfantAdmissionsAppeals/Withdrawn"/>
							</xsl:call-template>
						</td>
						<td class="clsNumber">
							<xsl:call-template name="HandleEmptyNumerics">
								<xsl:with-param name="NullNode" select="/Message/School/SecondaryAdmissionsAppeals/Withdrawn"/>
							</xsl:call-template>
						</td>
					</tr>
					<tr>
						<td class="clsHeading">Admissions appeals heard by independent admissions<br/>committee</td>
						<td class="clsNumber">
							<xsl:call-template name="HandleEmptyNumerics">
								<xsl:with-param name="NullNode" select="/Message/School/PrimaryAdmissionsAppeals/Heard"/>
							</xsl:call-template>
						</td>
						<td class="clsNumber">
							<xsl:call-template name="HandleEmptyNumerics">
								<xsl:with-param name="NullNode" select="/Message/School/InfantAdmissionsAppeals/Heard"/>
							</xsl:call-template>
						</td>
						<td class="clsNumber">
							<xsl:call-template name="HandleEmptyNumerics">
								<xsl:with-param name="NullNode" select="/Message/School/SecondaryAdmissionsAppeals/Heard"/>
							</xsl:call-template>
						</td>
					</tr>
					<tr>
						<td class="clsHeading">Admissions appeals heard by independent admissions<br/>committee - decided in parents favour</td>
						<td class="clsNumber">
							<xsl:call-template name="HandleEmptyNumerics">
								<xsl:with-param name="NullNode" select="/Message/School/PrimaryAdmissionsAppeals/Upheld"/>
							</xsl:call-template>
						</td>
						<td class="clsNumber">
							<xsl:call-template name="HandleEmptyNumerics">
								<xsl:with-param name="NullNode" select="/Message/School/InfantAdmissionsAppeals/Upheld"/>
							</xsl:call-template>
						</td>
						<td class="clsNumber">
							<xsl:call-template name="HandleEmptyNumerics">
								<xsl:with-param name="NullNode" select="/Message/School/SecondaryAdmissionsAppeals/Upheld"/>
							</xsl:call-template>
						</td>
					</tr>
					<tr>
						<td class="clsHeading">Admissions appeals heard by independent admissions<br/>committee – rejected</td>
						<td class="clsNumber">
							<xsl:call-template name="HandleEmptyNumerics">
								<xsl:with-param name="NullNode" select="/Message/School/PrimaryAdmissionsAppeals/Rejected"/>
							</xsl:call-template>
						</td>
						<td class="clsNumber">
							<xsl:call-template name="HandleEmptyNumerics">
								<xsl:with-param name="NullNode" select="/Message/School/InfantAdmissionsAppeals/Rejected"/>
							</xsl:call-template>
						</td>
						<td class="clsNumber">
							<xsl:call-template name="HandleEmptyNumerics">
								<xsl:with-param name="NullNode" select="/Message/School/SecondaryAdmissionsAppeals/Rejected"/>
							</xsl:call-template>
						</td>
					</tr>
				</table>
				<p class="clsFootnote">Schools will only complete the columns that are applicable to their phase of education / age ranges. We would only expect all three columns to be completed by all-through schools. Primary schools will complete column (A) and (B) with 
						secondary schools completing column (C). Please note: where applicable, the number of primary appeals includes infant admission appeals.</p>
			</xsl:when>
		</xsl:choose>
		<br/>


		<h2>Table 19: Classes as taught at the school's selected time [for: primary only]</h2>
		<xsl:choose>
			<xsl:when test="$term != 'SPR'">
				<p class="clsFootnote">This table does not apply to the <xsl:value-of select="$thiscensus"/> census, as classes taught information is only collected in the spring census.</p>
			</xsl:when>
			<xsl:when test="$phase != 'PS'"/>
			<xsl:otherwise>
				<table border="1" class="summaryreport">
					<tr>
						<th>Primary</th>
						<th>Foundation</th>
						<th>Key Stage 1</th>
						<th>Key Stage 2, 3 <br/>or mixed</th>
					</tr>
					<tr>
						<td class="clsHeading">Number of classes</td>
						<td class="clsNumber">
							<xsl:value-of select="count(/Message/School/Classes/Class[KeyStage = 'F'] )"/>
						</td>
						<td class="clsNumber">
							<xsl:value-of select="count(/Message/School/Classes/Class[KeyStage = '1'] )"/>
						</td>
						<td class="clsNumber">
							<xsl:value-of select="count(/Message/School/Classes/Class[contains(' 2 3 M ', concat(' ', KeyStage, ' ') ) ] )"/>
						</td>
					</tr>
					<tr>
						<td class="clsHeading">Total number of pupils (from this school and other schools) in these classes</td>
						<td class="clsNumber">
							<xsl:value-of select="sum(/Message/School/Classes/Class[KeyStage= 'F']/HomePupils) + sum(/Message/School/Classes/Class[KeyStage= 'F']/GuestPupils)"/>
						</td>
						<td class="clsNumber">
							<xsl:value-of select="sum(/Message/School/Classes/Class[KeyStage= '1']/HomePupils) + sum(/Message/School/Classes/Class[KeyStage= '1']/GuestPupils)"/>
						</td>
						<td class="clsNumber">
							<xsl:value-of select="sum(/Message/School/Classes/Class[contains(' 2 3 M ', concat(' ', KeyStage, ' ') ) ]/HomePupils) + sum(/Message/School/Classes/Class[contains(' 2 3 M ', concat(' ', KeyStage, ' ') ) ]/GuestPupils)"/>
						</td>
					</tr>
					<tr>
						<td class="clsHeading">Total number of teachers</td>
						<td class="clsNumber">
							<xsl:value-of select="sum(/Message/School/Classes/Class[KeyStage = 'F']/Teachers)"/>
						</td>
						<td class="clsNumber">
							<xsl:value-of select="sum(/Message/School/Classes/Class[KeyStage = '1']/Teachers)"/>
						</td>
						<td class="clsNumber">
							<xsl:value-of select="sum(/Message/School/Classes/Class[contains(' 2 3 M ', concat(' ', KeyStage, ' ') ) ]/Teachers)"/>
						</td>
					</tr>
					<tr>
						<td class="clsHeading">Total number of non-teaching staff</td>
						<td class="clsNumber">
							<xsl:value-of select="sum(/Message/School/Classes/Class[KeyStage = 'F']/NonTeachers)"/>
						</td>
						<td class="clsNumber">
							<xsl:value-of select="sum(/Message/School/Classes/Class[KeyStage = '1']/NonTeachers)"/>
						</td>
						<td class="clsNumber">
							<xsl:value-of select="sum(/Message/School/Classes/Class[contains(' 2 3 M ', concat(' ', KeyStage, ' ') ) ]/NonTeachers)"/>
						</td>
					</tr>
					<tr>
						<td class="clsHeading">Largest class (in terms of number of pupils per adult)</td>
						<td class="clsNumber">
							<xsl:choose>
								<xsl:when test="count(/Message/School/Classes/Class[KeyStage = 'F'] ) = 0">0
									</xsl:when>
								<xsl:otherwise>
									<xsl:for-each select="//Classes/Class[KeyStage = 'F']">
										<xsl:sort select="(HomePupils + GuestPupils) div (Teachers + NonTeachers)" data-type="number" order="descending"/>
										<xsl:if test="position()=1">
											<xsl:value-of select="format-number(((HomePupils + GuestPupils) div (Teachers + NonTeachers) ), '#.##')"/>
										</xsl:if>
									</xsl:for-each>
								</xsl:otherwise>
							</xsl:choose>
						</td>
						<td class="clsNumber">
							<xsl:choose>
								<xsl:when test="count(/Message/School/Classes/Class[KeyStage = '1'] ) = 0">0
									</xsl:when>
								<xsl:otherwise>
									<xsl:for-each select="//Classes/Class[KeyStage = '1']">
										<xsl:sort select="(HomePupils + GuestPupils) div (Teachers + NonTeachers)" data-type="number" order="descending"/>
										<xsl:if test="position()=1">
											<xsl:value-of select="format-number(((HomePupils + GuestPupils) div (Teachers + NonTeachers) ), '#.##')"/>
										</xsl:if>
									</xsl:for-each>
								</xsl:otherwise>
							</xsl:choose>
						</td>
						<td class="clsNumber">
							<xsl:choose>
								<xsl:when test="count(/Message/School/Classes/Class[contains(' 2 3 M ', concat(' ', KeyStage, ' ') ) ] ) = 0">0
										</xsl:when>
								<xsl:otherwise>
									<xsl:for-each select="//Classes/Class[contains(' 2 3 M ', concat(' ', KeyStage, ' ') ) ]">
										<xsl:sort select="(HomePupils + GuestPupils) div (Teachers + NonTeachers)" data-type="number" order="descending"/>
										<xsl:if test="position()=1">
											<xsl:value-of select="format-number(((HomePupils + GuestPupils) div (Teachers + NonTeachers) ), '#.##')"/>
										</xsl:if>
									</xsl:for-each>
								</xsl:otherwise>
							</xsl:choose>
						</td>
					</tr>
					<tr>
						<td class="clsHeading">Largest class (in terms of number of pupils per teacher)</td>
						<td class="clsNumber">
							<xsl:choose>
								<xsl:when test="count(/Message/School/Classes/Class[KeyStage = 'F' and Teachers &gt; 0 ] ) = 0">0
									</xsl:when>
								<xsl:otherwise>
									<xsl:for-each select="//Classes/Class[KeyStage = 'F' and Teachers &gt; 0 ]">
										<xsl:sort select="(HomePupils + GuestPupils) div (Teachers)" data-type="number" order="descending"/>
										<xsl:if test="position()=1">
											<xsl:value-of select="format-number(((HomePupils + GuestPupils) div (Teachers) ), '#.##')"/>
										</xsl:if>
									</xsl:for-each>
								</xsl:otherwise>
							</xsl:choose>
						</td>
						<td class="clsNumber">
							<xsl:choose>
								<xsl:when test="count(/Message/School/Classes/Class[KeyStage = '1' and Teachers &gt; 0 ] ) = 0">0
									</xsl:when>
								<xsl:otherwise>
									<xsl:for-each select="//Classes/Class[KeyStage = '1'  and Teachers &gt; 0]">
										<xsl:sort select="(HomePupils + GuestPupils) div (Teachers )" data-type="number" order="descending"/>
										<xsl:if test="position()=1">
											<xsl:value-of select="format-number(((HomePupils + GuestPupils) div (Teachers) ), '#.##')"/>
										</xsl:if>
									</xsl:for-each>
								</xsl:otherwise>
							</xsl:choose>
						</td>
						<td class="clsNumber">
							<xsl:choose>
								<xsl:when test="count(/Message/School/Classes/Class[contains(' 2 3 M ', concat(' ', KeyStage, ' ') ) and Teachers &gt; 0 ] ) = 0">0
										</xsl:when>
								<xsl:otherwise>
									<xsl:for-each select="//Classes/Class[contains(' 2 3 M ', concat(' ', KeyStage, ' ') ) and Teachers &gt; 0 ]">
										<xsl:sort select="(HomePupils + GuestPupils) div (Teachers)" data-type="number" order="descending"/>
										<xsl:if test="position()=1">
											<xsl:value-of select="format-number(((HomePupils + GuestPupils) div (Teachers) ), '#.##')"/>
										</xsl:if>
									</xsl:for-each>
								</xsl:otherwise>
							</xsl:choose>
						</td>
					</tr>
					<tr>
						<td class="clsHeading">Number of classes with no teachers</td>
						<td class="clsNumber">
							<xsl:value-of select="count(/Message/School/Classes/Class[KeyStage = 'F' and Teachers = 0 ] )"/>
						</td>
						<td class="clsNumber">
							<xsl:value-of select="count(/Message/School/Classes/Class[KeyStage = '1' and Teachers = 0 ] )"/>
						</td>
						<td class="clsNumber">
							<xsl:value-of select="count(/Message/School/Classes/Class[contains(' 2 3 M ', concat(' ', KeyStage, ' ') ) and Teachers = 0 ] )"/>
						</td>
					</tr>
				</table>
			</xsl:otherwise>
		</xsl:choose>
		<br/>


		<h2>Table 20: Classes as taught at the schools selected time [for: middle-deemed primary and middle-deemed secondary only]</h2>
		<xsl:choose>
			<xsl:when test="$term != 'SPR'">
				<p class="clsFootnote">This table does not apply to the <xsl:value-of select="$thiscensus"/> census, as classes taught information is only collected in the spring census.</p>
			</xsl:when>
			<xsl:when test="not( contains( ' MP MS ', concat( ' ', $phase, ' ' ) ) )"/>
			<xsl:otherwise>
				<table border="1" class="summaryreport">
					<tr>
						<th>Middle</th>
						<th>Year Group 6<br/>or below<br/>(or mixed)</th>
						<th>Year Group 7<br/>or above</th>
					</tr>
					<tr>
						<td class="clsHeading">Number of classes</td>
						<td class="clsNumber">
							<xsl:value-of select="count(/Message/School/Classes/Class[YearGroup &lt; 7 or contains( ' M N1 N2 R ', concat( ' ', YearGroup, ' ' ) ) ] )"/>
						</td>
						<td class="clsNumber">
							<xsl:value-of select="count(/Message/School/Classes/Class[YearGroup &gt; 6] )"/>
						</td>
					</tr>
					<tr>
						<td class="clsHeading">Total number of pupils (from this school and other schools) in these classes</td>
						<td class="clsNumber">
							<xsl:value-of select="sum(/Message/School/Classes/Class[YearGroup &lt; 7 or contains( ' M N1 N2 R ', concat( ' ', YearGroup, ' ' ) ) ]/HomePupils) 
								+ sum(/Message/School/Classes/Class[YearGroup &lt; 7 or contains( ' M N1 N2 R ', concat( ' ', YearGroup, ' ' ) ) ]/GuestPupils)"/>
						</td>
						<td class="clsNumber">
							<xsl:value-of select="sum(/Message/School/Classes/Class[YearGroup &gt; 6]/HomePupils) + sum(/Message/School/Classes/Class[YearGroup &gt; 6]/GuestPupils)"/>
						</td>
					</tr>
					<tr>
						<td class="clsHeading">Total number of teachers</td>
						<td class="clsNumber">
							<xsl:value-of select="sum(/Message/School/Classes/Class[YearGroup &lt; 7 or contains( ' M N1 N2 R ', concat( ' ', YearGroup, ' ' ) ) ]/Teachers)"/>
						</td>
						<td class="clsNumber">
							<xsl:value-of select="sum(/Message/School/Classes/Class[YearGroup &gt; 6]/Teachers)"/>
						</td>
					</tr>
					<tr>
						<td class="clsHeading">Total number of non-teaching staff</td>
						<td class="clsNumber">
							<xsl:value-of select="sum(/Message/School/Classes/Class[YearGroup &lt; 7 or contains( ' M N1 N2 R ', concat( ' ', YearGroup, ' ' ) ) ]/NonTeachers)"/>
						</td>
						<td class="clsNumber">
							<xsl:value-of select="sum(/Message/School/Classes/Class[YearGroup &gt; 6]/NonTeachers)"/>
						</td>
					</tr>
					<tr>
						<td class="clsHeading">Largest class (in terms of number of pupils per teacher)</td>
						<td class="clsNumber">
							<xsl:choose>
								<xsl:when test="count(/Message/School/Classes/Class[YearGroup &lt; 7 or contains( ' M N1 N2 R ', concat( ' ', YearGroup, ' ' ) ) and Teachers &gt; 0] ) = 0">0
										</xsl:when>
								<xsl:otherwise>
									<xsl:for-each select="//Classes/Class[contains( ' M N1 N2 R 1 2 3 4 5 6 ', concat( ' ', YearGroup, ' ' ) ) and Teachers &gt; 0]">
										<xsl:sort select="(HomePupils + GuestPupils) div Teachers" data-type="number" order="descending"/>
										<xsl:if test="position()=1">
											<xsl:value-of select="format-number(((HomePupils + GuestPupils) div Teachers), '#.##')"/>
										</xsl:if>
									</xsl:for-each>
								</xsl:otherwise>
							</xsl:choose>
						</td>
						<td class="clsNumber">
							<xsl:choose>
								<xsl:when test="count(/Message/School/Classes/Class[YearGroup &gt; 6 and Teachers &gt; 0] ) = 0">0
										</xsl:when>
								<xsl:otherwise>
									<xsl:for-each select="//Classes/Class[YearGroup &gt; 6 and Teachers &gt; 0]">
										<xsl:sort select="(HomePupils + GuestPupils) div Teachers" data-type="number" order="descending"/>
										<xsl:if test="position()=1">
											<xsl:value-of select="format-number(((HomePupils + GuestPupils) div Teachers), '#.##')"/>
										</xsl:if>
									</xsl:for-each>
								</xsl:otherwise>
							</xsl:choose>
						</td>
					</tr>
					<tr>
						<td class="clsHeading">Number of classes with no teachers</td>
						<td class="clsNumber">
							<xsl:value-of select="count(/Message/School/Classes/Class[contains( ' M N1 N2 R 1 2 3 4 5 6 ', concat( ' ', YearGroup, ' ' ) ) and Teachers = 0] )"/>
						</td>
						<td class="clsNumber">
							<xsl:value-of select="count(/Message/School/Classes/Class[YearGroup &gt; 6 and Teachers = 0] )"/>
						</td>
					</tr>
				</table>
			</xsl:otherwise>
		</xsl:choose>
		<br/>


		<h2>Table 21: Classes as taught at the schools selected time [for: secondary only] </h2>
		<xsl:choose>
			<xsl:when test="$term != 'SPR'">
				<p class="clsFootnote">This table does not apply to the <xsl:value-of select="$thiscensus"/> census as classes taught information is only collected in the spring census.</p>
			</xsl:when>
			<xsl:when test="$phase != 'SS'"/>
			<!-- Footnote was removed some time back-->
			<xsl:otherwise>
				<table border="1" class="summaryreport">
					<tr>
						<th>Secondary</th>
						<th>Year 9<br/>or below<br/>(or mixed)</th>
						<th>Years 10<br/>and 11</th>
						<th>Year 12<br/>or above</th>
					</tr>
					<tr>
						<td class="clsHeading">Number of classes</td>
						<td class="clsNumber">
							<xsl:value-of select="count(/Message/School/Classes/Class[YearGroup &lt; 10 or contains( ' M ', concat( ' ', YearGroup, ' ' ) ) ] )"/>
						</td>
						<!--Update aut 2017.  Spec excludes N1 N2 R  so have removed.  If these need to be reported the spec will need updating. This change throughout this table.-->
						<td class="clsNumber">
							<xsl:value-of select="count(/Message/School/Classes/Class[YearGroup = 10 or YearGroup = 11 ] )"/>
						</td>
						<td class="clsNumber">
							<xsl:value-of select="count(/Message/School/Classes/Class[YearGroup &gt; 11] )"/>
						</td>
					</tr>
					<tr>
						<td class="clsHeading">Total number of pupils (from this school and other schools) in these classes</td>
						<td class="clsNumber">
							<xsl:value-of select="sum(/Message/School/Classes/Class[YearGroup &lt; 10 or contains( ' M ', concat( ' ', YearGroup, ' ' ) ) ]/HomePupils) 
								+ sum(/Message/School/Classes/Class[YearGroup &lt; 10 or contains( ' M ', concat( ' ', YearGroup, ' ' ) ) ]/GuestPupils)"/>
						</td>
						<td class="clsNumber">
							<xsl:value-of select="sum(/Message/School/Classes/Class[YearGroup = 10 or YearGroup = 11]/HomePupils) + sum(/Message/School/Classes/Class[YearGroup = 10 or YearGroup = 11]/GuestPupils)"/>
						</td>
						<td class="clsNumber">
							<xsl:value-of select="sum(/Message/School/Classes/Class[YearGroup &gt; 11]/HomePupils) + sum(/Message/School/Classes/Class[YearGroup &gt; 11]/GuestPupils)"/>
						</td>
					</tr>
					<tr>
						<td class="clsHeading">Total number of teachers</td>
						<td class="clsNumber">
							<xsl:value-of select="sum(/Message/School/Classes/Class[YearGroup &lt; 10 or contains( ' M ', concat( ' ', YearGroup, ' ' ) ) ]/Teachers)"/>
						</td>
						<td class="clsNumber">
							<xsl:value-of select="sum(/Message/School/Classes/Class[YearGroup = 10 or YearGroup = 11 ]/Teachers)"/>
						</td>
						<td class="clsNumber">
							<xsl:value-of select="sum(/Message/School/Classes/Class[YearGroup &gt; 11]/Teachers)"/>
						</td>
					</tr>
					<tr>
						<td class="clsHeading">Total number of non-teaching staff</td>
						<td class="clsNumber">
							<xsl:value-of select="sum(/Message/School/Classes/Class[YearGroup &lt; 10 or contains( ' M ', concat( ' ', YearGroup, ' ' ) ) ]/NonTeachers)"/>
						</td>
						<td class="clsNumber">
							<xsl:value-of select="sum(/Message/School/Classes/Class[YearGroup = 10 or YearGroup = 11 ]/NonTeachers)"/>
						</td>
						<td class="clsNumber">
							<xsl:value-of select="sum(/Message/School/Classes/Class[YearGroup &gt; 11]/NonTeachers)"/>
						</td>
					</tr>
					<tr>
						<td class="clsHeading">Largest class (in terms of number of pupils per teacher)</td>
						<td class="clsNumber">
							<xsl:choose>
								<xsl:when test="count(/Message/School/Classes/Class[contains( ' M 1 2 3 4 5 6 7 8 9 ', concat( ' ', YearGroup, ' ' ) ) and Teachers &gt; 0] ) = 0">0
										</xsl:when>
								<xsl:otherwise>
									<xsl:for-each select="//Classes/Class[contains( ' M 1 2 3 4 5 6 7 8 9 ', concat( ' ', YearGroup, ' ' ) ) and Teachers &gt; 0]">
										<xsl:sort select="(HomePupils + GuestPupils) div Teachers" data-type="number" order="descending"/>
										<xsl:if test="position()=1">
											<xsl:value-of select="format-number(((HomePupils + GuestPupils) div Teachers), '#.##')"/>
										</xsl:if>
									</xsl:for-each>
								</xsl:otherwise>
							</xsl:choose>
						</td>
						<td class="clsNumber">
							<xsl:choose>
								<xsl:when test="count(/Message/School/Classes/Class[contains( ' 10 11 ', concat(' ', YearGroup, ' ') ) and Teachers &gt; 0] ) = 0">0
										</xsl:when>
								<xsl:otherwise>
									<xsl:for-each select="//Classes/Class[contains( ' 10 11 ', concat(' ', YearGroup, ' ') ) and Teachers &gt; 0]">
										<xsl:sort select="(HomePupils + GuestPupils) div Teachers" data-type="number" order="descending"/>
										<xsl:if test="position()=1">
											<xsl:value-of select="format-number(((HomePupils + GuestPupils) div Teachers), '#.##')"/>
										</xsl:if>
									</xsl:for-each>
								</xsl:otherwise>
							</xsl:choose>
						</td>
						<td class="clsNumber">
							<xsl:choose>
								<xsl:when test="count(/Message/School/Classes/Class[YearGroup &gt; 11 and Teachers &gt; 0] ) = 0">0
										</xsl:when>
								<xsl:otherwise>
									<xsl:for-each select="//Classes/Class[YearGroup &gt; 11 and Teachers &gt; 0]">
										<xsl:sort select="(HomePupils + GuestPupils) div Teachers" data-type="number" order="descending"/>
										<xsl:if test="position()=1">
											<xsl:value-of select="format-number(((HomePupils + GuestPupils) div Teachers), '#.##')"/>
										</xsl:if>
									</xsl:for-each>
								</xsl:otherwise>
							</xsl:choose>
						</td>
					</tr>
					<tr>
						<td class="clsHeading">Number of classes with no teachers</td>
						<td class="clsNumber">
							<xsl:value-of select="count(/Message/School/Classes/Class[contains( ' M 1 2 3 4 5 6 7 8 9 ', concat( ' ', YearGroup, ' ' ) ) and Teachers = 0] )"/>
						</td>
						<td class="clsNumber">
							<xsl:value-of select="count(/Message/School/Classes/Class[contains( ' 10 11 ', concat( ' ', YearGroup, ' ' ) )  and Teachers = 0] )"/>
						</td>
						<td class="clsNumber">
							<xsl:value-of select="count(/Message/School/Classes/Class[YearGroup &gt; 11 and Teachers = 0] )"/>
						</td>
					</tr>
				</table>
			</xsl:otherwise>
		</xsl:choose>
		<br/>


		<h2>Table 22: Classes as taught at the school's selected time [for: all-through only]</h2>
		<xsl:choose>
			<xsl:when test="$term != 'SPR'">
				<p class="clsFootNote">This table does not apply to the <xsl:value-of select="$thiscensus"/> census, as classes taught information is only collected in the spring census.</p>
			</xsl:when>
			<xsl:when test="$phase != 'AT'"/>
			<xsl:otherwise>
				<table border="1" class="summaryreport">
					<tr>
						<th class="clsHeading">Year groups</th>
						<th class="clsHeading">Number of classes</th>
						<th class="clsHeading">Total number of pupils (from this school and other schools)</th>
						<th class="clsHeading">Total number of teachers</th>
						<th class="clsHeading">Total number of non-teaching staff</th>
						<th class="clsHeading">Largest class (in terms of number of pupils per teacher)</th>
						<th class="clsHeading">Number of classes with no teachers</th>
					</tr>
					<tr>
						<td class="clsHeading">E1, E2, N1 and N2</td>
						<td class="clsNumber">
							<xsl:value-of select="count(/Message/School/Classes/Class[contains( ' E1 E2 N1 N2 ', concat( ' ', YearGroup, ' ' ) ) ] )"/>
						</td>
						<td class="clsNumber">
							<xsl:value-of select="sum(/Message/School/Classes/Class[contains( ' E1 E2 N1 N2 ', concat( ' ', YearGroup, ' ' ) ) ]/HomePupils) 
								+ sum(/Message/School/Classes/Class[contains( ' E1 E2 N1 N2 ', concat( ' ', YearGroup, ' ' ) ) ]/GuestPupils)"/>
						</td>
						<td class="clsNumber">
							<xsl:value-of select="sum(/Message/School/Classes/Class[contains( ' E1 E2 N1 N2 ', concat( ' ', YearGroup, ' ' ) ) ]/Teachers)"/>
						</td>
						<td class="clsNumber">
							<xsl:value-of select="sum(/Message/School/Classes/Class[contains( ' E1 E2 N1 N2 ', concat( ' ', YearGroup, ' ' ) ) ]/NonTeachers)"/>
						</td>
						<td class="clsNumber">
							<xsl:choose>
								<xsl:when test="count(/Message/School/Classes/Class[contains( ' E1 E2 N1 N2 ', concat( ' ', YearGroup, ' ' ) ) and Teachers &gt; 0] ) = 0">0</xsl:when>
								<xsl:otherwise>
									<xsl:for-each select="//Classes/Class[contains( ' E1 E2 N1 N2 ', concat( ' ', YearGroup, ' ' ) ) and Teachers &gt; 0]">
										<xsl:sort select="(HomePupils + GuestPupils) div Teachers" data-type="number" order="descending"/>
										<xsl:if test="position()=1">
											<xsl:value-of select="format-number(((HomePupils + GuestPupils) div Teachers), '#.##')"/>
										</xsl:if>
									</xsl:for-each>
								</xsl:otherwise>
							</xsl:choose>
						</td>
						<td class="clsNumber">
							<xsl:value-of select="count(/Message/School/Classes/Class[contains( ' E1 E2 N1 N2 ', concat( ' ', YearGroup, ' ' ) ) and Teachers = 0] )"/>
						</td>
					</tr>
					<tr>
						<td class="clsHeading">R, 1, 2 and 3</td>
						<td class="clsNumber">
							<xsl:value-of select="count(/Message/School/Classes/Class[contains( ' R 1 2 3 ', concat( ' ', YearGroup, ' ' ) ) ] )"/>
						</td>
						<td class="clsNumber">
							<xsl:value-of select="sum(/Message/School/Classes/Class[contains( ' R 1 2 3 ', concat( ' ', YearGroup, ' ' ) ) ]/HomePupils) 
								+ sum(/Message/School/Classes/Class[contains( ' R 1 2 3 ', concat( ' ', YearGroup, ' ' ) ) ]/GuestPupils)"/>
						</td>
						<td class="clsNumber">
							<xsl:value-of select="sum(/Message/School/Classes/Class[contains( ' R 1 2 3 ', concat( ' ', YearGroup, ' ' ) ) ]/Teachers)"/>
						</td>
						<td class="clsNumber">
							<xsl:value-of select="sum(/Message/School/Classes/Class[contains( ' R 1 2 3 ', concat( ' ', YearGroup, ' ' ) ) ]/NonTeachers)"/>
						</td>
						<td class="clsNumber">
							<xsl:choose>
								<xsl:when test="count(/Message/School/Classes/Class[contains( ' R 1 2 3 ', concat( ' ', YearGroup, ' ' ) ) and Teachers &gt; 0] ) = 0">0</xsl:when>
								<xsl:otherwise>
									<xsl:for-each select="//Classes/Class[contains( ' R 1 2 3 ', concat( ' ', YearGroup, ' ' ) ) and Teachers &gt; 0]">
										<xsl:sort select="(HomePupils + GuestPupils) div Teachers" data-type="number" order="descending"/>
										<xsl:if test="position()=1">
											<xsl:value-of select="format-number(((HomePupils + GuestPupils) div Teachers), '#.##')"/>
										</xsl:if>
									</xsl:for-each>
								</xsl:otherwise>
							</xsl:choose>
						</td>
						<td class="clsNumber">
							<xsl:value-of select="count(/Message/School/Classes/Class[contains( ' R 1 2 3 ', concat( ' ', YearGroup, ' ' ) ) and Teachers = 0] )"/>
						</td>
					</tr>
					<tr>
						<td class="clsHeading">4, 5 and 6</td>
						<td class="clsNumber">
							<xsl:value-of select="count(/Message/School/Classes/Class[contains( ' 4 5 6 ', concat( ' ', YearGroup, ' ' ) ) ] )"/>
						</td>
						<td class="clsNumber">
							<xsl:value-of select="sum(/Message/School/Classes/Class[contains( ' 4 5 6 ', concat( ' ', YearGroup, ' ' ) ) ]/HomePupils) 
								+ sum(/Message/School/Classes/Class[contains( ' 4 5 6 ', concat( ' ', YearGroup, ' ' ) ) ]/GuestPupils)"/>
						</td>
						<td class="clsNumber">
							<xsl:value-of select="sum(/Message/School/Classes/Class[contains( ' 4 5 6 ', concat( ' ', YearGroup, ' ' ) ) ]/Teachers)"/>
						</td>
						<td class="clsNumber">
							<xsl:value-of select="sum(/Message/School/Classes/Class[contains( ' 4 5 6 ', concat( ' ', YearGroup, ' ' ) ) ]/NonTeachers)"/>
						</td>
						<td class="clsNumber">
							<xsl:choose>
								<xsl:when test="count(/Message/School/Classes/Class[contains( ' 4 5 6 ', concat( ' ', YearGroup, ' ' ) ) and Teachers &gt; 0] ) = 0">0</xsl:when>
								<xsl:otherwise>
									<xsl:for-each select="//Classes/Class[contains( ' 4 5 6 ', concat( ' ', YearGroup, ' ' ) ) and Teachers &gt; 0]">
										<xsl:sort select="(HomePupils + GuestPupils) div Teachers" data-type="number" order="descending"/>
										<xsl:if test="position()=1">
											<xsl:value-of select="format-number(((HomePupils + GuestPupils) div Teachers), '#.##')"/>
										</xsl:if>
									</xsl:for-each>
								</xsl:otherwise>
							</xsl:choose>
						</td>
						<td class="clsNumber">
							<xsl:value-of select="count(/Message/School/Classes/Class[contains( ' 4 5 6 ', concat( ' ', YearGroup, ' ' ) ) and Teachers = 0] )"/>
						</td>
					</tr>
					<tr>
						<td class="clsHeading">7, 8 and 9</td>
						<td class="clsNumber">
							<xsl:value-of select="count(/Message/School/Classes/Class[contains( ' 7 8 9 ', concat( ' ', YearGroup, ' ' ) ) ] )"/>
						</td>
						<td class="clsNumber">
							<xsl:value-of select="sum(/Message/School/Classes/Class[contains( ' 7 8 9 ', concat( ' ', YearGroup, ' ' ) ) ]/HomePupils) 
								+ sum(/Message/School/Classes/Class[contains( ' 7 8 9 ', concat( ' ', YearGroup, ' ' ) ) ]/GuestPupils)"/>
						</td>
						<td class="clsNumber">
							<xsl:value-of select="sum(/Message/School/Classes/Class[contains( ' 7 8 9 ', concat( ' ', YearGroup, ' ' ) ) ]/Teachers)"/>
						</td>
						<td class="clsNumber">
							<xsl:value-of select="sum(/Message/School/Classes/Class[contains( ' 7 8 9 ', concat( ' ', YearGroup, ' ' ) ) ]/NonTeachers)"/>
						</td>
						<td class="clsNumber">
							<xsl:choose>
								<xsl:when test="count(/Message/School/Classes/Class[contains( ' 7 8 9 ', concat( ' ', YearGroup, ' ' ) ) and Teachers &gt; 0] ) = 0">0</xsl:when>
								<xsl:otherwise>
									<xsl:for-each select="//Classes/Class[contains( ' 7 8 9 ', concat( ' ', YearGroup, ' ' ) ) and Teachers &gt; 0]">
										<xsl:sort select="(HomePupils + GuestPupils) div Teachers" data-type="number" order="descending"/>
										<xsl:if test="position()=1">
											<xsl:value-of select="format-number(((HomePupils + GuestPupils) div Teachers), '#.##')"/>
										</xsl:if>
									</xsl:for-each>
								</xsl:otherwise>
							</xsl:choose>
						</td>
						<td class="clsNumber">
							<xsl:value-of select="count(/Message/School/Classes/Class[contains( ' 7 8 9 ', concat( ' ', YearGroup, ' ' ) ) and Teachers = 0] )"/>
						</td>
					</tr>
					<tr>
						<td class="clsHeading">10 and 11</td>
						<td class="clsNumber">
							<xsl:value-of select="count(/Message/School/Classes/Class[contains( ' 10 11 ', concat( ' ', YearGroup, ' ' ) ) ] )"/>
						</td>
						<td class="clsNumber">
							<xsl:value-of select="sum(/Message/School/Classes/Class[contains( ' 10 11 ', concat( ' ', YearGroup, ' ' ) ) ]/HomePupils) 
								+ sum(/Message/School/Classes/Class[contains( ' 10 11 ', concat( ' ', YearGroup, ' ' ) ) ]/GuestPupils)"/>
						</td>
						<td class="clsNumber">
							<xsl:value-of select="sum(/Message/School/Classes/Class[contains( ' 10 11 ', concat( ' ', YearGroup, ' ' ) ) ]/Teachers)"/>
						</td>
						<td class="clsNumber">
							<xsl:value-of select="sum(/Message/School/Classes/Class[contains( ' 10 11 ', concat( ' ', YearGroup, ' ' ) ) ]/NonTeachers)"/>
						</td>
						<td class="clsNumber">
							<xsl:choose>
								<xsl:when test="count(/Message/School/Classes/Class[contains( ' 10 11 ', concat( ' ', YearGroup, ' ' ) ) and Teachers &gt; 0] ) = 0">0</xsl:when>
								<xsl:otherwise>
									<xsl:for-each select="//Classes/Class[contains( ' 10 11 ', concat( ' ', YearGroup, ' ' ) ) and Teachers &gt; 0]">
										<xsl:sort select="(HomePupils + GuestPupils) div Teachers" data-type="number" order="descending"/>
										<xsl:if test="position()=1">
											<xsl:value-of select="format-number(((HomePupils + GuestPupils) div Teachers), '#.##')"/>
										</xsl:if>
									</xsl:for-each>
								</xsl:otherwise>
							</xsl:choose>
						</td>
						<td class="clsNumber">
							<xsl:value-of select="count(/Message/School/Classes/Class[contains( ' 10 11 ', concat( ' ', YearGroup, ' ' ) ) and Teachers = 0] )"/>
						</td>
					</tr>
					<tr>
						<td class="clsHeading">12 or above</td>
						<td class="clsNumber">
							<xsl:value-of select="count(/Message/School/Classes/Class[YearGroup &gt; 11] )"/>
						</td>
						<td class="clsNumber">
							<xsl:value-of select="sum(/Message/School/Classes/Class[YearGroup &gt; 11]/HomePupils) 
								+ sum(/Message/School/Classes/Class[YearGroup &gt; 11]/GuestPupils)"/>
						</td>
						<td class="clsNumber">
							<xsl:value-of select="sum(/Message/School/Classes/Class[YearGroup &gt; 11]/Teachers)"/>
						</td>
						<td class="clsNumber">
							<xsl:value-of select="sum(/Message/School/Classes/Class[YearGroup &gt; 11]/NonTeachers)"/>
						</td>
						<td class="clsNumber">
							<xsl:choose>
								<xsl:when test="count(/Message/School/Classes/Class[YearGroup &gt; 11 and Teachers &gt; 0] ) = 0">0</xsl:when>
								<xsl:otherwise>
									<xsl:for-each select="//Classes/Class[YearGroup &gt; 11 and Teachers &gt; 0]">
										<xsl:sort select="(HomePupils + GuestPupils) div Teachers" data-type="number" order="descending"/>
										<xsl:if test="position()=1">
											<xsl:value-of select="format-number(((HomePupils + GuestPupils) div Teachers), '#.##')"/>
										</xsl:if>
									</xsl:for-each>
								</xsl:otherwise>
							</xsl:choose>
						</td>
						<td class="clsNumber">
							<xsl:value-of select="count(/Message/School/Classes/Class[YearGroup &gt; 11 and Teachers = 0] )"/>
						</td>
					</tr>
				</table>
			</xsl:otherwise>
		</xsl:choose>
		<br/>


		<h2>Table 23:	Pupil reconciliation [not for: nursery school, special and PRU]</h2>
		<xsl:choose>
			<xsl:when test="$term != 'SPR'">
				<p class="clsFootNote">This table does not apply to the <xsl:value-of select="$thiscensus"/> census, as pupil reconciliation data is only collected in the spring census.</p>
			</xsl:when>
			<xsl:when test="contains( ' NS SP PR ', concat(' ', $phase, ' ' ) ) "/>
			<xsl:otherwise>
				<table class="summaryreport" border="1">
					<tr>
						<th/>
						<th>Number of pupils</th>
					</tr>
					<tr>
						<td class="clsHeading">Pupils (not including guest pupils) in classes at the selected time</td>
						<td class="clsNumber">
							<xsl:value-of select="sum(/Message/School/Classes/Class/HomePupils)"/>
						</td>
					</tr>
					<tr>
						<td class="clsHeading">Pupils from this school who are part-time and not scheduled to be in attendance<br/>(Only pupils aged under 5 or over 15 years can be shown as part-time)</td>
						<td class="clsNumber">
							<xsl:value-of select="/Message/School/Reconciliation/PupilReconciliation/PartTimeNotIn"/>
						</td>
					</tr>
					<tr>
						<td class="clsHeading">Pupils engaged in private study</td>
						<td class="clsNumber">
							<xsl:value-of select="/Message/School/Reconciliation/PupilReconciliation/PrivateStudy"/>
						</td>
					</tr>
					<tr>
						<td class="clsHeading">Pupils attending another provision</td>
						<td class="clsNumber">
							<xsl:value-of select="/Message/School/Reconciliation/PupilReconciliation/AtOtherSchool"/>
						</td>
					</tr>
					<tr>
						<td class="clsHeading">Pupils on work experience</td>
						<td class="clsNumber">
							<xsl:choose>
								<xsl:when test="contains( ' PS MP ', concat(' ', $phase, ' ' ) ) ">0</xsl:when>
								<xsl:otherwise>
									<xsl:value-of select="/Message/School/Reconciliation/PupilReconciliation/WorkExperience"/>
								</xsl:otherwise>
							</xsl:choose>
						</td>
					</tr>
					<tr>
						<td class="clsHeading">Pupils attending a course at an FE college</td>
						<td class="clsNumber">
							<xsl:choose>
								<xsl:when test="contains( ' PS MP ', concat(' ', $phase, ' ' ) ) ">0</xsl:when>
								<xsl:otherwise>
									<xsl:value-of select="/Message/School/Reconciliation/PupilReconciliation/FEcollege"/>
								</xsl:otherwise>
							</xsl:choose>
						</td>
					</tr>
					<tr>
						<td class="clsHeading">Total number of pupils not in class at the selected time</td>
						<td class="clsNumber">
							<xsl:choose>
								<xsl:when test="contains( ' PS MP ', concat(' ', $phase, ' ' ) ) ">
									<xsl:value-of select="/Message/School/Reconciliation/PupilReconciliation/PartTimeNotIn + /Message/School/Reconciliation/PupilReconciliation/PrivateStudy + /Message/School/Reconciliation/PupilReconciliation/AtOtherSchool"/>
								</xsl:when>
								<xsl:otherwise>
									<xsl:value-of select="/Message/School/Reconciliation/PupilReconciliation/PartTimeNotIn + /Message/School/Reconciliation/PupilReconciliation/PrivateStudy + /Message/School/Reconciliation/PupilReconciliation/AtOtherSchool + /Message/School/Reconciliation/PupilReconciliation/WorkExperience  + /Message/School/Reconciliation/PupilReconciliation/FEcollege"/>
								</xsl:otherwise>
							</xsl:choose>
						</td>
					</tr>
					<tr>
						<td class="clsHeading">Overall total of above (must equal number of pupils on roll)</td>
						<td class="clsTotal">
							<xsl:choose>
								<xsl:when test="contains( ' PS MP ', concat(' ', $phase, ' ' ) ) ">
									<xsl:value-of select="/Message/School/Reconciliation/PupilReconciliation/PartTimeNotIn + /Message/School/Reconciliation/PupilReconciliation/PrivateStudy + /Message/School/Reconciliation/PupilReconciliation/AtOtherSchool + sum(/Message/School/Classes/Class/HomePupils)"/>
								</xsl:when>
								<xsl:otherwise>
									<xsl:value-of select="/Message/School/Reconciliation/PupilReconciliation/PartTimeNotIn + /Message/School/Reconciliation/PupilReconciliation/PrivateStudy + /Message/School/Reconciliation/PupilReconciliation/AtOtherSchool + /Message/School/Reconciliation/PupilReconciliation/WorkExperience + /Message/School/Reconciliation/PupilReconciliation/FEcollege + sum(/Message/School/Classes/Class/HomePupils)"/>
								</xsl:otherwise>
							</xsl:choose>
						</td>
					</tr>
					<tr>
						<td class="clsHeading">Number of pupils on roll (as in table 3)</td>
						<td class="clsTotal">
							<!-- Business rule changed to be the same as the 'Total' calculation on table 3 -->
							<xsl:value-of select="$b16"/>
						</td>
					</tr>
					<tr>
						<td class="clsHeading">Pupils from other schools (guest pupils)</td>
						<td class="clsNumber">
							<xsl:value-of select="sum(/Message/School/Classes/Class/GuestPupils)"/>
						</td>
					</tr>
				</table>
			</xsl:otherwise>
		</xsl:choose>
		<br/>


		<h2>Table 24: Unlawful infant classes - number of reported exceptions by category [For: Primary and All-through - with appropriate pupils]</h2>
		<xsl:choose>
			<xsl:when test="$term != 'SPR'">
				<p class="clsFootNote">This table does not apply to the <xsl:value-of select="$thiscensus"/> census, as class information is only collected in the spring census.</p>
			</xsl:when>
			<xsl:when test="contains( ' NS SS MS MP SP PR ', concat(' ', $phase, ' ' ) ) "/>
			<xsl:otherwise>
				<xsl:variable name="ExcA" select="sum(//ExceptionA[number(.) = .])"/>
				<xsl:variable name="ExcB" select="sum(//ExceptionB[number(.) = .])"/>
				<xsl:variable name="ExcC" select="sum(//ExceptionC[number(.) = .])"/>
				<xsl:variable name="ExcD" select="sum(//ExceptionD[number(.) = .])"/>
				<xsl:variable name="ExcE" select="sum(//ExceptionE[number(.) = .])"/>
				<xsl:variable name="ExcF" select="sum(//ExceptionF[number(.) = .])"/>
				<xsl:variable name="ExcG" select="sum(//ExceptionG[number(.) = .])"/>
				<xsl:variable name="ExcH" select="sum(//ExceptionH[number(.) = .])"/>
				<table class="summaryreport" border="1">
					<tr>
						<th>Exception category</th>
						<th>Number</th>
					</tr>
					<tr>
						<td class="clsHeading">Exception A - children admitted outside the normal admissions round with EHC plan specifying a school</td>
						<td class="clsNumber">
							<xsl:value-of select="$ExcA"/>
						</td>
					</tr>
					<tr>
						<td class="clsHeading">Exception B - looked after children and previously looked after children admitted outside the normal admissions</td>
						<td class="clsNumber">
							<xsl:value-of select="$ExcB"/>
						</td>
					</tr>
					<tr>
						<td class="clsHeading">Exception C - children admitted, after initial allocation of places, because of a procedural error in the original application process </td>
						<td class="clsNumber">
							<xsl:value-of select="$ExcC"/>
						</td>
					</tr>
					<tr>
						<td class="clsHeading">Exception D - children admitted after an independent appeals panel upholds an appeal </td>
						<td class="clsNumber">
							<xsl:value-of select="$ExcD"/>
						</td>
					</tr>
					<tr>
						<td class="clsHeading">Exception E - children who move into the area outside the normal admissions round </td>
						<td class="clsNumber">
							<xsl:value-of select="$ExcE"/>
						</td>
					</tr>
					<tr>
						<td class="clsHeading">Exception F - children of UK service personnel admitted outside the normal admissions round </td>
						<td class="clsNumber">
							<xsl:value-of select="$ExcF"/>
						</td>
					</tr>
					<tr>
						<td class="clsHeading">Exception G - children whose twin or sibling from a multiple birth is admitted otherwise than as an excepted pupil </td>
						<td class="clsNumber">
							<xsl:value-of select="$ExcG"/>
						</td>
					</tr>
					<tr>
						<td class="clsHeading">Exception H - children with special educational needs who attend some infant classes within the mainstream school</td>
						<td class="clsNumber">
							<xsl:value-of select="$ExcH"/>
						</td>
					</tr>
					<tr>
						<td class="clsHeading">Total number of excepted pupils</td>
						<td class="clsTotal">
							<xsl:value-of select="$ExcA + $ExcB + $ExcC + $ExcD + $ExcE + $ExcF + $ExcG + $ExcH"/>
						</td>
					</tr>
					<tr>
						<td class="clsHeading">Total number of teachers on planning and preparation time (PPA)</td>
						<td class="clsTotal">
							<xsl:value-of select="sum(//PPATeachers[number(.) = .])"/>
						</td>
					</tr>
				</table>
			</xsl:otherwise>
		</xsl:choose>
		<br/>


		<h2>Table 25: Universal infant school meals [ALL schools  - with appropriate pupils]</h2>
		<table class="summaryreport" border="1">
			<tr>
				<th rowspan="2">NC Year Group</th>
				<th rowspan="2">Number of pupils on roll</th>
				<th colspan="2">Of which</th>
			</tr>
			<tr>
				<th>School lunch taken on census day</th>
				<th>Currently FSM eligible on Census Day</th>
			</tr>
			<tr>
				<td class="clsHeading">Reception</td>
				<td class="clsNumber">
					<xsl:value-of select="count(/Message/Pupils/PupilsOnRoll/PupilOnRoll[PupilStatus/NCyearActual = 'R' ] )"/>
				</td>
				<td class="clsNumber">
					<xsl:value-of select="count(/Message/Pupils/PupilsOnRoll/PupilOnRoll[PupilStatus/NCyearActual = 'R' 
						and contains( $true, concat( ' ', PupilCharacteristics/SchoolLunchTaken, ' ' ) ) ] )"/>
				</td>
				<td class="clsNumber">
					<xsl:value-of select="count(/Message/Pupils/PupilsOnRoll/PupilOnRoll
						[PupilCharacteristics/FSMeligibility/FSMperiod
							[(not(FSMendDate) 
								or FSMendDate='' 
								or translate(FSMendDate, '-','') &gt;=$ReferenceDate) 
							and translate(FSMstartDate, '-','' ) &lt;= $ReferenceDate]
							and contains( $true, concat( ' ', PupilCharacteristics/SchoolLunchTaken, ' ' ) )
							and PupilStatus/NCyearActual = 'R' ] )"/>
				</td>
			</tr>
			<tr>
				<td class="clsHeading">Year 1</td>
				<td class="clsNumber">
					<xsl:value-of select="count(/Message/Pupils/PupilsOnRoll/PupilOnRoll[PupilStatus/NCyearActual = '1' ] )"/>
				</td>
				<td class="clsNumber">
					<xsl:value-of select="count(/Message/Pupils/PupilsOnRoll/PupilOnRoll
						[PupilStatus/NCyearActual = '1' 
							and contains( $true, concat( ' ', PupilCharacteristics/SchoolLunchTaken, ' ' ) ) ] )"/>
				</td>
				<td class="clsNumber">
					<xsl:value-of select="count(/Message/Pupils/PupilsOnRoll/PupilOnRoll
						[PupilCharacteristics/FSMeligibility/FSMperiod
							[(not(FSMendDate) 
								or FSMendDate='' 
								or translate(FSMendDate, '-','') &gt;=$ReferenceDate) 
							and translate(FSMstartDate, '-','' ) &lt;= $ReferenceDate]
							and contains( $true, concat( ' ', PupilCharacteristics/SchoolLunchTaken, ' ' ) )
							and PupilStatus/NCyearActual = '1' ] )"/>
				</td>
			</tr>
			<tr>
				<td class="clsHeading">Year 2</td>
				<td class="clsNumber">
					<xsl:value-of select="count(/Message/Pupils/PupilsOnRoll/PupilOnRoll[PupilStatus/NCyearActual = '2' ] )"/>
				</td>
				<td class="clsNumber">
					<xsl:value-of select="count(/Message/Pupils/PupilsOnRoll/PupilOnRoll
						[PupilStatus/NCyearActual = '2' 
							and contains( $true, concat( ' ', PupilCharacteristics/SchoolLunchTaken, ' ' ) ) ] )"/>
				</td>
				<td class="clsNumber">
					<xsl:value-of select="count(/Message/Pupils/PupilsOnRoll/PupilOnRoll   
							[PupilCharacteristics/FSMeligibility/FSMperiod
								[(not(FSMendDate) 
									or FSMendDate='' 
									or translate(FSMendDate, '-','') &gt;=$ReferenceDate) 
							and translate(FSMstartDate, '-','' ) &lt;= $ReferenceDate]
							and contains( $true, concat( ' ', PupilCharacteristics/SchoolLunchTaken, ' ' ) )
							and PupilStatus/NCyearActual = '2' ] )"/>
				</td>
			</tr>
			<tr>
				<td class="clsHeading">Year X - pupils aged 4 to 6 only</td>
				<td class="clsNumber">
					<xsl:value-of select="count(/Message/Pupils/PupilsOnRoll/PupilOnRoll
						[PupilStatus/NCyearActual = 'X' 
							and ($AcademicYear - substring( PupilIdentifiers/DOB, 1, 4 ) - (substring( PupilIdentifiers/DOB, 6, 2 ) &gt; $August) ) &gt;= 4 
							and ($AcademicYear - substring( PupilIdentifiers/DOB, 1, 4 ) - (substring( PupilIdentifiers/DOB, 6, 2 ) &gt; $August) ) &lt;= 6 ] )"/>
				</td>
				<td class="clsNumber">
					<xsl:value-of select="count(/Message/Pupils/PupilsOnRoll/PupilOnRoll
						[PupilStatus/NCyearActual = 'X' 
							and contains( $true, concat( ' ', PupilCharacteristics/SchoolLunchTaken, ' ' ) ) 
							and ($AcademicYear - substring( PupilIdentifiers/DOB, 1, 4 ) - (substring( PupilIdentifiers/DOB, 6, 2 ) &gt; $August) ) &gt;= 4 
							and ($AcademicYear - substring( PupilIdentifiers/DOB, 1, 4 ) - (substring( PupilIdentifiers/DOB, 6, 2 ) &gt; $August) ) &lt;= 6 ] )"/>
				</td>
				<td class="clsNumber">
					<xsl:value-of select="count(/Message/Pupils/PupilsOnRoll/PupilOnRoll
						[PupilCharacteristics/FSMeligibility/FSMperiod
							[(not(FSMendDate) 
								or FSMendDate='' 
								or translate(FSMendDate, '-','') &gt;=$ReferenceDate) 
							and translate(FSMstartDate, '-','' ) &lt;= $ReferenceDate]
							and contains( $true, concat( ' ', PupilCharacteristics/SchoolLunchTaken, ' ' ) )
							and PupilStatus/NCyearActual = 'X' 
							and ($AcademicYear - substring( PupilIdentifiers/DOB, 1, 4 ) - (substring( PupilIdentifiers/DOB, 6, 2 ) &gt; $August) ) &gt;= 4 
								and ($AcademicYear - substring( PupilIdentifiers/DOB, 1, 4 ) - (substring( PupilIdentifiers/DOB, 6, 2 ) &gt; $August) ) &lt;= 6 ] )"/>
				</td>
			</tr>
			<tr>
				<td class="clsHeading">Total infant pupils</td>
				<td class="clsNumber">
					<xsl:value-of select="count(/Message/Pupils/PupilsOnRoll/PupilOnRoll [contains( ' R 1 2 ', concat( ' ', PupilStatus/NCyearActual, ' ' ) ) or  (PupilStatus/NCyearActual = 'X' and ($AcademicYear - substring( PupilIdentifiers/DOB, 1, 4 ) - (substring( PupilIdentifiers/DOB, 6, 2 ) &gt; $August) ) &gt;= 4 and ($AcademicYear - substring( PupilIdentifiers/DOB, 1, 4 ) - (substring( PupilIdentifiers/DOB, 6, 2 ) &gt; $August) ) &lt;= 6) ] )"/>
				</td>
				<td class="clsNumber">
					<xsl:value-of select="count(/Message/Pupils/PupilsOnRoll/PupilOnRoll[ (contains( ' R 1 2 ', concat( ' ', PupilStatus/NCyearActual, ' ' ) ) or (PupilStatus/NCyearActual = 'X'  and ($AcademicYear - substring( PupilIdentifiers/DOB, 1, 4 ) - (substring( PupilIdentifiers/DOB, 6, 2 ) &gt; $August) ) &gt;= 4 and ($AcademicYear - substring( PupilIdentifiers/DOB, 1, 4 ) - (substring( PupilIdentifiers/DOB, 6, 2 ) &gt; $August) ) &lt;= 6) ) and contains( $true, concat( ' ', PupilCharacteristics/SchoolLunchTaken, ' ' ) ) ] )"/>
				</td>
				<td class="clsNumber">
					<xsl:value-of select="count(/Message/Pupils/PupilsOnRoll/PupilOnRoll[ 
						(contains( ' R 1 2 ', concat( ' ', PupilStatus/NCyearActual, ' ' ) ) 
							or (PupilStatus/NCyearActual = 'X' 
							and ($AcademicYear - substring( PupilIdentifiers/DOB, 1, 4 ) - (substring( PupilIdentifiers/DOB, 6, 2 ) &gt; $August) ) &gt;= 4 
							and ($AcademicYear - substring( PupilIdentifiers/DOB, 1, 4 ) - (substring( PupilIdentifiers/DOB, 6, 2 ) &gt; $August) ) &lt;= 6) ) 
						and PupilCharacteristics/FSMeligibility/FSMperiod[ 
							(not(FSMendDate) 
								or FSMendDate='' 
								or translate(FSMendDate, '-','') &gt;=$ReferenceDate) 
						and translate(FSMstartDate, '-','' ) &lt;= $ReferenceDate]
						and contains( $true, concat( ' ', PupilCharacteristics/SchoolLunchTaken, ' ' ) )
							 ] )"/>
				</td>
			</tr>
		</table>
		<br/>
		
		
		<h2>Table 26: Learner support (bursary funding for 16-19 year olds) [Not for: Nursery, Primary or Middle-deemed Primary]</h2>
		<xsl:choose>
			<xsl:when test="$term = 'AUT' ">
				<p class="clsFootnote">This table does not apply to the <xsl:value-of select="$thiscensus"/> census as learner support data is not collected in the <xsl:value-of select="$thiscensus"/> census.</p>
			</xsl:when>
			<xsl:when test="contains( ' MS SS AT SP PR ', concat(' ', /Message/School/SchoolCharacteristics/Phase, ' ' ) )">
				<table class="summaryreport" border="1">
					<tr>
						<th rowspan="2">Age as at 31 August <xsl:value-of select="$AcademicYear"/> </th>
						<th colspan="2">Number of pupils awarded bursaries since the beginning of the <xsl:value-of select="$AcademicYear"/> to <xsl:value-of select="$AcademicYear + 1"/> academic year (from <xsl:value-of select="$AcademicYear"/>-08-01) </th>
					</tr>
					<tr>
						<th>Vulnerable group bursary awarded (code 55)</th>
						<th>Discretionary bursary awarded (code 56)</th>
					</tr>
					<tr>
						<td class="clsHeading">16</td>
						<td class="clsNumber">
							<xsl:value-of select="count(/Message/Pupils/PupilsOnRoll/PupilOnRoll[PupilCharacteristics/LearnerSupport/LearnerSupportItem/SupportCode = '55'
																								 and floor(($AgeCalcDate - translate(PupilIdentifiers/DOB, '-','')) div 10000) = 16 ] )
												  +
  												  count(/Message/Pupils/PupilsNoLongerOnRoll/PupilNoLongerOnRoll[PupilCharacteristics/LearnerSupport/LearnerSupportItem/SupportCode = '55'
																								 and floor(($AgeCalcDate - translate(PupilIdentifiers/DOB, '-','')) div 10000) = 16 ] )"/>
						</td>
						<td class="clsNumber">
							<xsl:value-of select="count(/Message/Pupils/PupilsOnRoll/PupilOnRoll[PupilCharacteristics/LearnerSupport/LearnerSupportItem/SupportCode = '56'
																								 and floor(($AgeCalcDate - translate(PupilIdentifiers/DOB, '-','')) div 10000) = 16 ] )
												  +
												  count(/Message/Pupils/PupilsNoLongerOnRoll/PupilNoLongerOnRoll[PupilCharacteristics/LearnerSupport/LearnerSupportItem/SupportCode = '56'
																								 and floor(($AgeCalcDate - translate(PupilIdentifiers/DOB, '-','')) div 10000) = 16 ] )"/>
						</td>
					</tr>
					<tr>
						<td class="clsHeading">17</td>
						<td class="clsNumber">
							<xsl:value-of select="count(/Message/Pupils/PupilsOnRoll/PupilOnRoll[PupilCharacteristics/LearnerSupport/LearnerSupportItem/SupportCode = '55'
																								 and floor(($AgeCalcDate - translate(PupilIdentifiers/DOB, '-','')) div 10000) = 17 ] )
												  +
												  count(/Message/Pupils/PupilsNoLongerOnRoll/PupilNoLongerOnRoll[PupilCharacteristics/LearnerSupport/LearnerSupportItem/SupportCode = '55'
																								 and floor(($AgeCalcDate - translate(PupilIdentifiers/DOB, '-','')) div 10000) = 17 ] )"/>
						</td>
						<td class="clsNumber">
							<xsl:value-of select="count(/Message/Pupils/PupilsOnRoll/PupilOnRoll[PupilCharacteristics/LearnerSupport/LearnerSupportItem/SupportCode = '56'
																								 and floor(($AgeCalcDate - translate(PupilIdentifiers/DOB, '-','')) div 10000) = 17 ] )
												  +
												  count(/Message/Pupils/PupilsNoLongerOnRoll/PupilNoLongerOnRoll[PupilCharacteristics/LearnerSupport/LearnerSupportItem/SupportCode = '56'
																								 and floor(($AgeCalcDate - translate(PupilIdentifiers/DOB, '-','')) div 10000) = 17 ] )"/>
						</td>
					</tr>
					<tr>
						<td class="clsHeading">18</td>
						<td class="clsNumber">
							<xsl:value-of select="count(/Message/Pupils/PupilsOnRoll/PupilOnRoll[PupilCharacteristics/LearnerSupport/LearnerSupportItem/SupportCode = '55'
																								 and floor(($AgeCalcDate - translate(PupilIdentifiers/DOB, '-','')) div 10000) = 18 ] )
												  +
												  count(/Message/Pupils/PupilsNoLongerOnRoll/PupilNoLongerOnRoll[PupilCharacteristics/LearnerSupport/LearnerSupportItem/SupportCode = '55'
																								 and floor(($AgeCalcDate - translate(PupilIdentifiers/DOB, '-','')) div 10000) = 18 ] )"/>
						</td>
						<td class="clsNumber">
							<xsl:value-of select="count(/Message/Pupils/PupilsOnRoll/PupilOnRoll[PupilCharacteristics/LearnerSupport/LearnerSupportItem/SupportCode = '56'
																								 and floor(($AgeCalcDate - translate(PupilIdentifiers/DOB, '-','')) div 10000) = 18 ] )
												  +
												  count(/Message/Pupils/PupilsNoLongerOnRoll/PupilNoLongerOnRoll[PupilCharacteristics/LearnerSupport/LearnerSupportItem/SupportCode = '56'
																								 and floor(($AgeCalcDate - translate(PupilIdentifiers/DOB, '-','')) div 10000) = 18 ] )"/>
						</td>
					</tr>
					<tr>
						<td class="clsHeading">19</td>
						<td class="clsNumber">
							<xsl:value-of select="count(/Message/Pupils/PupilsOnRoll/PupilOnRoll[PupilCharacteristics/LearnerSupport/LearnerSupportItem/SupportCode = '55'
																								 and floor(($AgeCalcDate - translate(PupilIdentifiers/DOB, '-','')) div 10000) = 19 ] )
												  +
												  count(/Message/Pupils/PupilsNoLongerOnRoll/PupilNoLongerOnRoll[PupilCharacteristics/LearnerSupport/LearnerSupportItem/SupportCode = '55'
																								 and floor(($AgeCalcDate - translate(PupilIdentifiers/DOB, '-','')) div 10000) = 19 ] )"/>
						</td>
						<td class="clsNumber">
							<xsl:value-of select="count(/Message/Pupils/PupilsOnRoll/PupilOnRoll[PupilCharacteristics/LearnerSupport/LearnerSupportItem/SupportCode = '56'
																								 and floor(($AgeCalcDate - translate(PupilIdentifiers/DOB, '-','')) div 10000) = 19 ] )
												  +
												  count(/Message/Pupils/PupilsNoLongerOnRoll/PupilNoLongerOnRoll[PupilCharacteristics/LearnerSupport/LearnerSupportItem/SupportCode = '56'
																								 and floor(($AgeCalcDate - translate(PupilIdentifiers/DOB, '-','')) div 10000) = 19 ] )"/>
						</td>
					</tr>
					<tr>
						<td class="clsHeading">Total pupils</td>
						<td class="clsNumber">
							<xsl:value-of select="count(/Message/Pupils/PupilsOnRoll/PupilOnRoll[PupilCharacteristics/LearnerSupport/LearnerSupportItem/SupportCode = '55'
																								 and floor(($AgeCalcDate - translate(PupilIdentifiers/DOB, '-','')) div 10000) &gt;= 16 
																								 and floor(($AgeCalcDate - translate(PupilIdentifiers/DOB, '-','')) div 10000) &lt;= 19] )
												  +
												  count(/Message/Pupils/PupilsNoLongerOnRoll/PupilNoLongerOnRoll[PupilCharacteristics/LearnerSupport/LearnerSupportItem/SupportCode = '55'
																								 and floor(($AgeCalcDate - translate(PupilIdentifiers/DOB, '-','')) div 10000) &gt;= 16 
																								 and floor(($AgeCalcDate - translate(PupilIdentifiers/DOB, '-','')) div 10000) &lt;= 19] )"/>
						</td>
						<td class="clsNumber">
							<xsl:value-of select="count(/Message/Pupils/PupilsOnRoll/PupilOnRoll[PupilCharacteristics/LearnerSupport/LearnerSupportItem/SupportCode = '56'
																								 and floor(($AgeCalcDate - translate(PupilIdentifiers/DOB, '-','')) div 10000) &gt;= 16 
																								 and floor(($AgeCalcDate - translate(PupilIdentifiers/DOB, '-','')) div 10000) &lt;= 19])
												  +
												  count(/Message/Pupils/PupilsNoLongerOnRoll/PupilNoLongerOnRoll[PupilCharacteristics/LearnerSupport/LearnerSupportItem/SupportCode = '56'
																								 and floor(($AgeCalcDate - translate(PupilIdentifiers/DOB, '-','')) div 10000) &gt;= 16 
																								 and floor(($AgeCalcDate - translate(PupilIdentifiers/DOB, '-','')) div 10000) &lt;= 19] )"/>
						</td>
					</tr>
				</table>				
			</xsl:when>
			<xsl:otherwise>
				<p class="clsFootnote">This table does not apply to schools with a phase of NS, PS or MP</p>
			</xsl:otherwise>
		</xsl:choose>		
		

		<br/>
		<br/>
		<h2>Post 16 Learning Aims</h2>
		<p class="clsFootNote">If learners have dual registration it is important that their learning aims are assigned to the school which holds their main registration. Schools should not submit learning aims in respect of subsidiary registrations. 
				In the following tables figures relating to the previous academic year and/or to learning aims for learners no longer on roll may include learners who were dually registered with the school. Checks may need to be made with relevant staff 
				in the school as to the registration status of such pupils as this information may not be available from the MIS.</p>
		<br/>
		
		
		<xsl:choose>
			<xsl:when test="$term = 'AUT' ">
				<h2>Table 27: Post 16 learning aims - number of learners with learning aims which started this academic year - from 1 August <xsl:value-of select="$etyear "/>, or which are continuing from previous academic year(s) [for: secondary, all-through and PRU]</h2>
			</xsl:when>
			<xsl:when test="$term = 'SPR' or $term = 'SUM' ">
				<h2>Table 27: Post 16 learning aims - number of learners with learning aims which started this academic year - from 1 August <xsl:value-of select="$etyear -1 "/>, or which are continuing from previous academic year(s) [for: secondary, all-through and PRU]</h2>
			</xsl:when>
		</xsl:choose>
		<xsl:choose>
			<xsl:when test="$term != 'AUT' ">
				<p class="clsFootnote">This table does not apply to the <xsl:value-of select="$thiscensus"/> census as learning aims data is only collected in the autumn census.</p>
			</xsl:when>
			<xsl:when test="not(contains( ' SS PR AT ', concat(' ', /Message/School/SchoolCharacteristics/Phase, ' ' ) ) )"/>
			<xsl:when test="/Message/School/SchoolCharacteristics/HighestNCyear &lt;12"/>
			<xsl:otherwise>
				<!--F5 + F6 + F7 -->
				<xsl:variable name="LearnersOnRollCurrentYear" select="$PORLABase
					[ProgrammeAims/ProgrammeAim/LearningAims/LearningAim
							[string-length(LearningActualEndDate)=0 
								or translate(LearningActualEndDate,'-','') &gt; $Post16MaxLearningDate] ]"/>
				<!--F10 + F11 + F12 -->
				<xsl:variable name="LearnersOnRollContinuing" select="$PORLABase
					[ProgrammeAims/ProgrammeAim/LearningAims/LearningAim
						[ (string-length(LearningActualEndDate) = 0 
							or translate(LearningActualEndDate,'-','') &gt; $Post16MaxLearningDate)
						and translate(LearningStartDate,'-','') &lt;= $Post16MaxLearningDate ] ]"/>
				<!--F15 + F16 + F17 -->
				<xsl:variable name="LearnersOnRollStarted" select="/Message/Pupils/PupilsOnRoll/PupilOnRoll
					[ProgrammeAims/ProgrammeAim/LearningAims/LearningAim
						[translate(LearningStartDate,'-','') &gt; $Post16MaxLearningDate ] ]"/>
				<!--F20 + F21 + F22 -->
				<!-- This one doesn't work so commenting out for now-->
				<!--xsl:variable name="LearnersOnRollStartedThisYearOnly" select="$PORLABase
					[LearningAims/LearningAim
						[translate(LearningStartDate,'-','') &gt; $Post16MaxLearningDate ] 
						and not(translate(LearningStartDate,'-','') &lt;= $Post16MaxLearningDate ) ]" /-->
				<!--F28 = F25 + F26 + F27 -->
				<xsl:variable name="LearnersOnRollStartedVocational" select="$PORLABase
					[ProgrammeAims/ProgrammeAim/LearningAims/LearningAim
						[ ( string-length( LearningActualEndDate ) = 0 
							or translate(LearningActualEndDate,'-','') &gt; $Post16MaxLearningDate ) 
						and contains($true, concat(' ', CoreAim, ' ' ) ) ] ] "/>
				<xsl:variable name="LearnersOnRollStartedThisYearOnly12" select="count(/Message/Pupils/PupilsOnRoll/PupilOnRoll
					[PupilStatus/NCyearActual = '12' 
					and contains( ' C M F O ', concat(' ', PupilStatus/EnrolStatus, ' ') ) 
					and count(./ProgrammeAims/ProgrammeAim/LearningAims/LearningAim
						[translate(LearningStartDate,'-','') &gt; $Post16MaxLearningDate ] ) &gt;0
					and count(./ProgrammeAims/ProgrammeAim/LearningAims/LearningAim
						[translate(LearningStartDate,'-','') &lt;= $Post16MaxLearningDate ] ) =0 ] )"/>
				<xsl:variable name="LearnersOnRollStartedThisYearOnly13" select="count(/Message/Pupils/PupilsOnRoll/PupilOnRoll
					[PupilStatus/NCyearActual = '13' 
					and contains( ' C M F O ', concat(' ', PupilStatus/EnrolStatus, ' ') ) 
					and count(./ProgrammeAims/ProgrammeAim/LearningAims/LearningAim
						[translate(LearningStartDate,'-','') &gt; $Post16MaxLearningDate] ) &gt;0
					and count(./ProgrammeAims/ProgrammeAim/LearningAims/LearningAim
						[translate(LearningStartDate,'-','') &lt;= $Post16MaxLearningDate] ) = 0 ] )"/>
				<xsl:variable name="LearnersOnRollStartedThisYearOnly14" select="count(/Message/Pupils/PupilsOnRoll/PupilOnRoll
					[PupilStatus/NCyearActual = '14' 
						and contains( ' C M F O ', concat(' ', PupilStatus/EnrolStatus, ' ') ) 
						and count(./ProgrammeAims/ProgrammeAim/LearningAims/LearningAim
							[translate(LearningStartDate,'-','') &gt; $Post16MaxLearningDate] ) &gt;0
						and count(./ProgrammeAims/ProgrammeAim/LearningAims/LearningAim
							[translate(LearningStartDate,'-','') &lt;= $Post16MaxLearningDate ] ) =0 ] )"/>
				<xsl:variable name="LearnersOffRollCurrentYear" select="count(/Message/Pupils/PupilsNoLongerOnRoll/PupilNoLongerOnRoll
					[translate(PupilStatus/LeavingDate,'-','') &gt; $Post16MaxLearningDate
					and translate(PupilStatus/LeavingDate,'-','') &lt;= $ReferenceDate
					and count(./ProgrammeAims/ProgrammeAim/LearningAims/LearningAim[translate(LearningActualEndDate,'-','') &gt; $Post16MaxLearningDate] ) &gt;0 ] )"/>
				<xsl:variable name="LearnersOffRollContinuing" select="count(/Message/Pupils/PupilsNoLongerOnRoll/PupilNoLongerOnRoll
					[translate(PupilStatus/LeavingDate,'-','') &gt; $Post16MaxLearningDate
					and translate(PupilStatus/LeavingDate,'-','') &lt;= $ReferenceDate
					and count(ProgrammeAims/ProgrammeAim/LearningAims/LearningAim
						[translate(LearningActualEndDate,'-','') &gt; $Post16MaxLearningDate
						and translate(LearningStartDate,'-','') &lt;= $Post16MaxLearningDate] ) &gt;0 ] )"/>
				<xsl:variable name="LearnersOffRollStarted" select="count(/Message/Pupils/PupilsNoLongerOnRoll/PupilNoLongerOnRoll
					[translate(PupilStatus/LeavingDate,'-','') &gt; $Post16MaxLearningDate
					and translate(PupilStatus/LeavingDate,'-','') &lt;= $ReferenceDate
					and count(ProgrammeAims/ProgrammeAim/LearningAims/LearningAim
						[translate(LearningStartDate,'-','') &gt; $Post16MaxLearningDate ] ) &gt;0 ] )"/>
				<xsl:variable name="LearnersOffRollStartedThisYearOnly" select="count(/Message/Pupils/PupilsNoLongerOnRoll/PupilNoLongerOnRoll
					[translate(PupilStatus/LeavingDate,'-','') &gt; $Post16MaxLearningDate
						and translate(PupilStatus/LeavingDate,'-','') &lt;= $ReferenceDate
						and count(ProgrammeAims/ProgrammeAim/LearningAims/LearningAim
							[translate(LearningStartDate,'-','') &gt; $Post16MaxLearningDate ] ) &gt;0
						and count(./ProgrammeAims/ProgrammeAim/LearningAims/LearningAim
							[translate(LearningStartDate,'-','') &lt;= $Post16MaxLearningDate]) = 0 ] )"/>
				<table class="summaryreport" border="1">
					<tr>
						<th colspan="1"/>
						<th colspan="3">On Roll</th>
						<th colspan="2"/>
					</tr>
					<tr>
						<th>NC Year Group in <xsl:value-of select="$etyear"/>/<xsl:value-of select="$etyear - 1999"/>
							<br/>academic year</th>
						<th>Year 12</th>
						<th>Year 13</th>
						<th>Year 14</th>
						<th>No longer on roll<br/>(i.e. left between the<br/>end of the previous<br/>academic year and<br/>Census Day)<br/>
						</th>
						<th>Total</th>
					</tr>
					<tr>
						<td class="clsHeading">Number of learners on roll on<br/>Census day (excludes those<br/>with subsidiary registration)</td>
						<td class="clsNumber">
							<xsl:value-of select="count($PORLABase[PupilStatus/NCyearActual='12'])"/>
						</td>
						<td class="clsNumber">
							<xsl:value-of select="count($PORLABase[PupilStatus/NCyearActual='13' ] )"/>
						</td>
						<td class="clsNumber">
							<xsl:value-of select="count($PORLABase[PupilStatus/NCyearActual='14' ] ) "/>
						</td>
						<td class="clsEmpty">
						N/a
						</td>
						<td class="clsNumber">
							<xsl:value-of select="count($PORLABase)"/>
						</td>
					</tr>
					<!-- Number of Learning Aims in each year-->
					<tr>
						<td class="clsHeading">Number of learners with<br/>learning aims in the current<br/>academic year</td>
						<td class="clsNumber">
							<xsl:value-of select="count($LearnersOnRollCurrentYear[PupilStatus/NCyearActual='12'] ) "/>
						</td>
						<td class="clsNumber">
							<xsl:value-of select="count($LearnersOnRollCurrentYear[PupilStatus/NCyearActual='13'] ) "/>
						</td>
						<td class="clsNumber">
							<xsl:value-of select="count($LearnersOnRollCurrentYear[PupilStatus/NCyearActual='14'] ) "/>
						</td>
						<td class="clsNumber">
							<xsl:value-of select="$LearnersOffRollCurrentYear"/>
						</td>
						<td class="clsNumber">
							<xsl:value-of select="count($LearnersOnRollCurrentYear) + $LearnersOffRollCurrentYear"/>
						</td>
					</tr>
					<tr>
						<td class="clsHeading">Number of learners with at least<br/>one learning aim continuing<br/>from the previous year(s)</td>
						<td class="clsNumber">
							<xsl:value-of select="count($LearnersOnRollContinuing[PupilStatus/NCyearActual='12'] ) "/>
						</td>
						<td class="clsNumber">
							<xsl:value-of select="count($LearnersOnRollContinuing[PupilStatus/NCyearActual='13'] )"/>
						</td>
						<td class="clsNumber">
							<xsl:value-of select="count($LearnersOnRollContinuing[PupilStatus/NCyearActual='14'] )"/>
						</td>
						<td class="clsNumber">
							<xsl:value-of select="$LearnersOffRollContinuing"/>
						</td>
						<td class="clsNumber">
							<xsl:value-of select="count($LearnersOnRollContinuing) + $LearnersOffRollContinuing"/>
						</td>
					</tr>
					<tr>
						<td class="clsHeading">Number of learners with at least<br/>one learning aim which started<br/>this academic year</td>
						<td class="clsNumber">
							<xsl:value-of select="count($LearnersOnRollStarted[PupilStatus/NCyearActual='12'] ) "/>
						</td>
						<td class="clsNumber">
							<xsl:value-of select="count($LearnersOnRollStarted[PupilStatus/NCyearActual='13'] ) "/>
						</td>
						<td class="clsNumber">
							<xsl:value-of select="count($LearnersOnRollStarted[PupilStatus/NCyearActual='14'] ) "/>
						</td>
						<td class="clsNumber">
							<xsl:value-of select="$LearnersOffRollStarted"/>
						</td>
						<td class="clsNumber">
							<xsl:value-of select="count($LearnersOnRollStarted) + $LearnersOffRollStarted"/>
						</td>
					</tr>
					<tr>
						<td class="clsHeading">Number of learners with only<br/>learning aims which started this<br/>academic year</td>
						<td class="clsNumber">
							<xsl:value-of select="$LearnersOnRollStartedThisYearOnly12"/>
						</td>
						<td class="clsNumber">
							<xsl:value-of select="$LearnersOnRollStartedThisYearOnly13"/>
						</td>
						<td class="clsNumber">
							<xsl:value-of select="$LearnersOnRollStartedThisYearOnly14"/>
						</td>
						<td class="clsNumber">
							<xsl:value-of select="$LearnersOffRollStartedThisYearOnly"/>
						</td>
						<td class="clsNumber">
							<xsl:value-of select="$LearnersOnRollStartedThisYearOnly12 + $LearnersOnRollStartedThisYearOnly13 + $LearnersOnRollStartedThisYearOnly14 + $LearnersOffRollStartedThisYearOnly"/>
						</td>
					</tr>
					<tr>
						<td class="clsHeading">Number of learners with a core <br/>aim (vocational qualifications <br/>only) which started this <br/>academic year</td>
						<td class="clsNumber">
							<xsl:value-of select="count($LearnersOnRollStartedVocational[ PupilStatus/NCyearActual = '12' ] )"/>
						</td>
						<td class="clsNumber">
							<xsl:value-of select="count($LearnersOnRollStartedVocational[ PupilStatus/NCyearActual = '13' ] )"/>
						</td>
						<td class="clsNumber">
							<xsl:value-of select="count($LearnersOnRollStartedVocational[ PupilStatus/NCyearActual = '14' ] )"/>
						</td>
						<td class="clsEmpty">
						N/a
						</td>
						<td class="clsNumber">
							<xsl:value-of select="count($LearnersOnRollStartedVocational)"/>
						</td>
					</tr>
				</table>
				<p class="clsFootnote">Note: A learner may appear more than once in this table as they may have, for example, aims which are continuing from the previous academic year and also those which they started in this current academic year.</p>
			</xsl:otherwise>
		</xsl:choose>
		
		
		<xsl:choose>
			<xsl:when test="$term = 'AUT' ">
				<h2>Table 28: Post 16 learning aims - number of learners with learning aims which were active in the previous academic year from 1 August <xsl:value-of select="$etyear - 1"/> to 31 July <xsl:value-of select="$etyear"/> [For: Secondary, all-through and PRU] </h2>
			</xsl:when>
			<xsl:when test="$term = 'SPR' or $term = 'SUM' ">
				<h2>Table 28: Post 16 learning aims - number of learners with learning aims which were active in the previous academic year from 1 August <xsl:value-of select="$etyear - 2"/> to 31 July <xsl:value-of select="$etyear - 1"/> [For: Secondary, all-through and PRU] </h2>
			</xsl:when>
		</xsl:choose>
		<xsl:choose>
			<xsl:when test="$term != 'AUT' ">
				<p class="clsFootnote">This table does not apply to the <xsl:value-of select="$thiscensus"/> census as learning aims data is only collected in the autumn census.</p>
			</xsl:when>
			<xsl:when test="not(contains( ' SS PR AT ', concat(' ', /Message/School/SchoolCharacteristics/Phase, ' ' ) ) )"/>
			<xsl:when test="/Message/School/SchoolCharacteristics/HighestNCyear &lt;12"/>
			<xsl:otherwise>
				<xsl:variable name="f28" select="count(/Message/Pupils/PupilsOnRoll/PupilOnRoll
						[contains(' 12 13 ', concat(' ', PupilStatus/NCyearActual, ' ') ) 
						and contains( ' C M F O  ', concat(' ', PupilStatus/EnrolStatus, ' ') ) 
						and count(./ProgrammeAims/ProgrammeAim/LearningAims/LearningAim
							[translate(LearningStartDate,'-','') &lt;= $Post16MaxLearningDate
							and (string-length(LearningActualEndDate) = 0 
								or translate(LearningActualEndDate,'-','') &gt; $Post16PrevMaxLearningDate) ] ) &gt;0 ] )
					+ count(/Message/Pupils/PupilsNoLongerOnRoll/PupilNoLongerOnRoll
						[PupilStatus/NCyearLeaving = '12'
						and translate(PupilStatus/LeavingDate,'-','') &lt;= $Post16MaxLearningDate 
						and count(./ProgrammeAims/ProgrammeAim/LearningAims/LearningAim
							[translate(LearningStartDate,'-','') &lt;= $Post16MaxLearningDate
							and translate(LearningActualEndDate,'-','') &gt; $Post16PrevMaxLearningDate
							and translate(LearningActualEndDate,'-','') &lt;= $Post16MaxLearningDate] ) &gt;0 ] ) 
					+ count(/Message/Pupils/PupilsNoLongerOnRoll/PupilNoLongerOnRoll
						[PupilStatus/NCyearLeaving = '13'
						and translate(PupilStatus/LeavingDate,'-','') &gt; $Post16MaxLearningDate
						and translate(PupilStatus/LeavingDate,'-','') &lt;= $ReferenceDate
						and count(./ProgrammeAims/ProgrammeAim/LearningAims/LearningAim
							[translate(LearningStartDate,'-','') &lt;= $Post16MaxLearningDate
							and translate(LearningActualEndDate,'-','') &gt; $Post16PrevMaxLearningDate ] ) &gt;0 ] ) "/>
				<xsl:variable name="f29" select="count(/Message/Pupils/PupilsOnRoll/PupilOnRoll
						[PupilStatus/NCyearActual = '14' 
						and contains( ' C M F O ', concat(' ', PupilStatus/EnrolStatus, ' ') ) 
						and count(./ProgrammeAims/ProgrammeAim/LearningAims/LearningAim
							[translate(LearningStartDate,'-','') &lt;= $Post16MaxLearningDate
							and (string-length(LearningActualEndDate) = 0 
								or translate(LearningActualEndDate,'-','') &gt; $Post16PrevMaxLearningDate) ] ) &gt;0 ] )				
					+ count(/Message/Pupils/PupilsNoLongerOnRoll/PupilNoLongerOnRoll
						[PupilStatus/NCyearLeaving = '13'				
						and translate(PupilStatus/LeavingDate,'-','') &lt;= $Post16MaxLearningDate 
						and count(./ProgrammeAims/ProgrammeAim/LearningAims/LearningAim
							[translate(LearningStartDate,'-','') &lt;= $Post16MaxLearningDate
								and translate(LearningActualEndDate,'-','') &gt; $Post16PrevMaxLearningDate
								and translate(LearningActualEndDate,'-','') &lt;= $Post16MaxLearningDate ] ) &gt;0 ] )				
					+ count(/Message/Pupils/PupilsNoLongerOnRoll/PupilNoLongerOnRoll
						[PupilStatus/NCyearLeaving = '14'
						and translate(PupilStatus/LeavingDate,'-','') &gt; $Post16MaxLearningDate
						and translate(PupilStatus/LeavingDate,'-','') &lt;= $ReferenceDate
						and count(./ProgrammeAims/ProgrammeAim/LearningAims/LearningAim
							[translate(LearningStartDate,'-','') &lt;= $Post16MaxLearningDate
							and translate(LearningActualEndDate,'-','') &gt; $Post16PrevMaxLearningDate] ) &gt;0 ] ) "/>
				<xsl:variable name="f30" select="count(/Message/Pupils/PupilsNoLongerOnRoll/PupilNoLongerOnRoll
					[PupilStatus/NCyearLeaving = '14'
					and translate(PupilStatus/LeavingDate,'-','') &gt; $Post16PrevMaxLearningDate
					and translate(PupilStatus/LeavingDate,'-','') &lt;= $Post16MaxLearningDate 
					and count(./ProgrammeAims/ProgrammeAim/LearningAims/LearningAim
						[translate(LearningStartDate,'-','') &lt;= $Post16MaxLearningDate
						and translate(LearningActualEndDate,'-','') &gt; $Post16PrevMaxLearningDate ] ) &gt;0 ] ) "/>
				<xsl:variable name="f32" select="count(/Message/Pupils/PupilsOnRoll/PupilOnRoll
						[contains(' 12 13 ', concat(' ', PupilStatus/NCyearActual, ' ') )  
						and contains( ' C M F O ', concat(' ', PupilStatus/EnrolStatus, ' ') ) 
						and count(./ProgrammeAims/ProgrammeAim/LearningAims/LearningAim
							[translate(LearningActualEndDate,'-','') &lt;= $Post16MaxLearningDate
							and LearningAimStatus = '2'] ) &gt;0 ] )				
					+ count(/Message/Pupils/PupilsNoLongerOnRoll/PupilNoLongerOnRoll
						[PupilStatus/NCyearLeaving = '12'
						and translate(PupilStatus/LeavingDate,'-','') &lt;= $Post16MaxLearningDate 
						and count(./ProgrammeAims/ProgrammeAim/LearningAims/LearningAim
							[translate(LearningActualEndDate,'-','') &gt; $Post16PrevMaxLearningDate
							and translate(LearningActualEndDate,'-','') &lt;= $Post16MaxLearningDate
							and LearningAimStatus = '2' ] ) &gt;0 ] )				
					+ count(/Message/Pupils/PupilsNoLongerOnRoll/PupilNoLongerOnRoll
						[PupilStatus/NCyearLeaving = '13'
						and translate(PupilStatus/LeavingDate,'-','') &gt; $Post16MaxLearningDate
						and translate(PupilStatus/LeavingDate,'-','') &lt;= $ReferenceDate
						and count(./ProgrammeAims/ProgrammeAim/LearningAims/LearningAim
							[translate(LearningStartDate,'-','') &lt;= $Post16MaxLearningDate
							and translate(LearningActualEndDate,'-','') &gt; $Post16PrevMaxLearningDate
							and LearningAimStatus = '2' ] ) &gt;0 ] ) "/>
				<xsl:variable name="f33" select="count(/Message/Pupils/PupilsOnRoll/PupilOnRoll
					[PupilStatus/NCyearActual = '14' 
					and contains( ' C M F O ', concat(' ', PupilStatus/EnrolStatus, ' ') ) 
					and count(./ProgrammeAims/ProgrammeAim/LearningAims/LearningAim
						[translate(LearningActualEndDate,'-','') &lt;= $Post16MaxLearningDate
						and LearningAimStatus = '2' ] ) &gt;0 ] )				
				+ count(/Message/Pupils/PupilsNoLongerOnRoll/PupilNoLongerOnRoll
					[PupilStatus/NCyearLeaving = '13'
					and translate(PupilStatus/LeavingDate,'-','') &lt;= $Post16MaxLearningDate 
					and count(./ProgrammeAims/ProgrammeAim/LearningAims/LearningAim
						[translate(LearningActualEndDate,'-','') &gt; $Post16PrevMaxLearningDate
						and translate(LearningActualEndDate,'-','') &lt;= $Post16MaxLearningDate
						and LearningAimStatus = '2' ] ) &gt;0 ] )				
				+ count(/Message/Pupils/PupilsNoLongerOnRoll/PupilNoLongerOnRoll
					[PupilStatus/NCyearLeaving = '14'
					and translate(PupilStatus/LeavingDate,'-','') &gt; $Post16MaxLearningDate
					and translate(PupilStatus/LeavingDate,'-','') &lt;= $ReferenceDate
					and count(./ProgrammeAims/ProgrammeAim/LearningAims/LearningAim
						[translate(LearningStartDate,'-','') &lt;= $Post16MaxLearningDate
						and translate(LearningActualEndDate,'-','') &gt; $Post16PrevMaxLearningDate
						and LearningAimStatus = '2' ] ) &gt;0 ] ) "/>
				<xsl:variable name="f34" select="count(/Message/Pupils/PupilsNoLongerOnRoll/PupilNoLongerOnRoll
					[PupilStatus/NCyearLeaving = '14'
					and translate(PupilStatus/LeavingDate,'-','') &gt; $Post16PrevMaxLearningDate
					and translate(PupilStatus/LeavingDate,'-','') &lt;= $Post16MaxLearningDate
					and count(./ProgrammeAims/ProgrammeAim/LearningAims/LearningAim
						[translate(LearningStartDate,'-','') &lt;= $Post16MaxLearningDate
						and translate(LearningActualEndDate,'-','') &gt; $Post16PrevMaxLearningDate
						and LearningAimStatus = '2' ] ) &gt;0 ] ) "/>
				<xsl:variable name="f36" select="count(/Message/Pupils/PupilsOnRoll/PupilOnRoll
					[contains(' 12 13 ', concat(' ', PupilStatus/NCyearActual, ' ') ) 
					and contains( ' C M F O  ', concat(' ', PupilStatus/EnrolStatus, ' ') ) 
					and count(./ProgrammeAims/ProgrammeAim/LearningAims/LearningAim
						[translate(LearningActualEndDate,'-','') &lt;= $Post16MaxLearningDate
						and LearningAimStatus = '3' ] ) &gt;0 ] )				
				+ count(/Message/Pupils/PupilsNoLongerOnRoll/PupilNoLongerOnRoll
					[PupilStatus/NCyearLeaving = '12'
				and translate(PupilStatus/LeavingDate,'-','') &lt;= $Post16MaxLearningDate 
				and count(./ProgrammeAims/ProgrammeAim/LearningAims/LearningAim
					[translate(LearningActualEndDate,'-','') &gt; $Post16PrevMaxLearningDate
					and translate(LearningActualEndDate,'-','') &lt;= $Post16MaxLearningDate
					and LearningAimStatus = '3' ] ) &gt;0 ] )
				+ count(/Message/Pupils/PupilsNoLongerOnRoll/PupilNoLongerOnRoll
					[PupilStatus/NCyearLeaving = '13'
					and translate(PupilStatus/LeavingDate,'-','') &gt; $Post16MaxLearningDate
					and translate(PupilStatus/LeavingDate,'-','') &lt;= $ReferenceDate
					and count(./ProgrammeAims/ProgrammeAim/LearningAims/LearningAim
						[translate(LearningStartDate,'-','') &lt;= $Post16MaxLearningDate
						and translate(LearningActualEndDate,'-','') &gt; $Post16PrevMaxLearningDate
						and LearningAimStatus = '3' ] ) &gt;0 ] ) "/>
				<xsl:variable name="f37" select="count(/Message/Pupils/PupilsOnRoll/PupilOnRoll
					[PupilStatus/NCyearActual = '14' 
					and contains( ' C M F O ', concat(' ', PupilStatus/EnrolStatus, ' ') ) 
					and count(./ProgrammeAims/ProgrammeAim/LearningAims/LearningAim
						[translate(LearningActualEndDate,'-','') &lt;= $Post16MaxLearningDate
						and LearningAimStatus = '3' ] ) &gt;0 ] )				
				+ count(/Message/Pupils/PupilsNoLongerOnRoll/PupilNoLongerOnRoll
					[PupilStatus/NCyearLeaving = '13'
					and translate(PupilStatus/LeavingDate,'-','') &lt;= $Post16MaxLearningDate 
					and count(./ProgrammeAims/ProgrammeAim/LearningAims/LearningAim
						[translate(LearningActualEndDate,'-','') &gt; $Post16PrevMaxLearningDate
						and translate(LearningActualEndDate,'-','') &lt;= $Post16MaxLearningDate
						and LearningAimStatus = '3' ] ) &gt;0 ] )
				+ count(/Message/Pupils/PupilsNoLongerOnRoll/PupilNoLongerOnRoll
					[PupilStatus/NCyearLeaving = '14'
					and translate(PupilStatus/LeavingDate,'-','') &gt; $Post16MaxLearningDate
					and translate(PupilStatus/LeavingDate,'-','') &lt;= $ReferenceDate
					and count(./ProgrammeAims/ProgrammeAim/LearningAims/LearningAim
						[translate(LearningStartDate,'-','') &lt;= $Post16MaxLearningDate
						and translate(LearningActualEndDate,'-','') &gt; $Post16PrevMaxLearningDate
						and LearningAimStatus = '3' ] ) &gt;0 ] ) "/>
				<xsl:variable name="f38" select="count(/Message/Pupils/PupilsNoLongerOnRoll/PupilNoLongerOnRoll
					[PupilStatus/NCyearLeaving = '14'
					and translate(PupilStatus/LeavingDate,'-','') &gt;= $Post16PrevMaxLearningDate
					and translate(PupilStatus/LeavingDate,'-','') &lt;= $Post16MaxLearningDate
					and count(./ProgrammeAims/ProgrammeAim/LearningAims/LearningAim
						[translate(LearningStartDate,'-','') &lt;= $Post16MaxLearningDate
						and translate(LearningActualEndDate,'-','') &gt; $Post16PrevMaxLearningDate
						and LearningAimStatus = '3' ] ) &gt;0 ] ) "/>
				<xsl:variable name="f40" select="count(/Message/Pupils/PupilsOnRoll/PupilOnRoll
					[contains(' 12 13 ', concat(' ', PupilStatus/NCyearActual, ' ') ) 
					and contains( ' C M F O ', concat(' ', PupilStatus/EnrolStatus, ' ') ) 
					and count(./ProgrammeAims/ProgrammeAim/LearningAims/LearningAim
						[translate(LearningActualEndDate,'-','') &lt;= $Post16MaxLearningDate
						and LearningAimStatus = '4' ] ) &gt;0 ] )
				+ count(/Message/Pupils/PupilsNoLongerOnRoll/PupilNoLongerOnRoll
					[PupilStatus/NCyearLeaving = '12'
					and translate(PupilStatus/LeavingDate,'-','') &lt;= $Post16MaxLearningDate 
					and count(./ProgrammeAims/ProgrammeAim/LearningAims/LearningAim
						[translate(LearningActualEndDate,'-','') &gt; $Post16PrevMaxLearningDate
						and translate(LearningActualEndDate,'-','') &lt;= $Post16MaxLearningDate
						and LearningAimStatus = '4' ] ) &gt;0 ] )				
				+ count(/Message/Pupils/PupilsNoLongerOnRoll/PupilNoLongerOnRoll
					[PupilStatus/NCyearLeaving = '13'
					and translate(PupilStatus/LeavingDate,'-','') &gt; $Post16MaxLearningDate
					and translate(PupilStatus/LeavingDate,'-','') &lt;= $ReferenceDate
					and count(./ProgrammeAims/ProgrammeAim/LearningAims/LearningAim
						[translate(LearningStartDate,'-','') &lt;= $Post16MaxLearningDate
						and translate(LearningActualEndDate,'-','') &gt; $Post16PrevMaxLearningDate
						and LearningAimStatus = '4' ] ) &gt;0 ] ) "/>
				<xsl:variable name="f41" select="count(/Message/Pupils/PupilsOnRoll/PupilOnRoll
					[PupilStatus/NCyearActual = '14' 
					and contains( ' C M F O ', concat(' ', PupilStatus/EnrolStatus, ' ') ) 
					and count(./ProgrammeAims/ProgrammeAim/LearningAims/LearningAim
						[translate(LearningActualEndDate,'-','') &lt;= $Post16MaxLearningDate
						and LearningAimStatus = '4' ] ) &gt;0 ] )
				+ count(/Message/Pupils/PupilsNoLongerOnRoll/PupilNoLongerOnRoll
					[PupilStatus/NCyearLeaving = '13'
					and translate(PupilStatus/LeavingDate,'-','') &lt;= $Post16MaxLearningDate 
					and count(./ProgrammeAims/ProgrammeAim/LearningAims/LearningAim
						[translate(LearningActualEndDate,'-','') &gt; $Post16PrevMaxLearningDate
						and translate(LearningActualEndDate,'-','') &lt;= $Post16MaxLearningDate
						and LearningAimStatus = '4' ] ) &gt;0 ] )
				+ count(/Message/Pupils/PupilsNoLongerOnRoll/PupilNoLongerOnRoll
					[PupilStatus/NCyearLeaving = '14'
					and translate(PupilStatus/LeavingDate,'-','') &gt; $Post16MaxLearningDate
					and translate(PupilStatus/LeavingDate,'-','') &lt;= $ReferenceDate
					and count(./ProgrammeAims/ProgrammeAim/LearningAims/LearningAim
						[translate(LearningStartDate,'-','') &lt;= $Post16MaxLearningDate
						and translate(LearningActualEndDate,'-','') &gt; $Post16PrevMaxLearningDate
						and LearningAimStatus = '4' ] ) &gt;0 ] ) "/>
				<xsl:variable name="f42" select="count(/Message/Pupils/PupilsNoLongerOnRoll/PupilNoLongerOnRoll
					[PupilStatus/NCyearLeaving = '14'
					and translate(PupilStatus/LeavingDate,'-','') &gt; $Post16PrevMaxLearningDate
					and translate(PupilStatus/LeavingDate,'-','') &lt;= $Post16MaxLearningDate
					and count(./ProgrammeAims/ProgrammeAim/LearningAims/LearningAim
						[translate(LearningStartDate,'-','') &lt;= $Post16MaxLearningDate
						and translate(LearningActualEndDate,'-','') &gt; $Post16PrevMaxLearningDate
						and LearningAimStatus = '4' ] ) &gt;0 ] ) "/>
				<xsl:variable name="f44" select="count(/Message/Pupils/PupilsOnRoll/PupilOnRoll
					[contains(' 12 13 ', concat(' ', PupilStatus/NCyearActual, ' ') ) 
					and contains( ' C M F O ', concat(' ', PupilStatus/EnrolStatus, ' ') ) 
					and count(./ProgrammeAims/ProgrammeAim/LearningAims/LearningAim
						[translate(LearningStartDate,'-','') &lt;= $Post16MaxLearningDate
						and (string-length(LearningActualEndDate) = 0 
								or translate(LearningActualEndDate,'-','') &gt; $Post16PrevMaxLearningDate)						
						and contains($true, concat(' ', CoreAim, ' ' ) ) ] ) &gt;0 ] )
				+ count(/Message/Pupils/PupilsNoLongerOnRoll/PupilNoLongerOnRoll
					[PupilStatus/NCyearLeaving = '12'
					and translate(PupilStatus/LeavingDate,'-','') &lt;= $Post16MaxLearningDate 
					and count(./ProgrammeAims/ProgrammeAim/LearningAims/LearningAim
						[translate(LearningStartDate,'-','') &lt;= $Post16MaxLearningDate
						and translate(LearningActualEndDate,'-','') &gt; $Post16PrevMaxLearningDate
						and translate(LearningActualEndDate,'-','') &lt;= $Post16MaxLearningDate
						and contains($true, concat(' ', CoreAim, ' ' ) ) ] ) &gt;0 ] )
				+ count(/Message/Pupils/PupilsNoLongerOnRoll/PupilNoLongerOnRoll
					[PupilStatus/NCyearLeaving = '13'
					and translate(PupilStatus/LeavingDate,'-','') &gt; $Post16MaxLearningDate
					and translate(PupilStatus/LeavingDate,'-','') &lt;= $ReferenceDate
					and count(./ProgrammeAims/ProgrammeAim/LearningAims/LearningAim
						[translate(LearningStartDate,'-','') &lt;= $Post16MaxLearningDate
						and translate(LearningActualEndDate,'-','') &gt; $Post16PrevMaxLearningDate
						and translate(LearningActualEndDate,'-','') &lt;= $Post16MaxLearningDate
						and contains($true, concat(' ', CoreAim, ' ' ) ) ] ) &gt;0 ] ) "/>
				<xsl:variable name="f45" select="count(/Message/Pupils/PupilsOnRoll/PupilOnRoll
					[PupilStatus/NCyearActual = '14' 
					and contains( ' C M F O ', concat(' ', PupilStatus/EnrolStatus, ' ') ) 
					and count(./ProgrammeAims/ProgrammeAim/LearningAims/LearningAim
						[translate(LearningStartDate,'-','') &lt;= $Post16MaxLearningDate
						and (string-length(LearningActualEndDate) = 0 
								or translate(LearningActualEndDate,'-','') &gt; $Post16PrevMaxLearningDate)						
						and contains($true, concat(' ', CoreAim, ' ' ) ) ] ) &gt;0 ] )
				+ count(/Message/Pupils/PupilsNoLongerOnRoll/PupilNoLongerOnRoll
					[PupilStatus/NCyearLeaving = '13'
					and translate(PupilStatus/LeavingDate,'-','') &lt;= $Post16MaxLearningDate 
					and count(./ProgrammeAims/ProgrammeAim/LearningAims/LearningAim
						[translate(LearningStartDate,'-','') &lt;= $Post16MaxLearningDate
						and translate(LearningActualEndDate,'-','') &gt; $Post16PrevMaxLearningDate
						and translate(LearningActualEndDate,'-','') &lt;= $Post16MaxLearningDate
						and contains($true, concat(' ', CoreAim, ' ' ) ) ] ) &gt;0 ] )				
				+ count(/Message/Pupils/PupilsNoLongerOnRoll/PupilNoLongerOnRoll
					[PupilStatus/NCyearLeaving = '14'
					and translate(PupilStatus/LeavingDate,'-','') &gt; $Post16MaxLearningDate
					and translate(PupilStatus/LeavingDate,'-','') &lt;= $ReferenceDate
					and count(./ProgrammeAims/ProgrammeAim/LearningAims/LearningAim
						[translate(LearningStartDate,'-','') &lt;= $Post16MaxLearningDate
						and translate(LearningActualEndDate,'-','') &gt; $Post16PrevMaxLearningDate
						and translate(LearningActualEndDate,'-','') &lt;= $Post16MaxLearningDate
						and contains($true, concat(' ', CoreAim, ' ' ) ) ] ) &gt;0 ] ) "/>
				<xsl:variable name="f46" select="count(/Message/Pupils/PupilsNoLongerOnRoll/PupilNoLongerOnRoll
					[PupilStatus/NCyearLeaving = '14'
					and translate(PupilStatus/LeavingDate,'-','') &lt;= $Post16MaxLearningDate
					and count(./ProgrammeAims/ProgrammeAim/LearningAims/LearningAim
						[translate(LearningStartDate,'-','') &lt;= $Post16MaxLearningDate
						and translate(LearningActualEndDate,'-','') &gt; $Post16PrevMaxLearningDate
						and translate(LearningActualEndDate,'-','') &lt;= $Post16MaxLearningDate
						and contains($true, concat(' ', CoreAim, ' ' ) ) ] ) &gt;0 ] ) "/>
				<table class="summaryreport" border="1">
					<tr>
						<th>NC Year Group in 2022/23 academic year. For on<br/>roll pupils this is derived from their NC Year<br/>Group on Census Day</th>
						<th>Year 12</th>
						<th>Year 13</th>
						<th>Year 14</th>
						<th>Total</th>
					</tr>
					<tr>
						<td class="clsHeading">Number of learners with learning aims which were<br/>active in the previous academic year</td>
						<td class="clsNumber">
							<xsl:value-of select="$f28"/>
						</td>
						<td class="clsNumber">
							<xsl:value-of select="$f29"/>
						</td>
						<td class="clsNumber">
							<xsl:value-of select="$f30"/>
						</td>
						<td class="clsNumber">
							<xsl:value-of select="$f28 + $f29 + $f30"/>
						</td>
					</tr>
					<tr>
						<td colspan="5" class="clsHeading">Of which:</td>
					</tr>
					<tr>
						<td class="clsHeading">Number of learners that completed at least one<br/>learning aim</td>
						<td class="clsNumber">
							<xsl:value-of select="$f32"/>
						</td>
						<td class="clsNumber">
							<xsl:value-of select="$f33"/>
						</td>
						<td class="clsNumber">
							<xsl:value-of select="$f34"/>
						</td>
						<td class="clsNumber">
							<xsl:value-of select="$f32 + $f33 + $f34"/>
						</td>
					</tr>
					<tr>
						<td class="clsHeading">Number of learners that withdrew from at least one<br/>learning aim</td>
						<td class="clsNumber">
							<xsl:value-of select="$f36"/>
						</td>
						<td class="clsNumber">
							<xsl:value-of select="$f37"/>
						</td>
						<td class="clsNumber">
							<xsl:value-of select="$f38"/>
						</td>
						<td class="clsNumber">
							<xsl:value-of select="$f36 + $f37 + $f38"/>
						</td>
					</tr>
					<tr>
						<td class="clsHeading">Number of learners that transferred from at least one<br/>learning aim</td>
						<td class="clsNumber">
							<xsl:value-of select="$f40"/>
						</td>
						<td class="clsNumber">
							<xsl:value-of select="$f41"/>
						</td>
						<td class="clsNumber">
							<xsl:value-of select="$f42"/>
						</td>
						<td class="clsNumber">
							<xsl:value-of select="$f40 + $f41 + $f42"/>
						</td>
					</tr>
					<tr>
						<td class="clsHeading">Number of learners with a core aim (vocational<br/>qualifications only) in the previous academic year</td>
						<td class="clsNumber">
							<xsl:value-of select="$f44"/>
						</td>
						<td class="clsNumber">
							<xsl:value-of select="$f45"/>
						</td>
						<td class="clsNumber">
							<xsl:value-of select="$f46"/>
						</td>
						<td class="clsNumber">
							<xsl:value-of select="$f44 + $f45 + $f46"/>
						</td>
					</tr>
				</table>
				<br/>
				<p class="clsFootnote">Note: For on roll pupils the NC Year Group for the previous academic year is derived from their NC year Group on Census Day. So any learners that did not progress up a National Curriculum Year 
						Group from NC year 13 or 14 will be shown in the year group below the one they are in on census Day. For example, if they were in NC Year Group 13 for the academic year 2022-23 and on census day were still in NC 
						Year Group 13, they would be included in the column labelled Year 12 in this table. 
						<br/>
					<br/> In the case of pupils that were previously in NC year group 12 and are currently still in NC year group 12, their learning aims will be included
						in the column labelled Year 12 in this table. 
						<br/>
					<br/> This does not mean that they have been incorrectly recorded in the MIS merely that it is not possible to 
						automatically allocate them to the correct year group in this table.</p>
			</xsl:otherwise>
		</xsl:choose>
		
		
		
		<xsl:choose>
			<xsl:when test="$term = 'AUT' ">
				<h2>Table 29: Post 16 learning aims - number of learning aims that started this academic year - from 1 August <xsl:value-of select="$etyear"/> or continued from previous academic year(s) [for: secondary, all-through and PRU]</h2>
			</xsl:when>
			<xsl:when test="$term = 'SPR' or $term = 'SUM' ">
				<h2>Table 29: Post 16 learning aims - number of learning aims that started this academic year - from 1 August <xsl:value-of select="$etyear - 1"/> or continued from previous academic year(s) [for: secondary, all-through and PRU]</h2>
			</xsl:when>
		</xsl:choose>
		<xsl:choose>
			<xsl:when test="$term != 'AUT' ">
				<p class="clsFootnote">This table does not apply to the <xsl:value-of select="$thiscensus"/> census as learning aims data is only collected in the autumn census.</p>
			</xsl:when>
			<xsl:when test="not(contains( ' SS PR AT ', concat(' ', /Message/School/SchoolCharacteristics/Phase, ' ' ) ) )"/>
			<xsl:when test="not(contains(' 12 13 14 ', concat(' ', /Message/School/SchoolCharacteristics/HighestNCyear, ' ')))"/>
			<xsl:otherwise>
<!--				<xsl:variable name="LearningAimsCurrentYear" select="//ProgrammeAims/ProgrammeAim/LearningAims/LearningAim
					[contains(' 12 13 14 ', concat(' ', ../../PupilStatus/NCyearActual, ' ') ) 
					and contains(' C F M O ', concat(' ', ../../PupilStatus/EnrolStatus, ' ') )
					and translate(LearningStartDate, '-','') &gt;= $Post16MaxLearningDate]"/>
				<xsl:variable name="LearningAimsPreviousYear" select="//ProgrammeAims/ProgrammeAim/LearningAims/LearningAim
					[contains(' 12 13 14 ', concat(' ', ../../PupilStatus/NCyearActual, ' ') ) 
					and contains(' C F M O ', concat(' ', ../../PupilStatus/EnrolStatus, ' ') )
					and translate(LearningStartDate, '-','') &lt;= $Post16MaxLearningDate
					and (string-length(LearningActualEndDate) = 0
						or translate(LearningActualEndDate, '-','') &gt; $Post16MaxLearningDate) ] "/>	-->						
<!--			<xsl:variable name="f48" select="count($LearningAimsCurrentYear[ ../../PupilStatus/NCyearActual='12'] )"/>	
				<xsl:variable name="f49" select="count($LearningAimsCurrentYear[ ../../PupilStatus/NCyearActual='13'] )"/>	
				<xsl:variable name="f50" select="count($LearningAimsCurrentYear[ ../../PupilStatus/NCyearActual='14'] )"/>	-->
				<xsl:variable name="f48" select="
					count(/Message/Pupils/PupilsOnRoll/PupilOnRoll [contains(' 12 ', concat(' ', PupilStatus/NCyearActual, ' ') ) and contains(' C F M O ', concat(' ', PupilStatus/EnrolStatus, ' ') ) ]
						  /ProgrammeAims/ProgrammeAim/LearningAims/LearningAim[translate(LearningStartDate,'-','') &gt; $Post16MaxLearningDate
							and (LearningActualEndDate = '' or not(LearningActualEndDate) or translate(LearningActualEndDate,'-','') &gt; $Post16PrevMaxLearningDate) ] )"/>
							
				<xsl:variable name="f49" select="
					count(/Message/Pupils/PupilsOnRoll/PupilOnRoll [contains(' 13 ', concat(' ', PupilStatus/NCyearActual, ' ') ) and contains(' C F M O ', concat(' ', PupilStatus/EnrolStatus, ' ') ) ]
						  /ProgrammeAims/ProgrammeAim/LearningAims/LearningAim[translate(LearningStartDate,'-','') &gt; $Post16MaxLearningDate
							and (LearningActualEndDate = '' or not(LearningActualEndDate) or translate(LearningActualEndDate,'-','') &gt; $Post16PrevMaxLearningDate) ] )"/>
							
				<xsl:variable name="f50" select="
					count(/Message/Pupils/PupilsOnRoll/PupilOnRoll [contains(' 14 ', concat(' ', PupilStatus/NCyearActual, ' ') ) and contains(' C F M O ', concat(' ', PupilStatus/EnrolStatus, ' ') ) ]
						  /ProgrammeAims/ProgrammeAim/LearningAims/LearningAim[translate(LearningStartDate,'-','') &gt; $Post16MaxLearningDate
							and (LearningActualEndDate = '' or not(LearningActualEndDate) or translate(LearningActualEndDate,'-','') &gt; $Post16PrevMaxLearningDate) ] )"/>				
				<!--F51: Count learning aims for pupils off roll where LeavingDate (100064) is between 1 August 2016 and Reference Date and where LearningStartDate (100256) on or after 1 August 2017 and LearningActualEndDate (100258) is between 1 August 2017 and Reference Date-->
				<xsl:variable name="f51" select="
					count(/Message/Pupils/PupilsNoLongerOnRoll/PupilNoLongerOnRoll/ProgrammeAims/ProgrammeAim/LearningAims/LearningAim[translate(LearningStartDate, '-','') &gt; $Post16MaxLearningDate
							and translate(LearningActualEndDate, '-','') &gt; $Post16MaxLearningDate 
							and translate(LearningActualEndDate, '-','') &lt;= $ReferenceDate
							and translate(../../../../PupilStatus/LeavingDate, '-','') &gt; ($Post16MaxLearningDate - 10000)  
							and translate(../../../../PupilStatus/LeavingDate, '-','') &lt;= $ReferenceDate] )"/>
<!--			<xsl:variable name="f53" select="count($LearningAimsPreviousYear[ ../../PupilStatus/NCyearActual='12'] )"/>
				<xsl:variable name="f54" select="count($LearningAimsPreviousYear[ ../../PupilStatus/NCyearActual='13'] )"/>
				<xsl:variable name="f55" select="count($LearningAimsPreviousYear[ ../../PupilStatus/NCyearActual='14'] )"/>	-->
				<xsl:variable name="f53" select="
					count(/Message/Pupils/PupilsOnRoll/PupilOnRoll [contains(' 12 ', concat(' ', PupilStatus/NCyearActual, ' ') ) and contains(' C F M O ', concat(' ', PupilStatus/EnrolStatus, ' ') ) ]	
						  /ProgrammeAims/ProgrammeAim/LearningAims/LearningAim[translate(LearningStartDate,'-','') &lt;= $Post16MaxLearningDate
							and (LearningActualEndDate = '' or not(LearningActualEndDate) or translate(LearningActualEndDate,'-','') &gt; $Post16PrevMaxLearningDate) ] )"/>
							
				<xsl:variable name="f54" select="
					count(/Message/Pupils/PupilsOnRoll/PupilOnRoll [contains(' 13 ', concat(' ', PupilStatus/NCyearActual, ' ') ) and contains(' C F M O ', concat(' ', PupilStatus/EnrolStatus, ' ') ) ]
						  /ProgrammeAims/ProgrammeAim/LearningAims/LearningAim[translate(LearningStartDate,'-','') &lt;= $Post16MaxLearningDate
							and (LearningActualEndDate = '' or not(LearningActualEndDate) or translate(LearningActualEndDate,'-','') &gt; $Post16PrevMaxLearningDate) ] )"/>
							
				<xsl:variable name="f55" select="
					count(/Message/Pupils/PupilsOnRoll/PupilOnRoll [contains(' 14 ', concat(' ', PupilStatus/NCyearActual, ' ') ) and contains(' C F M O ', concat(' ', PupilStatus/EnrolStatus, ' ') ) ]
						  /ProgrammeAims/ProgrammeAim/LearningAims/LearningAim[translate(LearningStartDate,'-','') &lt;= $Post16MaxLearningDate
							and (LearningActualEndDate = '' or not(LearningActualEndDate) or translate(LearningActualEndDate,'-','') &gt; $Post16PrevMaxLearningDate) ] )"/>					
				<!--F56: Count learning aims for pupils off roll where LeavingDate (100064) is between 1  August 2017 and Reference Date and where LearningStartDate (100256) is before 1 August 2017 and LearningActualEndDate (100258) is between 1 August 2017 and Reference Date -->
				<xsl:variable name="f56" select="
					count(/Message/Pupils/PupilsNoLongerOnRoll/PupilNoLongerOnRoll/ProgrammeAims/ProgrammeAim/LearningAims/LearningAim[translate(LearningStartDate, '-','') &lt;= $Post16MaxLearningDate
						and translate(LearningActualEndDate, '-','') &gt; $Post16MaxLearningDate
						and translate(LearningActualEndDate, '-','') &lt;= $ReferenceDate
						and translate(../../../../PupilStatus/LeavingDate, '-','') &gt; $Post16MaxLearningDate
						and translate(../../../../PupilStatus/LeavingDate, '-','') &lt;= $ReferenceDate] )"/>
				<table class="summaryreport" border="1">
					<tr>
						<th colspan="1"/>
						<th colspan="3">On Roll</th>
						<th colspan="2"/>
					</tr>
					<tr>
						<th>NC Year Group in <xsl:value-of select="$etyear"/>/<xsl:value-of select="$etyear - 1999"/>
							<br/>academic year</th>
						<th>Year 12</th>
						<th>Year 13</th>
						<th>Year 14</th>
						<th>No longer on roll<br/>(i.e. left between the<br/>end of the previous<br/>academic year and<br/>Census Day)<br/>
						</th>
						<th>Total</th>
					</tr>
					<tr>
						<td class="clsHeading">Number of learning aims<br/>started from 1 August <xsl:value-of select="$etyear"/>
						</td>
						<td class="clsNumber">
							<xsl:value-of select="$f48"/>
						</td>
						<td class="clsNumber">
							<xsl:value-of select="$f49"/>
						</td>
						<td class="clsNumber">
							<xsl:value-of select="$f50"/>
						</td>
						<td class="clsNumber">
							<xsl:value-of select="$f51"/>
						</td>
						<td class="clsNumber">
							<xsl:value-of select="$f48 + $f49 + $f50 + $f51"/>
						</td>
					</tr>
					<tr>
						<td class="clsHeading">Number of learning aims that<br/>continued from previous<br/>academic year(s)</td>
						<td class="clsNumber">
							<xsl:value-of select="$f53"/>
						</td>
						<td class="clsNumber">
							<xsl:value-of select="$f54"/>
						</td>
						<td class="clsNumber">
							<xsl:value-of select="$f55"/>
						</td>
						<td class="clsNumber">
							<xsl:value-of select="$f56"/>
						</td>
						<td class="clsNumber">
							<xsl:value-of select="$f53 + $f54 + $f55 + $f56"/>
						</td>
					</tr>
				</table>
				<p class="clsFootnote">Note: These may include some learning aims that were completed or for learners who transferred or withdrew from learning before Census Day.</p>
			</xsl:otherwise>
		</xsl:choose>
		
		
		<xsl:choose>
			<xsl:when test="$term = 'AUT' ">
				<h2>Table 30: Post 16 Learning Aims - Number of learning aims which were active in the previous academic year from 1 August <xsl:value-of select="$etyear - 1"/> to 31 July <xsl:value-of select="$etyear"/> [For: Secondary, all-through and PRU]</h2>
			</xsl:when>
			<xsl:when test="$term = 'SPR' or $term = 'SUM' ">
				<h2>Table 30: Post 16 Learning Aims - Number of learning aims which were active in the previous academic year from 1 August <xsl:value-of select="$etyear - 2"/> to 31 July <xsl:value-of select="$etyear - 1"/> [For: Secondary, all-through and PRU]</h2>
			</xsl:when>
		</xsl:choose>
		<xsl:choose>
			<xsl:when test="$term != 'AUT' ">
				<p class="clsFootnote">This table does not apply to the <xsl:value-of select="$thiscensus"/> census as learning aims data is only collected in the autumn census.</p>
			</xsl:when>
			<xsl:when test="not(contains( ' SS PR AT ', concat(' ', /Message/School/SchoolCharacteristics/Phase, ' ' ) ) )"/>
			<xsl:when test="/Message/School/SchoolCharacteristics/HighestNCyear &lt;12"/>
			<xsl:otherwise>
				<xsl:variable name="f58" select="count(/Message/Pupils/PupilsOnRoll/PupilOnRoll
					[contains(' 12 13 ', concat(' ', PupilStatus/NCyearActual, ' ') ) 
					and contains( ' C M F O ', concat(' ', PupilStatus/EnrolStatus, ' ') ) ]/ProgrammeAims/ProgrammeAim/LearningAims/LearningAim
						[translate(LearningStartDate,'-','') &lt;= $Post16MaxLearningDate
						and (LearningActualEndDate = '' 
							or not(LearningActualEndDate) 
							or translate(LearningActualEndDate,'-','') &gt; $Post16PrevMaxLearningDate) ] ) 
					+ count(/Message/Pupils/PupilsNoLongerOnRoll/PupilNoLongerOnRoll
						[PupilStatus/NCyearLeaving = '12'
						and translate(PupilStatus/LeavingDate,'-','') &lt;= $Post16MaxLearningDate]/ProgrammeAims/ProgrammeAim/LearningAims/LearningAim
						[translate(LearningStartDate,'-','') &lt;= $Post16MaxLearningDate
							and translate(LearningActualEndDate,'-','') &gt; $Post16PrevMaxLearningDate
							and translate(LearningActualEndDate,'-','') &lt;= $Post16MaxLearningDate] ) 
					+ count(/Message/Pupils/PupilsNoLongerOnRoll/PupilNoLongerOnRoll
						[PupilStatus/NCyearLeaving = '13'
						and translate(PupilStatus/LeavingDate,'-','') &gt; $Post16MaxLearningDate
						and translate(PupilStatus/LeavingDate,'-','') &lt;= $ReferenceDate]/ProgrammeAims/ProgrammeAim/LearningAims/LearningAim
							[translate(LearningStartDate,'-','') &lt;= $Post16MaxLearningDate
							and translate(LearningActualEndDate,'-','') &gt; $Post16PrevMaxLearningDate ] )"/>
				<xsl:variable name="f59" select="count(/Message/Pupils/PupilsOnRoll/PupilOnRoll
					[PupilStatus/NCyearActual = '14' 
					and contains( ' C M F O ', concat(' ', PupilStatus/EnrolStatus, ' ') ) ]/ProgrammeAims/ProgrammeAim/LearningAims/LearningAim
						[translate(LearningStartDate,'-','') &lt;= $Post16MaxLearningDate
						and (LearningActualEndDate = '' 
							or not(LearningActualEndDate) 
							or translate(LearningActualEndDate,'-','') &gt; $Post16PrevMaxLearningDate) ] )				
					+ count(/Message/Pupils/PupilsNoLongerOnRoll/PupilNoLongerOnRoll
						[PupilStatus/NCyearLeaving = '13'				
						and translate(PupilStatus/LeavingDate,'-','') &lt;= $Post16MaxLearningDate]/ProgrammeAims/ProgrammeAim/LearningAims/LearningAim
							[translate(LearningStartDate,'-','') &lt;= $Post16MaxLearningDate
								and translate(LearningActualEndDate,'-','') &gt; $Post16PrevMaxLearningDate
								and translate(LearningActualEndDate,'-','') &lt;= $Post16MaxLearningDate ] )				
					+ count(/Message/Pupils/PupilsNoLongerOnRoll/PupilNoLongerOnRoll
						[PupilStatus/NCyearLeaving = '14'
						and translate(PupilStatus/LeavingDate,'-','') &gt; $Post16MaxLearningDate
						and translate(PupilStatus/LeavingDate,'-','') &lt;= $ReferenceDate]/ProgrammeAims/ProgrammeAim/LearningAims/LearningAim
							[translate(LearningStartDate,'-','') &lt;= $Post16MaxLearningDate
							and translate(LearningActualEndDate,'-','') &gt; $Post16PrevMaxLearningDate] ) "/>
				<xsl:variable name="f60" select="count(/Message/Pupils/PupilsNoLongerOnRoll/PupilNoLongerOnRoll
					[PupilStatus/NCyearLeaving = '14'
					and translate(PupilStatus/LeavingDate,'-','') &lt;= $Post16MaxLearningDate
					and translate(PupilStatus/LeavingDate,'-','') &gt;= $Post16PrevMaxLearningDate]/ProgrammeAims/ProgrammeAim/LearningAims/LearningAim
						[translate(LearningStartDate,'-','') &lt;= $Post16MaxLearningDate
					and translate(LearningActualEndDate,'-','') &gt; $Post16PrevMaxLearningDate
					and translate(LearningActualEndDate,'-','') &lt;= $ReferenceDate] ) "/>
				<xsl:variable name="f62" select="count(/Message/Pupils/PupilsOnRoll/PupilOnRoll
					[contains(' 12 13 ', concat(' ', PupilStatus/NCyearActual, ' ') ) 
					and contains( ' C M F O ', concat(' ', PupilStatus/EnrolStatus, ' ') ) ]/ProgrammeAims/ProgrammeAim/LearningAims/LearningAim
						[translate(LearningActualEndDate,'-','') &gt; $Post16PrevMaxLearningDate
					and translate(LearningActualEndDate,'-','') &lt;= $Post16MaxLearningDate
					and LearningAimStatus = '2' ] )
					+ count(/Message/Pupils/PupilsNoLongerOnRoll/PupilNoLongerOnRoll
						[PupilStatus/NCyearLeaving = '12'
						and translate(PupilStatus/LeavingDate,'-','') &lt;= $Post16MaxLearningDate]/ProgrammeAims/ProgrammeAim/LearningAims/LearningAim
							[translate(LearningActualEndDate,'-','') &gt; $Post16PrevMaxLearningDate
							and translate(LearningActualEndDate,'-','') &lt;= $Post16MaxLearningDate
							and LearningAimStatus = '2' ] )				
					+ count(/Message/Pupils/PupilsNoLongerOnRoll/PupilNoLongerOnRoll
						[PupilStatus/NCyearLeaving = '13'
						and translate(PupilStatus/LeavingDate,'-','') &gt; $Post16MaxLearningDate
						and translate(PupilStatus/LeavingDate,'-','') &lt;= $ReferenceDate]/ProgrammeAims/ProgrammeAim/LearningAims/LearningAim
							[translate(LearningStartDate,'-','') &lt;= $Post16MaxLearningDate
							and translate(LearningActualEndDate,'-','') &gt; $Post16PrevMaxLearningDate
							and LearningAimStatus = '2' ] ) "/>
				<xsl:variable name="f63" select="count(/Message/Pupils/PupilsOnRoll/PupilOnRoll
					[PupilStatus/NCyearActual = '14' 
					and contains( ' C M F O ', concat(' ', PupilStatus/EnrolStatus, ' ') ) ]/ProgrammeAims/ProgrammeAim/LearningAims/LearningAim
						[translate(LearningActualEndDate,'-','') &gt; $Post16PrevMaxLearningDate
						and translate(LearningActualEndDate,'-','') &lt;= $Post16MaxLearningDate
						and LearningAimStatus = '2' ] )				
					+ count(/Message/Pupils/PupilsNoLongerOnRoll/PupilNoLongerOnRoll
						[PupilStatus/NCyearLeaving = '13'
						and translate(PupilStatus/LeavingDate,'-','') &lt;= $Post16MaxLearningDate]/ProgrammeAims/ProgrammeAim/LearningAims/LearningAim
							[translate(LearningActualEndDate,'-','') &gt; $Post16PrevMaxLearningDate
							and translate(LearningActualEndDate,'-','') &lt;= $Post16MaxLearningDate
							and LearningAimStatus = '2' ] )				
					+ count(/Message/Pupils/PupilsNoLongerOnRoll/PupilNoLongerOnRoll
						[PupilStatus/NCyearLeaving = '14'
						and translate(PupilStatus/LeavingDate,'-','') &gt; $Post16MaxLearningDate
						and translate(PupilStatus/LeavingDate,'-','') &lt;= $ReferenceDate]/ProgrammeAims/ProgrammeAim/LearningAims/LearningAim
							[translate(LearningStartDate,'-','') &lt;= $Post16MaxLearningDate
							and translate(LearningActualEndDate,'-','') &gt; $Post16PrevMaxLearningDate
							and LearningAimStatus = '2' ] ) "/>
				<xsl:variable name="f64" select="count(/Message/Pupils/PupilsNoLongerOnRoll/PupilNoLongerOnRoll
					[PupilStatus/NCyearLeaving = '14'
					and translate(PupilStatus/LeavingDate,'-','') &gt; $Post16PrevMaxLearningDate
					and translate(PupilStatus/LeavingDate,'-','') &lt;= $Post16MaxLearningDate]/ProgrammeAims/ProgrammeAim/LearningAims/LearningAim
						[translate(LearningActualEndDate,'-','') &gt; $Post16PrevMaxLearningDate
						and translate(LearningActualEndDate,'-','') &lt;= $Post16MaxLearningDate				
						and LearningAimStatus = '2' ] ) "/>
				<xsl:variable name="f66" select="count(/Message/Pupils/PupilsOnRoll/PupilOnRoll
					[contains(' 12 13 ', concat(' ', PupilStatus/NCyearActual, ' ') ) 
					and contains( ' C M F O ', concat(' ', PupilStatus/EnrolStatus, ' ') ) ]/ProgrammeAims/ProgrammeAim/LearningAims/LearningAim
						[translate(LearningActualEndDate,'-','') &gt; $Post16PrevMaxLearningDate
						and translate(LearningActualEndDate,'-','') &lt;= $Post16MaxLearningDate
						and LearningAimStatus = '3' ] )				
					+ count(/Message/Pupils/PupilsNoLongerOnRoll/PupilNoLongerOnRoll[PupilStatus/NCyearLeaving = '12'
						and translate(PupilStatus/LeavingDate,'-','') &lt;= $Post16MaxLearningDate]/ProgrammeAims/ProgrammeAim/LearningAims/LearningAim
							[translate(LearningActualEndDate,'-','') &gt; $Post16PrevMaxLearningDate
							and translate(LearningActualEndDate,'-','') &lt;= $Post16MaxLearningDate
							and LearningAimStatus = '3' ] )				
					+ count(/Message/Pupils/PupilsNoLongerOnRoll/PupilNoLongerOnRoll[PupilStatus/NCyearLeaving = '13'
						and translate(PupilStatus/LeavingDate,'-','') &gt; $Post16MaxLearningDate
						and translate(PupilStatus/LeavingDate,'-','') &lt;= $ReferenceDate]/ProgrammeAims/ProgrammeAim/LearningAims/LearningAim
							[translate(LearningStartDate,'-','') &lt;= $Post16MaxLearningDate
							and translate(LearningActualEndDate,'-','') &gt; $Post16PrevMaxLearningDate
							and LearningAimStatus = '3'] ) "/>
				<xsl:variable name="f67" select="count(/Message/Pupils/PupilsOnRoll/PupilOnRoll
					[PupilStatus/NCyearActual = '14' 
					and contains( ' C M F O ', concat(' ', PupilStatus/EnrolStatus, ' ') ) ]/ProgrammeAims/ProgrammeAim/LearningAims/LearningAim
						[translate(LearningActualEndDate,'-','') &gt; $Post16PrevMaxLearningDate
						and translate(LearningActualEndDate,'-','') &lt;= $Post16MaxLearningDate
						and LearningAimStatus = '3' ] )				
					+ count(/Message/Pupils/PupilsNoLongerOnRoll/PupilNoLongerOnRoll
						[PupilStatus/NCyearLeaving = '13'
						and translate(PupilStatus/LeavingDate,'-','') &lt;= $Post16MaxLearningDate]/ProgrammeAims/ProgrammeAim/LearningAims/LearningAim
							[translate(LearningActualEndDate,'-','') &gt; $Post16PrevMaxLearningDate
							and translate(LearningActualEndDate,'-','') &lt;= $Post16MaxLearningDate
							and LearningAimStatus = '3' ] )				
					+ count(/Message/Pupils/PupilsNoLongerOnRoll/PupilNoLongerOnRoll
						[PupilStatus/NCyearLeaving = '14'
						and translate(PupilStatus/LeavingDate,'-','') &gt; $Post16MaxLearningDate
						and translate(PupilStatus/LeavingDate,'-','') &lt;= $ReferenceDate]/ProgrammeAims/ProgrammeAim/LearningAims/LearningAim
							[translate(LearningStartDate,'-','') &lt;= $Post16MaxLearningDate
							and translate(LearningActualEndDate,'-','') &gt; $Post16PrevMaxLearningDate
							and LearningAimStatus = '3' ] ) "/>
				<xsl:variable name="f68" select="count(/Message/Pupils/PupilsNoLongerOnRoll/PupilNoLongerOnRoll
					[PupilStatus/NCyearLeaving = '14'
					and translate(PupilStatus/LeavingDate,'-','') &gt; $Post16PrevMaxLearningDate
					and translate(PupilStatus/LeavingDate,'-','') &lt;= $Post16MaxLearningDate]
					/ProgrammeAims/ProgrammeAim/LearningAims/LearningAim
						[translate(LearningActualEndDate,'-','') &gt; $Post16PrevMaxLearningDate
						and translate(LearningActualEndDate,'-','') &lt;= $Post16MaxLearningDate				
						and LearningAimStatus = '3' ] ) "/>
				<xsl:variable name="f70" select="count(/Message/Pupils/PupilsOnRoll/PupilOnRoll
					[contains(' 12 13 ', concat(' ', PupilStatus/NCyearActual, ' ') ) 
					and contains( ' C M F O ', concat(' ', PupilStatus/EnrolStatus, ' ') ) ]
					/ProgrammeAims/ProgrammeAim/LearningAims/LearningAim
						[translate(LearningActualEndDate,'-','') &gt; $Post16PrevMaxLearningDate
						and translate(LearningActualEndDate,'-','') &lt;= $Post16MaxLearningDate
						and LearningAimStatus = '4' ] )				
					+ count(/Message/Pupils/PupilsNoLongerOnRoll/PupilNoLongerOnRoll
					[PupilStatus/NCyearLeaving = '12'
						and translate(PupilStatus/LeavingDate,'-','') &lt;= $Post16MaxLearningDate]/ProgrammeAims/ProgrammeAim/LearningAims/LearningAim
						[translate(LearningActualEndDate,'-','') &gt; $Post16PrevMaxLearningDate
							and translate(LearningActualEndDate,'-','') &lt;= $Post16MaxLearningDate
							and LearningAimStatus = '4' ] )
					+ count(/Message/Pupils/PupilsNoLongerOnRoll/PupilNoLongerOnRoll
					[PupilStatus/NCyearLeaving = '13'
						and translate(PupilStatus/LeavingDate,'-','') &gt; $Post16MaxLearningDate
						and translate(PupilStatus/LeavingDate,'-','') &lt;= $ReferenceDate]/ProgrammeAims/ProgrammeAim/LearningAims/LearningAim
						[translate(LearningStartDate,'-','') &lt;= $Post16MaxLearningDate
							and translate(LearningActualEndDate,'-','') &gt; $Post16PrevMaxLearningDate
							and LearningAimStatus = '4' ] ) "/>
				<xsl:variable name="f71" select="count(/Message/Pupils/PupilsOnRoll/PupilOnRoll
					[PupilStatus/NCyearActual = '14' 
					and contains( ' C M F O ', concat(' ', PupilStatus/EnrolStatus, ' ') ) ]/ProgrammeAims/ProgrammeAim/LearningAims/LearningAim
						[translate(LearningActualEndDate,'-','') &gt; $Post16PrevMaxLearningDate
						and translate(LearningActualEndDate,'-','') &lt;= $Post16MaxLearningDate
						and LearningAimStatus = '4' ] )				
					+ count(/Message/Pupils/PupilsNoLongerOnRoll/PupilNoLongerOnRoll
						[PupilStatus/NCyearLeaving = '13'
						and translate(PupilStatus/LeavingDate,'-','') &lt;= $Post16MaxLearningDate]/ProgrammeAims/ProgrammeAim/LearningAims/LearningAim
							[translate(LearningActualEndDate,'-','') &gt; $Post16PrevMaxLearningDate
							and translate(LearningActualEndDate,'-','') &lt;= $Post16MaxLearningDate
							and LearningAimStatus = '4' ]	)				
					+	count(/Message/Pupils/PupilsNoLongerOnRoll/PupilNoLongerOnRoll
						[PupilStatus/NCyearLeaving = '14'
						and translate(PupilStatus/LeavingDate,'-','') &gt; $Post16MaxLearningDate
						and translate(PupilStatus/LeavingDate,'-','') &lt;= $ReferenceDate]/ProgrammeAims/ProgrammeAim/LearningAims/LearningAim
							[translate(LearningStartDate,'-','') &lt;= $Post16MaxLearningDate
							and translate(LearningActualEndDate,'-','') &gt; $Post16PrevMaxLearningDate
							and LearningAimStatus = '4' ] ) "/>
				<xsl:variable name="f72" select="count(/Message/Pupils/PupilsNoLongerOnRoll/PupilNoLongerOnRoll
					[PupilStatus/NCyearLeaving = '14'
					and translate(PupilStatus/LeavingDate,'-','') &gt; $Post16PrevMaxLearningDate
					and translate(PupilStatus/LeavingDate,'-','') &lt;= $Post16MaxLearningDate]/ProgrammeAims/ProgrammeAim/LearningAims/LearningAim
						[translate(LearningActualEndDate,'-','') &gt; $Post16PrevMaxLearningDate
							and translate(LearningActualEndDate,'-','') &lt;= $Post16MaxLearningDate				
							and LearningAimStatus = '4' ] ) "/>
				<table class="summaryreport" border="1">
					<tr>
						<!--<th>NC Year Group in 2022/23 academic year. For on<br/>roll pupils this is derived from their NC Year<br/>Group on Census Day</th>-->
						<th>NC Year Group in <xsl:value-of select="$etyear - 1"/>/<xsl:value-of select="$etyear - 2000"/> academic year. For on<br/>roll pupils this is derived from their NC Year<br/>Group on Census Day</th>						
						<th>Year 12</th>
						<th>Year 13</th>
						<th>Year 14</th>
						<th>Total</th>
					</tr>
					<tr>
						<td class="clsHeading">Number of learning aims which were active in<br/>the previous academic year</td>
						<td class="clsNumber">
							<xsl:value-of select="$f58"/>
						</td>
						<td class="clsNumber">
							<xsl:value-of select="$f59"/>
						</td>
						<td class="clsNumber">
							<xsl:value-of select="$f60"/>
						</td>
						<td class="clsNumber">
							<xsl:value-of select="$f58 + $f59 + $f60"/>
						</td>
					</tr>
					<tr>
						<!--<td colspan="5" class="clsHeading">Of which during the 2022/23 academic year</td>-->
						<td colspan="5" class="clsHeading">Of which during the <xsl:value-of select="$etyear - 1"/>/<xsl:value-of select="$etyear - 2000"/> academic year</td>
					</tr>
					<tr>
						<td class="clsHeading">Number completed</td>
						<td class="clsNumber">
							<xsl:value-of select="$f62"/>
						</td>
						<td class="clsNumber">
							<xsl:value-of select="$f63"/>
						</td>
						<td class="clsNumber">
							<xsl:value-of select="$f64"/>
						</td>
						<td class="clsNumber">
							<xsl:value-of select="$f62 + $f63 + $f64"/>
						</td>
					</tr>
					<tr>
						<td class="clsHeading">Number withdrawn from</td>
						<td class="clsNumber">
							<xsl:value-of select="$f66"/>
						</td>
						<td class="clsNumber">
							<xsl:value-of select="$f67"/>
						</td>
						<td class="clsNumber">
							<xsl:value-of select="$f68"/>
						</td>
						<td class="clsNumber">
							<xsl:value-of select="$f66 + $f67 + $f68"/>
						</td>
					</tr>
					<tr>
						<td class="clsHeading">Number transferred from</td>
						<td class="clsNumber">
							<xsl:value-of select="$f70"/>
						</td>
						<td class="clsNumber">
							<xsl:value-of select="$f71"/>
						</td>
						<td class="clsNumber">
							<xsl:value-of select="$f72"/>
						</td>
						<td class="clsNumber">
							<xsl:value-of select="$f70 + $f71 + $f72"/>
						</td>
					</tr>
				</table>
				<p class="clsFootnote">Note: For on roll pupils the NC year group for the previous academic year is derived from their NC year group on census day. Any learning aims for learners that did not progress up a national curriculum year 
					group from NC year 13 or 14 will be shown in the year group below the one the learners are in on census day. For example, if learners were in NC year group 13 for the academic year <xsl:value-of select="$etyear - 1"/>-<xsl:value-of select="$etyear - 2000"/> and on census day were still in NC year group 13, 
					their learning aims would be included in the column labelled Year 12 in this table. <br/>
					<br/>In the case of pupils that were previously in NC year group 12 and are currently still in NC year group 12, their learning aims will be included in the column labelled Year 12 in this table.<br/>
					<br/> This does not mean that the learning aims have been incorrectly recorded in the MIS merely that it is not possible to automatically allocate them to the correct year group in this table.</p>
			</xsl:otherwise>
		</xsl:choose>


		<h2>Table 31: Maths and English prior attainment (for block 2 disadvantage funding) [For: Secondary, all-through and PRU]</h2>
		<xsl:choose>
			<xsl:when test="$term != 'AUT' ">
				<p class="clsFootnote">This table does not apply to the <xsl:value-of select="$thiscensus"/> census as learning aims data is only collected in the autumn census.</p>
			</xsl:when>
			<xsl:when test="not(contains( ' SS AT PR ', concat(' ', /Message/School/SchoolCharacteristics/Phase, ' ' ) ) and /Message/School/SchoolCharacteristics/HighestNCyear &gt; 10) ">
				<p class="clsFootnote">Table 31 only applies to schools with a phase of SS, AT or PR</p>
			</xsl:when>
			<xsl:otherwise>
				<xsl:variable name="h1" select="
					  count(/Message/Pupils/PupilsOnRoll/PupilOnRoll[ PupilCharacteristics/MathsGCSEPriorAttainmentYear11 = 1 ] ) 
				    + count(/Message/Pupils/PupilsNoLongerOnRoll/PupilNoLongerOnRoll[ PupilCharacteristics/MathsGCSEPriorAttainmentYear11 = 1 ] )"/>
							
				<xsl:variable name="h2" select="
					  count(/Message/Pupils/PupilsOnRoll/PupilOnRoll[ PupilCharacteristics/EnglishGCSEPriorAttainmentYear11 = 1 ] ) 
					+ count(/Message/Pupils/PupilsNoLongerOnRoll/PupilNoLongerOnRoll[ PupilCharacteristics/EnglishGCSEPriorAttainmentYear11 = 1 ] )"/>
					
				<xsl:variable name="h4" select="
					  count(/Message/Pupils/PupilsOnRoll/PupilOnRoll[ PupilCharacteristics/MathsGCSEPriorAttainmentYear11 = 2 ] ) 
					+ count(/Message/Pupils/PupilsNoLongerOnRoll/PupilNoLongerOnRoll[ PupilCharacteristics/MathsGCSEPriorAttainmentYear11 = 2 ] )"/>
					
				<xsl:variable name="h5" select="
					  count(/Message/Pupils/PupilsOnRoll/PupilOnRoll[ PupilCharacteristics/EnglishGCSEPriorAttainmentYear11 = 2 ] ) 
					+ count(/Message/Pupils/PupilsNoLongerOnRoll/PupilNoLongerOnRoll[ PupilCharacteristics/EnglishGCSEPriorAttainmentYear11 = 2 ] )"/>
					
				<xsl:variable name="h7" select="
					  count(/Message/Pupils/PupilsOnRoll/PupilOnRoll[ PupilCharacteristics/MathsGCSEPriorAttainmentYear11 = 3 ] ) 
					+ count(/Message/Pupils/PupilsNoLongerOnRoll/PupilNoLongerOnRoll[ PupilCharacteristics/MathsGCSEPriorAttainmentYear11 = 3 ] )"/>
					
				<xsl:variable name="h8" select="
					  count(/Message/Pupils/PupilsOnRoll/PupilOnRoll[ PupilCharacteristics/EnglishGCSEPriorAttainmentYear11 = 3 ] ) 
					+ count(/Message/Pupils/PupilsNoLongerOnRoll/PupilNoLongerOnRoll[ PupilCharacteristics/EnglishGCSEPriorAttainmentYear11 = 3 ] )"/>
					
				<table class="summaryreport" border="1">
					<tr>
						<th>Maths and English prior attainment on census day</th>
						<th>Maths</th>
						<th>English</th>
						<!--<th>Total</th>-->
					</tr>
					<tr>
						<td class="clsHeading">Number of learners who achieved A*-C / 9 - 4 at end year 11</td>
						<td class="clsNumber">
							<xsl:value-of select="$h1"/>
						</td>
						<td class="clsNumber">
							<xsl:value-of select="$h2"/>
						</td>
					</tr>
					<tr>
						<td class="clsHeading">Number of learners who achieved A*-C / 9 - 4 since end year 11</td>
						<td class="clsNumber">
							<xsl:value-of select="$h4"/>
						</td>
						<td class="clsNumber">
							<xsl:value-of select="$h5"/>
						</td>
					</tr>
					<tr>
						<td class="clsHeading">Number of learners who have not achieved A*-C / 9 - 4</td>
						<td class="clsNumber">
							<xsl:value-of select="$h7"/>
						</td>
						<td class="clsNumber">
							<xsl:value-of select="$h8"/>
						</td>
					</tr>
				</table>
			</xsl:otherwise>
		</xsl:choose>


		<h2>Table 32: Maths and English funding exemptions [For: Secondary, all-through and PRU]</h2>
		<xsl:choose>
			<xsl:when test="$term != 'AUT' ">
				<p class="clsFootnote">This table does not apply to the <xsl:value-of select="$thiscensus"/> census as learning aims data is only collected in the autumn census.</p>
			</xsl:when>
			<xsl:when test="not(contains( ' SS AT PR ', concat(' ', /Message/School/SchoolCharacteristics/Phase, ' ' ) ) and /Message/School/SchoolCharacteristics/HighestNCyear &gt; 11) ">
				<p class="clsFootnote">Table 32 only applies to schools with a phase of SS, AT or PR</p>
			</xsl:when>
			<xsl:otherwise>
				<xsl:variable name="h10" select="count(/Message/Pupils/PupilsOnRoll/PupilOnRoll[ PupilCharacteristics/MathsGCSEFundingExemption = 'L' ] )"/>
				<!-- and contains( ' C F M O ', concat(' ', PupilStatus/EnrolStatus, ' ') ) -->
				<xsl:variable name="h11" select="count(/Message/Pupils/PupilsOnRoll/PupilOnRoll[ PupilCharacteristics/EnglishGCSEFundingExemption = 'L' ] )"/>
				<xsl:variable name="h12" select="count(/Message/Pupils/PupilsOnRoll/PupilOnRoll[ PupilCharacteristics/MathsGCSEFundingExemption = 'O' ] )"/>
				<xsl:variable name="h13" select="count(/Message/Pupils/PupilsOnRoll/PupilOnRoll[ PupilCharacteristics/EnglishGCSEFundingExemption = 'O' ] )"/>
				<xsl:variable name="h14" select="count(/Message/Pupils/PupilsOnRoll/PupilOnRoll[ PupilCharacteristics/MathsGCSEFundingExemption = 'U' ] )"/>
				<xsl:variable name="h15" select="count(/Message/Pupils/PupilsOnRoll/PupilOnRoll[ PupilCharacteristics/EnglishGCSEFundingExemption = 'U' ] )"/>
				<xsl:variable name="h16" select="count(/Message/Pupils/PupilsOnRoll/PupilOnRoll[ PupilCharacteristics/MathsGCSEFundingExemption = 'F' ] )"/>
				<xsl:variable name="h17" select="count(/Message/Pupils/PupilsOnRoll/PupilOnRoll[ PupilCharacteristics/EnglishGCSEFundingExemption = 'F' ] )"/>
				<xsl:variable name="h18" select="count(/Message/Pupils/PupilsOnRoll/PupilOnRoll[ PupilCharacteristics/MathsGCSEFundingExemption = 'N' ] )"/>
				<!-- PupilCharacteristics/MathsGCSEHighestPriorAttainment = 3 and -->
				<xsl:variable name="h19" select="count(/Message/Pupils/PupilsOnRoll/PupilOnRoll[ PupilCharacteristics/EnglishGCSEFundingExemption = 'N' ] )"/>
				<!-- PupilCharacteristics/EnglishGCSEHighestPriorAttainment = 3 and -->
				<table class="summaryreport" border="1">
					<tr>
						<th>Maths and English funding exemptions</th>
						<th>Maths</th>
						<th>English</th>
					</tr>
					<tr>
						<td class="clsHeading">Exempt due to learning difficulty</td>
						<td class="clsNumber">
							<xsl:value-of select="$h10"/>
						</td>
						<td class="clsNumber">
							<xsl:value-of select="$h11"/>
						</td>
					</tr>
					<tr>
						<td class="clsHeading">Exempt due to overseas qualification</td>
						<td class="clsNumber">
							<xsl:value-of select="$h12"/>
						</td>
						<td class="clsNumber">
							<xsl:value-of select="$h13"/>
						</td>
					</tr>
					<tr>
						<td class="clsHeading">Holds a UK equivalent qualification</td>
						<td class="clsNumber">
							<xsl:value-of select="$h14"/>
						</td>
						<td class="clsNumber">
							<xsl:value-of select="$h15"/>
						</td>
					</tr>
					<tr>
						<td class="clsHeading">Learner holds a pass grade for functional skills level 2</td>
						<td class="clsNumber">
							<xsl:value-of select="$h16"/>
						</td>
						<td class="clsNumber">
							<xsl:value-of select="$h17"/>
						</td>
					</tr>
					<tr>
						<td class="clsHeading">No exemption</td>
						<td class="clsNumber">
							<xsl:value-of select="$h18"/>
						</td>
						<td class="clsNumber">
							<xsl:value-of select="$h19"/>
						</td>
					</tr>
				</table>
			</xsl:otherwise>
		</xsl:choose>


		<h2>Table 33: Number of pupils by previous year planned learning; previous year planned employability, enrichment and pastoral; and, previous years total planned hours [for: secondary, all-through and PRU]</h2>
		<xsl:choose>
			<xsl:when test="$term != 'AUT' ">
				<p class="clsFootnote">This table does not apply to the <xsl:value-of select="$thiscensus"/> census as planned hours data is only collected in the autumn census.</p>
			</xsl:when>
			<xsl:when test="not(contains( ' SS AT PR ', concat(' ', /Message/School/SchoolCharacteristics/Phase, ' ' ) ) and /Message/School/SchoolCharacteristics/HighestNCyear &gt; 11)">
				<p class="clsFootnote">Table 33 only applies to schools with a phase of SS, AT or PR</p>
			</xsl:when>
			<xsl:otherwise>
				<xsl:variable name="h20" select="count(/Message/Pupils/PupilsOnRoll/PupilOnRoll[PupilCharacteristics/QualHrsPreviousYear &gt;= 580] )"/>
				<xsl:variable name="h21" select="count(/Message/Pupils/PupilsOnRoll/PupilOnRoll
																			[PupilCharacteristics/QualHrsPreviousYear &gt;= 485 
																			and PupilCharacteristics/QualHrsPreviousYear &lt;= 579] )	"/>
				<xsl:variable name="h22" select="count(/Message/Pupils/PupilsOnRoll/PupilOnRoll
																			[PupilCharacteristics/QualHrsPreviousYear &gt;= 385 
																			and PupilCharacteristics/QualHrsPreviousYear &lt;= 484] ) "/>
				<xsl:variable name="h23" select="count(/Message/Pupils/PupilsOnRoll/PupilOnRoll
																			[PupilCharacteristics/QualHrsPreviousYear &gt;= 300 
																			and PupilCharacteristics/QualHrsPreviousYear &lt;= 384] ) "/>
				<xsl:variable name="h24" select="count(/Message/Pupils/PupilsOnRoll/PupilOnRoll
																			[PupilCharacteristics/QualHrsPreviousYear &gt;= 1 
																			and PupilCharacteristics/QualHrsPreviousYear &lt;= 299] ) "/>
				<xsl:variable name="h25" select="count(/Message/Pupils/PupilsOnRoll/PupilOnRoll
																			[PupilCharacteristics/QualHrsPreviousYear = 0 
																				or ((PupilCharacteristics/QualHrsPreviousYear) 
																				and string-length(PupilCharacteristics/QualHrsPreviousYear) = 0)] ) "/>
				<xsl:variable name="h26" select="count(/Message/Pupils/PupilsOnRoll/PupilOnRoll
																			[PupilCharacteristics/Non_qualHrsPreviousYear &gt;= 580] ) "/>
				<xsl:variable name="h27" select="count(/Message/Pupils/PupilsOnRoll/PupilOnRoll
																			[PupilCharacteristics/Non_qualHrsPreviousYear &gt;= 485 
																			and PupilCharacteristics/Non_qualHrsPreviousYear &lt;= 579] )	"/>
				<xsl:variable name="h28" select="count(/Message/Pupils/PupilsOnRoll/PupilOnRoll
																			[PupilCharacteristics/Non_qualHrsPreviousYear &gt;= 385
																			and PupilCharacteristics/Non_qualHrsPreviousYear &lt;= 484] ) "/>
				<xsl:variable name="h29" select="count(/Message/Pupils/PupilsOnRoll/PupilOnRoll
																			[PupilCharacteristics/Non_qualHrsPreviousYear &gt;= 300 
																			and PupilCharacteristics/Non_qualHrsPreviousYear &lt;= 384] ) "/>
				<xsl:variable name="h30" select="count(/Message/Pupils/PupilsOnRoll/PupilOnRoll
																			[PupilCharacteristics/Non_qualHrsPreviousYear &gt;= 1 
																			and PupilCharacteristics/Non_qualHrsPreviousYear &lt;= 299] ) "/>
				<xsl:variable name="h31" select="count(/Message/Pupils/PupilsOnRoll/PupilOnRoll
																			[PupilCharacteristics/Non_qualHrsPreviousYear = 0 
																				or ((PupilCharacteristics/Non_qualHrsPreviousYear) 
																				and string-length(PupilCharacteristics/Non_qualHrsPreviousYear) = 0)] ) "/>
			<!-- The original variables for the total columns don't handle the scenario of a blank value i.e. QualHrsPreviousYear = 850 but Non_qualHrsPreviousYear = blank then the pupil isn't included in the count. 
				Needed to split into 3 individual to handle original scenario and then if either of the values are blank-->
				<xsl:variable name="h32a" select="count(/Message/Pupils/PupilsOnRoll/PupilOnRoll
																			[PupilCharacteristics/QualHrsPreviousYear + PupilCharacteristics/Non_qualHrsPreviousYear &gt;= 580] ) "/>																		
				<xsl:variable name="h32b" select="count(/Message/Pupils/PupilsOnRoll/PupilOnRoll
																			[PupilCharacteristics/QualHrsPreviousYear &gt;= 580
																			and (string-length(PupilCharacteristics/Non_qualHrsPreviousYear) = 0 and (PupilCharacteristics/Non_qualHrsPreviousYear))] ) "/>																			
				<xsl:variable name="h32c" select="count(/Message/Pupils/PupilsOnRoll/PupilOnRoll
																			[PupilCharacteristics/Non_qualHrsPreviousYear &gt;= 580
																			and (string-length(PupilCharacteristics/QualHrsPreviousYear) = 0 and (PupilCharacteristics/QualHrsPreviousYear))] ) "/>															
				
				<xsl:variable name="h33a" select="count(/Message/Pupils/PupilsOnRoll/PupilOnRoll
																			[PupilCharacteristics/QualHrsPreviousYear + PupilCharacteristics/Non_qualHrsPreviousYear &gt;= 485 
																			and PupilCharacteristics/QualHrsPreviousYear + PupilCharacteristics/Non_qualHrsPreviousYear &lt;= 579] ) "/>
				<xsl:variable name="h33b" select="count(/Message/Pupils/PupilsOnRoll/PupilOnRoll
																			[PupilCharacteristics/QualHrsPreviousYear &gt;= 485 
																			and PupilCharacteristics/QualHrsPreviousYear &lt;= 579
																			and (string-length(PupilCharacteristics/Non_qualHrsPreviousYear) = 0 and (PupilCharacteristics/Non_qualHrsPreviousYear))] ) "/>
				<xsl:variable name="h33c" select="count(/Message/Pupils/PupilsOnRoll/PupilOnRoll
																			[PupilCharacteristics/Non_qualHrsPreviousYear &gt;= 485 
																			and PupilCharacteristics/Non_qualHrsPreviousYear &lt;= 579
																			and (string-length(PupilCharacteristics/QualHrsPreviousYear) = 0 and (PupilCharacteristics/QualHrsPreviousYear))] ) "/>
																			
				<xsl:variable name="h34a" select="count(/Message/Pupils/PupilsOnRoll/PupilOnRoll
																			[PupilCharacteristics/QualHrsPreviousYear + PupilCharacteristics/Non_qualHrsPreviousYear &gt;= 385 
																			and PupilCharacteristics/QualHrsPreviousYear + PupilCharacteristics/Non_qualHrsPreviousYear &lt;= 484] ) "/>
				<xsl:variable name="h34b" select="count(/Message/Pupils/PupilsOnRoll/PupilOnRoll
																			[PupilCharacteristics/QualHrsPreviousYear &gt;= 385 
																			and PupilCharacteristics/QualHrsPreviousYear &lt;= 484
																			and (string-length(PupilCharacteristics/Non_qualHrsPreviousYear) = 0 and (PupilCharacteristics/Non_qualHrsPreviousYear))] ) "/>
				<xsl:variable name="h34c" select="count(/Message/Pupils/PupilsOnRoll/PupilOnRoll
																			[PupilCharacteristics/Non_qualHrsPreviousYear &gt;= 385 
																			and PupilCharacteristics/Non_qualHrsPreviousYear &lt;= 484
																			and (string-length(PupilCharacteristics/QualHrsPreviousYear) = 0 and (PupilCharacteristics/QualHrsPreviousYear))] ) "/>	
																						
				<xsl:variable name="h35a" select="count(/Message/Pupils/PupilsOnRoll/PupilOnRoll
																			[PupilCharacteristics/QualHrsPreviousYear + PupilCharacteristics/Non_qualHrsPreviousYear &gt;= 300 
																			and PupilCharacteristics/QualHrsPreviousYear + PupilCharacteristics/Non_qualHrsPreviousYear &lt;= 384] ) "/>
				<xsl:variable name="h35b" select="count(/Message/Pupils/PupilsOnRoll/PupilOnRoll
																			[PupilCharacteristics/QualHrsPreviousYear &gt;= 300 
																			and PupilCharacteristics/QualHrsPreviousYear &lt;= 384
																			and (string-length(PupilCharacteristics/Non_qualHrsPreviousYear) = 0 and (PupilCharacteristics/Non_qualHrsPreviousYear))] ) "/>
				<xsl:variable name="h35c" select="count(/Message/Pupils/PupilsOnRoll/PupilOnRoll
																			[PupilCharacteristics/Non_qualHrsPreviousYear &gt;= 300 
																			and PupilCharacteristics/Non_qualHrsPreviousYear &lt;= 384
																			and (string-length(PupilCharacteristics/QualHrsPreviousYear) = 0 and (PupilCharacteristics/QualHrsPreviousYear))] ) "/>
																			
				<xsl:variable name="h36a" select="count(/Message/Pupils/PupilsOnRoll/PupilOnRoll
																			[PupilCharacteristics/QualHrsPreviousYear + PupilCharacteristics/Non_qualHrsPreviousYear &gt;= 1 
																			and PupilCharacteristics/QualHrsPreviousYear + PupilCharacteristics/Non_qualHrsPreviousYear &lt;= 299] )"/>
				<xsl:variable name="h36b" select="count(/Message/Pupils/PupilsOnRoll/PupilOnRoll
																			[PupilCharacteristics/QualHrsPreviousYear &gt;= 1 
																			and PupilCharacteristics/QualHrsPreviousYear &lt;= 299
																			and (string-length(PupilCharacteristics/Non_qualHrsPreviousYear) = 0 and (PupilCharacteristics/Non_qualHrsPreviousYear))] ) "/>
				<xsl:variable name="h36c" select="count(/Message/Pupils/PupilsOnRoll/PupilOnRoll
																			[PupilCharacteristics/Non_qualHrsPreviousYear &gt;= 1 
																			and PupilCharacteristics/Non_qualHrsPreviousYear &lt;= 299
																			and (string-length(PupilCharacteristics/QualHrsPreviousYear) = 0 and (PupilCharacteristics/QualHrsPreviousYear))] ) "/>
				
				<xsl:variable name="h37a" select="count(/Message/Pupils/PupilsOnRoll/PupilOnRoll
																			[PupilCharacteristics/QualHrsPreviousYear + PupilCharacteristics/Non_qualHrsPreviousYear = 0] )"/>
				<xsl:variable name="h37b" select="count(/Message/Pupils/PupilsOnRoll/PupilOnRoll															
																			[PupilCharacteristics/QualHrsPreviousYear = 0 
																			and (string-length(PupilCharacteristics/Non_qualHrsPreviousYear) = 0 and (PupilCharacteristics/Non_qualHrsPreviousYear))] ) "/>
				<xsl:variable name="h37c" select="count(/Message/Pupils/PupilsOnRoll/PupilOnRoll															
																			[PupilCharacteristics/Non_qualHrsPreviousYear = 0 
																			and (string-length(PupilCharacteristics/QualHrsPreviousYear) = 0 and (PupilCharacteristics/QualHrsPreviousYear))] ) "/>
																			
				<xsl:variable name="h37d" select="count(/Message/Pupils/PupilsOnRoll/PupilOnRoll															
																			[(string-length(PupilCharacteristics/QualHrsPreviousYear) = 0 and (PupilCharacteristics/QualHrsPreviousYear))
																			and (string-length(PupilCharacteristics/Non_qualHrsPreviousYear) = 0 and (PupilCharacteristics/Non_qualHrsPreviousYear))] ) "/>
				<table class="summaryreport" border="1">
					<tr>
						<!--<th>Number of hours by 2021-2022 academic year band</th>-->
						<th>Number of hours by <xsl:value-of select="$etyear - 1"/>-<xsl:value-of select="$etyear"/> academic year band</th>
						
						<th>Number of pupils<br/>previous year planned learning<br/>hours</th>
						<th>Number of pupils<br/>previous year planned<br/>employability,<br/>enrichment and<br/>pastoral hours</th>
						<th>Number of pupils<br/>by total previous year<br/>planned hours</th>
					</tr>
					<tr>
						<td class="clsHeading">580+ hours</td>
						<td class="clsNumber">
							<xsl:value-of select="$h20"/>
						</td>
						<td class="clsNumber">
							<xsl:value-of select="$h26"/>
						</td>
						<td class="clsNumber">
							<xsl:value-of select="$h32a + $h32b + $h32c"/>
						</td>
					</tr>
					<tr>
						<td class="clsHeading">485 to 579 hours</td>
						<td class="clsNumber">
							<xsl:value-of select="$h21"/>
						</td>
						<td class="clsNumber">
							<xsl:value-of select="$h27"/>
						</td>
						<td class="clsNumber">
							<xsl:value-of select="$h33a + $h33b + $h33c"/>
						</td>
					</tr>
					<tr>
						<td class="clsHeading">385 to 484 hours</td>
						<td class="clsNumber">
							<xsl:value-of select="$h22"/>
						</td>
						<td class="clsNumber">
							<xsl:value-of select="$h28"/>
						</td>
						<td class="clsNumber">
							<xsl:value-of select="$h34a + $h34b + $h34c"/>
						</td>
					</tr>
					<tr>
						<td class="clsHeading">300 to 384 hours</td>
						<td class="clsNumber">
							<xsl:value-of select="$h23"/>
						</td>
						<td class="clsNumber">
							<xsl:value-of select="$h29"/>
						</td>
						<td class="clsNumber">
							<xsl:value-of select="$h35a + $h35b + $h35c"/>
						</td>
					</tr>
					<tr>
						<td class="clsHeading">1 to 299 hours</td>
						<td class="clsNumber">
							<xsl:value-of select="$h24"/>
						</td>
						<td class="clsNumber">
							<xsl:value-of select="$h30"/>
						</td>
						<td class="clsNumber">
							<xsl:value-of select="$h36a + $h36b + $h36c"/>
						</td>
					</tr>
					<tr>
						<td class="clsHeading">Zero hours</td>
						<td class="clsNumber">
							<xsl:value-of select="$h25"/>
						</td>
						<td class="clsNumber">
							<xsl:value-of select="$h31"/>
						</td>
						<td class="clsNumber">
							<xsl:value-of select="$h37a + $h37b + $h37c + $h37d"/>
						</td>
					</tr>
				</table>
			</xsl:otherwise>
		</xsl:choose>
		
		
		<h2>Table 34: Number of pupils by planned learning; planned employability, enrichment and pastoral; and, total planned hours [for: secondary, all-through and PRU]</h2>
		<xsl:choose>
			<xsl:when test="$term != 'AUT' ">
				<p class="clsFootnote">This table does not apply to the <xsl:value-of select="$thiscensus"/> census as planned hours data is only collected in the autumn census.</p>
			</xsl:when>
			<xsl:when test="not(contains( ' SS AT PR ', concat(' ', /Message/School/SchoolCharacteristics/Phase, ' ' ) ) and /Message/School/SchoolCharacteristics/HighestNCyear &gt; 11)">
				<p class="clsFootnote">Table 34 only applies to schools with a phase of SS, AT or PR</p>
			</xsl:when>
			<xsl:otherwise>
				<xsl:variable name="J1" select="count(/Message/Pupils/PupilsOnRoll/PupilOnRoll[PupilCharacteristics/QualHrs &gt;= 580] )"/>
				<xsl:variable name="J2" select="count(/Message/Pupils/PupilsOnRoll/PupilOnRoll
																			[PupilCharacteristics/QualHrs &gt;= 485 
																			and PupilCharacteristics/QualHrs &lt;= 579] )	"/>
				<xsl:variable name="J3" select="count(/Message/Pupils/PupilsOnRoll/PupilOnRoll
																			[PupilCharacteristics/QualHrs &gt;= 385 
																			and PupilCharacteristics/QualHrs &lt;= 484] ) "/>
				<xsl:variable name="J4" select="count(/Message/Pupils/PupilsOnRoll/PupilOnRoll
																			[PupilCharacteristics/QualHrs &gt;= 300 
																			and PupilCharacteristics/QualHrs &lt;= 384] ) "/>
				<xsl:variable name="J5" select="count(/Message/Pupils/PupilsOnRoll/PupilOnRoll
																			[PupilCharacteristics/QualHrs &gt;= 1 
																			and PupilCharacteristics/QualHrs &lt;= 299] ) "/>
				<xsl:variable name="J6" select="count(/Message/Pupils/PupilsOnRoll/PupilOnRoll
																			[PupilCharacteristics/QualHrs = 0 or ((PupilCharacteristics/QualHrs) and string-length(PupilCharacteristics/QualHrs) = 0)] ) "/>
				<xsl:variable name="J7" select="count(/Message/Pupils/PupilsOnRoll/PupilOnRoll
																			[PupilCharacteristics/Non_qualHrs &gt;= 580] ) "/>
				<xsl:variable name="J8" select="count(/Message/Pupils/PupilsOnRoll/PupilOnRoll
																			[PupilCharacteristics/Non_qualHrs &gt;= 485 
																			and PupilCharacteristics/Non_qualHrs &lt;= 579] )	"/>
				<xsl:variable name="J9" select="count(/Message/Pupils/PupilsOnRoll/PupilOnRoll
																			[PupilCharacteristics/Non_qualHrs &gt;= 385 
																			and PupilCharacteristics/Non_qualHrs &lt;= 484] ) "/>
				<xsl:variable name="J10" select="count(/Message/Pupils/PupilsOnRoll/PupilOnRoll
																			[PupilCharacteristics/Non_qualHrs &gt;= 300 
																			and PupilCharacteristics/Non_qualHrs &lt;= 384] ) "/>
				<xsl:variable name="J11" select="count(/Message/Pupils/PupilsOnRoll/PupilOnRoll
																			[PupilCharacteristics/Non_qualHrs &gt;= 1 
																			and PupilCharacteristics/Non_qualHrs &lt;= 299] ) "/>
				<xsl:variable name="J12" select="count(/Message/Pupils/PupilsOnRoll/PupilOnRoll
																			[PupilCharacteristics/Non_qualHrs = 0 or ((PupilCharacteristics/Non_qualHrs) and string-length(PupilCharacteristics/Non_qualHrs) = 0)] ) "/>
	<!-- The original variables for the total columns don't handle the scenario of a blank value i.e. QualHrs = 850 but Non_qualHrs = blank then the pupil isn't included in the count. 
		Needed to split into 3 individual to handle original scenario and then if either of the values are blank-->
				<xsl:variable name="J13a" select="count(/Message/Pupils/PupilsOnRoll/PupilOnRoll
																			[PupilCharacteristics/QualHrs + PupilCharacteristics/Non_qualHrs &gt;= 580] ) "/>
				<xsl:variable name="J13b" select="count(/Message/Pupils/PupilsOnRoll/PupilOnRoll
																			[PupilCharacteristics/QualHrs &gt;= 580 
																			and (string-length(PupilCharacteristics/Non_qualHrs) = 0 and (PupilCharacteristics/Non_qualHrs) )] ) "/>
				<xsl:variable name="J13c" select="count(/Message/Pupils/PupilsOnRoll/PupilOnRoll
																			[(string-length(PupilCharacteristics/QualHrs) = 0 and (PupilCharacteristics/QualHrs))
																			and PupilCharacteristics/Non_qualHrs &gt;= 580] ) "/>
				
				<xsl:variable name="J14a" select="count(/Message/Pupils/PupilsOnRoll/PupilOnRoll
																			[PupilCharacteristics/QualHrs + PupilCharacteristics/Non_qualHrs &gt;= 485 
																			and PupilCharacteristics/QualHrs + PupilCharacteristics/Non_qualHrs &lt;= 579] ) "/>
				<xsl:variable name="J14b" select="count(/Message/Pupils/PupilsOnRoll/PupilOnRoll
																			[PupilCharacteristics/QualHrs &gt;= 485 
																			and PupilCharacteristics/QualHrs &lt;= 579
																			and (string-length(PupilCharacteristics/Non_qualHrs) = 0 and (PupilCharacteristics/Non_qualHrs))] ) "/>
				<xsl:variable name="J14c" select="count(/Message/Pupils/PupilsOnRoll/PupilOnRoll
																			[PupilCharacteristics/Non_qualHrs &gt;= 485 
																			and PupilCharacteristics/Non_qualHrs &lt;= 579
																			and (string-length(PupilCharacteristics/QualHrs) = 0 and (PupilCharacteristics/QualHrs))] ) "/>	
				
				<xsl:variable name="J15a" select="count(/Message/Pupils/PupilsOnRoll/PupilOnRoll
																			[PupilCharacteristics/QualHrs + PupilCharacteristics/Non_qualHrs &gt;= 385 
																			and PupilCharacteristics/QualHrs + PupilCharacteristics/Non_qualHrs &lt;= 484] ) "/>
				<xsl:variable name="J15b" select="count(/Message/Pupils/PupilsOnRoll/PupilOnRoll
																			[PupilCharacteristics/QualHrs &gt;= 385 
																			and PupilCharacteristics/QualHrs &lt;= 484
																			and (string-length(PupilCharacteristics/Non_qualHrs) = 0 and (PupilCharacteristics/Non_qualHrs))] ) "/>
				<xsl:variable name="J15c" select="count(/Message/Pupils/PupilsOnRoll/PupilOnRoll
																			[PupilCharacteristics/Non_qualHrs &gt;= 385 
																			and PupilCharacteristics/Non_qualHrs &lt;= 484
																			and (string-length(PupilCharacteristics/QualHrs) = 0 and (PupilCharacteristics/QualHrs))] ) "/>
																			
				<xsl:variable name="J16a" select="count(/Message/Pupils/PupilsOnRoll/PupilOnRoll
																			[PupilCharacteristics/QualHrs + PupilCharacteristics/Non_qualHrs &gt;= 300 
																			and PupilCharacteristics/QualHrs + PupilCharacteristics/Non_qualHrs &lt;= 384] ) "/>
				<xsl:variable name="J16b" select="count(/Message/Pupils/PupilsOnRoll/PupilOnRoll
																			[PupilCharacteristics/QualHrs &gt;= 300 
																			and PupilCharacteristics/QualHrs &lt;= 384
																			and (string-length(PupilCharacteristics/Non_qualHrs) = 0 and (PupilCharacteristics/Non_qualHrs))] ) "/>
				<xsl:variable name="J16c" select="count(/Message/Pupils/PupilsOnRoll/PupilOnRoll
																			[PupilCharacteristics/Non_qualHrs &gt;= 300 
																			and PupilCharacteristics/Non_qualHrs &lt;= 384
																			and (string-length(PupilCharacteristics/QualHrs) = 0 and (PupilCharacteristics/QualHrs))] ) "/>
				
				<xsl:variable name="J17a" select="count(/Message/Pupils/PupilsOnRoll/PupilOnRoll
																			[PupilCharacteristics/QualHrs + PupilCharacteristics/Non_qualHrs &gt;= 1 
																			and PupilCharacteristics/QualHrs + PupilCharacteristics/Non_qualHrs &lt;= 299] )"/>
				<xsl:variable name="J17b" select="count(/Message/Pupils/PupilsOnRoll/PupilOnRoll
																			[PupilCharacteristics/QualHrs &gt;= 1 
																			and PupilCharacteristics/QualHrs &lt;= 299
																			and (string-length(PupilCharacteristics/Non_qualHrs) = 0 and (PupilCharacteristics/Non_qualHrs))] ) "/>
				<xsl:variable name="J17c" select="count(/Message/Pupils/PupilsOnRoll/PupilOnRoll
																			[PupilCharacteristics/Non_qualHrs &gt;= 1 
																			and PupilCharacteristics/Non_qualHrs &lt;= 299
																			and (string-length(PupilCharacteristics/QualHrs) = 0 and (PupilCharacteristics/QualHrs))] ) "/>
				
				<xsl:variable name="J18a" select="count(/Message/Pupils/PupilsOnRoll/PupilOnRoll[PupilCharacteristics/QualHrs + PupilCharacteristics/Non_qualHrs = 0] )"/>
				<xsl:variable name="J18b" select="count(/Message/Pupils/PupilsOnRoll/PupilOnRoll
																			[PupilCharacteristics/QualHrs = 0 
																			and (string-length(PupilCharacteristics/Non_qualHrs) = 0 and (PupilCharacteristics/Non_qualHrs))] ) "/>
				<xsl:variable name="J18c" select="count(/Message/Pupils/PupilsOnRoll/PupilOnRoll
																			[(string-length(PupilCharacteristics/QualHrs) = 0 and (PupilCharacteristics/QualHrs))
																			and PupilCharacteristics/Non_qualHrs = 0] ) "/>
				<xsl:variable name="J18d" select="count(/Message/Pupils/PupilsOnRoll/PupilOnRoll
																			[(string-length(PupilCharacteristics/QualHrs) = 0 and (PupilCharacteristics/QualHrs))
																			and (string-length(PupilCharacteristics/Non_qualHrs) = 0 and (PupilCharacteristics/Non_qualHrs))] ) "/>
				
				<table class="summaryreport" border="1">
					<tr>
						<th>Number of hours by 2023-2024 academic year band</th>
						<th>Number of pupils<br/>planned learning<br/>hours</th>
						<th>Number of pupils<br/>planned<br/>employability,<br/>enrichment and<br/>pastoral hours</th>
						<th>Number of pupils<br/>by total<br/>planned hours</th>
					</tr>
					<tr>
						<td class="clsHeading">580+ hours</td>
						<td class="clsNumber">
							<xsl:value-of select="$J1"/>
						</td>
						<td class="clsNumber">
							<xsl:value-of select="$J7"/>
						</td>
						<td class="clsNumber">
							<xsl:value-of select="$J13a + $J13b + $J13c"/>
						</td>
					</tr>
					<tr>
						<td class="clsHeading">485 to 579 hours</td>
						<td class="clsNumber">
							<xsl:value-of select="$J2"/>
						</td>
						<td class="clsNumber">
							<xsl:value-of select="$J8"/>
						</td>
						<td class="clsNumber">
							<xsl:value-of select="$J14a + $J14b + $J14c"/>
						</td>
					</tr>
					<tr>
						<td class="clsHeading">385 to 484 hours</td>
						<td class="clsNumber">
							<xsl:value-of select="$J3"/>
						</td>
						<td class="clsNumber">
							<xsl:value-of select="$J9"/>
						</td>
						<td class="clsNumber">
							<xsl:value-of select="$J15a + $J15b + $J15c"/>
						</td>
					</tr>
					<tr>
						<td class="clsHeading">300 to 384 hours</td>
						<td class="clsNumber">
							<xsl:value-of select="$J4"/>
						</td>
						<td class="clsNumber">
							<xsl:value-of select="$J10"/>
						</td>
						<td class="clsNumber">
							<xsl:value-of select="$J16a + $J16b + $J16c"/>
						</td>
					</tr>
					<tr>
						<td class="clsHeading">1 to 299 hours</td>
						<td class="clsNumber">
							<xsl:value-of select="$J5"/>
						</td>
						<td class="clsNumber">
							<xsl:value-of select="$J11"/>
						</td>
						<td class="clsNumber">
							<xsl:value-of select="$J17a + $J17b + $J17c"/>
						</td>
					</tr>
					<tr>
						<td class="clsHeading">Zero hours</td>
						<td class="clsNumber">
							<xsl:value-of select="$J6"/>
						</td>
						<td class="clsNumber">
							<xsl:value-of select="$J12"/>
						</td>
						<td class="clsNumber">
							<xsl:value-of select="$J18a + $J18b + $J18c + $J18d"/>
						</td>
					</tr>
				</table>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>
	

	<!-- Global Variables-->
	<xsl:variable name="CollectionYear" select="string(/Message/Header/CollectionDetails/Year)"/>
	<xsl:variable name="term" select="string(/Message/Header/CollectionDetails/Term)"/>
	<xsl:variable name="phase" select=" string(/Message/School/SchoolCharacteristics/Phase)"/>
	<xsl:variable name="ReferenceDate" select="translate(/Message/Header/CollectionDetails/ReferenceDate,'-','')"/>
	<xsl:variable name="AcademicYear" select="2023"/>	<!--first year from academic year range  eg. for 2020-2021 this should be 2020-->
	<xsl:variable name="true" select=" ' True true 1 ' "/>
	<xsl:variable name="false" select=" ' False false 0 ' "/>
	<xsl:variable name="AttendanceAcademicYear">
		<xsl:choose>
			<xsl:when test="$term = 'SPR' or $term = 'SUM' ">
				<xsl:value-of select="number($AcademicYear)"/>
			</xsl:when>
			<xsl:when test="$term = 'AUT' ">
				<xsl:value-of select="number($AcademicYear) - 1"/>
			</xsl:when>
		</xsl:choose>
	</xsl:variable>
	<xsl:variable name="Post16MaxLearningDate" select="concat($AcademicYear, '0731')"/>

	<!--new for Aut 22.  Used on tables 16 & 17-->
	<xsl:variable name="APReasonMaxDate" >
		<xsl:choose>
			<xsl:when test="$term = 'AUT' ">
				<xsl:value-of select="concat($AcademicYear, '0519')"/>
			</xsl:when>
			<xsl:when test="$term = 'SPR' ">
				<xsl:value-of select="concat($AcademicYear, '1006')"/>
			</xsl:when>
			<xsl:when test="$term = 'SUM' ">
				<xsl:value-of select="concat($AcademicYear, '0119')"/>
			</xsl:when>
		</xsl:choose>	
	</xsl:variable>	
	
	<!--This variable is only used in Autumn therefore the use of AttendanceAcademicYear is appropriate-->
	<xsl:variable name="Post16PrevMaxLearningDate" select="concat($AttendanceAcademicYear, '0731')"/>
	<xsl:variable name="August" select="8"/>
	<xsl:variable name="December" select="12"/>
	<xsl:variable name="nErrors" select="count(document('./SC24ValidationResults.xml')/ProcessingResults/Errors/Error
							[Type='Error' 
						  	 and contains(Term, /ProcessingResults/ValidationResults/Header/CollectionDetails/Term) 
						     and contains(Phase, /ProcessingResults/ValidationResults/Summary/SchoolPhase) ] )"/>
	<xsl:variable name="nQueries" select="count(document('./SC24ValidationResults.xml')/ProcessingResults/Errors/Error
							[Type='Query' 
							and contains(Term, /ProcessingResults/ValidationResults/Header/CollectionDetails/Term)	
							and contains(Phase, /ProcessingResults/ValidationResults/Summary/SchoolPhase) ] )"/>
	<!--The following four variables select subsections of the main document for use in the attendance tables (t.14, 15)-->
	<xsl:variable name="OnRoll5_15" select="/Message/Pupils/PupilsOnRoll/PupilOnRoll
								[ ($AttendanceAcademicYear - substring( PupilIdentifiers/DOB, 1, 4 ) - (substring( PupilIdentifiers/DOB, 6, 2 ) &gt; $August) ) &gt;=5
								and ($AttendanceAcademicYear - substring( PupilIdentifiers/DOB, 1, 4 ) - (substring( PupilIdentifiers/DOB, 6, 2 ) &gt; $August) ) &lt;=15
								and (PupilStatus/Boarder='N' or string-length(PupilStatus/Boarder) = 0 ) ]"/>
	<xsl:variable name="OffRoll5_15" select="/Message/Pupils/PupilsNoLongerOnRoll/PupilNoLongerOnRoll
								[ ($AttendanceAcademicYear - substring( PupilIdentifiers/DOB, 1, 4 ) - (substring( PupilIdentifiers/DOB, 6, 2 ) &gt; $August) ) &gt;=5
								and ($AttendanceAcademicYear - substring( PupilIdentifiers/DOB, 1, 4 ) - (substring( PupilIdentifiers/DOB, 6, 2 ) &gt; $August) ) &lt;=15
								and (PupilStatus/Boarder='N' or string-length(PupilStatus/Boarder) = 0 ) ]"/>
	<xsl:variable name="OnRoll4" select="/Message/Pupils/PupilsOnRoll/PupilOnRoll
								[ ($AttendanceAcademicYear - substring( PupilIdentifiers/DOB, 1, 4 ) - (substring( PupilIdentifiers/DOB, 6, 2 ) &gt; $August) ) =4
								and (PupilStatus/Boarder='N' or string-length(PupilStatus/Boarder) = 0 ) ] "/>
	<xsl:variable name="OffRoll4" select="/Message/Pupils/PupilsNoLongerOnRoll/PupilNoLongerOnRoll
								[ ($AttendanceAcademicYear - substring( PupilIdentifiers/DOB, 1, 4 ) - (substring( PupilIdentifiers/DOB, 6, 2 ) &gt; $August) ) =4
								and (PupilStatus/Boarder='N' or string-length(PupilStatus/Boarder) = 0 ) ]"/>
	<!--The following two variables select subsections of the main document for use in the learning aims tables (autumn only, t.23-29)-->
	<xsl:variable name="PORLABase" select="/Message/Pupils/PupilsOnRoll/PupilOnRoll
			[contains(' 12 13 14 ', concat(' ', PupilStatus/NCyearActual, ' ') )
			and contains( ' C M F O  ', concat(' ', PupilStatus/EnrolStatus, ' ') ) ]"/>
	<xsl:variable name="PNORLABase" select="/Message/Pupils/PupilsNoLongerOnRoll/PupilNoLongerOnRoll		
			[contains(' 12 13 14 ', concat(' ', PupilStatus/NCyearLeaving, ' ') )
			and ProgrammeAims/ProgrammeAim/LearningAims/LearningAim[ (translate(LearningStartDate, '-','') &lt;= $Post16MaxLearningDate ) ] ]"/>
	<!--Variables used in reconciliation-->
	<xsl:variable name="b10" select="count(/Message/Pupils/PupilsOnRoll/PupilOnRoll[ contains( $false, concat( ' ', PupilStatus/PartTime, ' ' ) ) ] )"/>
	<xsl:variable name="b13" select="count(/Message/Pupils/PupilsOnRoll/PupilOnRoll[ contains( $true, concat( ' ', PupilStatus/PartTime, ' ' ) ) ] )"/>
	<xsl:variable name="b16" select="count(/Message/Pupils/PupilsOnRoll/PupilOnRoll[contains( ' 14 13 12 11 10 9 8 7 6 5 4 3 2 1 R N2 N1 E1 E2 X ', concat( ' ', PupilStatus/NCyearActual, ' ' ) ) ] )"/>
	<xsl:variable name="b19total" select="count(/Message/Pupils/PupilsOnRoll/PupilOnRoll/PupilCharacteristics/Language[ not(. = '') ] ) "/>
	<xsl:variable name="b28" select="count(/Message/Pupils/PupilsOnRoll/PupilOnRoll[contains( ' C M S F O ' , concat( ' ', PupilStatus/EnrolStatus, ' ' ) ) ] ) "/>
	<xsl:variable name="SENtypes" select=" ' E K ' "/>
	<xsl:variable name="gcseValidAttainment" select=" ' A* A B C 4 5 6 7 8 9 ' "/>
	<!--Used in table 7 (NS only)-->
	<xsl:variable name="EYPPNS" select="/Message/Pupils/PupilsOnRoll/PupilOnRoll[
					translate(PupilIdentifiers/DOB, '-', '') &gt;= '20190901' 
						and contains(' E1 E2 N1 N2 R ', concat(' ', PupilStatus/NCyearActual, ' ') )
						and translate(PupilIdentifiers/DOB, '-', '') &lt;= '20201231' ]"/>
	<!--Used in table 8 (not for NS)-->
	<xsl:variable name="EYPPOTH" select="/Message/Pupils/PupilsOnRoll/PupilOnRoll[
					translate(PupilIdentifiers/DOB, '-', '') &gt;= '20190901' 
						and contains(' E1 E2 N1 N2 R X ', concat(' ', PupilStatus/NCyearActual, ' ') )
						and translate(PupilIdentifiers/DOB, '-', '') &lt;= '20201231' ]"/>
	<xsl:variable name="EYPPOTH4YrOlds" select="/Message/Pupils/PupilsOnRoll/PupilOnRoll[
					translate(PupilIdentifiers/DOB, '-', '') &gt;= '20190901' 
						and contains(' E1 E2 N1 N2 R X ', concat(' ', PupilStatus/NCyearActual, ' ') )
						and translate(PupilIdentifiers/DOB, '-', '') &lt;= '20201231' ]"/>
	<xsl:variable name="AgeCalcDate" select=" '20230831' "/>
	<xsl:variable name="etyear">
		<xsl:choose>
			<xsl:when test="$term = 'AUT' ">
				<xsl:value-of select=" '2023' "/>
			</xsl:when>
			<xsl:when test="$term = 'SPR' ">
				<xsl:value-of select=" '2024' "/>
			</xsl:when>
			<xsl:when test="$term = 'SUM' ">
				<xsl:value-of select=" '2024' "/>
			</xsl:when>
		</xsl:choose>
	</xsl:variable>
	<xsl:variable name="dt31Aug" select=" '31/08/' "/>
	<xsl:variable name="dt01Sep" select=" '01/09/' "/>
	<xsl:variable name="dt31Dec" select=" '31/12/' "/>
	<xsl:variable name="dt01Jan" select=" '01/01/' "/>
	<xsl:variable name="dt31Mar" select=" '31/03/' "/>
	<xsl:variable name="dt01Apr" select=" '01/04/' "/>
	<xsl:variable name="thiscensus">
		<xsl:choose>
			<xsl:when test="$term = 'SPR' ">
				<xsl:value-of select=" 'spring' "/>
			</xsl:when>
			<xsl:when test="$term = 'SUM' ">
				<xsl:value-of select=" 'summer' "/>
			</xsl:when>
			<xsl:when test="$term = 'AUT' ">
				<xsl:value-of select=" 'autumn' "/>
			</xsl:when>
		</xsl:choose>
	</xsl:variable>
	<xsl:variable name="prevcensus">
		<xsl:choose>
			<xsl:when test="$term = 'SPR' ">
				<xsl:value-of select=" '2023 autumn' "/>
			</xsl:when>
			<xsl:when test="$term = 'SUM' ">
				<xsl:value-of select=" '2024 spring' "/>
			</xsl:when>
			<xsl:when test="$term = 'AUT' ">
				<xsl:value-of select=" '2023 summer' "/>
			</xsl:when>
		</xsl:choose>
	</xsl:variable>
	<xsl:variable name="prevterms">
		<xsl:choose>
			<xsl:when test="$term = 'SPR' ">
				<xsl:value-of select=" 'terms 1 and 2' "/>
			</xsl:when>
			<xsl:when test="$term = 'SUM' ">
				<xsl:value-of select=" 'terms 3 and 4' "/>
			</xsl:when>
			<xsl:when test="$term = 'AUT' ">
				<xsl:value-of select=" 'terms 5 and 6' "/>
			</xsl:when>
		</xsl:choose>
	</xsl:variable>
	<xsl:variable name="AgeAsAtHeadertext">
		<xsl:choose>
			<xsl:when test="$term = 'SPR' ">
				<xsl:value-of select=" '31/08/2023' "/>
			</xsl:when>
			<xsl:when test="$term = 'SUM' ">
				<xsl:value-of select=" '31/08/2023' "/>
			</xsl:when>
			<xsl:when test="$term = 'AUT' ">
				<xsl:value-of select=" '31/08/2022' "/>
			</xsl:when>
		</xsl:choose>
	</xsl:variable>
	<!--Following variables no longer referenced anywhere.  Removed 31/08/21 -->
	<!--<xsl:variable name="InfFSMDateMin" select=" translate( '2011-09-01', '-', '')"/>
	<xsl:variable name="InfFSMDateMax" select=" translate( '2014-08-31', '-', '')"/>	-->
</xsl:stylesheet>
