<?xml version="1.0" encoding="utf-8"?>

<!--NOTE - When updating for next term make sure variable dates are updated. These variables are defined towards the end.  Also need to update PupAge variable which is not found in the global section-->

<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:msxsl="urn:schemas-microsoft-com:xslt" xmlns:Error="Errors.uri" exclude-result-prefixes="Error">
	<xsl:variable name="ValidationRules">
		<!-- Version Details -->
		<CensusDetail type="School Census 2023-2024"/>
		<!-- Current Version Details -->
		<CurrentVersion>
			<Version number="2024.1.2" released="2023-09-27" author="Andy Naylor" comment="Corrected rules 2392 and 5165"/>
		</CurrentVersion>
		<!-- History (old Current Version Details) -->
		<VersionHistory>
			<Version number="2024.1.1" released="2023-09-08" author="Andy Naylor" comment="Corrected allowed DOB ranges for rule 2492. RFC 1253 change to rule 3125. Corrected headings on Table 14 of school summary"/>
			<Version number="2024.1.0" released="2023-08-25" author="Ian Windress" comment="Baselined version for release"/>		
			<Version number="2024.0.1" released="2023-07-01" author="Andy Naylor" comment="rolled over from summer census 2023 and updated for Autumn 23"/>
		</VersionHistory>
		<!-- End of Version Details -->
	</xsl:variable>
	<xsl:template match="/Message">
		<xsl:call-template name="HeaderReferenceDate"/>
		<xsl:apply-templates select="School"/>
		<xsl:call-template name="PupilLevelValidation"/>	
		<xsl:apply-templates select="Pupils"/>
	</xsl:template>
	<!--Header Reference Date-->
	<xsl:template name="HeaderReferenceDate">
		<!--100 - Check the Header Reference Date-->
		<xsl:variable name="HeaderDateVal" select="translate(Header/CollectionDetails/ReferenceDate, '-', '') "/>
		<xsl:if test="not(Header/CollectionDetails/ReferenceDate) or $HeaderDateVal != $RefDate">
			<xsl:call-template name="Error">
				<xsl:with-param name="err_num" select="100"/>
			</xsl:call-template>
		</xsl:if>
		<!--108 If the term doesn't match the term for this release, output a warning message-->
		<!--<xsl:if test="Header/CollectionDetails/Term != 'AUT' ">
			<xsl:call-template name="Error">
				<xsl:with-param name="err_num" select="108"/>
			</xsl:call-template>
		</xsl:if>-->
	</xsl:template>
	<!--Pupils-->
	<xsl:template match="Pupils">
		<xsl:apply-templates select="PupilsOnRoll"/>
		<xsl:apply-templates select="PupilsNoLongerOnRoll"/>
	</xsl:template>
	<xsl:template match="PupilsOnRoll">
		<xsl:apply-templates select="PupilOnRoll"/>
	</xsl:template>
	<xsl:template match="PupilsNoLongerOnRoll">
		<xsl:apply-templates select="PupilNoLongerOnRoll"/>
	</xsl:template>
	<xsl:template match="PupilOnRoll">
		<xsl:call-template name="PupilIdentifiersStructureValidation"/>
		<xsl:call-template name="PupilCharacteristicsValidation"/>
		<xsl:call-template name="PupilStatusValidation"/>
		<xsl:call-template name="SpecialEducationalNeedsValidation"/>
		<xsl:call-template name="APPlacementDetailsValidation"/>
		<xsl:apply-templates select="Exclusions/TermlyExclusion"/>
		<xsl:call-template name="HomeInformationValidation"/>
		<xsl:call-template name="TermlyAttendanceValidation"/>
		<xsl:if test="$term = 'AUT' ">
			<xsl:call-template name="SummerHalfTerm2AttendanceValidation"/>
			<xsl:apply-templates select="ProgrammeAims"/>
			<xsl:apply-templates select="ProgrammeAims/ProgrammeAim/LearningAims"/>
			<!--<xsl:apply-templates select="LearningAims"/>-->
		</xsl:if>
	</xsl:template>
	<xsl:template match="PupilNoLongerOnRoll">
		<xsl:call-template name="PupilIdentifiersStructureValidation"/>
		<xsl:call-template name="PupilCharacteristicsValidation"/>
		<xsl:call-template name="PupilStatusValidation"/>
		<xsl:call-template name="SpecialEducationalNeedsValidation"/>
		<xsl:call-template name="APPlacementDetailsValidation"/>
		<xsl:apply-templates select="Exclusions/TermlyExclusion"/>
		<xsl:call-template name="TermlyAttendanceValidation"/>
		<xsl:if test="$term = 'AUT' ">
			<xsl:call-template name="HomeInformationValidationOffRoll"/>
			<xsl:call-template name="SummerHalfTerm2AttendanceValidation"/>
			<xsl:apply-templates select="ProgrammeAims"/>
			<xsl:apply-templates select="ProgrammeAims/ProgrammeAim/LearningAims"/>
			<!--<xsl:apply-templates select="LearningAims"/>-->
		</xsl:if>
	</xsl:template>
	<!--Validate the <School> node and all its children-->
	<xsl:template match="School">
		<xsl:if test="string-length(SchoolCharacteristics) = 0">
			<xsl:call-template name="Error">
				<xsl:with-param name="err_num" select="9999"/>
				<xsl:with-param name="data" select=" 'School Characteristics' "/>
			</xsl:call-template>
		</xsl:if>
		<xsl:call-template name="SchoolAllTermsValidation"/>
		<!--Most of the school validations are spring-only-->
		<xsl:if test="$term='SPR' ">
			<xsl:call-template name="SchoolSpringValidation"/>
			<!--Moved from below 02-12-2016 IK SS: Also made conditional based on term/phase (previously was just suppressed at error message level)-->
			<xsl:if test="contains(' PS MP MS SS AT ', $_Phase_)
				and string-length(Classes/Class) = 0">
				<xsl:call-template name="Error">
					<xsl:with-param name="err_num" select="5160"/>
				</xsl:call-template>
			</xsl:if>
			<!--The following admissions appeals rules are all predicated on certain governances being present-->
			<xsl:if test="contains(' VA FO CA ', concat(' ', SchoolCharacteristics/Governance, ' ') )">
				<!--Test if PrimaryAdmissionsAppeals node is present as it is mandatory for Governance VA, FO, CA phases PS, MP, AT in Spring-->
				<xsl:if test="contains(' PS MP AT ', $_Phase_ ) 
					and string-length(PrimaryAdmissionsAppeals) = 0">
					<xsl:call-template name="Error">
						<xsl:with-param name="err_num" select="9999"/>
						<xsl:with-param name="data" select=" ' PrimaryAdmissionsAppeals ' "/>
					</xsl:call-template>
				</xsl:if>
				<!--Test if InfantAdmissionsAppeals node is present as it is mandatory for Governance VA, FO, CA phases PS, AT in Spring-->
				<xsl:if test="contains(' PS AT ', $_Phase_ ) 
					and string-length(InfantAdmissionsAppeals) = 0">
					<xsl:call-template name="Error">
						<xsl:with-param name="err_num" select="9999"/>
						<xsl:with-param name="data" select=" ' InfantAdmissionsAppeals ' "/>
					</xsl:call-template>
				</xsl:if>
				<!--Test if SecondaryAdmissionsAppeals node is present as it is mandatory for Governance VA, FO, CA phases PS,MP,MS,SS,AT in Spring-->
				<xsl:if test="contains(' MS SS AT ', $_Phase_ ) 
					and string-length(SecondaryAdmissionsAppeals) = 0">
					<xsl:call-template name="Error">
						<xsl:with-param name="err_num" select="9999"/>
						<xsl:with-param name="data" select=" ' SecondaryAdmissionsAppeals ' "/>
					</xsl:call-template>
				</xsl:if>
			</xsl:if>
			<!--Governance in {VA FO CA}-->
			<xsl:call-template name="PrimaryAdmissionsValidation"/>
			<xsl:call-template name="InfantAdmissionsValidation"/>
			<xsl:call-template name="SecondaryAdmissionsValidation"/>
			<xsl:call-template name="ReconciliationValidation"/>
			<xsl:call-template name="ClassesValidation"/>
			<xsl:call-template name="MiscellaneousValidation"/>
		</xsl:if>
		<!--Term=SPR-->
	</xsl:template>
	<!--School Characteristics-->
	<xsl:template name="SchoolAllTermsValidation">
		<!--This variable is for rule 230-->
		<xsl:variable name="BeforeHighestNCYearGroups" select="concat(substring-before($ncyears, concat(' ', SchoolCharacteristics/HighestNCyear, ' ') ),' ', SchoolCharacteristics/HighestNCyear, ' ') "/>
		<!--130 DfE number and phase are not consistent / 150 School type and phase not consistent-->
		<xsl:choose>
			<xsl:when test="$Phase='NS' ">
				<xsl:if test="not( ( $Estab &gt;= 1000 and $Estab &lt;= 1099 ) 
					or ( $Estab &gt;= 1800 and $Estab &lt;= 1899 ) 
					or ( $Estab &gt;= 6000 and $Estab &lt;= 6899 ) )">
					<xsl:call-template name="Error">
						<xsl:with-param name="err_num" select="130"/>
					</xsl:call-template>
				</xsl:if>
				<xsl:if test="not(contains(' 49 50 51 ', $SchoolType) )">
					<xsl:call-template name="Error">
						<xsl:with-param name="err_num" select="150"/>
					</xsl:call-template>
				</xsl:if>
			</xsl:when>
			<xsl:when test="$Phase='PS' ">
				<xsl:if test="not( ( $Estab &gt;= 2000 and $Estab &lt;= 3999 ) 
					or ( $Estab &gt;= 5200 and $Estab &lt;= 5299 ) 
					or ( $Estab &gt;= 5900 and $Estab &lt;= 5949 ) 
					or ( $Estab &gt;= 6000 and $Estab &lt;= 6899 ) )">
					<xsl:call-template name="Error">
						<xsl:with-param name="err_num" select="130"/>
					</xsl:call-template>
				</xsl:if>
				<!--UPDATED RFC 450-->
				<xsl:if test="not(contains(' 01 02 03 04 16 17 18 42 43 49 ', $SchoolType) )">
					<xsl:call-template name="Error">
						<xsl:with-param name="err_num" select="150"/>
					</xsl:call-template>
				</xsl:if>
			</xsl:when>
			<xsl:when test="$Phase='MP' ">
				<xsl:if test="not( ( $Estab &gt;= 2000 and $Estab &lt;= 3999 ) 
					or ( $Estab &gt;= 5200 and $Estab &lt;= 5299 ) 
					or ( $Estab &gt;= 5940 and $Estab &lt;= 5949 ) 
					or ( $Estab &gt;= 6000 and $Estab &lt;= 6899 ) )">
					<xsl:call-template name="Error">
						<xsl:with-param name="err_num" select="130"/>
					</xsl:call-template>
				</xsl:if>
				<!--UPDATED RFC 450-->
				<xsl:if test="not(contains(' 05 06 45 49 ', $SchoolType) )">
					<xsl:call-template name="Error">
						<xsl:with-param name="err_num" select="150"/>
					</xsl:call-template>
				</xsl:if>
			</xsl:when>
			<xsl:when test="$Phase='MS' ">
				<xsl:if test="not( ( $Estab &gt;= 4000 and $Estab &lt;= 4999 ) 
					or ( $Estab &gt;= 5400 and $Estab &lt;= 5499 ) 
					or ( $Estab &gt;= 5900 and $Estab &lt;= 5939 ) 
					or ( $Estab &gt;= 6000 and $Estab &lt;= 6899 ) )">
					<xsl:call-template name="Error">
						<xsl:with-param name="err_num" select="130"/>
					</xsl:call-template>
				</xsl:if>
				<!--UPDATED RFC 450-->
				<xsl:if test="not(contains(' 07 08 41 49 ', $SchoolType) )">
					<xsl:call-template name="Error">
						<xsl:with-param name="err_num" select="150"/>
					</xsl:call-template>
				</xsl:if>
			</xsl:when>
			<xsl:when test="$Phase='SS' ">
				<xsl:if test="not( ( $Estab &gt;= 4000 and $Estab &lt;= 4999 ) 
					or ( $Estab &gt;= 5400 and $Estab &lt;= 5499 ) 
					or ( $Estab &gt;= 5900 and $Estab &lt;= 5939 ) 
					or ( $Estab &gt;= 6000 and $Estab &lt;= 6999 ) )">
					<xsl:call-template name="Error">
						<xsl:with-param name="err_num" select="130"/>
					</xsl:call-template>
				</xsl:if>
				<!--UPDATED RFC 450-->
				<xsl:if test="not(contains(' 09 10 11 12 21 22 25 26 27 28 29 30 31 32 33 36 37 38 39 44 46 47 48 49 ', $SchoolType) )">
					<xsl:call-template name="Error">
						<xsl:with-param name="err_num" select="150"/>
					</xsl:call-template>
				</xsl:if>
			</xsl:when>
			<xsl:when test="$Phase='SP' ">
				<xsl:if test="not( $Estab &gt;= 5950 and $Estab &lt;= 7999 )">
					<xsl:call-template name="Error">
						<xsl:with-param name="err_num" select="130"/>
					</xsl:call-template>
				</xsl:if>
				<xsl:if test="not(contains(' 49 52 53 ', $SchoolType) )">
					<xsl:call-template name="Error">
						<xsl:with-param name="err_num" select="150"/>
					</xsl:call-template>
				</xsl:if>
			</xsl:when>
			<!--2013-04-30 Added for Spring unification of PRU and School Census collections-->
			<!--PRU-->
			<xsl:when test="$Phase='PR' ">
				<xsl:if test="not( ( ($Estab &gt;= 1100) and ($Estab &lt;= 1150) ) 
					or ( ($Estab &gt;= 6000) and ($Estab &lt;= 6899) ) )">
					<xsl:call-template name="Error">
						<xsl:with-param name="err_num" select="130"/>
					</xsl:call-template>
				</xsl:if>
				<xsl:if test="not(contains(' 49 54 ', $SchoolType) )">
					<xsl:call-template name="Error">
						<xsl:with-param name="err_num" select="150"/>
					</xsl:call-template>
				</xsl:if>
			</xsl:when>
			<!--All-through schools-->
			<!--These tests are the opposite of the ones setup for the other phases.
			 i.e. rather than returning an error if the Estab number is NOT in a range, here we're returning an error if the Estab number IS in a range,
			 the same is also true of the SchoolType check 150-->
			<xsl:when test="$Phase='AT' ">
				<xsl:if test="($Estab &gt;= 1000 and $Estab &lt;= 1150)
					or ($Estab &gt;= 1800 and $Estab &lt;= 1899)
					or ($Estab &gt;= 5950 and $Estab &lt;= 5999)
					or ($Estab &gt;= 7000 and $Estab &lt;= 7999) ">
					<xsl:call-template name="Error">
						<xsl:with-param name="err_num" select="130"/>
					</xsl:call-template>
				</xsl:if>
				<xsl:if test="not(contains(' 49 55 ', $SchoolType) )">
					<!--xsl:if test="contains(' 50 51 52 53 54 ', $SchoolType)"-->
					<xsl:call-template name="Error">
						<xsl:with-param name="err_num" select="150"/>
					</xsl:call-template>
				</xsl:if>
			</xsl:when>
		</xsl:choose>
		<!--Don't think this will ever actually appear as XSLT won't run all validations if Phase, Governance and Intake are missing-->
		<!--NB. Added check for module 9999 as part of the Schools validation so we can work around this - SS.-->
		<xsl:if test="string-length(/Message/School/SchoolCharacteristics) = 0
						or not(/Message/School/SchoolCharacteristics) 
						or /Message/School/SchoolCharacteristics = ''
						or count(/Message/School[SchoolCharacteristics] ) = 0">
			<xsl:call-template name="Error">
				<xsl:with-param name="err_num" select="165"/>
			</xsl:call-template>
		</xsl:if>
		<!--110 School name missing-->
		<xsl:if test="string-length(SchoolCharacteristics/SchoolName)=0">
			<xsl:call-template name="Error">
				<xsl:with-param name="err_num" select="110"/>
			</xsl:call-template>
		</xsl:if>
		<!--120 Phase is missing or invalid-->
		<xsl:if test="not(contains($phases, $_Phase_) )">
			<xsl:call-template name="Error">
				<xsl:with-param name="err_num" select="120"/>
			</xsl:call-template>
		</xsl:if>
		<!--140 School type is missing-->
		<xsl:if test="string-length(SchoolCharacteristics/SchoolType)=0">
			<xsl:call-template name="Error">
				<xsl:with-param name="err_num" select="140"/>
			</xsl:call-template>
		</xsl:if>
		<!--160 The establishment's EduBase URN is missing or an invalid value-->
		<xsl:if test="string-length(/Message/Header/Source/URN)=0 ">
			<xsl:call-template name="Error">
				<xsl:with-param name="err_num" select="160"/>
			</xsl:call-template>
		</xsl:if>
		<!--210 School’s highest national curriculum year group is missing or invalid-->
		<xsl:if test=" not( contains($ncyears, concat(' ', SchoolCharacteristics/HighestNCyear , ' ' ) ) )">
			<xsl:call-template name="Error">
				<xsl:with-param name="err_num" select="210"/>
			</xsl:call-template>
		</xsl:if>
		<!--220 School’s lowest national curriculum year group is missing or invalid-->
		<xsl:if test=" not( contains($ncyears, concat(' ', SchoolCharacteristics/LowestNCyear , ' ' ) ) )">
			<xsl:call-template name="Error">
				<xsl:with-param name="err_num" select="220"/>
			</xsl:call-template>
		</xsl:if>
		<!--223 Intake of 'SPEC' (special) or HOSP (hospital special) can only be returned for schools with a Phase of SP (special).-->
		<xsl:if test="$Phase != 'SP'
			and ($Intake = 'SPEC' or $Intake = 'HOSP') ">
			<xsl:call-template name="Error">
				<xsl:with-param name="err_num" select="223"/>
			</xsl:call-template>
		</xsl:if>
		<!--RFC1041 now includes intake type HOSP-->
		<!--224 Intake Type is missing or invalid. Intake type must be ‘SPEC’ or 'HOSP'-->
		<xsl:if test="$Phase = 'SP'
			and $Intake != 'SPEC' 
			and $Intake != 'HOSP' ">
			<xsl:call-template name="Error">
				<xsl:with-param name="err_num" select="224"/>
			</xsl:call-template>
		</xsl:if>
		<!--230 School’s lowest national curriculum year group cannot be greater than school’s highest national curriculum year group.-->
		<xsl:if test="not(contains($BeforeHighestNCYearGroups, concat(' ', SchoolCharacteristics/LowestNCyear, ' ') ) ) 
			or ( (SchoolCharacteristics/HighestNCyear = 'X' 
				or SchoolCharacteristics/LowestNCyear = 'X') 
			and $Phase != 'SP' ) 
			or ( ( (SchoolCharacteristics/HighestNCyear = 'X' 
					and SchoolCharacteristics/LowestNCyear != 'X') 
				or (SchoolCharacteristics/HighestNCyear != 'X' 
					and SchoolCharacteristics/LowestNCyear = 'X') ) 
			and $Phase = 'SP')">
			<xsl:call-template name="Error">
				<xsl:with-param name="err_num" select="230"/>
			</xsl:call-template>
		</xsl:if>
		<xsl:choose>
			<xsl:when test="SchoolCharacteristics/Phase = 'PR' ">
				<!--(PR) 221 Intake Type is missing or invalid. Intake type must be `COMP’ for PRU-->
				<xsl:if test="not(SchoolCharacteristics/Intake = 'COMP')">
					<xsl:call-template name="Error">
						<xsl:with-param name="err_num" select="221"/>
					</xsl:call-template>
				</xsl:if>
				<!--(PR) 222 <Governance> must be present and equal to `CO’ or 'CA' for PRU-->
				<xsl:if test="not(contains(' CO CA ', concat(' ', SchoolCharacteristics/Governance, ' ') ) )">
					<xsl:call-template name="Error">
						<xsl:with-param name="err_num" select="222"/>
					</xsl:call-template>
				</xsl:if>
				<xsl:if test="$term='SPR' ">
					<!--(PR) (SPR) 540 Child mothers indicator is missing or invalid-->
					<xsl:if test="not(contains($boolean, concat(' ', SchoolCharacteristics/ChildMothers, ' ') ) )">
						<xsl:call-template name="Error">
							<xsl:with-param name="err_num" select="540"/>
						</xsl:call-template>
					</xsl:if>
					<!--(PR) (SPR) 541 Count of places for teenage mothers is missing-->
					<xsl:if test="contains($true, concat(' ', SchoolCharacteristics/ChildMothers, ' ') )">
						<xsl:if test="string-length(SchoolCharacteristics/TeenMotherPlaces)=0 or SchoolCharacteristics/TeenMotherPlaces &lt; 0">
							<xsl:call-template name="Error">
								<xsl:with-param name="err_num" select="541"/>
							</xsl:call-template>
						</xsl:if>
					</xsl:if>
					<!--(PR) (SPR) 542 Childcare facilities indicator is missing or invalid-->
					<xsl:if test="not(contains($boolean, concat(' ', SchoolCharacteristics/ChildcarePlaces, ' ') ) )">
						<xsl:call-template name="Error">
							<xsl:with-param name="err_num" select="542"/>
						</xsl:call-template>
					</xsl:if>
				</xsl:if>
				<!--Term=SPR-->
			</xsl:when>
			<!--Phase=PR-->
			<xsl:otherwise>
				<!--(!PR) 240 Intake type is missing or invalid-->
				<xsl:if test="$Phase != 'SP'
					 and not( contains($intakes, $_Intake_ ) )">
					<xsl:call-template name="Error">
						<xsl:with-param name="err_num" select="240"/>
					</xsl:call-template>
				</xsl:if>
				<!--(!PR) 260 Governance is missing or invalid. Governance must not be 'IN'-->
				<xsl:if test=" not( contains($governances, concat(' ', SchoolCharacteristics/Governance , ' ' ) ) )">
					<xsl:call-template name="Error">
						<xsl:with-param name="err_num" select="260"/>
					</xsl:call-template>
				</xsl:if>
			</xsl:otherwise>
		</xsl:choose>
		<!--261 If school type is recorded as an academy (49) then the school governance must also be recorded as an academy with code CA-->
		<xsl:if test="SchoolCharacteristics/SchoolType = 49 and not(SchoolCharacteristics/Governance = 'CA')">
			<xsl:call-template name="Error">
				<xsl:with-param name="err_num" select="261"/>
			</xsl:call-template>
		</xsl:if>
		<!--262 If school governance is recorded as an academy (CA) then school type must also be recorded as an academy with code 49-->
		<xsl:if test="SchoolCharacteristics/Governance = 'CA' and not(SchoolCharacteristics/SchoolType = 49)">
			<xsl:call-template name="Error">
				<xsl:with-param name="err_num" select="262"/>
			</xsl:call-template>
		</xsl:if>
		<!--263 If school type is recorded as a CTC (47) then governance must also be recorded as a CTC with code CT-->
		<xsl:if test="SchoolCharacteristics/SchoolType = 47 and not(SchoolCharacteristics/Governance = 'CT')">
			<xsl:call-template name="Error">
				<xsl:with-param name="err_num" select="263"/>
			</xsl:call-template>
		</xsl:if>
		<!--264 If governance is recorded as a CTC (CT) then school type must also be recorded as a CTC with code 47-->
		<xsl:if test="SchoolCharacteristics/Governance = 'CT' and not(SchoolCharacteristics/SchoolType = 47)">
			<xsl:call-template name="Error">
				<xsl:with-param name="err_num" select="264"/>
			</xsl:call-template>
		</xsl:if>
		<!--270 Please check: School email address is missing-->
		<xsl:if test="string-length(SchoolCharacteristics/Email)=0">
			<xsl:call-template name="Error">
				<xsl:with-param name="err_num" select="270"/>
			</xsl:call-template>
		</xsl:if>
		<!--420 School telephone number is missing-->
		<xsl:if test="string-length(SchoolCharacteristics/PhoneNo)=0">
			<xsl:call-template name="Error">
				<xsl:with-param name="err_num" select="420"/>
			</xsl:call-template>
		</xsl:if>
	</xsl:template>
	<xsl:template name="SchoolSpringValidation">
		<!--280 School organisation (day, boarding or hospital) is missing or invalid-->
		<xsl:if test=" not( contains(' D B H ', concat(' ', SchoolCharacteristics/SpecialSchool/Accommodation , ' ' ) ) )">
			<xsl:call-template name="Error">
				<xsl:with-param name="err_num" select="280"/>
			</xsl:call-template>
		</xsl:if>
		<!--290 Please check: day school with a majority of boarding pupils-->
		<xsl:if test="SchoolCharacteristics/SpecialSchool/Accommodation='D' 
			and not (count(../Pupils/PupilsOnRoll/PupilOnRoll/PupilStatus[Boarder = 'N'] ) &gt; count(../Pupils/PupilsOnRoll/PupilOnRoll/PupilStatus[Boarder = '6' or Boarder = '7' ] ) )">
			<xsl:call-template name="Error">
				<xsl:with-param name="err_num" select="290"/>
			</xsl:call-template>
		</xsl:if>
		<!--300 Please check: boarding school with a majority of day pupils-->
		<xsl:if test="SchoolCharacteristics/SpecialSchool/Accommodation='B' 
			and not (count(../Pupils/PupilsOnRoll/PupilOnRoll/PupilStatus[Boarder = '6' or Boarder = '7' ] ) &gt; count(../Pupils/PupilsOnRoll/PupilOnRoll/PupilStatus[Boarder = 'N'] ) )">
			<xsl:call-template name="Error">
				<xsl:with-param name="err_num" select="300"/>
			</xsl:call-template>
		</xsl:if>
		<!--310 Approved maximum for day pupils is missing-->
		<xsl:if test="string-length(SchoolCharacteristics/SpecialSchool/MaxDayPupils) = 0 
			or SchoolCharacteristics/SpecialSchool/MaxDayPupils!=floor(SchoolCharacteristics/SpecialSchool/MaxDayPupils) 
			or SchoolCharacteristics/SpecialSchool/MaxDayPupils &lt; 0">
			<xsl:call-template name="Error">
				<xsl:with-param name="err_num" select="310"/>
			</xsl:call-template>
		</xsl:if>
		<!--320 Approved maximum for boarding pupils is missing (or, for hospital special schools, is provided when it is not required). Three separate tests-->
		<xsl:choose>
			<xsl:when test="SchoolCharacteristics/SpecialSchool/Accommodation='D' ">
				<xsl:if test="string-length(SchoolCharacteristics/SpecialSchool/MaxBoarders) = 0 
						or SchoolCharacteristics/SpecialSchool/MaxBoarders &lt; 0">
					<xsl:call-template name="Error">
						<xsl:with-param name="err_num" select="320"/>
					</xsl:call-template>
				</xsl:if>
			</xsl:when>
			<xsl:when test="SchoolCharacteristics/SpecialSchool/Accommodation='B' ">
				<xsl:if test="string-length(SchoolCharacteristics/SpecialSchool/MaxBoarders) = 0 
						or SchoolCharacteristics/SpecialSchool/MaxBoarders &lt; 1">
					<xsl:call-template name="Error">
						<xsl:with-param name="err_num" select="320"/>
					</xsl:call-template>
				</xsl:if>
			</xsl:when>
			<xsl:when test="SchoolCharacteristics/SpecialSchool/Accommodation='H' ">
				<xsl:if test="string-length(SchoolCharacteristics/SpecialSchool/MaxBoarders) !=0">
					<xsl:call-template name="Error">
						<xsl:with-param name="err_num" select="320"/>
					</xsl:call-template>
				</xsl:if>
			</xsl:when>
		</xsl:choose>
		<!--330 Please check: more day pupils on roll than the approved maximum-->
		<xsl:if test="SchoolCharacteristics/SpecialSchool/MaxDayPupils &lt; count(../Pupils/PupilsOnRoll/PupilOnRoll/PupilStatus[Boarder = 'N' or Boarder = '' or not(Boarder) ] )">
			<xsl:call-template name="Error">
				<xsl:with-param name="err_num" select="330"/>
			</xsl:call-template>
		</xsl:if>
		<!--340 Please check: more boarding pupils on roll than the approved maximum-->
		<xsl:if test="SchoolCharacteristics/SpecialSchool/MaxBoarders &lt; count(../Pupils/PupilsOnRoll/PupilOnRoll/PupilStatus[Boarder = '6' or Boarder = '7' ] )
				and (SchoolCharacteristics/SpecialSchool/Accommodation='D' 
						or SchoolCharacteristics/SpecialSchool/Accommodation='B')">
			<xsl:call-template name="Error">
				<xsl:with-param name="err_num" select="340"/>
			</xsl:call-template>
		</xsl:if>
		<!--350 <MinMaleAge> where present must be in the range 2 to 27 (inclusive) if the number of PupilsOnRoll with <Sex> = M is > 0-->
		<xsl:if test="count(../Pupils/PupilsOnRoll/PupilOnRoll/PupilIdentifiers[Sex = 'M' ] ) &gt; 0
				 and (SchoolCharacteristics/SpecialSchool/MinMaleAge &lt; 2 
					 or SchoolCharacteristics/SpecialSchool/MinMaleAge &gt; 27 
					 or string-length(SchoolCharacteristics/SpecialSchool/MinMaleAge) = 0)">
			<xsl:call-template name="Error">
				<xsl:with-param name="err_num" select="350"/>
			</xsl:call-template>
		</xsl:if>
		<!--360 Girls on roll not provided, or age not in range 2 to 27-->
		<xsl:if test="count(../Pupils/PupilsOnRoll/PupilOnRoll/PupilIdentifiers[Sex = 'F' ] ) &gt; 0 
				and (SchoolCharacteristics/SpecialSchool/MinFemaleAge &lt; 2 
					or SchoolCharacteristics/SpecialSchool/MinFemaleAge &gt; 27
					or string-length(SchoolCharacteristics/SpecialSchool/MinFemaleAge) = 0)">
			<xsl:call-template name="Error">
				<xsl:with-param name="err_num" select="360"/>
			</xsl:call-template>
		</xsl:if>
		<!--370 Approved maximum age (boys) is shown but there is no minimum, or vice versa-->
		<xsl:if test="(string-length(SchoolCharacteristics/SpecialSchool/MinMaleAge) = 0 
				and string-length(SchoolCharacteristics/SpecialSchool/MaxMaleAge) != 0 )
					or (string-length(SchoolCharacteristics/SpecialSchool/MinMaleAge) != 0 
				and string-length(SchoolCharacteristics/SpecialSchool/MaxMaleAge) = 0 )">
			<xsl:call-template name="Error">
				<xsl:with-param name="err_num" select="370"/>
			</xsl:call-template>
		</xsl:if>
		<!--380 Approved maximum age (girls) is shown but there is no minimum, or vice versa-->
		<xsl:if test="string-length(SchoolCharacteristics/SpecialSchool/MinFemaleAge) = 0 
				and string-length(SchoolCharacteristics/SpecialSchool/MaxFemaleAge) != 0 
					or string-length(SchoolCharacteristics/SpecialSchool/MinFemaleAge) != 0 
				and string-length(SchoolCharacteristics/SpecialSchool/MaxFemaleAge) = 0 ">
			<xsl:call-template name="Error">
				<xsl:with-param name="err_num" select="380"/>
			</xsl:call-template>
		</xsl:if>
		<!--390 Approved maximum age (boys) must be equal to or greater than minimum-->
		<xsl:if test="not( SchoolCharacteristics/SpecialSchool/MaxMaleAge &gt; SchoolCharacteristics/SpecialSchool/MinMaleAge) 
				and string-length(SchoolCharacteristics/SpecialSchool/MaxMaleAge) != 0 
				and string-length(SchoolCharacteristics/SpecialSchool/MinMaleAge) != 0 ">
			<xsl:call-template name="Error">
				<xsl:with-param name="err_num" select="390"/>
			</xsl:call-template>
		</xsl:if>
		<!--400 Approved maximum age (girls) must be equal to or greater than minimum-->
		<xsl:if test="not( SchoolCharacteristics/SpecialSchool/MaxFemaleAge &gt; SchoolCharacteristics/SpecialSchool/MinFemaleAge) 
				and string-length(SchoolCharacteristics/SpecialSchool/MaxFemaleAge) != 0
				and string-length(SchoolCharacteristics/SpecialSchool/MinFemaleAge) != 0">
			<xsl:call-template name="Error">
				<xsl:with-param name="err_num" select="400"/>
			</xsl:call-template>
		</xsl:if>
		<!--410 Information on SEN school types for which school is approved is missing or invalid -->
		<xsl:if test="count(SchoolCharacteristics/SpecialSchool/Provisions[SpecialSchoolType != '' ] ) &lt; 1
				or count(SchoolCharacteristics/SpecialSchool/Provisions/SpecialSchoolType
					[not(contains($SENschoolcodes, concat(' ', . , ' ' ) ) ) ] ) &gt; 0 ">
			<xsl:call-template name="Error">
				<xsl:with-param name="err_num" select="410"/>
			</xsl:call-template>
		</xsl:if>
		<!--5005 Data items in the Special School module are only required from schools with a phase of SP-->
		<xsl:if test="string-length(SchoolCharacteristics/SpecialSchool) and $Phase != 'SP' ">
			<xsl:call-template name="Error">
				<xsl:with-param name="err_num" select="5005"/>
			</xsl:call-template>
		</xsl:if>
		<!-- End of Special School checks -->
		<!--Ths following test applies to rules 5013 / 5018 / 5125-->
		<xsl:if test="not(contains(' VA FO CA ', concat(' ', SchoolCharacteristics/Governance, ' ') ) )">
			<!--5013 Data items in the admissions appeals module are only required from schools with governance type of VA, FO or CA-->
			<xsl:if test="string-length(/Message/School/PrimaryAdmissionsAppeals) != 0">
				<xsl:call-template name="Error">
					<xsl:with-param name="err_num" select="5013"/>
				</xsl:call-template>
			</xsl:if>
			<!--5018 Data items in the infant admission appeals module are only required from schools with governance type of VA, FO or CA-->
			<xsl:if test="string-length(/Message/School/InfantAdmissionsAppeals) != 0">
				<xsl:call-template name="Error">
					<xsl:with-param name="err_num" select="5018"/>
				</xsl:call-template>
			</xsl:if>
			<!--5125 Data items in the Secondary admission appeals module are only required from schools with governance type of VA, FO or CA-->
			<xsl:if test="string-length(/Message/School/SecondaryAdmissionsAppeals) != 0">
				<xsl:call-template name="Error">
					<xsl:with-param name="err_num" select="5125"/>
				</xsl:call-template>
			</xsl:if>
		</xsl:if>
		<!--/Governance {VA FO CA}-->
		<!--The following test applies to rules 5014 / 5126 (5019 is excluded as it has slightly different phase requirements-->
		<xsl:if test="contains(' NS SP PR ', $_Phase_)">
			<!--5014 Data items in the admissions appeals module are not required from schools with a phase of NS, SP or PR-->
			<xsl:if test="string-length(/Message/School/PrimaryAdmissionsAppeals) != 0">
				<xsl:call-template name="Error">
					<xsl:with-param name="err_num" select="5014"/>
				</xsl:call-template>
			</xsl:if>
			<!--5126 Data items in the Secondary admission appeals module are not required from schools with a phase of NS, SP or PR-->
			<xsl:if test="string-length(/Message/School/SecondaryAdmissionsAppeals) != 0">
				<xsl:call-template name="Error">
					<xsl:with-param name="err_num" select="5126"/>
				</xsl:call-template>
			</xsl:if>
		</xsl:if>
		<!--/Phase {NS SP PR}-->
		<!--5019 Data items in the Iinfant admission appeals module are only required from schools with a phase of PS or AT-->
		<xsl:if test="not(contains(' PS AT ', $_Phase_) )">
			<xsl:if test="string-length(/Message/School/InfantAdmissionsAppeals) != 0">
				<xsl:call-template name="Error">
					<xsl:with-param name="err_num" select="5019"/>
				</xsl:call-template>
			</xsl:if>
		</xsl:if>
		<!--5023 Data items in the pupil reconciliation module are only required from schools with a phase of PS, MP, MS, SS or AT.-->
		<xsl:if test="not(contains(' PS MP MS SS AT ', $_Phase_) )">
			<xsl:if test="string-length(/Message/School/Reconciliation) != 0">
				<xsl:call-template name="Error">
					<xsl:with-param name="err_num" select="5023"/>
				</xsl:call-template>
			</xsl:if>
		</xsl:if>
	</xsl:template>
	<!--Miscellaneous Validation-->
	<xsl:template name="MiscellaneousValidation">
		<!--Again, this module will only run during spring term-->
		<xsl:if test="string-length(Miscellaneous/FreeMealsTaken) = 0">
			<xsl:call-template name="Error">
				<xsl:with-param name="err_num" select="1310"/>
			</xsl:call-template>
		</xsl:if>
		<!--1320 Please check: Free meals taken exceeds total eligible pupils -->
		<xsl:if test="Miscellaneous/FreeMealsTaken &gt; count(/Message/Pupils/PupilsOnRoll/PupilOnRoll
			[PupilCharacteristics/FSMeligibility/FSMperiod
				[FSMstartDate 
					and ( ( string-length(FSMendDate) = 0 
						or (translate(FSMendDate, '-', '') &gt;= $RefDate) ) ) ] ] )">
			<xsl:call-template name="Error">
				<xsl:with-param name="err_num" select="1320"/>
			</xsl:call-template>
		</xsl:if>
		<xsl:if test="Miscellaneous/FreeMealsTaken = 0
					and count(/Message/Pupils/PupilsOnRoll/PupilOnRoll
						[PupilCharacteristics/FSMeligibility/FSMperiod
							[string-length(FSMstartDate) != 0 
								and string-length(FSMendDate)=0 ] ] ) &gt; 0">
			<xsl:call-template name="Error">
				<xsl:with-param name="err_num" select="1330"/>
			</xsl:call-template>
		</xsl:if>
		<xsl:if test="not(contains(' NS ', $_Phase_))
					  and string-length(Miscellaneous/SchoolTime) != 0 
					  and not(contains(' 00 25 50 75 ',substring-after(Miscellaneous/SchoolTime, '.')))">
			<xsl:call-template name="Error">
				<xsl:with-param name="err_num" select="2980"/>
			</xsl:call-template>
		</xsl:if>
		<xsl:if test=" $Phase = 'NS'
					  and string-length(Miscellaneous/SchoolTime) != 0 ">
			<xsl:call-template name="Error">
				<xsl:with-param name="err_num" select="2981"/>
			</xsl:call-template>
		</xsl:if>	
		<xsl:if test="$Phase != 'NS'
					  and string-length(Miscellaneous/SchoolTime) != 0 
					  and (Miscellaneous/SchoolTime &lt; 10
						   or Miscellaneous/SchoolTime &gt; 99)">
			<xsl:call-template name="Error">
				<xsl:with-param name="err_num" select="2982"/>
			</xsl:call-template>
		</xsl:if>
		<!--Childcare Module - expected to be up to four rows, no more.-->
		<xsl:for-each select="Miscellaneous/Childcare">
			<xsl:choose>
				<xsl:when test="OnSite='Y' ">
					<!--Credit to Simon Chilvers (RM) who pointed out the correct way to do this rather than using horrible pattern matching.-->
					<xsl:variable name="opentimemins" select="number(substring(OpeningTime, 1, 2) ) * 60 + number(substring(OpeningTime, 4, 2) ) "/>
					<xsl:variable name="closetimemins" select="number(substring(ClosingTime, 1, 2) ) * 60 + number(substring(ClosingTime, 4, 2) ) "/>
					<xsl:variable name="availabletimemins" select="$closetimemins - $opentimemins"/>
					<!--2960: Please check: Opening time is expected to be within the range 06:00 to 09:00-->
					<xsl:if test="contains(' B H U ', concat(' ', TypeOfChildcare, ' ') )
						and ($opentimemins &lt; 360
								 or $opentimemins &gt; 540
								 or string($opentimemins) = 'NaN'
								 or substring(OpeningTime, 3, 1) != ':' )">
						<xsl:call-template name="Error">
							<xsl:with-param name="err_num" select="2960"/>
						</xsl:call-template>
					</xsl:if>
					<!--2965: Please check: Closing time is expected to be within the range 16:00 to 20:00-->
					<xsl:if test="contains(' A H U ', concat(' ', TypeOfChildcare, ' ') )
						and ($closetimemins &lt; 960
								 or $closetimemins &gt; 1200
								 or string($closetimemins) = 'NaN'
								 or substring(ClosingTime, 3, 1) != ':' )">
						<xsl:call-template name="Error">
							<xsl:with-param name="err_num" select="2965"/>
						</xsl:call-template>
					</xsl:if>
					<!--New rule late addition 2018-01-12-->
					<!--2970 If the school has under 5 childcare the number of hours for this provision must be equal to or greater than 9-->
					<xsl:if test="contains(' U ', concat(' ', TypeOfChildcare, ' ') )
						and $availabletimemins &lt; 540 ">
						<xsl:call-template name="Error">
							<xsl:with-param name="err_num" select="2970"/>
						</xsl:call-template>
					</xsl:if>
					<!--2915 Where <OnSite> = 'Y' (common criteria) and <TypeOfChildcare> = 'B', 'H' or 'U' <OpeningTime> must be present and a valid value-->
					<xsl:if test="contains(' B H U ', concat(' ', TypeOfChildcare, ' ') )
						and translate(OpeningTime, $digits, $all_9s) != '99:99' ">
						<xsl:call-template name="Error">
							<xsl:with-param name="err_num" select="2915"/>
						</xsl:call-template>
					</xsl:if>
					<!--2916 Where <OnSite> equals 'Y' (common criteria) and <TypeOfChildcare> does not equal 'B', 'H' or 'U' <OpeningTime> must not be present-->
					<xsl:if test="not(contains(' B H U ', concat(' ', TypeOfChildcare, ' ') ) )
						and string-length(OpeningTime) != 0 ">
						<xsl:call-template name="Error">
							<xsl:with-param name="err_num" select="2916"/>
						</xsl:call-template>
					</xsl:if>
					<!--2920 Where <OnSite> = 'Y' (common criteria) and <TypeOfChildcare> = 'A', 'H' or 'U' <ClosingTime> must be present and a valid value-->
					<xsl:if test="contains(' A H U ', concat(' ', TypeOfChildcare, ' ') ) 
						and translate(ClosingTime, $digits, $all_9s) != '99:99' ">
						<xsl:call-template name="Error">
							<xsl:with-param name="err_num" select="2920"/>
						</xsl:call-template>
					</xsl:if>
					<!--2921 Where <OnSite> (common criteria) equals 'Y' and <TypeOfChildcare> does not equal 'A', 'H' or 'U' <ClosingTime> must not be present-->
					<xsl:if test="not(contains(' A H U ', concat(' ', TypeOfChildcare, ' ') ) ) 
						and string-length(ClosingTime) != 0 ">
						<xsl:call-template name="Error">
							<xsl:with-param name="err_num" select="2921"/>
						</xsl:call-template>
					</xsl:if>
					<!--2925 Where <OnSite> = 'Y' (common criteria) and <TypeOfChildcare> = 'A', 'B', 'H' or 'U' <ChildcarePlaces> must be present and a valid value-->
					<xsl:if test="(string-length(NoOfChildcarePlaces) = 0
							or string-length(NoOfChildcarePlaces) &gt; 4
							or string-length(translate(NoOfChildcarePlaces, $digits, '') ) != 0 )">
						<xsl:call-template name="Error">
							<xsl:with-param name="err_num" select="2925"/>
						</xsl:call-template>
					</xsl:if>
					<!--2930 Where <OnSite> = 'Y' (common criteria) and <TypeOfChildcare> = 'A', 'B', 'H' or 'U' <ChildcareProvider> must be present and a valid value-->
					<xsl:if test="not(contains(' SCH SIP OTH ', concat(' ', ChildcareProvider, ' ') ) )">
						<xsl:call-template name="Error">
							<xsl:with-param name="err_num" select="2930"/>
						</xsl:call-template>
					</xsl:if>
					<!--2935 Where <OnSite> = 'Y' (common criteria) and <TypeOfChildcare> = 'A', 'B' or 'H' <OtherSchools> must be present and a valid value-->
					<xsl:if test="contains(' A B H ', concat(' ', TypeOfChildcare, ' ') ) 
						and not(contains(' Y N U ', concat(' ', OtherSchools, ' ') ) ) ">
						<xsl:call-template name="Error">
							<xsl:with-param name="err_num" select="2935"/>
						</xsl:call-template>
					</xsl:if>
					<!--2936 Where <OnSite> equals 'Y' (common criteria) and <TypeOfChildcare> does not equal 'A', 'B' or 'H' <OtherSchools> must not be present-->
					<xsl:if test="not(contains(' A B H ', concat(' ', TypeOfChildcare, ' ') ) )
						and string-length(OtherSchools) != 0 ">
						<xsl:call-template name="Error">
							<xsl:with-param name="err_num" select="2936"/>
						</xsl:call-template>
					</xsl:if>
					<!--2940 Where <OnSite> equals 'Y' (common criteria) and Number of weeks which regular childcare provision is open is missing or out of the range 1 to 38-->
					<xsl:if test="TypeOfChildcare = 'U' 
						and (string-length(ChildcareWksOpen) = 0 
							or ChildcareWksOpen &lt; 1 
							or ChildcareWksOpen &gt; 38 )">
						<!--NaN is regarded as < any numeric so is less than 1.-->
						<xsl:call-template name="Error">
							<xsl:with-param name="err_num" select="2940"/>
						</xsl:call-template>
					</xsl:if>
					<!--2941 Where <OnSite> equals 'Y' (common criteria) and <TypeOfChildcare> does not equal 'U' or 'H' <ChildcareWksOpen> must not be present-->
					<xsl:if test="not(contains(' U H ', concat(' ', TypeOfChildcare, ' ')  ) )
						and string-length(ChildcareWksOpen) != 0 ">
						<xsl:call-template name="Error">
							<xsl:with-param name="err_num" select="2941"/>
						</xsl:call-template>
					</xsl:if>
					<!--2975 Where <OnSite> equals 'Y' (common criteria) and Number of weeks which regular childcare provision is open is missing or out of the range 1 to 15-->
					<xsl:if test="TypeOfChildcare = 'H' 
						and (string-length(ChildcareWksOpen) = 0 
							or ChildcareWksOpen &lt; 1 
							or ChildcareWksOpen &gt; 15 )" >
						<!--NaN is regarded as < any numeric so is less than 1.-->
						<xsl:call-template name="Error">
							<xsl:with-param name="err_num" select="2975"/>
						</xsl:call-template>
					</xsl:if>
				</xsl:when>
				<!--OnSite='Y'-->
				<xsl:when test="OnSite='N' ">
					<!--2945 Only details on ChildcareSignposting and TypeOfChildcare are required. Other childcare details are not required where childcare is not provided on site-->
					<xsl:if test="string-length(OpeningTime) 
						+ string-length(ClosingTime) 
						+ string-length(NoOfChildcarePlaces)
						+ string-length(ChildcareProvider) 
						+ string-length(OtherSchools)
						+ string-length(ChildcareWksOpen) &gt; 0 ">
						<xsl:call-template name="Error">
							<xsl:with-param name="err_num" select="2945"/>
						</xsl:call-template>
					</xsl:if>
				</xsl:when>
				<xsl:otherwise>
					<!--2900 <OnSite> must be present and equal 'Y' or 'N'-->
					<xsl:call-template name="Error">
						<xsl:with-param name="err_num" select="2900"/>
					</xsl:call-template>
				</xsl:otherwise>
			</xsl:choose>
			<!--2910 <ChildcareSingposting> must be present and = 'YF', 'YL', 'N' or 'U'-->
			<!--Update for validation 2.0, new CBDS entry supplied (RFC 819)-->
			<xsl:if test="not(contains($childcaresignposting, concat(' ', ChildcareSignposting, ' ') ) )">
				<xsl:call-template name="Error">
					<xsl:with-param name="err_num" select="2910"/>
				</xsl:call-template>
			</xsl:if>
		</xsl:for-each>
		<!--2950 and 2955 are evaluated for each type of childcare.-->
		<!--2950: Childcare Type '?' has not been provided (the error message should indicate which <TypeOfChildcare> is missing)-->
		<!--2955: The type of childcare has been reported more than once-->
		<xsl:choose>
			<xsl:when test="count(Miscellaneous/Childcare[TypeOfChildcare='A'] ) = 1"/>
			<!--This is the expected behaviour - do nothing-->
			<xsl:when test="count(Miscellaneous/Childcare[TypeOfChildcare='A'] ) = 0">
				<!--Missing this code - raise one of the four variants of rule 2950-->
				<xsl:call-template name="Error">
					<xsl:with-param name="err_num" select="29501"/>
				</xsl:call-template>
			</xsl:when>
			<xsl:otherwise>
				<!--Greater than one type of childcare present for this code, raise error.-->
				<xsl:call-template name="Error">
					<xsl:with-param name="err_num" select="2955"/>
				</xsl:call-template>
			</xsl:otherwise>
		</xsl:choose>
		<xsl:choose>
			<xsl:when test="count(Miscellaneous/Childcare[TypeOfChildcare='B'] ) = 1"/>
			<xsl:when test="count(Miscellaneous/Childcare[TypeOfChildcare='B'] ) = 0">
				<xsl:call-template name="Error">
					<xsl:with-param name="err_num" select="29502"/>
				</xsl:call-template>
			</xsl:when>
			<xsl:otherwise>
				<xsl:call-template name="Error">
					<xsl:with-param name="err_num" select="2955"/>
				</xsl:call-template>
			</xsl:otherwise>
		</xsl:choose>
		<xsl:choose>
			<xsl:when test="count(Miscellaneous/Childcare[TypeOfChildcare='H'] ) = 1"/>
			<xsl:when test="count(Miscellaneous/Childcare[TypeOfChildcare='H'] ) = 0">
				<xsl:call-template name="Error">
					<xsl:with-param name="err_num" select="29503"/>
				</xsl:call-template>
			</xsl:when>
			<xsl:otherwise>
				<xsl:call-template name="Error">
					<xsl:with-param name="err_num" select="2955"/>
				</xsl:call-template>
			</xsl:otherwise>
		</xsl:choose>
		<xsl:choose>
			<xsl:when test="count(Miscellaneous/Childcare[TypeOfChildcare='U'] ) = 1"/>
			<xsl:when test="count(Miscellaneous/Childcare[TypeOfChildcare='U'] ) = 0">
				<xsl:call-template name="Error">
					<xsl:with-param name="err_num" select="29504"/>
				</xsl:call-template>
			</xsl:when>
			<xsl:otherwise>
				<xsl:call-template name="Error">
					<xsl:with-param name="err_num" select="2955"/>
				</xsl:call-template>
			</xsl:otherwise>
		</xsl:choose>
		<!--END OF CHILDCARE MODULE-->
	</xsl:template>
	<!--Classes -->
	<xsl:template name="ClassesValidation">
		<!--This is only called for spring census-->
		<!--The following variables are used in rules 1270 and 1280-->
		<xsl:variable name="startYear" select="SchoolCharacteristics/LowestNCyear"/>
		<xsl:variable name="endYear" select="SchoolCharacteristics/HighestNCyear"/>
		<!--5032 Data items in the class information module are only required from schools with a phase of PS, MP, MS, SS or AT-->
		<xsl:if test="Classes and not( contains(' PS MP MS SS AT ', concat(' ', /Message/School/SchoolCharacteristics/Phase, ' ') ) )">
			<xsl:call-template name="Error">
				<xsl:with-param name="err_num" select="5032"/>
			</xsl:call-template>
		</xsl:if>
		<xsl:for-each select="Classes/Class">
			<xsl:if test="string-length(ClassName) = 0">
				<xsl:call-template name="Error">
					<xsl:with-param name="err_num" select="1050"/>
					<xsl:with-param name="data" select="concat('Class Name: missing ','' ) "/>
				</xsl:call-template>
			</xsl:if>
			<!--1060 Two (or more) classes have the same name-->
			<xsl:if test="ClassName[. = preceding::ClassName]">
				<xsl:call-template name="Error">
					<xsl:with-param name="err_num" select="1060"/>
					<xsl:with-param name="err_param1" select="ClassName"/>
				</xsl:call-template>
			</xsl:if>
			<!--1070 Number of teachers in class is missing -->
			<xsl:if test="string-length(Teachers) = 0 or not(Teachers &gt;= 0)
				or (Teachers &gt;= 5 
					and contains(' MP MS SS ', concat(' ', /Message/School/SchoolCharacteristics/Phase, ' ') ) )
				or (Teachers &gt;= 6 
					and contains(' PS AT ', concat(' ', /Message/School/SchoolCharacteristics/Phase, ' ') ) )">
				<xsl:call-template name="Error">
					<xsl:with-param name="err_num" select="1070"/>
					<xsl:with-param name="data" select="concat('Class Name: ', ClassName) "/>
				</xsl:call-template>
			</xsl:if>
			<!--1090 Number of support staff in class is missing-->
			<xsl:if test="string-length(NonTeachers) = 0 or NonTeachers &lt; 0">
				<xsl:call-template name="Error">
					<xsl:with-param name="err_num" select="1090"/>
					<xsl:with-param name="data" select="concat('Class Name: ', ClassName) "/>
				</xsl:call-template>
			</xsl:if>
			<!--1100 Class with no staff-->
			<xsl:if test="( ( sum(Teachers) + sum(NonTeachers) ) &lt; 1) 
				or (string-length(Teachers) = 0 
					and string-length(NonTeachers) = 0)">
				<xsl:call-template name="Error">
					<xsl:with-param name="err_num" select="1100"/>
					<xsl:with-param name="data" select="concat('Class Name: ', ClassName) "/>
				</xsl:call-template>
			</xsl:if>
			<!--1200 Number of home pupils in class is missing-->
			<xsl:if test="string-length(HomePupils) = 0 
				or HomePupils &lt; 0">
				<xsl:call-template name="Error">
					<xsl:with-param name="err_num" select="1200"/>
					<xsl:with-param name="data" select="concat('Class Name: ', ClassName) "/>
				</xsl:call-template>
			</xsl:if>
			<!--1210 Number of guest pupils in class is missing-->
			<xsl:if test="string-length(GuestPupils) = 0 
				or GuestPupils &lt; 0">
				<xsl:call-template name="Error">
					<xsl:with-param name="err_num" select="1210"/>
					<xsl:with-param name="data" select="concat('Class Name: ', ClassName) "/>
				</xsl:call-template>
			</xsl:if>
			<!--1220 Class with no pupils-->
			<xsl:if test="(HomePupils + GuestPupils) &lt; 1">
				<xsl:call-template name="Error">
					<xsl:with-param name="err_num" select="1220"/>
					<xsl:with-param name="data" select="concat('Class Name: ', ClassName) "/>
				</xsl:call-template>
			</xsl:if>

			<!--New for 19-20 -->
			<!--1245 PPATeachers must only be present if Phase is PS or AT and Keystage = 1 or YearGroup = R -->
			<xsl:if test="string-length(PPATeachers) &gt; 0 
								  and ( not (contains(' PS AT ', concat(' ', /Message/School/SchoolCharacteristics/Phase, ' ') ) )
										  or (not(KeyStage = '1') and ( not(YearGroup = 'R') ) )
										  )
								  ">
				<xsl:call-template name="Error">
					<xsl:with-param name="err_num" select="1245"/>
					<xsl:with-param name="data" select="concat('Class Name:', ClassName) "/>
				</xsl:call-template>
			</xsl:if>
			<!-- 1250 Exception A-H must only be present if Phase is PS or AT and Keystage = 1 or YearGroup = R -->
			<xsl:if test="( (string-length(ExceptionA) &gt; 0 or string-length(ExceptionB) &gt; 0 or string-length(ExceptionC) &gt; 0 or
									 string-length(ExceptionD) &gt; 0 or string-length(ExceptionE) &gt; 0 or string-length(ExceptionF) &gt; 0 or
									 string-length(ExceptionG) &gt; 0 or string-length(ExceptionH) &gt; 0)
								  and ( not (contains(' PS AT ', concat(' ', /Message/School/SchoolCharacteristics/Phase, ' ') ) )
										  or (not(KeyStage = '1') and ( not(YearGroup = 'R') ) ) )
								  )
								  ">
				<xsl:call-template name="Error">
					<xsl:with-param name="err_num" select="1250"/>
					<xsl:with-param name="data" select="concat('Class Name:', ClassName) "/>
				</xsl:call-template>
			</xsl:if>

			<!--5036 Class type can only be returned from schools with a phase of PS or AT, and may be present only for year groups E1, E2, N1, N2, R, 1-7, or M-->
			<xsl:choose>
				<xsl:when test="string-length(ClassType)=0"/>
				<xsl:when test="contains(' PS AT ', concat(' ', /Message/School/SchoolCharacteristics/Phase, ' ') )
					 and contains(' E1 E2 N1 N2 R 1 2 3 4 5 6 7 M ', concat(' ', YearGroup, ' ') ) "/>
				<xsl:otherwise>
					<xsl:call-template name="Error">
						<xsl:with-param name="err_num" select="5036"/>
						<xsl:with-param name="data" select="concat('Class Name:', ClassName) "/>
					</xsl:call-template>
				</xsl:otherwise>
			</xsl:choose>
			<!-- 5037 Class key stage can only be returned from schools with a phase of PS or AT, and may be present only for year groups E1, E2, N1, N2, R, 1-7, or M-->
			<xsl:choose>
				<xsl:when test="string-length(KeyStage)=0"/>
				<xsl:when test="contains(' PS AT ', concat(' ', /Message/School/SchoolCharacteristics/Phase, ' ') ) 
					and contains(' E1 E2 N1 N2 R 1 2 3 4 5 6 7 M ', concat(' ', YearGroup, ' ') ) "/>
				<xsl:otherwise>
					<xsl:call-template name="Error">
						<xsl:with-param name="err_num" select="5037"/>
						<xsl:with-param name="data" select="concat('Class Name:', ClassName) "/>
					</xsl:call-template>
				</xsl:otherwise>
			</xsl:choose>
			<!--5038 Class Activity can only be returned from schools with a phase of PS or AT, and may be present only for year groups E1, E2, N1, N2, R, 1-7, or M-->
			<xsl:choose>
				<xsl:when test="string-length(ClassActivity)=0"/>
				<xsl:when test="contains(' PS AT ', concat(' ', /Message/School/SchoolCharacteristics/Phase, ' ') ) 
					and contains(' E1 E2 N1 N2 R 1 2 3 4 5 6 7 M ', concat(' ', YearGroup, ' ') ) "/>
				<xsl:otherwise>
					<xsl:call-template name="Error">
						<xsl:with-param name="err_num" select="5038"/>
						<xsl:with-param name="data" select="concat('Class Name:', ClassName) "/>
					</xsl:call-template>
				</xsl:otherwise>
			</xsl:choose>
			<!--5039 The number of home pupils is only required from schools with a phase of PS, MP, MS, SS or AT-->
			<xsl:if test="not( contains(' PS MP MS SS AT ', concat(' ', /Message/School/SchoolCharacteristics/Phase, ' ') ) )">
				<xsl:if test="string-length(HomePupils) != 0">
					<xsl:call-template name="Error">
						<xsl:with-param name="err_num" select="5039"/>
					</xsl:call-template>
				</xsl:if>
			</xsl:if>
			<!--5040 The number of guest pupils is only required from schools with a phase of PS, MP, MS, SS or AT-->
			<xsl:if test="not( contains(' PS MP MS SS AT ', concat(' ', /Message/School/SchoolCharacteristics/Phase, ' ') ) )">
				<xsl:if test="string-length(GuestPupils) != 0">
					<xsl:call-template name="Error">
						<xsl:with-param name="err_num" select="5040"/>
					</xsl:call-template>
				</xsl:if>
			</xsl:if>
			<!--1240 Please check the number of guest pupils in the class is equal to the number of home pupils-->
			<!--Changed March 2018 - no longer tests both fields for existance of data following amendment to specification-->
			<!--xsl:if test="string-length(HomePupils) != 0 and string-length(GuestPupils) != 0 and GuestPupils &gt;= HomePupils"-->
			<xsl:if test="GuestPupils &gt;= HomePupils">
				<xsl:call-template name="Error">
					<xsl:with-param name="err_num" select="1240"/>
					<xsl:with-param name="data" select="concat('Class Name:', ClassName) "/>
				</xsl:call-template>
			</xsl:if>
			<!--SS July 2014 - have moved all validations which are PS/AT only into the following block to save redundancy-->
			<xsl:if test="contains(' PS AT ', concat(' ', /Message/School/SchoolCharacteristics/Phase, ' ') )">
				<!--1130 Class Type is missing or invalid-->
				<!--RFC 640 SS:2013-07-25 Added criteria for YearGroup-->
				<xsl:if test="contains(' E1 E2 N1 N2 R 1 2 3 4 5 6 ', concat(' ', YearGroup, ' ') ) 
					and not( contains(' N O ', concat(' ', ClassType , ' ' ) ) )">
					<xsl:call-template name="Error">
						<xsl:with-param name="err_num" select="1130"/>
						<xsl:with-param name="data" select="concat('Class Name:', ClassName) "/>
					</xsl:call-template>
				</xsl:if>
				<!--1150 Please check: Class type and class year group different-->
				<xsl:if test="ClassType='N' 
					and not( contains(' E1 E2 N1 N2 M ', concat(' ', YearGroup, ' ') ) ) ">
					<xsl:call-template name="Error">
						<xsl:with-param name="err_num" select="1150"/>
						<xsl:with-param name="data" select="concat('Class Name:', ClassName) "/>
					</xsl:call-template>
				</xsl:if>
				<!--1155 Please check: Class type and class year group different-->
				<xsl:if test="contains(' E1 E2 N1 N2 ', concat(' ', YearGroup, ' ') )
					 and not(ClassType='N')">
					<xsl:call-template name="Error">
						<xsl:with-param name="err_num" select="1155"/>
						<xsl:with-param name="data" select="concat('Class Name:', ClassName) "/>
					</xsl:call-template>
				</xsl:if>
				<!--1160 Class key stage not present or invalid-->
				<xsl:if test="(/Message/School/SchoolCharacteristics/Phase = 'PS' 
						and not(contains($keystages, concat(' ', KeyStage, ' ') ) ) ) 
					or (/Message/School/SchoolCharacteristics/Phase = 'AT' 
						and contains(' E1 E2 N1 N2 R 1 2 3 4 5 6 ', concat(' ', YearGroup, ' ') ) 
						and not(contains($keystages, concat(' ', KeyStage, ' ') ) ) )">
					<xsl:call-template name="Error">
						<xsl:with-param name="err_num" select="1160"/>
						<xsl:with-param name="data" select="concat('Class Name:', ClassName) "/>
					</xsl:call-template>
				</xsl:if>
				<!--1170 Class activity is missing or invalid-->
				<xsl:if test="(/Message/School/SchoolCharacteristics/Phase = 'PS' 
						and not(contains($classactivities, concat(' ', ClassActivity,' ') ) ) ) 
					or (/Message/School/SchoolCharacteristics/Phase = 'AT' 
						and contains(' E1 E2 N1 N2 R 1 2 3 4 5 6 ', concat(' ', YearGroup, ' ') ) 
						and not(contains($classactivities, concat(' ', ClassActivity,' ') ) ) )">
					<xsl:call-template name="Error">
						<xsl:with-param name="err_num" select="1170"/>
						<xsl:with-param name="data" select="concat('Class Name:', ClassName) "/>
					</xsl:call-template>
				</xsl:if>
				<!--1190 Class year group and key stage not consistent-->
				<xsl:if test="(KeyStage != 'F' and contains(' E1 E2 N1 N2 R ', concat(' ', YearGroup, ' ') ) )
								or (KeyStage != '1' and contains(' 1 2 ', concat(' ', YearGroup, ' ') ) )
								or (KeyStage != '2' and contains(' 3 4 5 6 ', concat(' ', YearGroup, ' ') ) )
								or (KeyStage != '3' and YearGroup = '7')
								or (YearGroup = 'M' and not(contains($keystages, concat(' ', KeyStage, ' ') ) ) )">
					<xsl:call-template name="Error">
						<xsl:with-param name="err_num" select="1190"/>
						<xsl:with-param name="data" select="concat('Class Name:', ClassName) "/>
					</xsl:call-template>
				</xsl:if>
				<!--1230 Please check: KS1 or Reception class with pupil / teacher ratio greater than 30-->
				<xsl:if test="(YearGroup = 'R' or KeyStage = '1')
					and not(contains(' TV PE MD ',concat(' ', ClassActivity, ' ') ) )
					and (concat('0', HomePupils) + concat('0', GuestPupils) 
						- concat('0', ExceptionA) - concat('0', ExceptionB) 
						- concat('0', ExceptionC) - concat('0', ExceptionD)
						- concat('0', ExceptionE) - concat('0', ExceptionF)
						- concat('0', ExceptionG) - concat('0', ExceptionH) ) 
					&gt; ( (concat('0', Teachers) + concat('0', PPATeachers) ) * 30)">
					<xsl:call-template name="Error">
						<xsl:with-param name="err_num" select="1230"/>
						<xsl:with-param name="data" select="concat('Class Name:', ClassName) "/>
					</xsl:call-template>
				</xsl:if>
				<!--1235 For KS1 or Reception classes Class Activity must reflect an “academic” activity -->
				<xsl:if test="(YearGroup = 'R' or KeyStage = '1')
							and contains(' TV PE MD ',concat(' ', ClassActivity, ' ') )">
					<xsl:call-template name="Error">
						<xsl:with-param name="err_num" select="1235"/>
						<xsl:with-param name="data" select="concat('Class Name:', ClassName) "/>
					</xsl:call-template>
				</xsl:if>
				<!--1260 Please check: Nursery class with more pupils than expected-->
				<xsl:if test="ClassType = 'N' 
							and (sum(HomePupils) + sum(GuestPupils) ) &gt; ( (sum(Teachers) + sum(NonTeachers) ) * 13)	">
					<xsl:call-template name="Error">
						<xsl:with-param name="err_num" select="1260"/>
						<xsl:with-param name="data" select="concat('Class Name:', ClassName) "/>
					</xsl:call-template>
				</xsl:if>
			</xsl:if>
			<!--End of $phase in (PS, AT)-->
			<!--1140 "Class year group is missing, or invalid for this phase of school."-->
			<xsl:choose>
				<xsl:when test="contains(' NS SP PR ', $_Phase_) "/>
				<!--Rule does not apply to phases NS SP or PR-->
				<xsl:when test="../../SchoolCharacteristics/Phase='PS' 
					and contains(' E1 E2 N1 N2 R 1 2 3 4 5 6 7 M ', concat(' ', YearGroup, ' ') ) "/>
				<xsl:when test="../../SchoolCharacteristics/Phase='MP' 
					and contains(' 4 5 6 7 8 9 M ', concat(' ', YearGroup, ' ') ) "/>
				<xsl:when test="../../SchoolCharacteristics/Phase='MS' 
					and contains(' 4 5 6 7 8 9 M ', concat(' ', YearGroup, ' ') ) "/>
				<xsl:when test="../../SchoolCharacteristics/Phase='SS' 
					and contains(' 6 7 8 9 10 11 12 13 14 M ', concat(' ', YearGroup, ' ') ) "/>
				<xsl:when test="../../SchoolCharacteristics/Phase='AT' 
					and contains(' E1 E2 N1 N2 R 1 2 3 4 5 6 7 8 9 10 11 12 13 14 M ', concat(' ', YearGroup, ' ') ) "/>
				<xsl:otherwise>
					<xsl:call-template name="Error">
						<xsl:with-param name="err_num" select="1140"/>
						<xsl:with-param name="data" select="concat('Class Name:', ClassName) "/>
						<xsl:with-param name="err_param1" select="../../SchoolCharacteristics/Phase"/>
					</xsl:call-template>
				</xsl:otherwise>
			</xsl:choose>
			<!-- 1280 Please check: Classes shown for an unexpected year group-->
			<xsl:if test="contains(concat(substring-before($ncyears, concat(' ', $startYear, ' ') ), ' '), concat(' ', YearGroup, ' ') )
							or contains(concat(' ',translate(substring-after($ncyears, concat(' ', $endYear, ' ') ), 'MX', '')), concat(' ', YearGroup, ' ') )">
				<xsl:call-template name="Error">
					<xsl:with-param name="err_num" select="1280"/>
					<xsl:with-param name="data" select="concat('Class Name:', ClassName) "/>
				</xsl:call-template>
			</xsl:if>
		</xsl:for-each>
		<!-- fix for presence of M Year Group, now 1270 not generated if M year group is present -->
		<!--1270 should not be run once per class -->
		<!--1270-redux: fixing non-numeric year groups-->
		<xsl:if test="count(Classes/Class/YearGroup[. = 'M'] ) = 0">
			<xsl:if test="contains(' PS MP MS SS AT ', $_Phase_ )">
				<xsl:call-template name="CheckClasses">
					<!--Note - no leading space but a trailing space in parameter-->
					<xsl:with-param name="YearsToCheck" select="concat(concat($startYear, substring-after(concat(translate(substring-before($ncyears, concat(' ', $endYear, ' ') ), 'MX', ''), ' ', $endYear), $startYear) ), ' ')"/>
				</xsl:call-template>
			</xsl:if>
		</xsl:if>
		<!--1110 Please check: No support staff reported for any class-->
		<xsl:if test="contains(' PS MP MS SS AT ', $_Phase_ )
			and sum(Classes/Class/NonTeachers) = 0 ">
			<xsl:call-template name="Error">
				<xsl:with-param name="err_num" select="1110"/>
			</xsl:call-template>
		</xsl:if>
		<xsl:if test="contains(' PS AT ', $_Phase_ )
			and count(Classes/Class[ClassType = 'N'] ) &gt; 0 
			and (count(../Pupils/PupilsOnRoll/PupilOnRoll/PupilStatus[TypeOfClass = 'N'] ) &lt; 1 )">
			<!-- ? -->
			<xsl:call-template name="Error">
				<xsl:with-param name="err_num" select="1300"/>
			</xsl:call-template>
		</xsl:if>
		<!--1180 Please check: Activity shown as other for all classes-->
		<xsl:if test="contains(' PS AT ', $_Phase_ )
			and not(count(Classes/Class[
				string-length(ClassActivity) != 0
				and ClassActivity != 'OT'] 
			) &gt; 0)">
			<xsl:call-template name="Error">
				<xsl:with-param name="err_num" select="1180"/>
			</xsl:call-template>
		</xsl:if>
	</xsl:template>
	<!-- Support Template for 1270 - different approach-->
	<xsl:template name="CheckClasses">
		<xsl:param name="YearsToCheck"/>
		<xsl:if test="string-length($YearsToCheck) &gt; 0 ">
			<xsl:if test="count(Classes/Class/YearGroup[. = substring-before($YearsToCheck, ' ' ) ] ) = 0">
				<xsl:call-template name="Error">
					<xsl:with-param name="err_num" select="1270"/>
					<xsl:with-param name="err_param1" select="substring-before($YearsToCheck, ' ' )"/>
				</xsl:call-template>
			</xsl:if>
			<xsl:call-template name="CheckClasses">
				<xsl:with-param name="YearsToCheck" select="substring-after($YearsToCheck, ' ')"/>
			</xsl:call-template>
		</xsl:if>
	</xsl:template>
	<!-- Primary Admissions Appeals -->
	<xsl:template name="PrimaryAdmissionsValidation">
		<!--Note, only called in Spring and on certain governances-->
		<!--Three variables used in validation 570-->
		<xsl:variable name="AAU">
			<xsl:choose>
				<xsl:when test="string(number(PrimaryAdmissionsAppeals/Upheld) ) != 'NaN' ">
					<xsl:value-of select="sum(PrimaryAdmissionsAppeals/Upheld) "/>
				</xsl:when>
				<xsl:otherwise>0</xsl:otherwise>
			</xsl:choose>
		</xsl:variable>
		<xsl:variable name="AAR">
			<xsl:choose>
				<xsl:when test="string(number(PrimaryAdmissionsAppeals/Rejected) ) != 'NaN' ">
					<xsl:value-of select="sum(PrimaryAdmissionsAppeals/Rejected) "/>
				</xsl:when>
				<xsl:otherwise>0</xsl:otherwise>
			</xsl:choose>
		</xsl:variable>
		<xsl:variable name="AAH">
			<xsl:choose>
				<xsl:when test="string(number(PrimaryAdmissionsAppeals/Heard) ) != 'NaN' ">
					<xsl:value-of select="sum(PrimaryAdmissionsAppeals/Heard) "/>
				</xsl:when>
				<xsl:otherwise>0</xsl:otherwise>
			</xsl:choose>
		</xsl:variable>
		<!--560 There were more appeals withdrawn or heard than were actually lodged-->
		<xsl:if test="(sum(PrimaryAdmissionsAppeals/Withdrawn) + sum(PrimaryAdmissionsAppeals/Heard) ) != sum(PrimaryAdmissionsAppeals/Lodged)">
			<xsl:call-template name="Error">
				<xsl:with-param name="err_num" select="560"/>
			</xsl:call-template>
		</xsl:if>
		<!--564Q Admissions Appeals Lodged have not been provided-->
		<xsl:if test="contains(' PS MP AT ', $_Phase_) and contains(' VA FO CA ', $Governance)
							and (string-length(PrimaryAdmissionsAppeals/Lodged) = 0 or sum(PrimaryAdmissionsAppeals/Lodged) = 0)">
			<xsl:call-template name="Error">
				<xsl:with-param name="err_num" select="564"/>
			</xsl:call-template>
		</xsl:if>
		<!--570 Appeals upheld plus appeals rejected should match the number of appeals heard-->
		<xsl:if test="$AAU + $AAR != $AAH ">
			<xsl:call-template name="Error">
				<xsl:with-param name="err_num" select="570"/>
			</xsl:call-template>
		</xsl:if>
	</xsl:template>
	<!-- Infant Admissions Added IS 2006-02-20 -->
	<xsl:template name="InfantAdmissionsValidation">
		<!--Note, only called in Spring and on certain governances-->
		<!--Three variables used in validation 640-->
		<xsl:variable name="IAU">
			<xsl:choose>
				<xsl:when test="string(number(InfantAdmissionsAppeals/Upheld) ) != 'NaN' ">
					<xsl:value-of select="sum(InfantAdmissionsAppeals/Upheld) "/>
				</xsl:when>
				<xsl:otherwise>0</xsl:otherwise>
			</xsl:choose>
		</xsl:variable>
		<xsl:variable name="IAR">
			<xsl:choose>
				<xsl:when test="string(number(InfantAdmissionsAppeals/Rejected) ) != 'NaN' ">
					<xsl:value-of select="sum(InfantAdmissionsAppeals/Rejected) "/>
				</xsl:when>
				<xsl:otherwise>0</xsl:otherwise>
			</xsl:choose>
		</xsl:variable>
		<xsl:variable name="IAH">
			<xsl:choose>
				<xsl:when test="string(number(InfantAdmissionsAppeals/Heard) ) != 'NaN' ">
					<xsl:value-of select="sum(InfantAdmissionsAppeals/Heard) "/>
				</xsl:when>
				<xsl:otherwise>0</xsl:otherwise>
			</xsl:choose>
		</xsl:variable>
		<!--566Q Infants Admissions Appeals Lodged have not been provided-->
		<xsl:if test="contains(' PS AT ', $_Phase_ ) and contains(' VA FO CA ', $Governance)
			and contains(' E1 E2 N1 N2 R 1 2 ', concat(' ', SchoolCharacteristics/LowestNCyear, ' ') ) 
			and (string-length(InfantAdmissionsAppeals/Lodged) = 0 
				or sum(InfantAdmissionsAppeals/Lodged) = 0)">
			<xsl:call-template name="Error">
				<xsl:with-param name="err_num" select="566"/>
			</xsl:call-template>
		</xsl:if>
		<!--580 Overall appeals lodged less than infant appeals lodged-->
		<xsl:if test="InfantAdmissionsAppeals/Lodged &gt; 0 
			and (sum(InfantAdmissionsAppeals/Lodged) &gt; sum(PrimaryAdmissionsAppeals/Lodged) 
				or InfantAdmissionsAppeals/Lodged = '' or not(InfantAdmissionsAppeals/Lodged) )">
			<xsl:call-template name="Error">
				<xsl:with-param name="err_num" select="580"/>
			</xsl:call-template>
		</xsl:if>
		<!--590 Overall appeals withdrawn less than infant appeals withdrawn-->
		<xsl:if test="InfantAdmissionsAppeals/Withdrawn &gt; 0 
			and (sum(InfantAdmissionsAppeals/Withdrawn) &gt; sum(PrimaryAdmissionsAppeals/Withdrawn) 
				or InfantAdmissionsAppeals/Withdrawn = '' 
				or not(InfantAdmissionsAppeals/Withdrawn) )">
			<xsl:call-template name="Error">
				<xsl:with-param name="err_num" select="590"/>
			</xsl:call-template>
		</xsl:if>
		<!--600 Overall appeals heard less than infant appeals heard-->
		<xsl:if test="InfantAdmissionsAppeals/Heard &gt; 0 
			and (sum(InfantAdmissionsAppeals/Heard) &gt; sum(PrimaryAdmissionsAppeals/Heard) 
				or InfantAdmissionsAppeals/Heard = '' 
				or not(InfantAdmissionsAppeals/Heard) )">
			<xsl:call-template name="Error">
				<xsl:with-param name="err_num" select="600"/>
			</xsl:call-template>
		</xsl:if>
		<!--610 Overall appeals upheld less than infant appeals upheld -->
		<xsl:if test="InfantAdmissionsAppeals/Upheld &gt; 0 
			and (sum(InfantAdmissionsAppeals/Upheld) &gt; sum(PrimaryAdmissionsAppeals/Upheld) 
				or InfantAdmissionsAppeals/Upheld = '' 
				or not(InfantAdmissionsAppeals/Upheld) )">
			<xsl:call-template name="Error">
				<xsl:with-param name="err_num" select="610"/>
			</xsl:call-template>
		</xsl:if>
		<!--620 Overall appeals rejected less than infant appeals rejected-->
		<xsl:if test="InfantAdmissionsAppeals/Rejected &gt; 0 
			and (sum(InfantAdmissionsAppeals/Rejected) &gt; sum(PrimaryAdmissionsAppeals/Rejected) 
			or InfantAdmissionsAppeals/Rejected = '' 
			or not(InfantAdmissionsAppeals/Rejected) )">
			<xsl:call-template name="Error">
				<xsl:with-param name="err_num" select="620"/>
			</xsl:call-template>
		</xsl:if>
		<!--630 More appeals withdrawn or heard than were lodged for infant classes-->
		<xsl:if test="(sum(InfantAdmissionsAppeals/Withdrawn) + sum(InfantAdmissionsAppeals/Heard) ) &gt; sum(InfantAdmissionsAppeals/Lodged)">
			<xsl:call-template name="Error">
				<xsl:with-param name="err_num" select="630"/>
			</xsl:call-template>
		</xsl:if>
		<!--640 Appeals upheld plus appeals rejected should match the number of appeals heard-->
		<xsl:if test="$IAU + $IAR != $IAH ">
			<xsl:call-template name="Error">
				<xsl:with-param name="err_num" select="640"/>
			</xsl:call-template>
		</xsl:if>
	</xsl:template>
	<!-- Secondary Admissions Added SS 2016-08-30 -->
	<xsl:template name="SecondaryAdmissionsValidation">
		<!--Note, only called in Spring and on certain governances-->
		<!--Three variables used in validation 571-->
		<xsl:variable name="SAU">
			<xsl:choose>
				<xsl:when test="string(number(SecondaryAdmissionsAppeals/Upheld) ) != 'NaN' ">
					<xsl:value-of select="sum(SecondaryAdmissionsAppeals/Upheld) "/>
				</xsl:when>
				<xsl:otherwise>0</xsl:otherwise>
			</xsl:choose>
		</xsl:variable>
		<xsl:variable name="SAR">
			<xsl:choose>
				<xsl:when test="string(number(SecondaryAdmissionsAppeals/Rejected) ) != 'NaN' ">
					<xsl:value-of select="sum(SecondaryAdmissionsAppeals/Rejected) "/>
				</xsl:when>
				<xsl:otherwise>0</xsl:otherwise>
			</xsl:choose>
		</xsl:variable>
		<xsl:variable name="SAH">
			<xsl:choose>
				<xsl:when test="string(number(SecondaryAdmissionsAppeals/Heard) ) != 'NaN' ">
					<xsl:value-of select="sum(SecondaryAdmissionsAppeals/Heard) "/>
				</xsl:when>
				<xsl:otherwise>0</xsl:otherwise>
			</xsl:choose>
		</xsl:variable>
		<!--561 There were more Secondary admission appeals withdrawn and / or heard than were actually lodged-->
		<xsl:if test="(sum(SecondaryAdmissionsAppeals/Withdrawn) + sum(SecondaryAdmissionsAppeals/Heard) ) &gt; sum(SecondaryAdmissionsAppeals/Lodged)">
			<xsl:call-template name="Error">
				<xsl:with-param name="err_num" select="561"/>
			</xsl:call-template>
		</xsl:if>
		<!--Added 2016-08-30 SS-->
		<!--565Q Please check: Secondary admission appeals figures should be provided and greater than zero-->
		<xsl:if test="contains(' PS MP MS SS AT ', $_Phase_ ) and contains(' VA FO CA ', $Governance)
			and (string-length(SecondaryAdmissionsAppeals/Lodged) = 0 
				or sum(SecondaryAdmissionsAppeals/Lodged) = 0)">
			<xsl:call-template name="Error">
				<xsl:with-param name="err_num" select="565"/>
			</xsl:call-template>
		</xsl:if>
		<!--571 Appeals upheld plus appeals rejected should match the number of appeals heard-->
		<xsl:if test="$SAU + $SAR != $SAH ">
			<xsl:call-template name="Error">
				<xsl:with-param name="err_num" select="571"/>
			</xsl:call-template>
		</xsl:if>
	</xsl:template>
	<!--Reconciliation Validation-->
	<xsl:template name="ReconciliationValidation">
		<!--Note, only called in Spring-->
		<xsl:choose>
			<!--9999 School reconciliation module is missing-->
			<xsl:when test="contains(' PS MP MS SS AT ', $_Phase_ ) 
										and string-length(Reconciliation) = 0 ">
				<xsl:call-template name="Error">
					<xsl:with-param name="err_num" select="9999"/>
					<xsl:with-param name="data" select=" 'Reconciliation' "/>
				</xsl:call-template>
			</xsl:when>
			<xsl:otherwise>
				<xsl:for-each select="Reconciliation">
					<!--920 Number of part-time pupils not at school is missing-->
					<xsl:if test="string-length(PupilReconciliation/PartTimeNotIn) = 0 
						or PupilReconciliation/PartTimeNotIn &lt; 0">
						<xsl:call-template name="Error">
							<xsl:with-param name="err_num" select="920"/>
						</xsl:call-template>
					</xsl:if>
					<!--930 More part-time pupils not in school than total part-time pupils registered.-->
					<xsl:if test="PupilReconciliation/PartTimeNotIn &gt; count(../../Pupils/PupilsOnRoll/PupilOnRoll/PupilStatus[contains($true, concat(' ', PartTime, ' ') )] )">
						<xsl:call-template name="Error">
							<xsl:with-param name="err_num" select="930"/>
						</xsl:call-template>
					</xsl:if>
					<!--940 Number of private study pupils is missing-->
					<xsl:if test="string-length(PupilReconciliation/PrivateStudy) = 0 
						or PupilReconciliation/PrivateStudy &lt; 0">
						<xsl:call-template name="Error">
							<xsl:with-param name="err_num" select="940"/>
						</xsl:call-template>
					</xsl:if>
					<!--950 Number of pupils at another school is missing-->
					<xsl:if test="string-length(PupilReconciliation/AtOtherSchool) = 0 
						or PupilReconciliation/AtOtherSchool &lt; 0">
						<xsl:call-template name="Error">
							<xsl:with-param name="err_num" select="950"/>
						</xsl:call-template>
					</xsl:if>
					<!--953 Number of pupils on work experience is missing-->
					<xsl:if test="string-length(PupilReconciliation/WorkExperience) = 0 
						or PupilReconciliation/WorkExperience &lt; 0">
						<xsl:call-template name="Error">
							<xsl:with-param name="err_num" select="953"/>
						</xsl:call-template>
					</xsl:if>
					<!--957 Number of pupils at FE colleges is missing -->
					<xsl:if test="string-length(PupilReconciliation/FEcollege) = 0 
						or PupilReconciliation/FEcollege &lt; 0">
						<xsl:call-template name="Error">
							<xsl:with-param name="err_num" select="957"/>
						</xsl:call-template>
					</xsl:if>
					<xsl:choose>
						<xsl:when test="../SchoolCharacteristics/Phase='PS' or ../SchoolCharacteristics/Phase='MP' ">
							<!--1010 Please check:10%+ of pupils not in class at selected time-->
							<!--New part of validation for these phases 2016-08-30-->
							<xsl:if test="not( (PupilReconciliation/PrivateStudy 
										+ PupilReconciliation/AtOtherSchool 
										) &lt; 
										( (count(../../Pupils/PupilsOnRoll/PupilOnRoll) 
											- (count(../../Pupils/PupilsOnRoll/PupilOnRoll/PupilStatus[contains($true, concat(' ', PartTime, ' ') )] ) * 0.5) )
										* 0.1)
										)">
								<xsl:call-template name="Error">
									<xsl:with-param name="err_num" select="1010"/>
								</xsl:call-template>
							</xsl:if>
						</xsl:when>
						<xsl:when test="../SchoolCharacteristics/Phase='MS' ">
							<!--1010 Please check:10%+ of pupils not in class at selected time -->
							<xsl:if test="not( (PupilReconciliation/PrivateStudy 
										+ PupilReconciliation/AtOtherSchool 
										+ PupilReconciliation/WorkExperience 
										+ PupilReconciliation/FEcollege 
										) &lt; 
										(count(../../Pupils/PupilsOnRoll/PupilOnRoll) * 0.1)
										)">
								<xsl:call-template name="Error">
									<xsl:with-param name="err_num" select="1010"/>
								</xsl:call-template>
							</xsl:if>
						</xsl:when>
						<xsl:when test="../SchoolCharacteristics/Phase='SS' or ../SchoolCharacteristics/Phase='AT' ">
							<!--1010 Please check:10%+ of pupils not in class at selected time-->
							<!--Added test for schools with phase of 'AT' IK 2013-05-10 -->
							<xsl:if test="not( (PupilReconciliation/PrivateStudy 
										+ PupilReconciliation/AtOtherSchool 
										+ PupilReconciliation/WorkExperience 
										+ PupilReconciliation/FEcollege 
										) &lt; 
										( (count(../../Pupils/PupilsOnRoll/PupilOnRoll) 
											- (count(../../Pupils/PupilsOnRoll/PupilOnRoll/PupilStatus[contains($true, concat(' ', PartTime, ' ') )] ) * 0.5) )
										* 0.1)
										)">
								<xsl:call-template name="Error">
									<xsl:with-param name="err_num" select="1010"/>
								</xsl:call-template>
							</xsl:if>
						</xsl:when>
						<xsl:otherwise>
							<!--Rule 1010 does not apply to phases NS, SP, or PR-->
						</xsl:otherwise>
					</xsl:choose>
					<!--The following tests apply to 1000 / 5026 / 5027-->
					<xsl:choose>
						<xsl:when test="contains(' SS MS AT ', concat(' ', ../SchoolCharacteristics/Phase, ' ') )">
							<!--1000 Pupil reconciliation does not match number of pupils on roll-->
							<xsl:if test="(PupilReconciliation/PartTimeNotIn 
										+ PupilReconciliation/PrivateStudy 
										+ PupilReconciliation/AtOtherSchool 
										+ PupilReconciliation/WorkExperience 
										+ PupilReconciliation/FEcollege 
										+ sum(../Classes/Class/HomePupils)
										) != count(../../Pupils/PupilsOnRoll/PupilOnRoll/PupilStatus[contains(' C M S ', EnrolStatus)] )">
								<xsl:call-template name="Error">
									<xsl:with-param name="err_num" select="1000"/>
								</xsl:call-template>
							</xsl:if>
						</xsl:when>
						<xsl:otherwise>
							<!--1000 Pupil reconciliation does not match number of pupils on roll (PS, MP only)-->
							<xsl:if test=" (../SchoolCharacteristics/Phase='PS' or ../SchoolCharacteristics/Phase='MP')">
								<xsl:if test="(PupilReconciliation/PartTimeNotIn 
											+ PupilReconciliation/PrivateStudy 
											+ PupilReconciliation/AtOtherSchool 
											+ sum(../Classes/Class/HomePupils)
											) != count(../../Pupils/PupilsOnRoll/PupilOnRoll/PupilStatus[contains(' C M S ', EnrolStatus)] )">
									<xsl:call-template name="Error">
										<xsl:with-param name="err_num" select="1000"/>
									</xsl:call-template>
								</xsl:if>
							</xsl:if>
							<!--5026 Pupils can only be on work experience if the census return is from a school with a phase of MS, SS or AT-->
							<xsl:if test="string-length(/Message/School/Reconciliation/PupilReconciliation/WorkExperience) != 0">
								<xsl:call-template name="Error">
									<xsl:with-param name="err_num" select="5026"/>
								</xsl:call-template>
							</xsl:if>
							<!--5027 Pupils can only be attending an FE college if the census return is from a school with a phase of MS, SS or AT-->
							<xsl:if test="string-length(/Message/School/Reconciliation/PupilReconciliation/FEcollege) != 0">
								<xsl:call-template name="Error">
									<xsl:with-param name="err_num" select="5027"/>
								</xsl:call-template>
							</xsl:if>
							<!-- End of additions -->
						</xsl:otherwise>
					</xsl:choose>
				</xsl:for-each>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>
	<xsl:template name="PupilIdentifiersStructureValidation">
		<!--This selection checks to see if there is a PupilIdentifier node is present on the input-->
		<!--if there isn't a default UPN missing message is written-->
		<!--Otherwise carry out the normal validation testing-->
		<xsl:variable name="data" select="concat('UPN: ', PupilIdentifiers/UPN, '. Name: ', PupilIdentifiers/Surname, ', ', PupilIdentifiers/Forename, '. Date of Birth: ', PupilIdentifiers/DOB, ', ', PupilIdentifiers/Sex )" />

		<!--2901 Programme aim missing or invalid - crowbarring in here as it might be appropriate-->
		<!--SS: I don't think an 'or invalid' is appropriate in the error message as we aren't doing anything other than checking for presence.-->
		<!--SS: Furthermore, no phase check on here at present - but inappropriate schools should be filtered out via the error message phase.-->
		<!--removed for 21-22
		<xsl:if test="../PupilOnRoll 
			and count(LearningAims) &gt; 0
			and (string-length(ProgrammeAims) = 0
					or count(ProgrammeAims) = 0
					or count(ProgrammeAims/ProgrammeAim) = 0) ">
			<xsl:call-template name="Error">
				<xsl:with-param name="err_num" select="2901"/>
				<xsl:with-param name="data" select="$data"/>
			</xsl:call-template>
		</xsl:if>		-->
		<xsl:choose>
			<xsl:when test="not(PupilIdentifiers) or PupilIdentifiers = '' ">
				<xsl:call-template name="Error">
					<xsl:with-param name="err_num" select="9999"/>
					<xsl:with-param name="data" select="concat('UPN: ', 'Name: ', 'Date of Birth: PupilIdentifiers') "/>
				</xsl:call-template>
			</xsl:when>
			<xsl:otherwise>
				<xsl:apply-templates select="PupilIdentifiers"/>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>
	<xsl:template match="PupilIdentifiers">
		<!--Note: the following two rules check the age at census date / leaving date by subtracting one from the other (after removing the hyphens).
			so, while this isn't useful for calculating the actual number of days, it works for the age boundaries. On the last day of the pupil's thirteenth year,
			the expression evaluates to 139999. On their fourteenth birthday, it kicks over to 140000. Think of it as a netmask, style of thing-->
		<xsl:variable name="data" select="concat('UPN: ', UPN, '. Name: ', Surname, ', ', Forename, '. Date of Birth: ', DOB, ', ', Sex )" />
		<!--1570 Unique learner number must be provided for pupils aged 14 and over on census day-->
		<xsl:if test="../../PupilOnRoll
			and string-length(UniqueLearnerNumber)=0 
			and $RefDate - translate(DOB, '-', '') &gt;= 140000">
			<xsl:call-template name="Error">
				<xsl:with-param name="err_num" select="1570"/>
				<xsl:with-param name="data" select=" $data"/>
			</xsl:call-template>
		</xsl:if>
		<!--1573 Unique learner number must be provided for pupils aged 14 and over at date of leaving-->
		<xsl:if test="../../PupilNoLongerOnRoll
			and string-length(UniqueLearnerNumber)=0 
			and translate(../PupilStatus/LeavingDate, '-', '') - translate(DOB, '-', '') &gt;= 140000">
			<xsl:call-template name="Error">
				<xsl:with-param name="err_num" select="1573"/>
				<xsl:with-param name="data" select="concat('UPN: ', UPN, '. Name: ', Surname, ', ', Forename, '. Date of Birth: ', DOB, ', ', Sex ) "/>
			</xsl:call-template>
		</xsl:if>
		<xsl:if test="UPN and not(UPN = '')">
			<xsl:call-template name="UPN">
				<xsl:with-param name="UPN" select="UPN"/>
				<xsl:with-param name="type" select=" 'Main UPN: ' "/>
			</xsl:call-template>
		</xsl:if>
		<xsl:if test="FormerUPN and not(FormerUPN = '')">
			<xsl:call-template name="UPN">
				<xsl:with-param name="UPN" select="FormerUPN"/>
				<xsl:with-param name="type" select=" 'Former UPN: ' "/>
			</xsl:call-template>
		</xsl:if>
		<xsl:call-template name="PupilIdentifiersValidation"/>
	</xsl:template>
	<xsl:template match="Exclusions/TermlyExclusion">
		<xsl:call-template name="ExclusionsValidation"/>
	</xsl:template>
	<xsl:template match="ProgrammeAims">
		<!--Separate template from learning aims as only called for on-roll-->
		<xsl:call-template name="Post16ProgrammeAimsValidation"/>
	</xsl:template>
	<xsl:template match="ProgrammeAims/ProgrammeAim/LearningAims">
		<xsl:call-template name="Post16LearningAimsValidation"/>
	</xsl:template>	
	<!--Pupil Level Validation %-->
	<xsl:template name="PupilLevelValidation">
		<xsl:variable name="SupportCodeCount" select="count(/Message/Pupils/PupilsOnRoll/PupilOnRoll/PupilCharacteristics/LearnerSupport/LearnerSupportItem/SupportCode
			[. = '55' or .='56'] ) "/>
		<!--Used in 1750Q-->
		<xsl:variable name="FSMcount" select="count(/Message/Pupils/PupilsOnRoll/PupilOnRoll[count(PupilCharacteristics/FSMeligibility/FSMperiod) &gt; 0] ) "/>
		<!--Both the following used in 1751Q-->
		<xsl:variable name="FSMcountR" select=" count(/Message/Pupils/PupilsOnRoll/PupilOnRoll
			[PupilCharacteristics/FSMeligibility/FSMperiod 
			and contains(' R ', concat(' ', PupilStatus/NCyearActual, ' ') ) ] ) "/>
		<xsl:variable name="PupilOnRollCountR" select="count(/Message/Pupils/PupilsOnRoll/PupilOnRoll
			[contains(' R ', concat(' ', PupilStatus/NCyearActual, ' ') ) ] ) "/>
		<!--Both the following used in 1752Q-->
		<xsl:variable name="FSMcount1" select=" count(/Message/Pupils/PupilsOnRoll/PupilOnRoll
			[PupilCharacteristics/FSMeligibility/FSMperiod 
			and contains(' 1 ', concat(' ', PupilStatus/NCyearActual, ' ') ) ] ) "/>
		<xsl:variable name="PupilOnRollCount1" select="count(/Message/Pupils/PupilsOnRoll/PupilOnRoll
			[contains(' 1 ', concat(' ', PupilStatus/NCyearActual, ' ') ) ] ) "/>
		<!--Both the following used in 1753Q-->
		<xsl:variable name="FSMcount7" select=" count(/Message/Pupils/PupilsOnRoll/PupilOnRoll
			[PupilCharacteristics/FSMeligibility/FSMperiod 
			and contains(' 7 ', concat(' ', PupilStatus/NCyearActual, ' ') ) ] ) "/>
		<xsl:variable name="PupilOnRollCount7" select="count(/Message/Pupils/PupilsOnRoll/PupilOnRoll
			[contains(' 7 ', concat(' ', PupilStatus/NCyearActual, ' ') ) ] ) "/>
		<!--1490 There should be at least one <PupilOnRoll> record present-->
		<xsl:if test="string-length(/Message/Pupils/PupilsOnRoll)=0 
			or not(/Message/Pupils/PupilsOnRoll) 
			or /Message/Pupils/PupilsOnRoll = '' 
			or count(/Message/Pupils[PupilsOnRoll] )=0 
			or count( //PupilsOnRoll[PupilOnRoll and not(//PupilOnRoll = '') ] ) = 0	">
			<xsl:call-template name="Error">
				<xsl:with-param name="err_num" select="1490"/>
			</xsl:call-template>
		</xsl:if>
		<xsl:if test="$Phase != 'NS'
			and (string-length(/Message/Pupils/PupilsNoLongerOnRoll)=0 
				or not(/Message/Pupils/PupilsNoLongerOnRoll) 
				or /Message/Pupils/PupilsNoLongerOnRoll = '' 
				or count(/Message/Pupils[PupilsNoLongerOnRoll] )=0 
				or count( //PupilsNoLongerOnRoll[PupilNoLongerOnRoll and not(//PupilNoLongerOnRoll = '') ] ) = 0 )">
			<xsl:call-template name="Error">
				<xsl:with-param name="err_num" select="1495"/>
			</xsl:call-template>
		</xsl:if>
		<!-- 1496 is identical to 1495 but is an error instead of a query and only comes out on Autumn collection. 1495 applies to only Spring & Summer-->
		<xsl:if test="$Phase != 'NS'
			and (string-length(/Message/Pupils/PupilsNoLongerOnRoll)=0 
				or not(/Message/Pupils/PupilsNoLongerOnRoll) 
				or /Message/Pupils/PupilsNoLongerOnRoll = '' 
				or count(/Message/Pupils[PupilsNoLongerOnRoll] )=0 
				or count( //PupilsNoLongerOnRoll[PupilNoLongerOnRoll and not(//PupilNoLongerOnRoll = '') ] ) = 0 )">
			<xsl:call-template name="Error">
				<xsl:with-param name="err_num" select="1496"/>
			</xsl:call-template>
		</xsl:if>		
		<!--1885 Please check: Percentage of pupils in school with a new entry date seems high-->
		<xsl:if test="count(Pupils/PupilsOnRoll/PupilOnRoll[translate(PupilStatus/EntryDate, '-', '') &gt;= $EntryDateCheck ]) &gt; count(Pupils/PupilsOnRoll/PupilOnRoll) * 0.5 ">
			<xsl:call-template name="Error">
				<xsl:with-param name="err_num" select="1885"/>
			</xsl:call-template>
		</xsl:if>
		<!--2695Q / RFC 786 Please check: More than 90% of infant pupils have periods of free school meal eligibility.-->
		<!--amended to check for current FSM eligibility rather than just any FSM record - v1.7 of spec ACN 19/8/15-->
		<xsl:if test="$R12XPupilsFSMPeriod &gt;= ($R12XPupilsAll * 0.9) and $R12XPupilsAll &gt; 0">
			<xsl:call-template name="Error">
				<xsl:with-param name="err_num" select="2695"/>
			</xsl:call-template>
		</xsl:if>
		<!--1999 Please check: No pupils have planned employability, enrichment and pastoral hours-->
		<xsl:if test="$term = 'AUT' 
			and contains(' SS AT PR ', $_Phase_ )
			and (count(/Message/Pupils/PupilsOnRoll/PupilOnRoll
				[PupilCharacteristics/QualHrs &gt; 0] ) 
				+ count(/Message/Pupils/PupilsNoLongerOnRoll/PupilNoLongerOnRoll
					[PupilCharacteristics/QualHrs &gt; 0] ) &gt; 0 
						and count(/Message/Pupils/PupilsOnRoll/PupilOnRoll
						[PupilCharacteristics/Non_qualHrs &gt; 0] ) 
					+ count(/Message/Pupils/PupilsNoLongerOnRoll/PupilNoLongerOnRoll[
						PupilCharacteristics/Non_qualHrs &gt; 0] ) = 0)">
			<xsl:call-template name="Error">
				<xsl:with-param name="err_num" select="1999"/>
			</xsl:call-template>
		</xsl:if>
		<!--(AUT) 1892 new for 19-20-->
		<xsl:if test="$term = 'AUT' 
						and contains(' SS AT PR ', $_Phase_ )
						and (count(/Message/Pupils/PupilsOnRoll/PupilOnRoll [PupilCharacteristics/QualHrsPreviousYear &gt; 0] ) 
								+ count(/Message/Pupils/PupilsNoLongerOnRoll/PupilNoLongerOnRoll [PupilCharacteristics/QualHrsPreviousYear &gt; 0] ) &gt; 0 
						and count(/Message/Pupils/PupilsOnRoll/PupilOnRoll [PupilCharacteristics/Non_qualHrsPreviousYear &gt; 0] ) 
								+ count(/Message/Pupils/PupilsNoLongerOnRoll/PupilNoLongerOnRoll[PupilCharacteristics/Non_qualHrsPreviousYear &gt; 0] ) = 0)">
			<xsl:call-template name="Error">
				<xsl:with-param name="err_num" select="1892"/>
			</xsl:call-template>
		</xsl:if>
		<!--1991 Please check: No pupils with a statement of SEN or EHCP are reported as being in receipt of top-up funding?-->
		<xsl:if test="count(/Message/Pupils/PupilsOnRoll/PupilOnRoll
				[contains(' E ', concat(' ', SpecialEducationalNeeds/SENprovision,' ') ) ] ) &gt;0 
			and count(/Message/Pupils/PupilsOnRoll/PupilOnRoll
				[contains($true, concat(' ', PupilCharacteristics/TopUpFunding, ' ') )  
					and (contains(' E ', concat(' ', SpecialEducationalNeeds/SENprovision,' ') ) ) ] ) = 0">
			<xsl:call-template name="Error">
				<xsl:with-param name="err_num" select="1991"/>
			</xsl:call-template>
		</xsl:if>
		<!--1873 Where count of pupils aged between 16 to 19 as at %date% is greater than 10 there should be at least one <SupportCode> node present-->
		<xsl:if test="$PupilsAgedOver15 &gt; 10">
			<xsl:if test="$SupportCodeCount = 0 ">
				<xsl:call-template name="Error">
					<xsl:with-param name="err_num" select="1873"/>
				</xsl:call-template>
			</xsl:if>
		</xsl:if>
		<!-- RFC1183 NEW RULE ADDED - IW 2021-08-20-->	
		<!--4007Q No pupils on roll are in receipt of School Led Tutoring-->
		<xsl:if test="( (count(/Message/Pupils/PupilsOnRoll/PupilOnRoll/PupilStatus[contains(' 1 2 3 4 5 6 7 8 9 10 11 ', concat( ' ', NCyearActual, ' ' ))]) != 0
						or count(/Message/Pupils/PupilsOnRoll/PupilOnRoll/PupilIdentifiers[translate(DOB, '-', '') &lt;= $y5DoBmax 
																							and translate(DOB, '-', '') &gt;= $y15min 
																							and ../PupilStatus/NCyearActual = 'X'] ) != 0
						)
						and count(/Message/Pupils/PupilsOnRoll/PupilOnRoll/PupilCharacteristics/LearnerFAMModule/LearnerFAM[contains(' 01 ', concat( ' ', LearnFAMCode, ' ' ))]) = 0 
					)">
			<xsl:call-template name="Error">
				<xsl:with-param name="err_num" select="4007"/>
			</xsl:call-template>
		</xsl:if>
		<!-- RFC1183 NEW RULE ADDED - IW 2021-08-20-->	
		<!--4008Q No students on roll are in receipt of 16-19 Learner Funding and Monitoring-->
		<xsl:if test="( count(/Message/Pupils/PupilsOnRoll/PupilOnRoll/PupilStatus[contains(' 12 13 14 ', concat( ' ', NCyearActual, ' ' ))]) != 0
						and count(/Message/Pupils/PupilsOnRoll/PupilOnRoll/PupilCharacteristics/LearnerFAMModule/LearnerFAM[contains(' 21 22 ', concat( ' ', LearnFAMCode, ' ' ))]) = 0 
					)">
			<xsl:call-template name="Error">
				<xsl:with-param name="err_num" select="4008"/>
			</xsl:call-template>
		</xsl:if>
		<!--4015Q At least one <SchoolArrangedAPDetail> node should be present -->		
		<xsl:if test="$Phase != 'NS' and string-length(//SchoolArrangedAPDetail) = 0">													   
			<xsl:call-template name="Error">
				<xsl:with-param name="err_num" select="4015"/>
			</xsl:call-template>		
		</xsl:if>
		<!--4016 At least one <APProvisionDetail> node should be present -->
		<xsl:if test="$Phase = 'PR' and string-length(//APProvisionDetail) = 0">													   
			<xsl:call-template name="Error">
				<xsl:with-param name="err_num" select="4016"/>
			</xsl:call-template>		
		</xsl:if>
		<!--5065: Added 2014-04-10 ACN-->
		<xsl:if test="(string-length(/Message/Pupils/PupilsNoLongerOnRoll) !=0 
			or (/Message/Pupils/PupilsNoLongerOnRoll) 
			or count(/Message/Pupils[PupilsNoLongerOnRoll] )>0) 
				and (/Message/School/SchoolCharacteristics/Phase) = 'NS' ">
			<xsl:call-template name="Error">
				<xsl:with-param name="err_num" select="5065"/>
			</xsl:call-template>
		</xsl:if>
		<!--1520: UPN should be unique-->
		<!--Excludes off-roll for nursery schools-->
		<xsl:choose>
			<xsl:when test="$Phase = 'NS' ">
				<xsl:for-each select="//PupilsOnRoll//UPN[ ( . =  preceding::UPN ) and not( . = following::UPN ) ]">
					<xsl:for-each select="//PupilIdentifiers[ UPN = current() ] ">
						<xsl:variable name="ErrSex">
							<xsl:if test="Sex = 'M' ">Male</xsl:if>
							<xsl:if test="Sex = 'F' ">Female</xsl:if>
						</xsl:variable>
						<xsl:call-template name="Error">
							<xsl:with-param name="err_num" select="1520"/>
							<xsl:with-param name="data" select="concat('UPN: ', UPN, 
								 '. Name: ', Surname, ', ' , Forename, '.' , 
								 ' Date of Birth: ', DOB, ', ',
								 $ErrSex ) "/>
						</xsl:call-template>
					</xsl:for-each>
				</xsl:for-each>
			</xsl:when>
			<xsl:otherwise>
				<xsl:for-each select="//UPN[ ( . =  preceding::UPN ) and not( . = following::UPN ) ]">
					<xsl:for-each select="//PupilIdentifiers[ UPN = current() ] ">
						<xsl:variable name="ErrSex">
							<xsl:if test="Sex = 'M' ">Male</xsl:if>
							<xsl:if test="Sex = 'F' ">Female</xsl:if>
						</xsl:variable>
						<xsl:call-template name="Error">
							<xsl:with-param name="err_num" select="1520"/>
							<xsl:with-param name="data" select="concat('UPN: ', UPN, 
								 '. Name: ', Surname, ', ' , Forename, '.' , 
								 ' Date of Birth: ', DOB, ', ',
								 $ErrSex ) "/>
						</xsl:call-template>
					</xsl:for-each>
				</xsl:for-each>
			</xsl:otherwise>
		</xsl:choose>
		<!--1578: UniqueLearnerNumber should be unique-->
		<xsl:for-each select="//UniqueLearnerNumber[ ( . =  preceding::UniqueLearnerNumber ) and not( . = following::UniqueLearnerNumber ) ]">
			<xsl:for-each select="//PupilIdentifiers[ UniqueLearnerNumber = current() ] ">
				<xsl:if test="not(UniqueLearnerNumber = '')">
					<xsl:variable name="ErrSex">
						<xsl:if test="Sex = 'M' ">Male</xsl:if>
						<xsl:if test="Sex = 'F' ">Female</xsl:if>
					</xsl:variable>
					<xsl:call-template name="Error">
						<xsl:with-param name="err_num" select="1578"/>
						<xsl:with-param name="data" select="concat('UPN: ', UPN, 
										 '. Name: ', Surname, ', ' , Forename, '.' ,  
										 ' Date of Birth: ', DOB, ', ', $ErrSex, ',' ,' ULN: ', UniqueLearnerNumber ) "/>
					</xsl:call-template>
				</xsl:if>
			</xsl:for-each>
		</xsl:for-each>
		<!--3160: The 30-hour code is a duplicate of that used in another record.-->
		<xsl:for-each select="//ThirtyHourCode[ ( . =  preceding::ThirtyHourCode) and not( . = following::ThirtyHourCode) ]">
			<xsl:for-each select="//PupilCharacteristics[ ThirtyHourCode = current() ] ">
				<xsl:if test="not(ThirtyHourCode = '')">
					<xsl:variable name="ErrSex">
						<xsl:if test="../PupilIdentifiers/Sex = 'M' ">Male</xsl:if>
						<xsl:if test="../PupilIdentifiers/Sex = 'F' ">Female</xsl:if>
					</xsl:variable>
					<xsl:call-template name="Error">
						<xsl:with-param name="err_num" select="3160"/>
						<xsl:with-param name="data" select="concat('UPN: ', ../PupilIdentifiers/UPN, 
							 '. Name: ', ../PupilIdentifiers/Surname, ', ' , ../PupilIdentifiers/Forename, '.' ,  
							 ' Date of Birth: ', ../PupilIdentifiers/DOB, ', ', $ErrSex ) "/>
					</xsl:call-template>
				</xsl:if>
			</xsl:for-each>
		</xsl:for-each>
		<!--1620Q: Pupil Details should be different-->
		<xsl:for-each select="//Surname">
			<xsl:if test="count(//PupilIdentifiers[translate(Surname, $lowercase, $alphabet) = translate(current() , $lowercase, $alphabet) ] ) &gt; 1">
				<!--data in case of errors found-->
				<xsl:variable name="errsurn" select="../Surname"/>
				<xsl:variable name="errfn" select="../Forename"/>
				<!--duplicate surnames - check the other details-->
				<xsl:variable name="ref" select="../UPN"/>
				<xsl:variable name="surn" select="translate(../Surname, $lowercase, $alphabet) "/>
				<xsl:variable name="fn" select="translate(../Forename, $lowercase, $alphabet) "/>
				<xsl:variable name="gend" select="../Sex"/>
				<xsl:variable name="bd" select="../DOB"/>
				<!--if count of common details more than 1 duplicate-->
				<xsl:if test="count(//PupilIdentifiers[translate(Surname, $lowercase, $alphabet) =$surn
						and translate(Forename, $lowercase, $alphabet) = $fn
						and Sex=$gend 
						and DOB=$bd] ) &gt; 1">
					<xsl:variable name="ErrSex">
						<xsl:if test="$gend = 'M' ">Male</xsl:if>
						<xsl:if test="$gend = 'F' ">Female</xsl:if>
					</xsl:variable>
					<xsl:call-template name="Error">
						<xsl:with-param name="err_num" select="1620"/>
						<xsl:with-param name="data" select="concat('UPN: ', $ref, 
							 '. Name: ', $errsurn, ', ' , $errfn, '.'  ,
							 ' Date of Birth: ', $bd, ', ',
							 $ErrSex ) "/>
					</xsl:call-template>
				</xsl:if>
			</xsl:if>
		</xsl:for-each>
		<!--Pupil Characteristics-->
		<!--1750Q Please check: Percentage of pupils with periods of free school meal eligibility is high (greater than 45%)-->
		<xsl:if test="$PupilOnRollCount &gt;= 25">
			<xsl:if test="$FSMcount &gt; $PupilOnRollCount * 0.45">
				<xsl:call-template name="Error">
					<xsl:with-param name="err_num" select="1750"/>
				</xsl:call-template>
			</xsl:if>
		</xsl:if>
		<!--1751Q: Please check: Percentage of pupils in Reception with periods of free school meal eligibility is high (greater than 50%)-->
		<xsl:if test="$PupilOnRollCountR &gt;= 10">
			<xsl:if test="$FSMcountR &gt; $PupilOnRollCountR * 0.5">
				<xsl:call-template name="Error">
					<xsl:with-param name="err_num" select="1751"/>
				</xsl:call-template>
			</xsl:if>
		</xsl:if>
		<!--1752Q: Please check: Percentage of pupils in NC Year 1 with periods of free school meal eligibility is high (greater than 50%)-->
		<xsl:if test="$PupilOnRollCount1 &gt;= 10">
			<xsl:if test="$FSMcount1 &gt; $PupilOnRollCount1 * 0.5">
				<xsl:call-template name="Error">
					<xsl:with-param name="err_num" select="1752"/>
				</xsl:call-template>
			</xsl:if>
		</xsl:if>
		<!--1753Q: Please check: Percentage of pupils in NC Year 7 with periods of free school meal eligibility is high (greater than 50%)-->
		<xsl:if test="$PupilOnRollCount7 &gt;= 10">
			<xsl:if test="$FSMcount7 &gt; $PupilOnRollCount7 * 0.5">
				<xsl:call-template name="Error">
					<xsl:with-param name="err_num" select="1753"/>
				</xsl:call-template>
			</xsl:if>
		</xsl:if>
		<!--1760Q: Please check: No pupils in the school eligible for free school meals during the period since the last census-->
		<xsl:if test="count(/Message/Pupils/PupilsOnRoll/PupilOnRoll/PupilCharacteristics/FSMeligibility/FSMperiod) = 0 ">
			<xsl:call-template name="Error">
				<xsl:with-param name="err_num" select="1760"/>
			</xsl:call-template>
		</xsl:if>
		<!--1850Q: Please check: Percentage of pupils where language has not been obtained is high-->
		<xsl:if test="count(/Message/Pupils/PupilsOnRoll/PupilOnRoll/PupilCharacteristics[Language = 'NOT'] ) &gt; $PupilOnRollCount * 0.1">
			<xsl:call-template name="Error">
				<xsl:with-param name="err_num" select="1850"/>
			</xsl:call-template>
		</xsl:if>
		<!--1877Q Take up of school lunches for pupils in reception, year 1 and year 2 (plus pupils aged 4 to 6 in year X) greater than 95%. Please confirm more than 95% of infant pupils took a school lunch on census day-->
		<xsl:if test="$Phase != 'NS' 
			and $R12XPupilsFSMTaken &gt; ($R12XPupilsAll * 0.95)">
			<xsl:call-template name="Error">
				<xsl:with-param name="err_num" select="1877"/>
			</xsl:call-template>
		</xsl:if>
		<!--1878Q Where count of pupils [in <NCyearActual> = R, 1 or 2] is >0 then there should be at least one pupil with <SchoolLunchTaken> equal to true or 1-->
		<xsl:if test="$Phase != 'NS' 
			and $R12XPupilsAll &gt; 0 and $R12XPupilsFSMTaken = 0">
			<xsl:call-template name="Error">
				<xsl:with-param name="err_num" select="1878"/>
			</xsl:call-template>
		</xsl:if>
		<!--1870Q: Please check: Percentage of pupils with sole registrations at the school is low-->
		<xsl:if test="count(/Message/Pupils/PupilsOnRoll/PupilOnRoll/PupilStatus[EnrolStatus = 'C'] ) &lt;
					 $PupilOnRollCount * 0.95">
			<xsl:call-template name="Error">
				<xsl:with-param name="err_num" select="1870"/>
			</xsl:call-template>
		</xsl:if>
		<!--1872 Please check: Percentage of pupils on roll on census day reported as having ceased to be looked after is high (greater than 5%)-->
		<xsl:if test="count(/Message/Pupils/PupilsOnRoll/PupilOnRoll/PupilCharacteristics[PLAA != 'N'] )
					 &gt; $PupilOnRollCount * 0.05">
			<xsl:call-template name="Error">
				<xsl:with-param name="err_num" select="1872"/>
			</xsl:call-template>
		</xsl:if>
		<!--1960Q: Please check: Percentage of part-time pupils in school seems high-->
		<xsl:if test="count(/Message/Pupils/PupilsOnRoll/PupilOnRoll/PupilStatus
								[contains($true, concat(' ', PartTime , ' ') ) ] ) 
							&gt; $PupilOnRollCount * 0.35">
			<xsl:call-template name="Error">
				<xsl:with-param name="err_num" select="1960"/>
			</xsl:call-template>
		</xsl:if>
		<!--Please check: School has reported boarding pupils-->
		<xsl:if test="contains(' PS MP MS SS AT PR ', $_Phase_ )
			and count(/Message/Pupils/PupilsOnRoll/PupilOnRoll/PupilStatus[Boarder= 'B'] ) &gt; 0 ">
			<xsl:call-template name="Error">
				<xsl:with-param name="err_num" select="1980"/>
			</xsl:call-template>
		</xsl:if>
		<!--2010 Test number out of year-->
		<!--Update from autumn 2018 onwards - now checks DOB at different dates for pupils under four years old-->
		<!--Age calculation is taken by subtracting DOB from RisingDate and dividing by 10k effectively-->
		<xsl:variable name="NumOutOfYear">
			<xsl:value-of select="
				count(/Message/Pupils/PupilsOnRoll/PupilOnRoll
					[ $InfRisingDate - translate(PupilIdentifiers/DOB, '-', '') &lt; 20000 
						and (not(contains(' E1 E2 ', concat(' ', PupilStatus/NCyearActual, ' ') ) ) ) ] ) 
				+ count(/Message/Pupils/PupilsOnRoll/PupilOnRoll
					[ $InfRisingDate - translate(PupilIdentifiers/DOB, '-', '') &gt;= 20000 and $InfRisingDate - translate(PupilIdentifiers/DOB, '-', '') &lt; 30000
						and (not(contains(' E1 E2 N1 N2 ', concat(' ', PupilStatus/NCyearActual, ' ') ) ) ) ] ) 
				+ count(/Message/Pupils/PupilsOnRoll/PupilOnRoll
					[ $InfRisingDate - translate(PupilIdentifiers/DOB, '-', '') &gt;= 30000 and $InfRisingDate - translate(PupilIdentifiers/DOB, '-', '') &lt; 40000 
						and (not(contains(' N1 N2 ', concat(' ', PupilStatus/NCyearActual ,' ') ) ) ) ] ) 
			 	+ count(/Message/Pupils/PupilsOnRoll/PupilOnRoll
					[ ( floor(($AgeCalcDate - translate(PupilIdentifiers/DOB, '-','')) div 10000) = 4 ) 
						and (not(contains(' N1 N2 R 1 ', concat(' ', PupilStatus/NCyearActual, ' ') ) ) ) ] ) 
				+ count(/Message/Pupils/PupilsOnRoll/PupilOnRoll
					[ ( floor(($AgeCalcDate - translate(PupilIdentifiers/DOB, '-','')) div 10000) = 5 ) 
						and (not(contains(' R 1 2 ', concat(' ', PupilStatus/NCyearActual, ' ') ) ) ) ] ) 
				+ count(/Message/Pupils/PupilsOnRoll/PupilOnRoll
					[ ( floor(($AgeCalcDate - translate(PupilIdentifiers/DOB, '-','')) div 10000) &gt; 5 )
						and floor(($AgeCalcDate - translate(PupilIdentifiers/DOB, '-','')) div 10000) &lt; 19
						and ( floor(($AgeCalcDate - translate(PupilIdentifiers/DOB, '-','')) div 10000) - 4 
						!= PupilStatus/NCyearActual) ] )
				+ count(/Message/Pupils/PupilsOnRoll/PupilOnRoll
					[ ( floor(($AgeCalcDate - translate(PupilIdentifiers/DOB, '-','')) div 10000) &gt;= 19 )
						and not(PupilStatus/NCyearActual) = 14 ] ) "/>
		</xsl:variable>
		<xsl:if test="$NumOutOfYear &gt; $PupilOnRollCount * 0.1">
			<xsl:call-template name="Error">
				<xsl:with-param name="err_num" select="2010"/>
			</xsl:call-template>
		</xsl:if>
		<!--2040: Please check: Expected year group with no pupils (apart from year 14)-->
		<!--Amended on 27/07/2015 to exclude Type = 49 after discussion with CSU. Code within each section (Phase) left in for now but blanket exclusion put in at the top.-->
		<xsl:choose>
			<!--Exclusions: various school types / academies-->
			<xsl:when test="contains(' NS SP PR ', $_Phase_ ) "/>
			<xsl:when test="$SchoolType = '49' "/>
			<!--Primary Schools-->
			<xsl:when test="$Phase = 'PS' and $SchoolType = '01' and $PupilsAged5 * $PupilsAged6 * $PupilsAged7 != 0 "/>
			<xsl:when test="$Phase = 'PS' and $SchoolType = '16' and $PupilsAged5 * $PupilsAged6 != 0 "/>
			<xsl:when test="$Phase = 'PS' and $SchoolType = '02' and $PupilsAged5 * $PupilsAged6 * $PupilsAged7 * $PupilsAged8 != 0"/>
			<xsl:when test="$Phase = 'PS' and $SchoolType = '03' and $PupilsAged5 * $PupilsAged6 * $PupilsAged7 * $PupilsAged8 * $PupilsAged9 != 0"/>
			<xsl:when test="$Phase = 'PS' and $SchoolType = '04' and $PupilsAged5 * $PupilsAged6 * $PupilsAged7 * $PupilsAged8 * $PupilsAged9 * $PupilsAged10 * $PupilsAged11!= 0"/>
			<xsl:when test="$Phase = 'PS' and $SchoolType = '17' and $PupilsAged7 * $PupilsAged8 * $PupilsAged9 * $PupilsAged10 != 0"/>
			<xsl:when test="$Phase = 'PS' and $SchoolType = '18' and $PupilsAged5 * $PupilsAged6 * $PupilsAged7 * $PupilsAged8 * $PupilsAged9 * $PupilsAged10 != 0"/>
			<xsl:when test="$Phase = 'PS' and $SchoolType = '42' and $PupilsAged5 * $PupilsAged6 != 0"/>
			<xsl:when test="$Phase = 'PS' and $SchoolType = '43' and $PupilsAged7 * $PupilsAged8 * $PupilsAged9 != 0"/>
			<!--Middle Deemed Primary-->
			<xsl:when test="$Phase = 'MP' and $SchoolType = '05' and $PupilsAged8 * $PupilsAged9 * $PupilsAged10 * $PupilsAged11 != 0"/>
			<xsl:when test="$Phase = 'MP' and $SchoolType = '06' and $PupilsAged9 * $PupilsAged10 * $PupilsAged11 * $PupilsAged12 != 0 "/>
			<xsl:when test="$Phase = 'MP' and $SchoolType = '45' and $PupilsAged9 * $PupilsAged10 * $PupilsAged11 != 0"/>
			<!--Middle Deemed Secondary and Secondary-->
			<xsl:when test="contains( ' MS SS ', $_Phase_) and $SchoolType = '07' and $PupilsAged9 * $PupilsAged10 * $PupilsAged11* $PupilsAged12 != 0"/>
			<xsl:when test="contains( ' MS SS ', $_Phase_) and $SchoolType = '08' and $PupilsAged10 * $PupilsAged11 * $PupilsAged12 != 0 "/>
			<xsl:when test="contains( ' MS SS ', $_Phase_) and $SchoolType = '09' and $PupilsAged12 * $PupilsAged13 * $PupilsAged14 *$PupilsAged15 != 0"/>
			<xsl:when test="contains( ' MS SS ', $_Phase_) and $SchoolType = '10' and $PupilsAged12 * $PupilsAged13 * $PupilsAged14 * $PupilsAged15*$PupilsAged16*$PupilsAged17 != 0"/>
			<xsl:when test="contains( ' MS SS ', $_Phase_) and contains( ' 11 29 ', $_SchoolType_ ) and $PupilsAged13 * $PupilsAged14 * $PupilsAged15 != 0 "/>
			<xsl:when test="contains( ' MS SS ', $_Phase_) and contains( ' 12 30 31 ', $_SchoolType_ ) and $PupilsAged13 * $PupilsAged14 * $PupilsAged15 * $PupilsAged16 * $PupilsAged17 != 0"/>
			<xsl:when test="contains( ' MS SS ', $_Phase_) and contains( ' 21 27 28 48 ', $_SchoolType_ ) and $PupilsAged11*$PupilsAged12 * $PupilsAged13 * $PupilsAged14 * $PupilsAged15 != 0 "/>
			<xsl:when test="contains( ' MS SS ', $_Phase_) and contains( ' 22 36 37 38 39 47 ', $_SchoolType_ ) and $PupilsAged11 * $PupilsAged12 * $PupilsAged13 * $PupilsAged14 * $PupilsAged15 * $PupilsAged16 * $PupilsAged17 != 0"/>
			<xsl:when test="contains( ' MS SS ', $_Phase_) and $SchoolType = '25' and $PupilsAged11 * $PupilsAged12 != 0"/>
			<xsl:when test="contains( ' MS SS ', $_Phase_) and $SchoolType = '26' and $PupilsAged11 * $PupilsAged12 * $PupilsAged13 != 0 "/>
			<xsl:when test="contains( ' MS SS ', $_Phase_) and contains( ' 32 33 44 ', $_SchoolType_ ) and $PupilsAged14 * $PupilsAged15 * $PupilsAged16 * $PupilsAged17 != 0"/>
			<xsl:when test="contains( ' MS SS ', $_Phase_) and $SchoolType = '41' and $PupilsAged10 * $PupilsAged11 * $PupilsAged12 * $PupilsAged13 != 0"/>
			<xsl:when test="contains( ' MS SS ', $_Phase_) and $SchoolType = '46' and $PupilsAged10 * $PupilsAged11 * $PupilsAged12 * $PupilsAged13 * $PupilsAged14 * $PupilsAged15 != 0"/>
			<!--All-through, added autumn 2018-->
			<xsl:when test="$Phase = 'AT' and $PupilsAged7 * $PupilsAged8 * $PupilsAged9 * $PupilsAged10 * $PupilsAged11 * $PupilsAged12 * $PupilsAged13 * $PupilsAged14 != 0 "/>
			<xsl:otherwise>
				<xsl:call-template name="Error">
					<xsl:with-param name="err_num" select="2040"/>
				</xsl:call-template>
			</xsl:otherwise>
		</xsl:choose>
		<!--2050: Please check: Is school type correct? Some pupils are outside the expected age range for this type.-->
		<!--Initial selection based on school type is made as not all schools will undergo this test. Note, Academies (type 49) are specifically excluded-->
		<xsl:if test="contains( ' 05 06 07 08 09 10 11 12 17 21 22 25 26 27 28 29 30 31 32 33 36 37 38 39 41 43 44 45 46 47 48 ', (concat(' ', $SchoolType , '') ) ) ">
			<xsl:choose>
				<!--Updated to add in the exclusion of NS AT SP and PR phases IK 2016-05-25-->
				<xsl:when test="contains(' NS AT SP PR ', $_Phase_ ) "/>
				<!--Primary schools-->
				<xsl:when test="$Phase = 'PS' and $SchoolType = '17' and ( ($PupilOnRollCount - $PupilsAged7 - $PupilsAged8 - $PupilsAged9 - $PupilsAged10) &lt;= $PupilOnRollCount * 0.05) "/>
				<xsl:when test="$Phase = 'PS' and $SchoolType = '43' and ( ($PupilOnRollCount - $PupilsAged7 - $PupilsAged8 - $PupilsAged9) &lt;= $PupilOnRollCount * 0.05) "/>
				<!--Middle deemed primary and secondary-->
				<xsl:when test="contains( ' MP MS ', $_Phase_) and $SchoolType = '05' and ( ($PupilOnRollCount - $PupilsAged8 - $PupilsAged9 - $PupilsAged10 - $PupilsAged11) &lt;= $PupilOnRollCount * 0.05) "/>
				<xsl:when test="contains( ' MP MS ', $_Phase_) and contains( ' 06 07 ', $_SchoolType_ ) and ( ($PupilOnRollCount - $PupilsAged9 - $PupilsAged10 - $PupilsAged11 - $PupilsAged12) &lt;= $PupilOnRollCount * 0.05) "/>
				<xsl:when test="contains( ' MP MS ', $_Phase_) and $SchoolType = '08' and ( ($PupilOnRollCount - $PupilsAged10 - $PupilsAged11 - $PupilsAged12) &lt;= $PupilOnRollCount * 0.05) "/>
				<xsl:when test="contains( ' MP MS ', $_Phase_) and $SchoolType = '41' and ( ($PupilOnRollCount - $PupilsAged10 - $PupilsAged11 - $PupilsAged12 - $PupilsAged13) &lt;= $PupilOnRollCount * 0.05) "/>
				<xsl:when test="contains( ' MP MS ', $_Phase_) and $SchoolType = '45' and ( ($PupilOnRollCount - $PupilsAged9 - $PupilsAged10 - $PupilsAged11) &lt;= $PupilOnRollCount * 0.05) "/>
				<!--Secondary Schools-->
				<xsl:when test="$Phase = 'SS' and $SchoolType = '09' and ( ($PupilOnRollCount - $PupilsAged12 - $PupilsAged13 - $PupilsAged14 - $PupilsAged15) &lt;= $PupilOnRollCount * 0.05) "/>
				<xsl:when test="$Phase = 'SS' and $SchoolType = '10' and ( ($PupilOnRollCount - $PupilsAged12 - $PupilsAged13 - $PupilsAged14 - $PupilsAged15 - $PupilsAged16 - $PupilsAged17) &lt;= $PupilOnRollCount * 0.05) "/>
				<xsl:when test="$Phase = 'SS' and contains( ' 11 29 ', $_SchoolType_ ) and ( ($PupilOnRollCount - $PupilsAged13 - $PupilsAged14 - $PupilsAged15 ) &lt;= $PupilOnRollCount * 0.05) "/>
				<xsl:when test="$Phase = 'SS' and contains( ' 12 30 31 ', $_SchoolType_ ) and ( ($PupilOnRollCount - $PupilsAged13 - $PupilsAged14 - $PupilsAged15 - $PupilsAged16 - $PupilsAged17 ) &lt;= $PupilOnRollCount * 0.05) "/>
				<xsl:when test="$Phase = 'SS' and contains( ' 21 27 28 48 ', $_SchoolType_ ) and ( ($PupilOnRollCount - $PupilsAged11 - $PupilsAged12 - $PupilsAged13 - $PupilsAged14 - $PupilsAged15 ) &lt;= $PupilOnRollCount * 0.05) "/>
				<xsl:when test="$Phase = 'SS' and contains( ' 22 36 37 38 39 47 ', $_SchoolType_ ) and ( ($PupilOnRollCount - $PupilsAged11 - $PupilsAged12 - $PupilsAged13 - $PupilsAged14 - $PupilsAged15 - $PupilsAged16 - $PupilsAged17 ) &lt;= $PupilOnRollCount * 0.05) "/>
				<xsl:when test="$Phase = 'SS' and $SchoolType = '25' and ( ($PupilOnRollCount - $PupilsAged11 - $PupilsAged12) &lt;= $PupilOnRollCount * 0.05) "/>
				<xsl:when test="$Phase = 'SS' and $SchoolType = '26' and ( ($PupilOnRollCount - $PupilsAged11 - $PupilsAged12 - $PupilsAged13 ) &lt;= $PupilOnRollCount * 0.05) "/>
				<xsl:when test="$Phase = 'SS' and contains( ' 32 33 44 ', $_SchoolType_ ) and ( ($PupilOnRollCount - $PupilsAged14 - $PupilsAged15 - $PupilsAged16 - $PupilsAged17 ) &lt;= $PupilOnRollCount * 0.05) "/>
				<xsl:when test="$Phase = 'SS' and $SchoolType = '46' and ( ($PupilOnRollCount - $PupilsAged10 - $PupilsAged11 - $PupilsAged12 - $PupilsAged13 - $PupilsAged14 - $PupilsAged15) &lt;= $PupilOnRollCount * 0.05) "/>
				<xsl:otherwise>
					<xsl:call-template name="Error">
						<xsl:with-param name="err_num" select="2050"/>
						<xsl:with-param name="err_param1" select="$SchoolType"/>
					</xsl:call-template>
				</xsl:otherwise>
			</xsl:choose>
		</xsl:if>
		<!--Special Educational Needs-->
		<!--2190: Please check: Percentage of pupils in school with SEN provision of statements or EHCPs seems high-->
		<xsl:if test="count(/Message/Pupils/PupilsOnRoll/PupilOnRoll/SpecialEducationalNeeds
				[ contains( ' E ', concat( ' ', SENprovision, ' ' ) ) ] ) 
					&gt; $PupilOnRollCount * 0.1">
			<xsl:call-template name="Error">
				<xsl:with-param name="err_num" select="2190"/>
			</xsl:call-template>
		</xsl:if>
		<!--2200: Please check: There are no pupils in the school with SEN provision-->
		<xsl:if test="not(count(/Message/Pupils/PupilsOnRoll/PupilOnRoll/SpecialEducationalNeeds
			[ contains( ' K E ', concat( ' ', SENprovision, ' ' ) ) ] ) > 0)">
			<xsl:call-template name="Error">
				<xsl:with-param name="err_num" select="2200"/>
			</xsl:call-template>
		</xsl:if>
		<!--2205: Please check: Percentage of pupils in school with SEN provision of SEN support seems high-->
		<xsl:if test="count(/Message/Pupils/PupilsOnRoll/PupilOnRoll/SpecialEducationalNeeds
				[ contains( ' K ', concat( ' ', SENprovision, ' ' ) ) ] ) 
					&gt; $PupilOnRollCount * 0.4">
			<xsl:call-template name="Error">
				<xsl:with-param name="err_num" select="2205"/>
			</xsl:call-template>
		</xsl:if>
		<!--2210: Please check: Percentage of pupils in school with statement or EHCP seems low for a special school-->
		<xsl:if test="$Phase = 'SP' ">
			<!--Added SPEC check which was not present previously IK 2016-05-25-->
			<xsl:if test="count(/Message/Pupils/PupilsOnRoll/PupilOnRoll/SpecialEducationalNeeds
				[contains( ' E ', concat( ' ', SENprovision, ' ' ) ) ] ) 
					&lt; $PupilOnRollCount * 0.7">
				<xsl:call-template name="Error">
					<xsl:with-param name="err_num" select="2210"/>
				</xsl:call-template>
			</xsl:if>
		</xsl:if>
		<xsl:if test="$Phase != 'NS' ">
			<!--(!NS) 2540Q Please check: There would normally be at least one pupil who would have at least one authorised absence -->
			<xsl:if test="count(//TermlyAttendance[SessionsAuthorised &gt; 0]) = 0							
							and count(//SessionDetail [contains( $ValidAuthAttendance, concat(' ', AttendanceReason, ' ') ) 
							and Sessions &gt; 0]) = 0" >
				<xsl:call-template name="Error">
					<xsl:with-param name="err_num" select="2540"/>
				</xsl:call-template>
			</xsl:if>
			<!--(!NS) 2550Q Please check: There would normally be at least one pupil who would have at least one unauthorised absence-->
			<xsl:if test="count(//Attendance/TermlyAttendance [SessionsUnauthorised &gt; 0]) = 0 
							 and count(//Attendance/TermlyAttendance/SessionDetails/SessionDetail [contains( $ValidUnauthAttendance, concat(' ', AttendanceReason, ' ') ) 
							and Sessions &gt; 0]) = 0">
				<xsl:call-template name="Error">
					<xsl:with-param name="err_num" select="2550"/>
				</xsl:call-template>
			</xsl:if>
		</xsl:if>
		<!--The following six variables apply to rules 3080 / 3085 / 3090-->
		<xsl:variable name="slRAll" select="count(/Message/Pupils/PupilsOnRoll/PupilOnRoll
			[ ( PupilStatus/NCyearActual = 'R' 
				or (PupilStatus/NCyearActual = 'X' 
					and translate(PupilIdentifiers/DOB, '-', '') &gt; $y5DoBmax 
					and translate(PupilIdentifiers/DOB, '-', '') &lt;= $y4DoBmax) ) ] ) "/>
		<xsl:variable name="slRTaken" select="count(/Message/Pupils/PupilsOnRoll/PupilOnRoll
			[ ( ( PupilStatus/NCyearActual = 'R' 
				or (PupilStatus/NCyearActual = 'X' 
					and translate(PupilIdentifiers/DOB, '-', '') &gt; $y5DoBmax 
					and translate(PupilIdentifiers/DOB, '-', '') &lt;= $y4DoBmax) ) ) 
					and contains($true, concat(' ', PupilCharacteristics/SchoolLunchTaken, ' ') ) ] ) "/>
		<xsl:variable name="sl1All" select="count(/Message/Pupils/PupilsOnRoll/PupilOnRoll
			[ ( PupilStatus/NCyearActual = '1' 
				or (PupilStatus/NCyearActual = 'X' 
					and translate(PupilIdentifiers/DOB, '-', '') &gt; $y6DoBmax 
					and translate(PupilIdentifiers/DOB, '-', '') &lt;= $y5DoBmax) ) ] ) "/>
		<xsl:variable name="sl1Taken" select="count(/Message/Pupils/PupilsOnRoll/PupilOnRoll
			[ ( ( PupilStatus/NCyearActual = '1' 
					or (PupilStatus/NCyearActual = 'X' 
						and translate(PupilIdentifiers/DOB, '-', '') &gt; $y6DoBmax 
						and translate(PupilIdentifiers/DOB, '-', '') &lt;= $y5DoBmax) ) ) 
						and contains($true, concat(' ', PupilCharacteristics/SchoolLunchTaken, ' ') ) ] ) "/>
		<xsl:variable name="sl2All" select="count(/Message/Pupils/PupilsOnRoll/PupilOnRoll
			[ ( PupilStatus/NCyearActual = '2' 
					or (PupilStatus/NCyearActual = 'X' 
						and translate(PupilIdentifiers/DOB, '-', '') &gt; $y7DoBmax 
						and translate(PupilIdentifiers/DOB, '-', '') &lt;= $y6DoBmax) ) ] ) "/>
		<xsl:variable name="sl2Taken" select="count(/Message/Pupils/PupilsOnRoll/PupilOnRoll
			[ ( ( PupilStatus/NCyearActual = '2' 
					or (PupilStatus/NCyearActual = 'X' 
						and translate(PupilIdentifiers/DOB, '-', '') &gt; $y7DoBmax 
						and translate(PupilIdentifiers/DOB, '-', '') &lt;= $y6DoBmax) ) ) 
						and contains($true, concat(' ', PupilCharacteristics/SchoolLunchTaken, ' ') ) ] ) "/>
		<!--3080 Take up of school lunches for pupils in reception (plus pupils aged 4 in year X) is 50% or lower. Please confirm that less than 50% of reception pupils took a school lunch on census day-->
		<xsl:if test="$Phase != 'NS' 
			and $slRAll &gt;= $slThreshold 
			and $slRTaken &lt;= ($slRAll * $slRatio)">
			<xsl:call-template name="Error">
				<xsl:with-param name="err_num" select="3080"/>
			</xsl:call-template>
		</xsl:if>
		<!--3085 Take up of school lunches for pupils in year 1 (plus pupils aged 5 in year X) is 50% or lower. Please confirm that less than 50% of pupils in year 1 took a school lunch on census day-->
		<xsl:if test="$Phase != 'NS' 
			and $sl1All &gt;= $slThreshold 
			and $sl1Taken &lt;= ($sl1All * $slRatio)">
			<xsl:call-template name="Error">
				<xsl:with-param name="err_num" select="3085"/>
			</xsl:call-template>
		</xsl:if>
		<!--3090 Take up of school lunches for pupils in year 2 (plus pupils aged 6 in year X) is 50% or lower. Please confirm that less than 50% of pupils in year 2 took a school lunch on census day-->
		<xsl:if test="$Phase != 'NS' 
			and $sl2All &gt;= $slThreshold 
			and $sl2Taken &lt;= ($sl2All * $slRatio) ">
			<xsl:call-template name="Error">
				<xsl:with-param name="err_num" select="3090"/>
			</xsl:call-template>
		</xsl:if>
		<!--Autumn-specific validation (mostly attendance - have to take summer half term 2 attendance into account)-->
		<xsl:if test="$term='AUT' ">
			<!--(AUT) 1910Q Checking % new admissions Summer-->
			<xsl:if test="count(/Message/Pupils/PupilsOnRoll/PupilOnRoll/PupilStatus
						[translate(EntryDate, '-', '') &gt;= $StartPreviousTerm
							and translate(EntryDate, '-', '') &lt;= $StartCurrentTerm] )
							 &gt; $PupilOnRollCount * 0.25">
				<xsl:call-template name="Error">
					<xsl:with-param name="err_num" select="1910"/>
				</xsl:call-template>
			</xsl:if>
			<!--(AUT) 2560 Authorised Absence > 30%-->
			<xsl:if test="sum(//Attendance/TermlyAttendance[SessionsAuthorised &gt; 0]/SessionsAuthorised) 
			+ sum(//Attendance/SummerHalfTerm2Attendance[SessionsAuthorised &gt; 0]/SessionsAuthorised) 
			+ sum(//Attendance/TermlyAttendance/SessionDetails/SessionDetail
			[contains( $ValidAuthAttendance, concat(' ', AttendanceReason, ' ') ) 
				and Sessions &gt; 0] /Sessions) 
				+ sum(//Attendance/SummerHalfTerm2Attendance/SessionDetails/SessionDetail
					[contains( $ValidAuthAttendance, concat(' ', AttendanceReason, ' ') ) and Sessions &gt; 0] / Sessions)
					&gt; 0.3 * (sum(//Attendance/TermlyAttendance[SessionsPossible &gt; 0]/SessionsPossible) 
						+ sum(//Attendance/SummerHalfTerm2Attendance[SessionsPossible &gt; 0]/SessionsPossible) ) ">
				<xsl:call-template name="Error">
					<xsl:with-param name="err_num" select="2560"/>
				</xsl:call-template>
			</xsl:if>
			<!--(AUT) 2570 Unauthorised Absence > 30% - changes to second condition-->
			<xsl:if test="sum(//Attendance/TermlyAttendance[SessionsUnauthorised &gt; 0]/SessionsUnauthorised) 
				+ sum(//Attendance/SummerHalfTerm2Attendance[SessionsUnauthorised &gt; 0]/SessionsUnauthorised) 
				+ sum(//Attendance/TermlyAttendance/SessionDetails/SessionDetail
					[contains( $ValidUnauthAttendance, concat(' ', AttendanceReason, ' ') ) 
					and Sessions &gt; 0] / Sessions) 
				+ sum(//Attendance/SummerHalfTerm2Attendance/SessionDetails/SessionDetail
					[contains( $ValidUnauthAttendance, concat(' ', AttendanceReason, ' ') ) 
					and Sessions &gt; 0] / Sessions) 
				&gt; 0.3 * (sum(//Attendance/TermlyAttendance[SessionsPossible &gt; 0]/SessionsPossible) 
					+ sum(//Attendance/SummerHalfTerm2Attendance[SessionsPossible &gt; 0]/SessionsPossible) ) ">
				<xsl:call-template name="Error">
					<xsl:with-param name="err_num" select="2570"/>
				</xsl:call-template>
			</xsl:if>
			<!--(AUT) 2583 Would expect at least 1 authorised absence -in summer 2nd half term-->
			<xsl:if test="count(//Attendance/SummerHalfTerm2Attendance[SessionsAuthorised &gt; 0] ) = 0
							 and count(//Attendance/SummerHalfTerm2Attendance/SessionDetails/SessionDetail 
								[contains( $ValidAuthAttendance, concat(' ', AttendanceReason, ' ') ) and Sessions &gt; 0] ) = 0 ">
				<xsl:call-template name="Error">
					<xsl:with-param name="err_num" select="2583"/>
				</xsl:call-template>
			</xsl:if>
			<!--(AUT) 2584 would expect at least 1 unauthorised absence -in summer 2nd half term-->
			<xsl:if test="count(//Attendance/SummerHalfTerm2Attendance [SessionsUnauthorised &gt; 0] ) = 0 
							 and count(//Attendance/SummerHalfTerm2Attendance/SessionDetails/SessionDetail
							[contains( $ValidUnauthAttendance, concat(' ', AttendanceReason, ' ') ) and Sessions &gt; 0] ) = 0 ">
				<xsl:call-template name="Error">
					<xsl:with-param name="err_num" select="2584"/>
				</xsl:call-template>
			</xsl:if>
		</xsl:if>
		<xsl:if test="$term = 'SPR' ">
			<xsl:variable name="FTnursery" select=" count(/Message/Pupils/PupilsOnRoll/PupilOnRoll/PupilStatus 
				[TypeOfClass = 'N' 
					and contains($false, concat(' ', PartTime, ' ') ) ] ) "/>
			<!--(SPR) 1700 high % count where ethnicity not obtained-->
			<xsl:if test="count(/Message/Pupils/PupilsOnRoll/PupilOnRoll[PupilCharacteristics/Ethnicity = 'NOBT' ] ) &gt; count(/Message/Pupils/PupilsOnRoll/PupilOnRoll) * 0.1">
				<xsl:call-template name="Error">
					<xsl:with-param name="err_num" select="1700"/>
				</xsl:call-template>
			</xsl:if>
			<!--(SPR) 1890 Checking % new admissions in the Autumn term - rule applies to Spring Census-->
			<xsl:if test="$Phase != 'PR' 
				and count(/Message/Pupils/PupilsOnRoll/PupilOnRoll/PupilStatus
						[translate(EntryDate, '-', '') &gt;= $StartPreviousTerm
							and translate(EntryDate, '-', '') &lt;= $StartCurrentTerm]
						) &gt; $PupilOnRollCount * 0.40">
				<xsl:call-template name="Error">
					<xsl:with-param name="err_num" select="1890"/>
				</xsl:call-template>
			</xsl:if>
			<!--(SPR) 2090 Please check: Nursery pupils reported but no nursery class records-->
			<xsl:if test="count(/Message/Pupils/PupilsOnRoll/PupilOnRoll/PupilStatus [ TypeOfClass = 'N' ]) &gt; 0 
				and ( count( /Message/School/Classes/Class [ClassType = 'N' ]) = 0
				and ( /Message/School/Reconciliation/PupilReconciliation/PartTimeNotIn = 0 
						or string-length( /Message/School/Reconciliation/PupilReconciliation/PartTimeNotIn) = 0 ) )">
				<xsl:call-template name="Error">
					<xsl:with-param name="err_num" select="2090"/>
				</xsl:call-template>
			</xsl:if>
			<!--(SPR) 2100 Please check: More FT nursery pupils than number on nursery class records-->
			<xsl:if test="$FTnursery &gt; 0 
				and $FTnursery &gt; sum(/Message/School/Classes/Class 
														[ClassType = 'N' ]/HomePupils)">
				<xsl:call-template name="Error">
					<xsl:with-param name="err_num" select="2100"/>
				</xsl:call-template>
			</xsl:if>
			<!--(SPR) 2110 Please check: more pupils in Nursery classes than nursery pupils-->
			<xsl:if test="count(/Message/Pupils/PupilsOnRoll/PupilOnRoll/PupilStatus
				[TypeOfClass = 'N' ] ) &lt; sum(/Message/School/Classes/Class 
																[ClassType = 'N' ]/HomePupils)">
				<xsl:call-template name="Error">
					<xsl:with-param name="err_num" select="2110"/>
				</xsl:call-template>
			</xsl:if>
		</xsl:if>
		<!--End of validation for Spring-->
		<xsl:if test="$term='SUM' ">
			<!--(SUM) 1900 Please check: Percentage of new admissions in Spring term in school seems high-->
			<xsl:if test="$Phase != 'PR' 
				and count(/Message/Pupils/PupilsOnRoll/PupilOnRoll/PupilStatus
						[translate(EntryDate, '-', '') &gt;= $StartPreviousTerm
							and translate(EntryDate, '-', '') &lt;= $StartCurrentTerm]
					) &gt; $PupilOnRollCount * 0.30">
				<xsl:call-template name="Error">
					<xsl:with-param name="err_num" select="1900"/>
				</xsl:call-template>
			</xsl:if>
		</xsl:if>
		<xsl:if test="$term='SPR' or $term='SUM' ">
			<!--(SPR SUM) 2560 Please check: Percentage of authorised absence is greater than 30% - are you sure?-->
			<xsl:if test="(sum(//Attendance/TermlyAttendance
							[SessionsAuthorised &gt; 0]/SessionsAuthorised)
					+ sum(//Attendance/TermlyAttendance/SessionDetails/SessionDetail 
						[contains( $ValidAuthAttendance, concat(' ', AttendanceReason, ' ') ) and Sessions &gt; 0]/ Sessions) )
					&gt; 0.3 * sum(//Attendance/TermlyAttendance[SessionsPossible &gt; 0]/SessionsPossible) ">
				<xsl:call-template name="Error">
					<xsl:with-param name="err_num" select="2560"/>
				</xsl:call-template>
			</xsl:if>
			<!--(SPR SUM) 2570 Please check: Percentage of unauthorised absence is greater than 30% - are you sure?-->
			<xsl:if test="(sum(//Attendance/TermlyAttendance
							[SessionsUnauthorised &gt; 0]/SessionsUnauthorised) 
					+ sum(//Attendance/TermlyAttendance/SessionDetails/SessionDetail 
						[contains( $ValidUnauthAttendance, concat(' ', AttendanceReason, ' ') ) and Sessions &gt; 0]/ Sessions ) )
					&gt; 0.3 * sum(//Attendance/TermlyAttendance[SessionsPossible &gt; 0]/SessionsPossible) ">
				<xsl:call-template name="Error">
					<xsl:with-param name="err_num" select="2570"/>
				</xsl:call-template>
			</xsl:if>
		</xsl:if>
		<!--END OF VALIDATIONS FOR SPRING AND SUMMER-->
	</xsl:template>
	<!--UPN-->
	<xsl:template name="UPN">
		<xsl:param name="UPN"/>
		<xsl:param name="type"/>
		<xsl:variable name="ErrSex">
			<xsl:if test="Sex = 'M' ">Male</xsl:if>
			<xsl:if test="Sex = 'F' ">Female</xsl:if>
		</xsl:variable>
		<xsl:variable name="data" select="concat( $type, $UPN, 
					'. Name: ', Surname, ', ' , Forename, '.'  ,
					' Date of Birth: ', DOB, ', ', $ErrSex )"/>
		<xsl:variable name="checkval">
			<xsl:call-template name="checksum">
				<xsl:with-param name="rest" select="substring( $UPN , 2 )"/>
			</xsl:call-template>
		</xsl:variable>
		<xsl:if test="substring( $UPNletters, $checkval + 1, 1 ) != substring( $UPN, 1, 1)">
			<!--1510 UPN Invalid - check digit wrong-->
			<xsl:call-template name="Error">
				<xsl:with-param name="err_num" select="1510"/>
				<xsl:with-param name="data" select="$data"/>
			</xsl:call-template>
		</xsl:if>
		<!--1530: UPN invalid 2-4 not a recognised LA code-->
		<xsl:if test=" not( contains($LEAs, concat(' ', substring( $UPN , 2, 3), ' ' ) ) )">
			<xsl:call-template name="Error">
				<xsl:with-param name="err_num" select="1530"/>
				<xsl:with-param name="data" select="$data"/>
			</xsl:call-template>
		</xsl:if>
		<xsl:if test="not(translate( substring( $UPN , 5, 8 ), $digits, $all_9s ) = '99999999')">
			<xsl:call-template name="Error">
				<xsl:with-param name="err_num" select="1540"/>
				<xsl:with-param name="data" select="$data"/>
			</xsl:call-template>
		</xsl:if>
		<!--1550: UPN invalid character 13 not recognised-->
		<xsl:if test="string-length($UPN) &gt; 0 
			and (string-length($UPN) &lt; 13 
				or not( contains( concat( $UPNletters, $digits ), substring( $UPN, 13, 1 ) ) ) )">
			<xsl:call-template name="Error">
				<xsl:with-param name="err_num" select="1550"/>
				<xsl:with-param name="data" select="$data"/>
			</xsl:call-template>
		</xsl:if>
	</xsl:template>
	<xsl:template name="checksum">
		<xsl:param name="rest"/>
		<xsl:variable name="lastvalue">
			<xsl:choose>
				<xsl:when test="contains( $UPNletters, substring( $rest, 12, 1) )">
					<xsl:value-of select=" string-length ( substring-before( $UPNletters, substring( $rest, 12, 1) ) ) "/>
				</xsl:when>
				<xsl:otherwise>
					<xsl:value-of select="substring( $rest, 12, 1) "/>
				</xsl:otherwise>
			</xsl:choose>
		</xsl:variable>
		<xsl:value-of select=" ( substring($rest,1,1) * 2
			+ substring($rest, 2, 1) * 3
			+ substring($rest, 3, 1) * 4 
			+ substring($rest, 4, 1) * 5 
			+ substring($rest, 5, 1) * 6 
			+ substring($rest, 6, 1) * 7 
			+ substring($rest, 7, 1) * 8 
			+ substring($rest, 8, 1) * 9 
			+ substring($rest, 9, 1) * 10 
			+ substring($rest, 10, 1) * 11 
			+ substring($rest, 11, 1) * 12 
			+ $lastvalue * 13) 
			mod 23"/>
	</xsl:template>
	<!--Pupil Identifiers %-->
	<xsl:template name="PupilIdentifiersValidation">
		<xsl:variable name="ErrSex">
			<xsl:if test="../PupilIdentifiers/Sex = 'M' ">Male</xsl:if>
			<xsl:if test="../PupilIdentifiers/Sex = 'F' ">Female</xsl:if>
		</xsl:variable>
		<xsl:variable name="data" select="concat('UPN: ', ../PupilIdentifiers/UPN, '. Name: ', ../PupilIdentifiers/Surname, ', ' , ../PupilIdentifiers/Forename, '.', ' Date of Birth: ', ../PupilIdentifiers/DOB, ', ', $ErrSex ) "/>
		<!--This is going to have to change as a result of the changes to 1601Q-->
		<xsl:variable name="PupAge">
			<xsl:choose>
				<!--TODO: Assemble date from Academic Year-->
				<xsl:when test="$term='AUT' ">
					<xsl:value-of select="floor((20230831 - translate(../PupilIdentifiers/DOB, '-','')) div 10000)"/>
				</xsl:when>
				<!-- need to subtract an extra year in Spr and Sum compared to Aut to get back to the correct start year for the academic year. $AcademicYear holds the year from ReferenceDate which is +1 for Spr and Sum -->
				<xsl:when test="$term='SPR' ">
					<xsl:value-of select="floor((20231231 - translate(../PupilIdentifiers/DOB, '-','')) div 10000)"/>
				</xsl:when>
				<xsl:when test="$term='SUM' ">
					<xsl:value-of select="floor((20240331 - translate(../PupilIdentifiers/DOB, '-','')) div 10000)"/>
				</xsl:when>
			</xsl:choose>
		</xsl:variable>
		<!--From the spec. The age calculation for 1601 is different for two year-olds (calculated due to term position) from older children. $PupAge is appropriate for calculating two year old pupils; otherwise use Age.-->
		<xsl:variable name="age" select="floor(($AgeCalcDate - translate(../PupilIdentifiers/DOB, '-','')) div 10000)"/>
		<xsl:variable name="data1" select="concat('UPN: ', UPN, '. Name: ', Surname, ', ' , Forename, '.', ' Date of Birth: ', DOB, ', ', $ErrSex) "/>
		<!--1500 UPN must be present-->
		<xsl:if test="string-length(UPN) = 0 ">
			<xsl:call-template name="Error">
				<xsl:with-param name="err_num" select="1500"/>
				<xsl:with-param name="data" select="$data"/>
			</xsl:call-template>
		</xsl:if>
		<!--If present, then check UniqueLearnerNumber check digit is valid-->
		<xsl:if test="string-length(UniqueLearnerNumber) != 0 ">
			<xsl:call-template name="UniqueLearnerNumber">
				<xsl:with-param name="UniqueLearnerNumber" select="UniqueLearnerNumber"/>
			</xsl:call-template>
		</xsl:if>
		<!--1580 Surname must be present-->
		<xsl:if test="string-length(Surname) = 0 ">
			<xsl:call-template name="Error">
				<xsl:with-param name="err_num" select="1580"/>
				<xsl:with-param name="data" select="$data"/>
			</xsl:call-template>
		</xsl:if>
		<!--1590 Forename must be present-->
		<xsl:if test="string-length(Forename) = 0 ">
			<xsl:call-template name="Error">
				<xsl:with-param name="err_num" select="1590"/>
				<xsl:with-param name="data" select="$data"/>
			</xsl:call-template>
		</xsl:if>
		<!--1600 Date of birth must be present-->
		<xsl:if test="string-length(DOB) = 0 ">
			<xsl:call-template name="Error">
				<xsl:with-param name="err_num" select="1600"/>
				<xsl:with-param name="data" select="$data"/>
			</xsl:call-template>
		</xsl:if>
		<!--1610 Sex must be present and valid-->
		<xsl:if test="string-length(Sex) = 0 or not(Sex='F' or Sex='M' )">
			<xsl:call-template name="Error">
				<xsl:with-param name="err_num" select="1610"/>
				<xsl:with-param name="data" select="$data"/>
			</xsl:call-template>
		</xsl:if>
		<xsl:if test="../../PupilOnRoll">
			<xsl:choose>
				<!--do nothing if data matches the following conditions-->
				<!--ignore special schools-->
				<xsl:when test="$Phase = 'SP' "/>
				<!--Phase added to each check 2014-09-05 ACN-->
				<xsl:when test="$Phase = 'NS' and (contains(' 50 51 ', $_SchoolType_ ) and ($PupAge &gt;=2 and $age &lt;=7) ) "/>
				<!--Primary Schools-->
				<xsl:when test="$Phase = 'PS' and (contains(' 01 16 ', $_SchoolType_ ) and ($PupAge &gt;=2 and $age &lt;=9) ) "/>
				<xsl:when test="$Phase = 'PS' and (contains(' 02 ', $_SchoolType_ ) and ($PupAge &gt;=2 and $age &lt;=10) ) "/>
				<xsl:when test="$Phase = 'PS' and (contains(' 03 ', $_SchoolType_ ) and ($PupAge &gt;=2 and $age &lt;=11) ) "/>
				<xsl:when test="$Phase = 'PS' and (contains(' 04 ', $_SchoolType_ ) and ($PupAge &gt;=2 and $age &lt;=13) ) "/>
				<xsl:when test="$Phase = 'PS' and (contains(' 17 ', $_SchoolType_ ) and ($age &gt;=7 and $age &lt;=12) ) "/>
				<xsl:when test="$Phase = 'PS' and (contains(' 18 ', $_SchoolType_ ) and ($PupAge &gt;=2 and $age &lt;=11) ) "/>
				<xsl:when test="$Phase = 'PS' and (contains(' 42 ', $_SchoolType_ ) and ($PupAge &gt;=2 and $age &lt;=8) ) "/>
				<xsl:when test="$Phase = 'PS' and (contains(' 43 ', $_SchoolType_ ) and ($age &gt;=7 and $age &lt;=11) ) "/>
				<xsl:when test="$Phase = 'PS' and (contains(' 49 ', $_SchoolType_ ) and ($PupAge &gt;=2 and $age &lt;=13) ) "/>
				<!--Middle Deemed Primary Schools-->
				<xsl:when test="$Phase = 'MP' and (contains(' 05 ', $_SchoolType_ ) and ($age &gt;=8 and $age &lt;=13) ) "/>
				<xsl:when test="$Phase = 'MP' and (contains(' 06 ', $_SchoolType_ ) and ($age &gt;=9 and $age &lt;=14) ) "/>
				<xsl:when test="$Phase = 'MP' and (contains(' 45 ', $_SchoolType_ ) and ($age &gt;=9 and $age &lt;=13) ) "/>
				<xsl:when test="$Phase = 'MP' and (contains(' 49 ', $_SchoolType_ ) and ($age &gt;=8 and $age &lt;=14) ) "/>
				<!--Secondary and Middle Deemed Secondary Schools-->
				<xsl:when test="contains(' MS SS ', $Phase ) and contains(' 07 ', $_SchoolType_ ) and ($age &gt;=9 and $age &lt;=14) "/>
				<xsl:when test="contains(' MS SS ', $Phase ) and contains(' 08 ', $_SchoolType_ ) and ($age &gt;=10 and $age &lt;=14) "/>
				<xsl:when test="contains(' MS SS ', $Phase ) and contains(' 09 ', $_SchoolType_ ) and ($age &gt;=12 and $age &lt;=17) "/>
				<xsl:when test="contains(' MS SS ', $Phase ) and contains(' 10 ', $_SchoolType_ ) and ($age &gt;=12 and $age &lt;=19) "/>
				<xsl:when test="contains(' MS SS ', $Phase ) and contains(' 11 29 ', $_SchoolType_ ) and ($age &gt;=13 and $age &lt;=17) "/>
				<xsl:when test="contains(' MS SS ', $Phase ) and contains(' 12 30 31 ', $_SchoolType_ ) and ($age &gt;=13 and $age &lt;=20) "/>
				<xsl:when test="contains(' MS SS ', $Phase ) and contains(' 21 27 28 48 ', $_SchoolType_ ) and ($age &gt;=11 and $age &lt;=17) "/>
				<xsl:when test="contains(' MS SS ', $Phase ) and contains(' 22 36 37 38 39 47 ', $_SchoolType_ ) and ($age &gt;=11 and $age &lt;=20) "/>
				<xsl:when test="contains(' MS SS ', $Phase ) and contains(' 25 ', $_SchoolType_ ) and ($age &gt;=11 and $age &lt;=14) "/>
				<xsl:when test="contains(' MS SS ', $Phase ) and contains(' 26 ', $_SchoolType_ ) and ($age &gt;=11 and $age &lt;=15) "/>
				<xsl:when test="contains(' MS SS ', $Phase ) and contains(' 32 33 44 ', $_SchoolType_ ) and ($age &gt;=14 and $age &lt;=20) "/>
				<xsl:when test="contains(' MS SS ', $Phase ) and contains(' 41 ', $_SchoolType_ ) and ($age &gt;=10 and $age &lt;=15) "/>
				<xsl:when test="contains(' MS SS ', $Phase ) and contains(' 46 ', $_SchoolType_ ) and ($age &gt;=10 and $age &lt;=17) "/>
				<xsl:when test="contains(' MS SS ', $Phase ) and contains(' 49 ', $_SchoolType_ ) and ($age &gt;=9 and $age &lt;=20) "/>
				<!--All through Schools-->
				<xsl:when test="$Phase = 'AT' and contains(' 49 55 ', $_SchoolType_ ) and ($PupAge &gt;=2 and $age &lt;=20) "/>
				<!--PRU Schools-->
				<xsl:when test="($Phase = 'PR' and contains(' 49 54 ', $_SchoolType_ ) and ($age &gt;=3 and $age &lt;=18) ) "/>
				<xsl:otherwise>
					<xsl:call-template name="Error">
						<xsl:with-param name="err_num" select="1601"/>
						<xsl:with-param name="data" select="concat($data1,', Age: ', $age) "/>
					</xsl:call-template>
				</xsl:otherwise>
			</xsl:choose>
			<!--End-->
		</xsl:if>
	</xsl:template>
	<!--UniqueLearnerNumber %-->
	<xsl:template name="UniqueLearnerNumber">
		<xsl:param name="UniqueLearnerNumber"/>
		<xsl:variable name="ErrSex">
			<xsl:if test="Sex = 'M' ">Male</xsl:if>
			<xsl:if test="Sex = 'F' ">Female</xsl:if>
		</xsl:variable>
		<xsl:variable name="data" select="concat('UPN: ', UPN, 
				   	          '. Name: ', Surname, ', ' , Forename, '.'  ,
						 ' Date of Birth: ', DOB, ', ', $ErrSex, ',' ,
						 ' ULN: ', UniqueLearnerNumber ) "/>
		<!--$ErrSex-->
		<!--1575: UniqueLearnerNumber where present, must contain the correct check character-->
		<!--SS and SP schools only from 2011. Error XSLT will apply this filter-->
		<xsl:variable name="UniqueLearnerNumberCheckval">
			<xsl:call-template name="UniqueLearnerNumberChecksum">
				<xsl:with-param name="uln" select="$UniqueLearnerNumber"/>
			</xsl:call-template>
		</xsl:variable>
		<!--hg-->
		<xsl:variable name="UniqueLearnerNumberCheckRemainder">
			<xsl:call-template name="UniqueLearnerNumberCheckRem">
				<xsl:with-param name="ulnr" select="$UniqueLearnerNumber"/>
			</xsl:call-template>
		</xsl:variable>
		<!--hg end-->
		<xsl:if test="(substring($UniqueLearnerNumberCheckval, 1, 1 ) != substring( $UniqueLearnerNumber, 10, 1) ) or (substring($UniqueLearnerNumberCheckRemainder, 1, 1 ) = 0)">
			<!--1575 UniqueLearnerNumber Invalid - check digit wrong-->
			<xsl:call-template name="Error">
				<xsl:with-param name="err_num" select="1575"/>
				<xsl:with-param name="data" select="$data"/>
			</xsl:call-template>
		</xsl:if>
	</xsl:template>
	<xsl:template name="UniqueLearnerNumberChecksum">
		<xsl:param name="uln"/>
		<xsl:value-of select=" 10 -( ( (substring($uln,1,1) * 10) + (substring($uln,2,1) * 9) + (substring($uln,3,1) * 8) + (substring($uln,4,1) * 7) + (substring($uln,5,1) * 6) + (substring($uln,6,1) * 5) + (substring($uln,7,1) * 4) + (substring($uln,8,1) * 3) + (substring($uln,9,1) * 2) ) mod 11) "/>
	</xsl:template>
	<xsl:template name="UniqueLearnerNumberCheckRem">
		<xsl:param name="ulnr"/>
		<xsl:value-of select=" ( ( (substring($ulnr,1,1) * 10) + (substring($ulnr,2,1) * 9) + (substring($ulnr,3,1) * 8) + (substring($ulnr,4,1) * 7) + (substring($ulnr,5,1) * 6) + (substring($ulnr,6,1) * 5) + (substring($ulnr,7,1) * 4) + (substring($ulnr,8,1) * 3) + (substring($ulnr,9,1) * 2) ) mod 11) "/>
	</xsl:template>
	<!--Pupil Characteristics %-->
	<xsl:template name="PupilCharacteristicsValidation">
		<!--This selection checks to see if there is a Pupil Characteristics Node present on the input-->
		<!--if there isn't there an error message relevant to all pupils is produced-->
		<!--Otherwise carry out the normal validation testing-->
		<xsl:variable name="ErrSex">
			<xsl:if test="PupilIdentifiers/Sex = 'M' ">Male</xsl:if>
			<xsl:if test="PupilIdentifiers/Sex = 'F' ">Female</xsl:if>
		</xsl:variable>
		<!--The following three are for rule 1859-->
		<xsl:variable name="valFundedHours">
			<xsl:if test="number(PupilCharacteristics/FundedHours) != number(PupilCharacteristics/FundedHours)">0</xsl:if>
			<xsl:if test="number(PupilCharacteristics/FundedHours) = number(PupilCharacteristics/FundedHours)">
				<xsl:value-of select="number(PupilCharacteristics/FundedHours)">
				</xsl:value-of>
			</xsl:if>
		</xsl:variable>
		<xsl:variable name="valHoursAtSetting">
			<xsl:if test="number(PupilCharacteristics/HoursAtSetting) != number(PupilCharacteristics/HoursAtSetting)">0</xsl:if>
			<xsl:if test="number(PupilCharacteristics/HoursAtSetting) = number(PupilCharacteristics/HoursAtSetting)">
				<xsl:value-of select="number(PupilCharacteristics/HoursAtSetting)">
				</xsl:value-of>
			</xsl:if>
		</xsl:variable>
		<xsl:variable name="valExtendedHours">
			<xsl:if test="number(PupilCharacteristics/ExtendedHours) != number(PupilCharacteristics/ExtendedHours)">0</xsl:if>
			<xsl:if test="number(PupilCharacteristics/ExtendedHours) = number(PupilCharacteristics/ExtendedHours)">
				<xsl:value-of select="number(PupilCharacteristics/ExtendedHours)">
				</xsl:value-of>
			</xsl:if>
		</xsl:variable>
		<xsl:variable name="data" select="concat('UPN: ', PupilIdentifiers/UPN, 
						'. Name: ', PupilIdentifiers/Surname, ', ' , PupilIdentifiers/Forename, '.' , 
						' Date of Birth: ', PupilIdentifiers/DOB, ', ',
						$ErrSex ) "/>
		<xsl:choose>
			<xsl:when test="not(PupilCharacteristics) or PupilCharacteristics='' ">
				<xsl:call-template name="Error">
					<xsl:with-param name="err_num" select="9999"/>
					<xsl:with-param name="data" select="concat($data , ' PupilCharacteristics ') "/>
				</xsl:call-template>
			</xsl:when>
			<xsl:otherwise>
				<xsl:for-each select="PupilCharacteristics">
					<!--The first group of rules are for both on and off roll pupils for all terms. Further down there are blocks of validations specific to terms or on- or off-roll pupils.-->
					<xsl:variable name="age" select="floor(($AgeCalcDate - translate(../PupilIdentifiers/DOB, '-','')) div 10000)"/> 
					<!--1840: Language must be present and valid-->
					<!--Criteria changed to simply make Language mandatory. Nursery have no off-roll pupils anyway.-->
					<xsl:if test="string-length(Language) = 0 
						or not(contains($Language, concat(' ', Language, ' ') ) )">
						<xsl:call-template name="Error">
							<xsl:with-param name="err_num" select="1840"/>
							<xsl:with-param name="data" select="$data"/>
						</xsl:call-template>
					</xsl:if>
					<!--This line of criteria applies to 5094, 5095, 5210, 5215-->
					<xsl:if test="contains(' NM CT ', concat( ' ', $Governance, ' ' ) ) ">
						<!--5094 Hours at setting is not required from CTCs or non-maintained special schools -->
						<xsl:if test="string-length(HoursAtSetting) != 0">
							<xsl:call-template name="Error">
								<xsl:with-param name="err_num" select="5094"/>
								<xsl:with-param name="data" select="$data"/>
							</xsl:call-template>
						</xsl:if>
						<!--5095 Funded hours are not required from CTCs or non-maintained special schools -->
						<xsl:if test="string-length(FundedHours) != 0">
							<xsl:call-template name="Error">
								<xsl:with-param name="err_num" select="5095"/>
								<xsl:with-param name="data" select="$data"/>
							</xsl:call-template>
						</xsl:if>
						<!--5096 30-Hour code is not required from CTCs or non-maintained special schools -->
						<xsl:if test="string-length(ThirtyHourCode) != 0">
							<xsl:call-template name="Error">
								<xsl:with-param name="err_num" select="5096"/>
								<xsl:with-param name="data" select="$data"/>
							</xsl:call-template>
						</xsl:if>
						<!--5097 <EYPPR> must NOT be present when <Governance> equals 'NM' (non-maintained special school) OR 'CT' (CTC) -->
						<xsl:if test="contains(' NM CT ', concat( ' ', $Governance, ' ' ) )
									  and string-length(EYPPR) &gt; 0">
							<xsl:call-template name="Error">
								<xsl:with-param name="err_num" select="5097"/>
								<xsl:with-param name="data" select="$data"/>
							</xsl:call-template>
						</xsl:if>
						<!--5210 Extended hours are not required from CTCs or non-maintained special schools-->
						<!--New for Autumn 2017 - SS-->
						<xsl:if test="string-length(ExtendedHours) != 0">
							<xsl:call-template name="Error">
								<xsl:with-param name="err_num" select="5210"/>
								<xsl:with-param name="data" select="$data"/>
							</xsl:call-template>
						</xsl:if>
						<!--5215 Disability access fund information is not required from CTCs or non-maintained special schools -->
						<!--New for Autumn 2017 - SS-->
						<xsl:if test="string-length(DAFIndicator) != 0">
							<xsl:call-template name="Error">
								<xsl:with-param name="err_num" select="5215"/>
								<xsl:with-param name="data" select="$data"/>
							</xsl:call-template>
						</xsl:if>
					</xsl:if>
					<!--End of CTCs and non-maintained special schools-->
					<xsl:for-each select="FSMeligibility/FSMperiod">
						<!--1745 Please check: The start date and end date are the same within a single Free School Meal period.-->
						<xsl:if test="string-length(FSMstartDate) != 0 
							and string-length(FSMendDate) != 0
							and FSMstartDate = FSMendDate ">
							<xsl:call-template name="Error">
								<xsl:with-param name="err_num" select="1745"/>
								<xsl:with-param name="data" select="$data"/>
							</xsl:call-template>
						</xsl:if>
						<!--1761: A start date must be provided for each period of free school meal eligibility-->
						<xsl:if test="string-length(FSMstartDate) = 0 ">
							<xsl:call-template name="Error">
								<xsl:with-param name="err_num" select="1761"/>
								<xsl:with-param name="data" select="$data"/>
							</xsl:call-template>
						</xsl:if>
						<!--1762: Periods of free school meal eligibility that started after the Census Day should not be included in the return.-->
						<xsl:if test="translate(FSMstartDate, '-', '') &gt; $RefDate">
							<xsl:call-template name="Error">
								<xsl:with-param name="err_num" select="1762"/>
								<xsl:with-param name="data" select="$data"/>
							</xsl:call-template>
						</xsl:if>
						<!--1763: Periods of FSM eligibility nust be in a specfic period.-->
						<xsl:if test="string-length(FSMendDate) !=0 
							and (translate(FSMendDate, '-', '') &lt; $FSMEndDateLowerBound 
								or translate(FSMendDate, '-', '') &gt; $RefDate)">
							<xsl:call-template name="Error">
								<xsl:with-param name="err_num" select="1763"/>
								<xsl:with-param name="data" select="$data"/>
							</xsl:call-template>
						</xsl:if>
						<!--1764: The country code associated with the period of free school meal eligibility is not a valid value-->
						<xsl:if test="string-length(UKcountry) != 0 
							and not(contains(' ENG NIR SCT WLS ' , concat(' ', UKcountry, ' ' ) ) )">
							<xsl:call-template name="Error">
								<xsl:with-param name="err_num" select="1764"/>
								<xsl:with-param name="data" select="$data"/>
							</xsl:call-template>
						</xsl:if>
						<!--1765 Any period of FSM eligibility outside of England, ie Country of UK = NIR, SCT or WLS, must have an FSM eligibility end date before census day-->
						<xsl:if test="string-length(FSMstartDate) != 0 
							and string-length(FSMendDate) = 0
							and string-length(UKcountry) != 0 
							and UKcountry != 'ENG' ">
							<xsl:call-template name="Error">
								<xsl:with-param name="err_num" select="1765"/>
								<xsl:with-param name="data" select="$data"/>
							</xsl:call-template>
						</xsl:if>
						<!--1766 The FSM end date is prior to the FSM start date.-->
						<xsl:if test="string-length(FSMstartDate) != 0 
							and string-length(FSMendDate) != 0
							and translate(FSMstartDate, '-', '') &gt; translate(FSMendDate, '-', '') ">
							<xsl:call-template name="Error">
								<xsl:with-param name="err_num" select="1766"/>
								<xsl:with-param name="data" select="$data"/>
							</xsl:call-template>
						</xsl:if>
						<!--1767 Due to FSM protection we would not expect FSM periods to have an end date. Please provide a reason.-->
						<xsl:if test="string-length(FSMendDate) != 0
							and (string-length(UKcountry) = 0 
								 or UKcountry = 'ENG') ">
							<xsl:call-template name="Error">
								<xsl:with-param name="err_num" select="1767"/>
								<xsl:with-param name="data" select="$data"/>
							</xsl:call-template>
						</xsl:if>
					</xsl:for-each>
					<!--RFC1041 Rule added July 2018-->
					<!--1768 Pupil cannot have multiple open FSM periods.-->
					<!--Outside of for-each structure as otherwise this generates as many errors as there are FSM periods when triggered-->
					<xsl:if test="count(FSMeligibility/FSMperiod[string-length(FSMendDate)=0]) &gt; 1 ">
						<xsl:call-template name="Error">
							<xsl:with-param name="err_num" select="1768"/>
							<xsl:with-param name="data" select="$data"/>
						</xsl:call-template>
					</xsl:if>
					<!--END FSM VALIDATION-->
					<!--START LEARNER FAM VALIDATION - new for 21/22-->
					<xsl:if test="count(LearnerFAMModule/LearnerFAM/LearnFAMCode[. = '21']) &gt; 1
							   or count(LearnerFAMModule/LearnerFAM/LearnFAMCode[. = '22']) &gt; 1
							   or count(LearnerFAMModule/LearnerFAM/LearnFAMCode[. = '01']) &gt; 1 ">
						<xsl:call-template name="Error">
							<xsl:with-param name="err_num" select="4014"/>
							<xsl:with-param name="data" select="$data"/>
						</xsl:call-template>
					</xsl:if>
					<xsl:for-each select="LearnerFAMModule/LearnerFAM">
						<xsl:if test="$Phase != 'NS' ">
							<xsl:if test="not(contains(' NLM ', concat( ' ', LearnFAMType, ' ' ) ))
										or (not(contains(' 01 21 22 ', concat( ' ', LearnFAMCode, ' ') )) )">
								<xsl:call-template name="Error">
									<xsl:with-param name="err_num" select="4000"/>
									<xsl:with-param name="data" select="$data"/>
								</xsl:call-template>
							</xsl:if>
							<xsl:if test=" ../../../../PupilOnRoll 
									and contains(' 01 ', concat( ' ', LearnFAMCode, ' ') )
									and not(contains(' 1 2 3 4 5 6 7 8 9 10 11 ', concat( ' ', ../../../PupilStatus/NCyearActual, ' ' ))
											or (translate(../../../PupilIdentifiers/DOB, '-', '') &lt;= $y5DoBmax
												and translate(../../../PupilIdentifiers/DOB, '-', '') &gt;= $y15min
												and ../../../PupilStatus/NCyearActual = 'X'
												)
											) ">
								<xsl:call-template name="Error">
									<xsl:with-param name="err_num" select="4001"/>
									<xsl:with-param name="data" select="$data"/>
								</xsl:call-template>
							</xsl:if>
							<xsl:if test="../../../../PupilNoLongerOnRoll 
									and contains(' 01 ', concat( ' ', LearnFAMCode, ' ') )
									and not(translate(../../../PupilIdentifiers/DOB, '-', '') &lt;= $y5DoBmax
											and translate(../../../PupilIdentifiers/DOB, '-', '') &gt;= $y15min												
											) ">
								<xsl:call-template name="Error">
									<xsl:with-param name="err_num" select="4002"/>
									<xsl:with-param name="data" select="$data"/>
								</xsl:call-template>
							</xsl:if>
							<xsl:if test="../../../../PupilOnRoll
										and contains(' 21 ', concat( ' ', LearnFAMCode, ' ') )
										and not(translate(../../../PupilIdentifiers/DOB, '-', '') &lt; $y15min
												and contains(' 12 13 14 ', concat( ' ', ../../../PupilStatus/NCyearActual, ' ' ))
												) ">
								<xsl:call-template name="Error">
									<xsl:with-param name="err_num" select="4003"/>
									<xsl:with-param name="data" select="$data"/>
								</xsl:call-template>
							</xsl:if>
							<xsl:if test="../../../../PupilNoLongerOnRoll
										and contains(' 21 ', concat( ' ', LearnFAMCode, ' ') )
										and not(translate(../../../PupilIdentifiers/DOB, '-', '') &lt; $y15min) ">
								<xsl:call-template name="Error">
									<xsl:with-param name="err_num" select="4004"/>
									<xsl:with-param name="data" select="$data"/>
								</xsl:call-template>
							</xsl:if>
							<xsl:if test="../../../../PupilOnRoll
										and contains(' 22 ', concat( ' ', LearnFAMCode, ' ') )
										and not(contains(' 12 13 14 ', concat( ' ', ../../../PupilStatus/NCyearActual, ' ' ))
												) ">
								<xsl:call-template name="Error">
									<xsl:with-param name="err_num" select="4005"/>
									<xsl:with-param name="data" select="$data"/>
								</xsl:call-template>
							</xsl:if>
							<xsl:if test="../../../../PupilOnRoll
										and contains(' 21 22 ', concat( ' ', LearnFAMCode, ' ') )
										and contains(' S ', concat( ' ', ../../../PupilStatus/EnrolStatus, ' ' )) ">
								<xsl:call-template name="Error">
									<xsl:with-param name="err_num" select="4006"/>
									<xsl:with-param name="data" select="$data"/>
								</xsl:call-template>
							</xsl:if>
							<!-- RFC1189 NEW RULE ADDED - ACN 2021-09-21-->	
							<!--4010 If <Phase> is not equal to ‘AT’, ‘SS’ or PR then <LearnFAMCode> ‘21’ or ‘22’ must not be present-->
							<xsl:if test="not(contains( ' SS AT PR ', $Phase ))
											and contains(' 21 22 ', concat( ' ', LearnFAMCode, ' ') ) ">
								<xsl:call-template name="Error">
									<xsl:with-param name="err_num" select="4010"/>
									<xsl:with-param name="data" select="$data"/>
								</xsl:call-template>
							</xsl:if>
							<!-- RFC1189 NEW RULE ADDED - ACN 2021-09-21-->	
							<!--4011 Where <LearnFAMCode> is equal to '22', pupil must be aged 18 or 19 as at 2022-08-31 (DOB is between 2001-09-01 and 2005-08-31 inclusive)-->
							<xsl:if test="../../../../PupilNoLongerOnRoll
										  and contains(' 22 ', concat( ' ', LearnFAMCode, ' ') ) 
										  and not(translate(../../../PupilIdentifiers/DOB, '-', '') &gt;= $y19min
												  and (translate(../../../PupilIdentifiers/DOB, '-', '') &lt;= $y18max))">
								<xsl:call-template name="Error">
									<xsl:with-param name="err_num" select="4011"/>
									<xsl:with-param name="data" select="$data"/>
								</xsl:call-template>
							</xsl:if>
							<!-- RFC1195 NEW RULE ADDED - ACN 2021-11-24-->
							<xsl:if test="(LearnFAMHours = 0 or string-length(LearnFAMHours) = 0)
											and LearnFAMCode = '01' ">
								<xsl:call-template name="Error">
									<xsl:with-param name="err_num" select="4012"/>
									<xsl:with-param name="data" select="$data"/>
								</xsl:call-template>
							</xsl:if>
							<!-- RFC1195 NEW RULE ADDED - ACN 2021-11-24-->
							<xsl:if test="LearnFAMHours &gt; 0 
											and contains(' 21 22 ', concat( ' ', LearnFAMCode, ' ') ) ">
								<xsl:call-template name="Error">
									<xsl:with-param name="err_num" select="4013"/>
									<xsl:with-param name="data" select="$data"/>
								</xsl:call-template>
							</xsl:if>
							<!--4017 Where <LearnFAMHours> are present they must be in the range 1-9 -->
							<xsl:if test="LearnFAMHours &lt; 1 or LearnFAMHours &gt; 15 ">
								<xsl:call-template name="Error">
									<xsl:with-param name="err_num" select="4017"/>
									<xsl:with-param name="data" select="$data"/>
								</xsl:call-template>
							</xsl:if>
						</xsl:if>
					</xsl:for-each>
					<xsl:if test="../../PupilOnRoll">
						<!--4040: <YoungCarer> must be present and a valid value-->
						<xsl:if test="string-length(YoungCarer) = 0 
									  or not(contains( ' P S N ', concat( ' ', YoungCarer, ' ' ) ) )">
							<xsl:call-template name="Error">
								<xsl:with-param name="err_num" select="4040"/>
								<xsl:with-param name="data" select="$data"/>
							</xsl:call-template>
						</xsl:if>
						<!--5046: Youth support services indicator is not required from schools with a phase of NS or PS-->
						<xsl:if test="($Phase = 'NS' or $Phase = 'PS') and string-length(YSSA) != 0">
							<xsl:call-template name="Error">
								<xsl:with-param name="err_num" select="5046"/>
								<xsl:with-param name="data" select="$data"/>
							</xsl:call-template>
						</xsl:if>
						<!--1869: Top Up Funding indicator is missing or invalid-->
						<xsl:if test="string-length(TopUpFunding) = 0 
							or not(contains($boolean, concat( ' ', TopUpFunding, ' ') ) )">
							<xsl:call-template name="Error">
								<xsl:with-param name="err_num" select="1869"/>
								<xsl:with-param name="data" select="$data"/>
							</xsl:call-template>
						</xsl:if>
						<!--1871: Post looked after arrangements indicator is missing or invalid-->
						<xsl:if test="string-length(PLAA) = 0 
							or not(contains( ' N A G R C O ', concat( ' ', PLAA, ' ' ) ) )">
							<xsl:call-template name="Error">
								<xsl:with-param name="err_num" select="1871"/>
								<xsl:with-param name="data" select="$data"/>
							</xsl:call-template>
						</xsl:if>
						<!--1990: Please check: Pupil is in receipt of top-up funding but is not classed as having a 'statement' of SEN or an EHCP?-->
						<xsl:if test="contains($true, concat( ' ', TopUpFunding, ' ' ) )
							and not(contains(' E ', concat(' ', ../SpecialEducationalNeeds/SENprovision,' ') ) )">
							<xsl:call-template name="Error">
								<xsl:with-param name="err_num" select="1990"/>
								<xsl:with-param name="data" select="$data"/>
							</xsl:call-template>
						</xsl:if>
						<xsl:choose>
							<!--1770: Youth Support Services (previously known as Connexions) agreement is missing or invalid-->
							<xsl:when test="$age &gt;= 12 
								and $age &lt;= 25
								and ../SpecialEducationalNeeds/SENprovision='E'
								and (not( contains( ' Yes No UNS SNR ', concat( ' ', YSSA, ' ' ) ) )
										or not(YSSA) )">
								<xsl:call-template name="Error">
									<xsl:with-param name="err_num" select="1770"/>
									<xsl:with-param name="data" select="$data"/>
								</xsl:call-template>
							</xsl:when>
							<!--Note that YSSA is a two-part validation depending on the age and SEN category for the pupil in question-->
							<xsl:when test="$age &gt;= 12 
								and $age &lt;= 20
								and ../SpecialEducationalNeeds/SENprovision != 'E' 
								and (not( contains( ' Yes No UNS SNR ', concat( ' ', YSSA, ' ' ) ) )
										or not(YSSA) )">
								<xsl:call-template name="Error">
									<xsl:with-param name="err_num" select="1770"/>
									<xsl:with-param name="data" select="$data"/>
								</xsl:call-template>
							</xsl:when>
						</xsl:choose>
						<!--1875 School lunch taken is missing or invalid.-->
						<xsl:if test="( contains(' R 1 2 ' , concat(' ', ../PupilStatus/NCyearActual, ' ' ) )
							or (../PupilStatus/NCyearActual = 'X' 
								and contains(' 4 5 6 ', concat(' ', $age, ' ' ) ) ) )
							and not(contains($boolean, concat(' ', SchoolLunchTaken,' ') ) )">
							<xsl:call-template name="Error">
								<xsl:with-param name="err_num" select="1875"/>
								<xsl:with-param name="data" select="$data"/>
							</xsl:call-template>
						</xsl:if>
						<!--1876 School lunch taken only required from pupils in reception, year 1 or year 2 or from pupils aged 4 to 6 in year X-->
						<xsl:if test="not( contains(' R 1 2 ' , concat(' ', ../PupilStatus/NCyearActual, ' ' ) )
							or (../PupilStatus/NCyearActual = 'X' 
								and contains(' 4 5 6 ', concat(' ', $age, ' ' ) ) ) )
							and string-length(SchoolLunchTaken) != 0 ">
							<xsl:call-template name="Error">
								<xsl:with-param name="err_num" select="1876"/>
								<xsl:with-param name="data" select="$data"/>
							</xsl:call-template>
						</xsl:if>
						<!--The following line of criteria apply to the following rules: 1851/2/4/5/9, 3100/5/10/20/30/40/50, 5170/80/90/200/25/30/5/40-->
						<xsl:if test="not(contains(' NM CT ', concat( ' ', $Governance, ' ' ) ) )">
							<xsl:choose>
								<xsl:when test="(translate(../PupilIdentifiers/DOB, '-', '') &gt; $y4DoBmax and translate(../PupilIdentifiers/DOB, '-', '') &lt;= $y3DoBmax)
												or (translate(../PupilIdentifiers/DOB, '-', '') &lt;= $y4DoBmax
													and translate(../PupilIdentifiers/DOB, '-', '') &gt;= $EYPPYr5Max
													and (contains (' E1 E2 N1 N2 ', concat(' ', ../PupilStatus/NCyearActual, ' ') ) ) )">
									<!--(NON-CTC / NMSS) 3100 Extended childcare hours have been entered where pupil is not in the eligible age range or year groups or ***does not have a valid 30-hour code*** (two-parter, see below)-->
									<xsl:if test="string-length(ExtendedHours) != 0
										and string-length(ThirtyHourCode) = 0">
										<xsl:call-template name="Error">
											<xsl:with-param name="err_num" select="3100"/>
											<xsl:with-param name="data" select="$data"/>
										</xsl:call-template>
									</xsl:if>
									<!--(NON-CTC / NMSS) 3110 - A 30-hour code has been entered where pupil is not in the eligible age range or year groups or ***extended hours is missing***-->
									<xsl:if test="string-length(ThirtyHourCode) != 0
										and string-length(ExtendedHours) = 0 ">
										<xsl:call-template name="Error">
											<xsl:with-param name="err_num" select="3110"/>
											<xsl:with-param name="data" select="$data"/>
										</xsl:call-template>
									</xsl:if>
									<!--(NON-CTC / NMSS) 3130 - 30-hours eligibility code missing for pupil aged 3 or 4 with extended hours present-->
									<xsl:if test="string-length(ExtendedHours) != 0 
										and ( string-length(ThirtyHourCode) != 11 
												or translate (ThirtyHourCode, $digits, $all_9s) != '99999999999' ) ">
										<xsl:call-template name="Error">
											<xsl:with-param name="err_num" select="3130"/>
											<xsl:with-param name="data" select="$data"/>
										</xsl:call-template>
									</xsl:if>
									<!--(NON-CTC / NMSS) 3140 - Child’s extended hours not provided or out of the range of 0 to 15 hours-->
									<xsl:if test="string-length(ThirtyHourCode) != 0 
										and (ExtendedHours &gt; 15 
											or ExtendedHours &lt; 0
											or string-length(ExtendedHours) = 0 )">
										<xsl:call-template name="Error">
											<xsl:with-param name="err_num" select="3140"/>
											<xsl:with-param name="data" select="$data"/>
										</xsl:call-template>
									</xsl:if>									
								</xsl:when>								
								<xsl:otherwise>
									<!--(NON-CTC / NMSS) 3100 Extended childcare hours have been entered where pupil ***is not in the eligible age range or year groups*** or does not have a valid 30-hour code (two-parter, see above)-->
									<xsl:if test="string-length(ExtendedHours) != 0">
										<xsl:call-template name="Error">
											<xsl:with-param name="err_num" select="3100"/>
											<xsl:with-param name="data" select="$data"/>
										</xsl:call-template>
									</xsl:if>
									<!--(NON-CTC / NMSS) 3110 - A 30-hour code has been entered where pupil is ***not in the eligible age range or year groups*** or extended hours is missing-->
									<xsl:if test="string-length(ThirtyHourCode) != 0">
										<xsl:call-template name="Error">
											<xsl:with-param name="err_num" select="3110"/>
											<xsl:with-param name="data" select="$data"/>
										</xsl:call-template>
									</xsl:if>
									<!--(NON-CTC / NMSS) 3120 - The disability access fund indicator should only be recorded for pupils aged 3 or 4 (in nursery provision).-->
									<!--Note - this rejects any data in the DAFIndicator node.  Validity is checked by 5230 above-->
									<xsl:if test="string-length(DAFIndicator) != 0">
										<xsl:call-template name="Error">
											<xsl:with-param name="err_num" select="3120"/>
											<xsl:with-param name="data" select="$data"/>
										</xsl:call-template>
									</xsl:if>
								</xsl:otherwise>
							</xsl:choose>
							<xsl:choose>
								<xsl:when test="(translate(../PupilIdentifiers/DOB, '-', '') &gt; $y4DoBmax and translate(../PupilIdentifiers/DOB, '-', '') &lt;= $y3DoBmax)
												or (translate(../PupilIdentifiers/DOB, '-', '') &gt;= $EYPPYr5Max 
													and translate(../PupilIdentifiers/DOB, '-', '') &lt;= $y4DoBmax													
													and (contains (' E1 E2 N1 N2 ', concat(' ', ../PupilStatus/NCyearActual, ' ') ) ) )">
									<!--(NON-CTC / NMSS) 5230 The disability access fund indicator is missing or not a valid value-->
									<xsl:if test="string-length(DAFIndicator) = 0 or not(contains($boolean, concat(' ', DAFIndicator,' ') ) )">
										<xsl:call-template name="Error">
											<xsl:with-param name="err_num" select="5230"/>
											<xsl:with-param name="data" select="$data"/>
										</xsl:call-template>
									</xsl:if>
								</xsl:when>
							</xsl:choose>
							<!--$y4DoBmax = 31 08 2017-->
							<!--$y1DoBmax = 31 12 2019-->							
							<!--Spring 2022 - amended how 1852 works.  Second test after this one will pick up 4 year olds (as per spec) while this test just covers 2 & 3 year olds section in spec-->
							<xsl:if test="translate(../PupilIdentifiers/DOB, '-', '') &gt; $y4DoBmax	
								and translate(../PupilIdentifiers/DOB, '-', '') &lt;= $y1DoBmax ">		
								<!--(NON-CTC / NMSS) 1852: Child’s funded hours not provided or out of the range 0 to 15 to two decimal places for pupils aged 2 or 3-->
								<xsl:if test="(string-length(FundedHours) = 0
												or FundedHours &lt; 0 
												or FundedHours &gt; 15
												or string-length(substring-after(FundedHours, '.') )  &gt; 2 ) ">
									<xsl:call-template name="Error">
										<xsl:with-param name="err_num" select="1852"/>
										<xsl:with-param name="data" select="$data"/>
									</xsl:call-template>
								</xsl:if>
								<!--(NON-CTC / NMSS) 1855: Hours at setting is missing or invalid for 2 and, 3 year olds.-->
								<xsl:if test="HoursAtSetting &lt; 0 
									or string-length(HoursAtSetting) = 0
									or HoursAtSetting &gt; 70 ">
									<!--or string-length(substring-after(HoursAtSetting, '.') ) &gt; 2 -->									
									<xsl:call-template name="Error">
										<xsl:with-param name="err_num" select="1855"/>
										<xsl:with-param name="data" select="$data"/>
									</xsl:call-template>
								</xsl:if>
							</xsl:if>
							<xsl:if test="translate(../PupilIdentifiers/DOB, '-', '') &gt; $y5DoBmax
								and translate(../PupilIdentifiers/DOB, '-', '') &lt;= $y4DoBmax">
								<xsl:choose>									
									<!--NCyearActual in {e1 e2 n1 n2}-->
									<xsl:when test="not(contains(' E1 E2 N1 N2 ', concat(' ', ../PupilStatus/NCyearActual, ' ') ) ) ">
										<!--(NON-CTC / NMSS) 5170 - Child’s funded hours must not be provided for pupil aged 4 in reception-->
										<xsl:if test="string-length(FundedHours) != 0">
											<xsl:call-template name="Error">
												<xsl:with-param name="err_num" select="5170"/>
												<xsl:with-param name="data" select="$data"/>
											</xsl:call-template>
										</xsl:if>
										<!--(NON-CTC / NMSS) 5190 - Child’s hours at setting must not be provided for pupil aged 4 in reception-->
										<xsl:if test="string-length(HoursAtSetting) != 0">
											<xsl:call-template name="Error">
												<xsl:with-param name="err_num" select="5190"/>
												<xsl:with-param name="data" select="$data"/>
											</xsl:call-template>
										</xsl:if>
									</xsl:when>
									<!--NCyearActual NOT in {e1 e2 n1 n2}-->
								</xsl:choose>
							</xsl:if>
							<!--1852 part 2 - test 4 year olds, as per spec this includes NC Year test-->
							<!-- new variable $EYPPYr5Max used from Spr 21 onwards due to changes in RFC 1184 -->
							<xsl:if test="translate(../PupilIdentifiers/DOB, '-', '') &gt;= $EYPPYr5Max
								and translate(../PupilIdentifiers/DOB, '-', '') &lt;= $y4DoBmax">
								<xsl:choose>									
									<xsl:when test="contains(' E1 E2 N1 N2 ' , concat(' ', ../PupilStatus/NCyearActual, ' ' ) )">
										<xsl:if test="string-length(FundedHours) = 0 
											or FundedHours &lt; 0 
											or FundedHours &gt; 15
											or string-length(substring-after(FundedHours, '.') ) &gt; 2">
											<xsl:call-template name="Error">
												<xsl:with-param name="err_num" select="1852"/>
												<xsl:with-param name="data" select="$data"/>
											</xsl:call-template>
										</xsl:if>
										<!--(NON-CTC / NMSS) 5200 - Child’s hours at setting not provided for pupils aged 4 in nursery provision-->
										<xsl:if test="string-length(HoursAtSetting) = 0
													  or HoursAtSetting &gt; 70 ">
											<xsl:call-template name="Error">
												<xsl:with-param name="err_num" select="5200"/>
												<xsl:with-param name="data" select="$data"/>
											</xsl:call-template>
										</xsl:if>
									</xsl:when>
								</xsl:choose>
							</xsl:if>
							<!--Pupils aged 4-->
							<xsl:if test="translate(../PupilIdentifiers/DOB,'-','') &gt; $y2DoBmax
								or translate(../PupilIdentifiers/DOB,'-','') &lt; $EYPPYr5Max ">
								<!--(NON-CTC / NMSS) Child’s funded hours must not be provided for pupil aged 5 and over or aged under 2-->
								<xsl:if test="string-length(FundedHours) != 0 ">
									<xsl:call-template name="Error">
										<xsl:with-param name="err_num" select="1851"/>
										<xsl:with-param name="data" select="$data"/>
									</xsl:call-template>
								</xsl:if>
								<!--(NON-CTC / NMSS) 1854 Childs hours at setting must not be provided for pupil aged 5 and overor pupils aged 2 and under-->
								<xsl:if test="string-length(HoursAtSetting) != 0">
									<xsl:call-template name="Error">
										<xsl:with-param name="err_num" select="1854"/>
										<xsl:with-param name="data" select="$data"/>
									</xsl:call-template>
								</xsl:if>
							</xsl:if>
							<!--/Outside age range 2-5-->
							<!--(NON-CTC / NMSS) 1859: Funded hours cannot be more than the hours at setting -->
							<xsl:if test="$valFundedHours + $valExtendedHours &gt; $valHoursAtSetting ">
								<xsl:call-template name="Error">
									<xsl:with-param name="err_num" select="1859"/>
									<xsl:with-param name="data" select="$data"/>
								</xsl:call-template>
							</xsl:if>
							<xsl:if test="string-length(ThirtyHourCode) != 0 
								and translate (ThirtyHourCode, $digits, $all_9s) != '99999999999' ">
								<xsl:call-template name="Error">
									<xsl:with-param name="err_num" select="3105"/>
									<xsl:with-param name="data" select="$data"/>
								</xsl:call-template>
							</xsl:if>
							<!--(NON-CTC / NMSS) 5220 The disability access fund indicator is only available for pupils with funded or extended hours-->
							<xsl:if test="contains($true, concat(' ', DAFIndicator, ' ' ) )
									and not(number(FundedHours) &gt; 0) 
									and not(number(ExtendedHours) &gt; 0)">
								<xsl:call-template name="Error">
									<xsl:with-param name="err_num" select="5220"/>
									<xsl:with-param name="data" select="$data"/>
								</xsl:call-template>
							</xsl:if>
							<!--(NON-CTC / NMSS) 5235 2-year-old basis of funding is missing or an invalid value or 2-year-old funding basis has been provided without any funded hours being present-->
							<xsl:if test="../../PupilOnRoll 
								and $term = 'SPR' ">
								<!--Two parts: Check the data items exist and then test for validity-->
								<!--Old test.  Unsure what the meaning of the second block of critera was, and it was logged as faulty - so commenting out for now-->
								<!--xsl:if test="FundedHours &gt; 0
										and substring(../PupilIdentifiers/DOB, 1, 4) = ($AcademicYear - 2)
										and string-length(FundingBasisItems/FundingBasis) = 0
									or not(FundedHours) &lt;= 0
										and substring(../PupilIdentifiers/DOB, 1, 4) = ($AcademicYear - 2)
										and string-length(FundingBasisItems/FundingBasis) != 0"-->
								<xsl:if test="FundedHours &gt; 0
										and substring(../PupilIdentifiers/DOB, 1, 4) = ($AcademicYear - 2)
										and string-length(FundingBasisItems/FundingBasis) = 0">
									<xsl:call-template name="Error">
										<xsl:with-param name="err_num" select="5235"/>
										<xsl:with-param name="data" select="$data"/>
									</xsl:call-template>
								</xsl:if>
								<xsl:for-each select="FundingBasisItems/FundingBasis">
									<xsl:if test="string-length(.) != 0 
										and not(contains(' ECO HSD LAA ', concat( ' ', ., ' ' ) ) )">
										<xsl:call-template name="Error">
											<xsl:with-param name="err_num" select="5235"/>
											<xsl:with-param name="data" select="$data"/>
										</xsl:call-template>
									</xsl:if>
									<xsl:if test=". = 'HSD'
												  and ../../../SpecialEducationalNeeds/SENprovision != 'E' ">
										<xsl:call-template name="Error">
											<xsl:with-param name="err_num" select="3211"/>
											<xsl:with-param name="data" select="$data"/>
										</xsl:call-template>
									</xsl:if>
								</xsl:for-each>
								<xsl:if test="count(FundingBasisItems/FundingBasis[. = 'ECO']) &gt; 1
									or count(FundingBasisItems/FundingBasis[. = 'HSD']) &gt; 1
									or count(FundingBasisItems/FundingBasis[. = 'LAA']) &gt; 1 ">
									<xsl:call-template name="Error">
										<xsl:with-param name="err_num" select="3210"/>
										<xsl:with-param name="data" select="$data"/>
									</xsl:call-template>
								</xsl:if>
								<xsl:if test="translate(../PupilIdentifiers/DOB, '-', '') &gt;= $v5236Start
											  and translate(../PupilIdentifiers/DOB, '-', '') &lt;= $v5236End
											  and FundedHours &gt; 0
											  and ../SpecialEducationalNeeds/SENprovision = 'E' 
											  and count(FundingBasisItems/FundingBasis[. = 'HSD']) = 0">
									<xsl:call-template name="Error">
										<xsl:with-param name="err_num" select="5236"/>
										<xsl:with-param name="data" select="$data"/>
									</xsl:call-template>
								</xsl:if>
							</xsl:if>
							<!--(NON-CTC / NMSS) 3200: The basis for funding should only be recorded for pupils aged 2 with funded hours greater than zero-->
							<xsl:if test="$term = 'SPR'
								and string-length(FundingBasisItems/FundingBasis) != 0
								and not ($valFundedHours &gt; 0
											and substring(../PupilIdentifiers/DOB, 1, 4) = /Message/Header/CollectionDetails/Year - 3) ">
								<xsl:call-template name="Error">
									<xsl:with-param name="err_num" select="3200"/>
									<xsl:with-param name="data" select="$data"/>
								</xsl:call-template>
							</xsl:if>
							<!--(NON-CTC / NMSS) 5240: Please check: The number of hours at setting indicates that the pupils may be attending the school full time. However, they have been recorded as part-time-->
							<xsl:if test="number(HoursAtSetting) &gt;= 25
								and not(contains($false, concat(' ', ../PupilStatus/PartTime, ' ') ) )">
								<xsl:call-template name="Error">
									<xsl:with-param name="err_num" select="5240"/>
									<xsl:with-param name="data" select="$data"/>
								</xsl:call-template>
							</xsl:if>
						</xsl:if>
					</xsl:if>
					<!--End of CTC/Non-maintained special schools block-->
					<!--1856 Service children in education indicator missing or invalid-->
					<xsl:if test="../../PupilOnRoll 
						and not(contains(' Y N R U ', concat(' ' ,ServiceChild, ' ' ) ) )">
						<xsl:call-template name="Error">
							<xsl:with-param name="err_num" select="1856"/>
							<xsl:with-param name="data" select="$data"/>
						</xsl:call-template>
					</xsl:if>
					<!--1741 Service Child Free School Meals invalid-->
					<xsl:if test="../../PupilOnRoll 
						and (ServiceChild = 'Y') 
						and (count(FSMeligibility/FSMperiod
							[FSMstartDate 
							and (string-length(FSMendDate)=0 
								or (translate(FSMendDate, '-', '') &gt;= $RefDate) ) ] 
							) &gt; 0)">
						<xsl:call-template name="Error">
							<xsl:with-param name="err_num" select="1741"/>
							<xsl:with-param name="data" select="$data"/>
						</xsl:call-template>
					</xsl:if>
					<!--1874 <PLAA> must not be equal to 'R' where <DOB> is on or after 2014-04-22
						New for 22/23.  Date is fixed constant value and doesn't change every term or year like other date comparisons -->
					<xsl:if test="PLAA = 'R' and translate(../PupilIdentifiers/DOB, '-', '') &gt;= 20140422" >
						<xsl:call-template name="Error">
							<xsl:with-param name="err_num" select="1874"/>
							<xsl:with-param name="data" select="$data"/>
						</xsl:call-template>
					</xsl:if>					
					<!--SPRING SPECIFIC VALIDATION-->
					<xsl:if test="$term='SPR' ">
						<!--(SPR) 1630: Ethnicity present and correct value-->
						<xsl:if test="($Phase != 'NS' or string-length(../../PupilOnRoll) != 0) and 
						(string-length(Ethnicity)=0 or
							(not(contains($EWhite, concat(' ', Ethnicity,' ') ) )
							and not(contains($EMixedDual, concat(' ', Ethnicity,' ') ) )
							and not(contains($EAsianBritA, concat(' ', Ethnicity,' ') ) )
							and not(contains($EBlackBritB , concat(' ', Ethnicity,' ') ) )
							and not(contains($EChinese, concat(' ', Ethnicity,' ') ) )	
							and not(contains($EOther, concat(' ', Ethnicity,' ') ) )
							and not(contains($ENone, concat(' ', Ethnicity,' ') ) )	
						) )">
							<xsl:call-template name="Error">
								<xsl:with-param name="err_num" select="1630"/>
								<xsl:with-param name="data" select="$data"/>
							</xsl:call-template>
						</xsl:if>
						<!--(SPR) 1843 Early years pupil premium basis for funding is missing or invalid-->
						<xsl:if test="EYPPR = 'Y' 
							and not(contains($EYPPBFs, concat(' ', EYPPBF, ' ') ) )">
							<xsl:call-template name="Error">
								<xsl:with-param name="err_num" select="1843"/>
								<xsl:with-param name="data" select="concat($data , ' PupilCharacteristics') "/>
							</xsl:call-template>
						</xsl:if>
						<!--(SPR) 1844 Early years pupil premium basis for funding is only required where early years pupil premium eligibility is 'Y'-->
						<xsl:if test="EYPPR = 'N' 
							and string-length(EYPPBF) != 0 ">
							<xsl:call-template name="Error">
								<xsl:with-param name="err_num" select="1844"/>
								<xsl:with-param name="data" select="concat($data , ' PupilCharacteristics') "/>
							</xsl:call-template>
						</xsl:if>
						<!--(SPR) 1846 Early years pupil premium must be recorded for all 3 year olds-->
						<xsl:if test="../../PupilOnRoll
							and (string-length(EYPPR) = 0 
								or not(contains(' Y N ', concat(' ', EYPPR, ' ') ) ) )
							and translate(../PupilIdentifiers/DOB, '-', '') &gt; $y4DoBmax
							and translate(../PupilIdentifiers/DOB, '-', '') &lt;= $Rising3DoB">
							<xsl:call-template name="Error">
								<xsl:with-param name="err_num" select="1846"/>
								<xsl:with-param name="data" select="$data"/>
							</xsl:call-template>
						</xsl:if>
						<!--(SPR) 1847 Early years pupil premium must be recorded for 4 year olds in Nursery provision-->
						<!--Added check for valid values Y or N as well as missing EYPPR. IK 28/10/2015-->
						<xsl:if test="../../PupilOnRoll
							and $Phase = 'NS' 
							and (string-length(EYPPR) = 0 or not(contains(' Y N ', concat(' ', EYPPR, ' ') ) ) )
							and translate(../PupilIdentifiers/DOB, '-', '') &gt;= $EYPPYr5Max 
							and translate(../PupilIdentifiers/DOB, '-', '') &lt;= $y4DoBmax ">
							<xsl:call-template name="Error">
								<xsl:with-param name="err_num" select="1847"/>
								<xsl:with-param name="data" select="$data"/>
							</xsl:call-template>
						</xsl:if>
						<!--(SPR) 1848 Early years pupil premium must be recorded for 4 year olds in N1 or N2 provision-->
						<!--Added check for valid values Y or N as well as missing EYPPR. IK 28/10/2015-->
						<xsl:if test="../../PupilOnRoll
							and ( string-length(EYPPR) = 0 or not(contains(' Y N ', concat(' ', EYPPR, ' ') ) ) )
							and translate(../PupilIdentifiers/DOB, '-', '') &gt;= $EYPPYr5Max
							and translate(../PupilIdentifiers/DOB, '-', '') &lt;= $y4DoBmax
							and contains(' E1 E2 N1 N2 ', concat(' ', ../PupilStatus/NCyearActual, ' ') ) ">
							<xsl:call-template name="Error">
								<xsl:with-param name="err_num" select="1848"/>
								<xsl:with-param name="data" select="$data"/>
							</xsl:call-template>
						</xsl:if>
						<!--(SPR) 1849 Please check: 3 year old and 4 year old in nursery adopted from care would be expected to be eligible for the early years pupil premium.-->
						<xsl:if test="contains(' A G C O ', concat(' ', PLAA, ' ') ) and string-length(EYPPR) > 0
							and ( EYPPR != 'Y' 
										or not(contains(' RB RO ', concat(' ', EYPPBF, ' ') ) ) )">
							<xsl:call-template name="Error">
								<xsl:with-param name="err_num" select="1849"/>
								<xsl:with-param name="data" select="$data"/>
							</xsl:call-template>
						</xsl:if>
						<!--(SPR) 1853 Please check: 3 year old and 4 year old in nursery eligible for FSM on census day would be expected to be eligible for the early years pupil premium.-->
						<xsl:if test="string-length(EYPPR) != 0
							and count(FSMeligibility/FSMperiod[string-length(FSMendDate) = 0 
								or (translate(FSMendDate, '-', '') &gt;= $RefDate) ] ) &gt; 0
							and ( EYPPR != 'Y' 
									or not(contains(' RB RE ', concat(' ', EYPPBF, ' ') ) ) )">
							<xsl:call-template name="Error">
								<xsl:with-param name="err_num" select="1853"/>
								<xsl:with-param name="data" select="$data"/>
							</xsl:call-template>
						</xsl:if>
						<!--(SPR) 1861 [two blocks] Early years pupil premium must only be recorded for 3 or for 4 year olds that are in Nursery provision, E1, E2, N1 or N2-->
						<xsl:if test="string-length(EYPPR) + string-length(EYPPBF) != 0 
							and(translate(../PupilIdentifiers/DOB, '-', '') &lt; $EYPPYr5Max
								or translate(../PupilIdentifiers/DOB, '-', '') &gt; $Rising3DoB ) ">
							<xsl:call-template name="Error">
								<xsl:with-param name="err_num" select="1861"/>
								<xsl:with-param name="data" select="$data"/>
							</xsl:call-template>
						</xsl:if>
						<!--(SPR) 1862 [two blocks] Early years pupil premium must only be recorded for 3 or for 4 year olds that are in Nursery provision, E1, E2, N1 or N2-->
						<xsl:if test="string-length(EYPPR) + string-length(EYPPBF) != 0 
							and( $Phase != 'NS'
							and not(contains(' E1 E2 N1 N2 ', concat(' ', ../PupilStatus/NCyearActual, ' ') ) )
							and translate(../PupilIdentifiers/DOB, '-', '') &gt;= $EYPPYr5Max
							and translate(../PupilIdentifiers/DOB, '-', '') &lt;= $y4DoBmax )">
							<xsl:call-template name="Error">
								<xsl:with-param name="err_num" select="1862"/>
								<xsl:with-param name="data" select="$data"/>
							</xsl:call-template>
						</xsl:if>
						<xsl:if test="../../PupilOnRoll 
							and $Phase='PR' ">
							<!--(SPR) 2690 Unit Contact Time missing or invlaid -->
							<xsl:if test="string-length(UnitContactTimePupil) = 0 ">
								<xsl:call-template name="Error">
									<xsl:with-param name="err_num" select="2690"/>
									<xsl:with-param name="data" select="$data"/>
								</xsl:call-template>
							</xsl:if>
							<!--(SPR) 2691 Unit Contact Time must be less than or = 25 hours -->
							<xsl:if test="UnitContactTimePupil &gt; 25 ">
								<xsl:call-template name="Error">
									<xsl:with-param name="err_num" select="2691"/>
									<xsl:with-param name="data" select="$data"/>
								</xsl:call-template>
							</xsl:if>
							<!--New for 19-20 -->
							<!--(SPR) 2692Q Unit Contact Time must be greater than zero -->
							<xsl:if test=" not(contains (' 9 99 ', concat(' ', translate( UnitContactTimePupil, $digits, $all_9s ), ' ') ) ) 
													or not(UnitContactTimePupil &gt; 0) ">
								<xsl:call-template name="Error">
									<xsl:with-param name="err_num" select="2692"/>
									<xsl:with-param name="data" select="$data"/>
								</xsl:call-template>
							</xsl:if>
						</xsl:if>
					</xsl:if>
					<!--End of Spring-only validation-->
					<!--SPRING AND SUMMER SPECIFIC VALIDATION-->
					<xsl:if test="$term = 'SPR' or $term = 'SUM' ">
						<!--(SPR) (SUM) 1864 Learner support code should not be provided for subsidiary pupils-->
						<xsl:if test="../../PupilOnRoll 
							and ../PupilStatus/EnrolStatus = 'S' 
							and string-length(LearnerSupport) != 0">
							<xsl:call-template name="Error">
								<xsl:with-param name="err_num" select="1864"/>
								<xsl:with-param name="data" select="$data"/>
							</xsl:call-template>
						</xsl:if>
						<!--(SPR) (SUM) 1865 Verify Learner Support Code is valid.-->
						<xsl:if test="count(LearnerSupport[LearnerSupportItem] )">
							<xsl:if test="count(LearnerSupport/LearnerSupportItem
								[SupportCode!='55' and SupportCode!='56'] )">
								<xsl:call-template name="Error">
									<xsl:with-param name="err_num" select="1865"/>
									<xsl:with-param name="data" select="$data"/>
								</xsl:call-template>
							</xsl:if>
							<!--(SPR) (SUM) 1866 The same Learner Support code should not appear more than once for the same pupil-->
							<!--Updated Nov 2017 to validate both methods for supplying support codes-->
							<xsl:if test="count(LearnerSupport/LearnerSupportItem[SupportCode='55'] ) &gt;1 
							or count(LearnerSupport/LearnerSupportItem[SupportCode='56'] ) &gt; 1
							or count(LearnerSupport/LearnerSupportItem/SupportCode[. = 55]) &gt; 1
							or count(LearnerSupport/LearnerSupportItem/SupportCode[. = 56]) &gt; 1">
								<xsl:call-template name="Error">
									<xsl:with-param name="err_num" select="1866"/>
									<xsl:with-param name="data" select="$data"/>
								</xsl:call-template>
							</xsl:if>
							<!--(SPR) (SUM) 1867 Learner is aged under 16 years as at 31 August and not eligible for Bursary Funding -->
							<xsl:if test="$age &lt; 16">
								<xsl:call-template name="Error">
									<xsl:with-param name="err_num" select="1867"/>
									<xsl:with-param name="data" select="$data"/>
								</xsl:call-template>
							</xsl:if>
							<!--(SPR) (SUM) 1868 Where <SupportCode> (100491) is present, learner must be aged under 20 years as at 31 August-->
							<xsl:if test="$age &gt;= 20">
								<xsl:call-template name="Error">
									<xsl:with-param name="err_num" select="1868"/>
									<xsl:with-param name="data" select="$data"/>
								</xsl:call-template>
							</xsl:if>
						</xsl:if>
					</xsl:if>
					<!--END OF SPRING/SUMMER SPECIFIC VALIDATION-->
					<!--AUTUMN SPECIFIC VALIDATION-->
					<xsl:if test="$term = 'AUT' ">
						<xsl:if test="contains( ' SS AT PR ', $_Phase_)">
							<!--On- and off-roll pupils -->
							<!--(AUT) 1635 Where the learner has not achieved grade A*-C / 9-4 in Maths GCSE the stage that the learner achieved this must not be equal to 1 or 2-->
							<xsl:if test="contains( ' D E F G U 3 2 1 ', concat( ' ', MathsGCSEHighestPriorAttainment, ' ' ) )
								 and MathsGCSEPriorAttainmentYear11 != 3">
								<xsl:call-template name="Error">
									<xsl:with-param name="err_num" select="1635"/>
									<xsl:with-param name="data" select="$data"/>
								</xsl:call-template>
							</xsl:if>
							<!--(AUT) 1636 Where learner has achieved grade A*-C / 9-4 in maths the prior attainment stage must be equal to 1 or 2-->
							<xsl:if test="contains( ' A* A B C 9 8 7 6 5 4 ', concat( ' ', MathsGCSEHighestPriorAttainment, ' ' ) )
								and not(contains( ' 1 2 ', concat( ' ', MathsGCSEPriorAttainmentYear11, ' ' ) ) )">
								<xsl:call-template name="Error">
									<xsl:with-param name="err_num" select="1636"/>
									<xsl:with-param name="data" select="$data"/>
								</xsl:call-template>
							</xsl:if>
							<!--(AUT) 1637 Where the learner has not achieved grade A*-C / 9-4 in English GCSE the stage that the learner achieved this must not be equal to 1 or 2-->
							<xsl:if test="contains( ' D E F G U 3 2 1 ', concat( ' ', EnglishGCSEHighestPriorAttainment, ' ' ) )
								and EnglishGCSEPriorAttainmentYear11 != 3">
								<xsl:call-template name="Error">
									<xsl:with-param name="err_num" select="1637"/>
									<xsl:with-param name="data" select="$data"/>
								</xsl:call-template>
							</xsl:if>
							<!--(AUT) 1638 Where learner has achieved grade A*-C / 9-4 in English the prior attainment stage must be equal to 1 or 2-->
							<!-- Removed as no longer required 21/09/2020 -->
<!--							<xsl:if test="contains( ' A* A B C 9 8 7 6 5 4 ', concat( ' ', EnglishGCSEHighestPriorAttainment, ' ' ) )
								and not(contains( ' 1 2 ', concat( ' ', EnglishGCSEPriorAttainmentYear11, ' ' ) ) )">
								<xsl:call-template name="Error">
									<xsl:with-param name="err_num" select="1638"/>
									<xsl:with-param name="data" select="$data"/>
								</xsl:call-template>
							</xsl:if>	-->
						</xsl:if>
						<!--(AUT) 3040 Maths GCSE funding exemption is missing or invalid-->
						<xsl:if test="string-length(MathsGCSEHighestPriorAttainment) != 0
								 and not(contains( ' L O U N F ', concat( ' ', MathsGCSEFundingExemption, ' ') ) )">
							<xsl:call-template name="Error">
								<xsl:with-param name="err_num" select="3040"/>
								<xsl:with-param name="data" select="$data"/>
							</xsl:call-template>
						</xsl:if>
						<!--(AUT) 3045 English GCSE funding exemption is missing or invalid-->
						<xsl:if test="string-length(EnglishGCSEHighestPriorAttainment) != 0
								 and not(contains( ' L O U N F ', concat( ' ', EnglishGCSEFundingExemption, ' ') ) )">
							<xsl:call-template name="Error">
								<xsl:with-param name="err_num" select="3045"/>
								<xsl:with-param name="data" select="$data"/>
							</xsl:call-template>
						</xsl:if>
						<!--1894 Student has at least one T Level component which has been active during the current year but there are no T Level planned learning hours recorded --> 
						<!-- IW AMENDED TO INCLUDE ProgrammeAims/ProgrammeAim/ - 2021-08-20 -->
						<xsl:if test="((TLevelQualHrs + TLevelNon_qualHrs = 0)
										or (string-length(TLevelQualHrs) = 0 
											and string-length(TLevelNon_qualHrs) = 0)
										or (string-length(TLevelQualHrs) = 0 
											and Non_qualHrs = 0)
										or (TLevelNon_qualHrs = 0 
											and string-length(TLevelNon_qualHrs) = 0))
									and count(../ProgrammeAims/ProgrammeAim/LearningAims/LearningAim
										[(translate(LearningStartDate, '-', '') &gt; $Aug1stAcadYrStart
										  or string-length(LearningStartDate) = 0)
										and ProgType = '31']) &gt; 0 ">
							<xsl:call-template name="Error">
								<xsl:with-param name="err_num" select="1894"/>
								<xsl:with-param name="data" select="$data"/>
							</xsl:call-template>
						</xsl:if>
						<!--1895 Student does not have at least one T Level component recorded therefore T Level planned learning hours and/or T level planned employability, enrichment and pastoral hours should not be present-->
						<!-- IW AMENDED TO INCLUDE ProgrammeAims/ProgrammeAim/ - 2021-08-20 -->
						<xsl:if test="(TLevelQualHrs &gt; 0
									or TLevelNon_qualHrs &gt; 0) 
								and count(../ProgrammeAims/ProgrammeAim/LearningAims/LearningAim[ProgType = '31']) = 0 ">
							<xsl:call-template name="Error">
								<xsl:with-param name="err_num" select="1895"/>
								<xsl:with-param name="data" select="$data"/>
							</xsl:call-template>
						</xsl:if>
						<!--On-roll only -->
						<xsl:if test="string-length(../../PupilOnRoll)">
							<!--1896 If a student has both planned learning hours and T Level planned learning hours they must have a programme aim with a programme type of T Level AND a programme aim with a programme type of Study programme or 'T Level transition programme-->
										<!--or (string-length(TLevelQualHrs) = 0 
													and string-length(TLevelNon_qualHrs) = 0)
												or (string-length(TLevelQualHrs) = 0 
													and Non_qualHrs = 0)	
											or (TLevelNon_qualHrs = 0 
												and string-length(TLevelNon_qualHrs) = 0)	-->						
							<xsl:if test="(TLevelQualHrs + TLevelNon_qualHrs > 0)
												and (QualHrs + Non_qualHrs > 0)
										and (count(../ProgrammeAims/ProgrammeAim
												[ProgType = '31']) = 0
											or count(../ProgrammeAims/ProgrammeAim
												[contains(' 01 30 ', concat(' ', ProgType, ' ') ) ] ) = 0
											) "	>
								<xsl:call-template name="Error">
									<xsl:with-param name="err_num" select="1896"/>
									<xsl:with-param name="data" select="$data"/>
								</xsl:call-template>
							</xsl:if>
							<!-- 2706 - On roll pupil with NC year Actual less than 12 then learning aims not expected-->
							<xsl:if test="(number(../PupilStatus/NCyearActual) &lt; 12 
								or contains(' E1 E2 N1 N2 R ', concat(' ', ../PupilStatus/NCyearActual,' ')))
									and (string-length(../ProgrammeAims) != 0
											or string-length(QualHrs) != 0
											or string-length(Non_qualHrs) != 0
											or string-length(QualHrsPreviousYear) != 0
											or string-length(Non_qualHrsPreviousYear) != 0
											or string-length(TLevelQualHrs) != 0
											or string-length(TLevelNon_qualHrs) != 0
											or string-length(FTEmp) != 0
											or string-length(MathsGCSEHighestPriorAttainment) != 0
											or string-length(MathsGCSEPriorAttainmentYear11) != 0
											or string-length(EnglishGCSEHighestPriorAttainment) != 0 
											or string-length(EnglishGCSEPriorAttainmentYear11) != 0  
											or string-length(MathsGCSEFundingExemption) !=  0 
											or string-length(EnglishGCSEFundingExemption) != 0
											or string-length(MathsGCSEHighestPriorAttainmentPreviousYear) != 0
											or string-length(EnglishGCSEHighestPriorAttainmentPreviousYear) != 0 
											 ) ">
								<xsl:call-template name="Error">
									<xsl:with-param name="err_num" select="2706"/>
									<xsl:with-param name="data" select="$data"/>
								</xsl:call-template>
							</xsl:if>
							<!--2715 Please check: Post 16 data should not be provided for pupils with subsidiary registration. Please ensure that all post 16 data for subsidiary registered pupils are returned by the school holding the main registration.-->
							<xsl:if test="../PupilStatus/EnrolStatus= 'S' 
									and (string-length(../ProgrammeAims) != 0
											or string-length(QualHrs) != 0
											or string-length(Non_qualHrs) != 0
											or string-length(QualHrsPreviousYear) != 0
											or string-length(Non_qualHrsPreviousYear) != 0											
											or string-length(TLevelQualHrs) != 0
											or string-length(TLevelNon_qualHrs) != 0
											or string-length(FTEmp) != 0
											or string-length(MathsGCSEHighestPriorAttainment) != 0
											or string-length(MathsGCSEPriorAttainmentYear11) != 0
											or string-length(EnglishGCSEHighestPriorAttainment) != 0 
											or string-length(EnglishGCSEPriorAttainmentYear11) != 0 
											or string-length(MathsGCSEFundingExemption) !=  0 
											or string-length(EnglishGCSEFundingExemption) != 0 
											or string-length(MathsGCSEHighestPriorAttainmentPreviousYear) != 0
											or string-length(EnglishGCSEHighestPriorAttainmentPreviousYear) != 0
											)">
								<xsl:call-template name="Error">
									<xsl:with-param name="err_num" select="2715"/>
									<xsl:with-param name="data" select="$data"/>
								</xsl:call-template>
							</xsl:if>
							<!-- New for 19-20 -->
							<!--2717 Please check: Post 16 data should not be provided from schools which do not have a phase of ‘AT’, ‘SS’ or ‘PR’.-->
							<xsl:if test="not(contains( ' SS AT PR ', $_Phase_))
									and (string-length(../ProgrammeAims) != 0
											or string-length(QualHrs) != 0
											or string-length(Non_qualHrs) != 0
											or string-length(QualHrsPreviousYear) != 0
											or string-length(Non_qualHrsPreviousYear) != 0											
											or string-length(TLevelQualHrs) != 0
											or string-length(TLevelNon_qualHrs) != 0
											or string-length(FTEmp) != 0
											or string-length(MathsGCSEHighestPriorAttainment) != 0
											or string-length(MathsGCSEPriorAttainmentYear11) != 0
											or string-length(EnglishGCSEHighestPriorAttainment) != 0 
											or string-length(EnglishGCSEPriorAttainmentYear11) != 0 
											or string-length(MathsGCSEFundingExemption) !=  0 
											or string-length(EnglishGCSEFundingExemption) != 0 
											or string-length(MathsGCSEHighestPriorAttainmentPreviousYear) != 0
											or string-length(EnglishGCSEHighestPriorAttainmentPreviousYear) != 0
											)">
								<xsl:call-template name="Error">
									<xsl:with-param name="err_num" select="2717"/>
									<xsl:with-param name="data" select="$data"/>
								</xsl:call-template>
							</xsl:if>
							<!--(AUT) 1633 Pupil has an exemption for English GCSE funding due to learning difficulties but does not have a statement of SEN or an education, health and care plan (EHCP)-->
							<xsl:if test="EnglishGCSEFundingExemption ='L' 
									and not(contains(' E ', concat(' ', ../SpecialEducationalNeeds/SENprovision,' ') ) )">
								<xsl:call-template name="Error">
									<xsl:with-param name="err_num" select="1633"/>
									<xsl:with-param name="data" select="$data"/>
								</xsl:call-template>
							</xsl:if>
							<!--(AUT) 1634 Pupil has an exemption for Maths GCSE funding due to learning difficulties but does not have a statement of SEN or an education, health and care plan (EHCP)-->
							<xsl:if test="string-length(../../PupilOnRoll) 
								and MathsGCSEFundingExemption ='L' 
								and not(contains(' E ', concat(' ', ../SpecialEducationalNeeds/SENprovision,' ') ) )">
								<xsl:call-template name="Error">
									<xsl:with-param name="err_num" select="1634"/>
									<xsl:with-param name="data" select="$data"/>
								</xsl:call-template>
							</xsl:if>
						</xsl:if>
						<!--/PupilOnRoll-->

						<!--Off-roll only -->
						<xsl:if test="../../PupilNoLongerOnRoll">
							<!--2707Q - Not On roll pupil with NC year Leaving less than 12 then learning aims not expected-->
							<xsl:if test="(number(../PupilStatus/NCyearLeaving) &lt; 12 or contains(' E1 E2 N1 N2 R ', concat(' ', ../PupilStatus/NCyearLeaving,' ')))
									and (string-length(../ProgrammeAims) != 0
											or string-length(QualHrs) != 0
											or string-length(Non_qualHrs) != 0
											or string-length(QualHrsPreviousYear) != 0
											or string-length(Non_qualHrsPreviousYear) != 0
											or string-length(TLevelQualHrs) != 0
											or string-length(TLevelNon_qualHrs) != 0
											or string-length(FTEmp) != 0
											or string-length(MathsGCSEHighestPriorAttainment) != 0
											or string-length(MathsGCSEPriorAttainmentYear11) != 0
											or string-length(EnglishGCSEHighestPriorAttainment) != 0 
											or string-length(EnglishGCSEPriorAttainmentYear11) != 0  
											or string-length(MathsGCSEFundingExemption) !=  0 
											or string-length(EnglishGCSEFundingExemption) != 0
											or string-length(MathsGCSEHighestPriorAttainmentPreviousYear) != 0
											or string-length(EnglishGCSEHighestPriorAttainmentPreviousYear) != 0 
											 ) ">
								<xsl:call-template name="Error">
									<xsl:with-param name="err_num" select="2707"/>
									<xsl:with-param name="data" select="$data"/>
								</xsl:call-template>
							</xsl:if>
							<!--2709 - Learning Aims from previous academic year expected for school leaver-->
							<!--date range for leaving date is from previous year's refdate up to and including the day before this years refdate--><!-- IW AMENDED TO INCLUDE ProgrammeAims/ProgrammeAim/ - 2021-08-20 -->
							<xsl:if test="number(../PupilStatus/NCyearLeaving) &gt; 11 
									and translate(../PupilStatus/LeavingDate, '-', '') &gt; $PrevYearRefDate
									and translate(../PupilStatus/LeavingDate, '-', '') &lt; $RefDate
									and count(../ProgrammeAims/ProgrammeAim/LearningAims/LearningAim) = 0 ">
								<xsl:call-template name="Error">
									<xsl:with-param name="err_num" select="2709"/>
									<xsl:with-param name="data" select="$data"/>
								</xsl:call-template>
							</xsl:if>
						</xsl:if>
						<!--/PupilNoLongerOnRoll-->
						
						<!--(AUT) 1992 Pupil has at least one learning aim which was active during the current year but there are no planned learning hours recorded for the current academic year--><!-- IW AMENDED TO INCLUDE ProgrammeAims/ProgrammeAim/ - 2021-08-20 -->
						<xsl:if test="count(../ProgrammeAims/ProgrammeAim/LearningAims/LearningAim
									[ (string-length(LearningActualEndDate) = 0 
										or translate(LearningActualEndDate, '-', '') &gt; $StartCurrentTerm )
									and contains(' 01 30 ', concat(' ', ProgType, ' ') ) ] ) &gt; 0">
							<xsl:if test="(QualHrs + Non_qualHrs = 0)
										or (string-length(QualHrs) = 0 and string-length(Non_qualHrs) = 0)
										or (string-length(QualHrs) = 0 and Non_qualHrs = 0)
										or (QualHrs = 0 and string-length(Non_qualHrs) = 0)">
								<xsl:call-template name="Error">
									<xsl:with-param name="err_num" select="1992"/>
									<xsl:with-param name="data" select="$data"/>
								</xsl:call-template>
							</xsl:if>
						</xsl:if>
						<!--(AUT) 1993 Pupil does not have at least one learning aim recorded therefore planned learning hours and/or planned employability, enrichment and pastoral hours should not be present--><!-- IW AMENDED TO INCLUDE ProgrammeAims/ProgrammeAim/ - 2021-08-20 -->
						<xsl:if test="count(../ProgrammeAims/ProgrammeAim/LearningAims/LearningAim[contains(' 01 30 ', concat(' ', ProgType, ' ') ) ]) = 0">
							<xsl:if test="(QualHrs + Non_qualHrs) &gt; 0
									or (string-length(QualHrs) = 0 and Non_qualHrs &gt; 0 )
									or (QualHrs &gt; 0 and string-length(Non_qualHrs) = 0)">
								<xsl:call-template name="Error">
									<xsl:with-param name="err_num" select="1993"/>
									<xsl:with-param name="data" select="$data"/>
								</xsl:call-template>
							</xsl:if>
						</xsl:if>
						<!--(AUT) 1996 Please check: The sum of planned learning hour and the planned employability, enrichment and pastoral hours must not be greater than 1,000 hours-->
						<xsl:if test="( (QualHrs + Non_qualHrs) &gt; 1000 and (QualHrs + Non_qualHrs) &lt;= 4000)
								or (string-length(QualHrs) = 0 and Non_qualHrs &gt; 1000 and Non_qualHrs &lt;= 4000)
								or (QualHrs &gt; 1000 and QualHrs &lt;= 4000 and string-length(Non_qualHrs) = 0)">
							<xsl:call-template name="Error">
								<xsl:with-param name="err_num" select="1996"/>
								<xsl:with-param name="data" select="$data"/>
							</xsl:call-template>
						</xsl:if>
						<!--(AUT) 1997 The sum of planned learning hours and planned employability, enrichment and pastoral hours must not be greater than 4,000 hours-->
						<xsl:if test="(QualHrs + Non_qualHrs) &gt; 4000 
								or (string-length(QualHrs) = 0 and Non_qualHrs &gt; 4000)
								or (QualHrs &gt; 4000 and string-length(Non_qualHrs) = 0)">
							<xsl:call-template name="Error">
								<xsl:with-param name="err_num" select="1997"/>
								<xsl:with-param name="data" select="$data"/>
							</xsl:call-template>
						</xsl:if>
						<!--(AUT) 1998 Please check: The pupil has  planned employability, enrichment and pastoral hours but no planned learning hours-->
						<xsl:if test="(string-length(QualHrs) = 0 and Non_qualHrs &gt;= 1 )
								or (QualHrs = 0 and Non_qualHrs &gt;= 1)">
							<xsl:call-template name="Error">
								<xsl:with-param name="err_num" select="1998"/>
								<xsl:with-param name="data" select="$data"/>
							</xsl:call-template>
						</xsl:if>
						<!--1886, 1887, 1888, 1889, 1891 all new for 19-20-->
						<!--(AUT) 1886 -->
						<xsl:if test="count(../ProgrammeAims/ProgrammeAim/LearningAims/LearningAim
									[ translate(LearningStartDate, '-', '') &lt;= $StartCurrentTerm 
									and (string-length(LearningActualEndDate) = 0
										or translate(LearningActualEndDate, '-', '') &lt;= $StartCurrentTerm )
									and contains(' 01 30 ', concat(' ', ProgType, ' ') ) ] ) &gt; 0">
							<xsl:if test="(QualHrsPreviousYear + Non_qualHrsPreviousYear = 0)
										or (string-length(QualHrsPreviousYear) = 0 
											and string-length(Non_qualHrsPreviousYear) = 0)
										or (string-length(QualHrsPreviousYear) = 0 
											and Non_qualHrsPreviousYear = 0)
										or (QualHrsPreviousYear = 0 
											and string-length(Non_qualHrsPreviousYear) = 0)">
								<xsl:call-template name="Error">
									<xsl:with-param name="err_num" select="1886"/>
									<xsl:with-param name="data" select="$data"/>
								</xsl:call-template>
							</xsl:if>
						</xsl:if>
						<!--(AUT) 1887 -->
						<xsl:if test="count(../ProgrammeAims/ProgrammeAim/LearningAims/LearningAim
									[ translate(LearningStartDate, '-', '') &lt;= $StartCurrentTerm 
									and contains(' 01 30 ', concat(' ', ProgType, ' ') ) ] ) = 0">
							<xsl:if test="QualHrsPreviousYear &gt; 0
									or Non_qualHrsPreviousYear &gt; 0 ">
								<xsl:call-template name="Error">
									<xsl:with-param name="err_num" select="1887"/>
									<xsl:with-param name="data" select="$data"/>
								</xsl:call-template>
							</xsl:if>
						</xsl:if>
						<!--(AUT) 1888 -->
						<xsl:if test="( (QualHrsPreviousYear + Non_qualHrsPreviousYear) &gt; 1000 and (QualHrsPreviousYear + Non_qualHrsPreviousYear) &lt;= 4000)
								or (string-length(QualHrsPreviousYear) = 0 and Non_qualHrsPreviousYear &gt; 1000 and Non_qualHrsPreviousYear &lt;= 4000)
								or (QualHrsPreviousYear &gt; 1000 and QualHrsPreviousYear &lt;= 4000 and string-length(Non_qualHrsPreviousYear) = 0)">
							<xsl:call-template name="Error">
								<xsl:with-param name="err_num" select="1888"/>
								<xsl:with-param name="data" select="$data"/>
							</xsl:call-template>
						</xsl:if>
						<!--(AUT) 1889 -->
						<xsl:if test="(QualHrsPreviousYear + Non_qualHrsPreviousYear) &gt; 4000 
								or (string-length(QualHrsPreviousYear) = 0 and Non_qualHrsPreviousYear &gt; 4000)
								or (QualHrsPreviousYear &gt; 4000 and string-length(Non_qualHrsPreviousYear) = 0)">
							<xsl:call-template name="Error">
								<xsl:with-param name="err_num" select="1889"/>
								<xsl:with-param name="data" select="$data"/>
							</xsl:call-template>
						</xsl:if>
						<!--(AUT) 1891 -->
						<xsl:if test="(string-length(QualHrsPreviousYear) = 0 and Non_qualHrsPreviousYear &gt;= 1 )
								or (QualHrsPreviousYear = 0 and Non_qualHrsPreviousYear &gt;= 1)">
							<xsl:call-template name="Error">
								<xsl:with-param name="err_num" select="1891"/>
								<xsl:with-param name="data" select="$data"/>
							</xsl:call-template>
						</xsl:if>
					</xsl:if>
					<!--Phase in {PR SS AT}-->
					<!--(AUT) 2775 Please check: The sum of planned learning hours and the planned employability, enrichment and pastoral hours is very low. Total planned hours should reflect the annual planned hours for the academic year..-->
					<xsl:if test="(string-length(QualHrs) + string-length(Non_qualHrs) &gt; 0)
						and ( ( (QualHrs + Non_qualHrs) &lt; 40)
							or (string-length(QualHrs) = 0 
								and Non_qualHrs &lt; 40)
							or (QualHrs &lt; 40 
								and string-length(Non_qualHrs) = 0) )">
						<xsl:if test="../../PupilOnRoll and contains(' 12 13 14 ',concat(' ',../PupilStatus/NCyearActual, ' ') ) 
								or (../../PupilNoLongerOnRoll and contains(' 12 13 14 ',concat(' ',../PupilStatus/NCyearLeaving, ' ') ) 
								and count(../ProgrammeAims/ProgrammeAim/LearningAims/LearningAim[translate(LearningActualEndDate, '-', '') &gt; $StartCurrentTerm ] ) > 0) ">
							<xsl:call-template name="Error">
								<xsl:with-param name="err_num" select="2775"/>
								<xsl:with-param name="data" select="$data"/>
							</xsl:call-template>
						</xsl:if>
					</xsl:if>
					<!--(AUT) 1893 new for 19-20 -->
					<xsl:if test="(string-length(QualHrsPreviousYear) + string-length(Non_qualHrsPreviousYear) &gt; 0)
						and ( ( (QualHrsPreviousYear + Non_qualHrsPreviousYear) &lt; 40)
							or (string-length(QualHrsPreviousYear) = 0 
								and Non_qualHrsPreviousYear &lt; 40)
							or (QualHrsPreviousYear &lt; 40 
								and string-length(Non_qualHrsPreviousYear) = 0) )">
						<xsl:if test="../../PupilOnRoll and contains(' 12 13 14 ',concat(' ',../PupilStatus/NCyearActual, ' ') ) 
								or (../../PupilNoLongerOnRoll and contains(' 12 13 14 ',concat(' ',../PupilStatus/NCyearLeaving, ' ') ) 
								and count(../ProgrammeAims/ProgrammeAim/LearningAims/LearningAim[translate(LearningActualEndDate, '-', '') &lt;= $StartCurrentTerm ] ) > 0) ">
							<xsl:call-template name="Error">
								<xsl:with-param name="err_num" select="1893"/>
								<xsl:with-param name="data" select="$data"/>
							</xsl:call-template>
						</xsl:if>
					</xsl:if>
					<!-- IW REMOVED PREDICATED 2021-08-20-->
					<!--The next eight validations are all predicated on the following-->
					<!--<xsl:if test="$Phase != 'SP'
							and( 	(../../PupilOnRoll and ../PupilStatus/NCyearActual &gt; 11) 
									or (../../PupilNoLongerOnRoll and ../PupilStatus/NCyearLeaving &gt; 11) 
								)">
					-->
						<!--(AUT) 3000 Maths GCSE attainment grade is missing or invalid-->
						<xsl:if test="count(../ProgrammeAims/ProgrammeAim/LearningAims/LearningAim[translate(LearningStartDate, '-', '') &gt;= $Aug1stAcadYrStart 
										or translate(LearningActualEndDate, '-', '') &gt;= $Aug1stAcadYrStart]) &gt; 0 ">
							<xsl:if test="string-length(MathsGCSEHighestPriorAttainment) = 0 
									or not(contains( ' A* A B C D E F G U 9 8 7 6 5 4 3 2 1 NR ', concat( ' ', MathsGCSEHighestPriorAttainment, ' ' ) ) )">
								<xsl:call-template name="Error">
									<xsl:with-param name="err_num" select="3000"/>
									<xsl:with-param name="data" select="$data"/>
								</xsl:call-template>
							</xsl:if>
							<!--(AUT) 3010 English GCSE attainment grade is missing or invalid-->
							<xsl:if test="string-length(EnglishGCSEHighestPriorAttainment) = 0 
									or not(contains( ' A* A B C D E F G U 9 8 7 6 5 4 3 2 1 NR ', concat( ' ', EnglishGCSEHighestPriorAttainment, ' ' ) ) )">
								<xsl:call-template name="Error">
									<xsl:with-param name="err_num" select="3010"/>
									<xsl:with-param name="data" select="$data"/>
								</xsl:call-template>
							</xsl:if>
						</xsl:if>
						<xsl:if test="count(../ProgrammeAims/ProgrammeAim/LearningAims/LearningAim) &gt; 0 ">
							<!--(AUT) 3005 The stage at which the learner achieved a Maths GCSE at grade A*-C / 9 - 4 or not is missing or invalid-->
							<xsl:if test="string-length(MathsGCSEPriorAttainmentYear11) = 0 
									or not(contains( ' 1 2 3 ', concat( ' ', MathsGCSEPriorAttainmentYear11, ' ') ) )">
								<xsl:call-template name="Error">
									<xsl:with-param name="err_num" select="3005"/>
									<xsl:with-param name="data" select="$data"/>
								</xsl:call-template>
							</xsl:if>
							<!--(AUT) 3015 The stage at which the learner achieved a English GCSE at grade A*-C / 9 - 4 or not is missing or invalid-->
							<xsl:if test="string-length(EnglishGCSEPriorAttainmentYear11) = 0 
									or not(contains( ' 1 2 3 ', concat( ' ', EnglishGCSEPriorAttainmentYear11, ' ' ) ) )">
								<xsl:call-template name="Error">
									<xsl:with-param name="err_num" select="3015"/>
									<xsl:with-param name="data" select="$data"/>
								</xsl:call-template>
							</xsl:if>							
						<!--</xsl:if>-->
						<!--(AUT) 3020 Please check: Maths GCSE grade achieved is D-F / 3-1 or U. Where the pupil is not undertaking the mandatory re-take of this subject, Maths GCSE funding exemption must be present and a valid value or the pupil may lose funding-->
						<xsl:if test="contains( ' D E F G U NR 3 2 1 ', concat( ' ', MathsGCSEHighestPriorAttainment, ' ' ) ) 
								and MathsGCSEFundingExemption = 'N' ">
							<xsl:call-template name="Error">
								<xsl:with-param name="err_num" select="3020"/>
								<xsl:with-param name="data" select="$data"/>
							</xsl:call-template>
						</xsl:if>
						<!--(AUT) 3025 Where maths GCSE achieved is grade A*-C / 9-4, funding exemption should equal ‘N’-->
						<xsl:if test="contains( ' A* A B C 9 8 7 6 5 4 ', concat( ' ', MathsGCSEHighestPriorAttainment, ' ' ) ) 
								 and (contains (' L F ', concat( ' ', MathsGCSEFundingExemption, ' ') ) ) 
								 and string-length(MathsGCSEFundingExemption) != 0">
							<xsl:call-template name="Error">
								<xsl:with-param name="err_num" select="3025"/>
								<xsl:with-param name="data" select="$data"/>
							</xsl:call-template>
						</xsl:if>
						<!--(AUT) RFC 1101 - 3027 Where <MathsGCSEFundingExemption> is equal to 'O' or 'U' <MathsGCSEHighestPriorAttainment> should be NR-->
						<xsl:if test="MathsGCSEHighestPriorAttainment != 'NR'
								 and (contains (' O U ', concat( ' ', MathsGCSEFundingExemption, ' ') ) ) 
								 and string-length(MathsGCSEFundingExemption) != 0">
							<xsl:call-template name="Error">
								<xsl:with-param name="err_num" select="3027"/>
								<xsl:with-param name="data" select="$data"/>
							</xsl:call-template>
						</xsl:if>
						<!--(AUT) 3030 Please check: English GCSE grade achieved is D-F / 3-1 or U. Where the pupil is not undertaking the mandatory re-take of this subject, English GCSE funding exemption must be present and a valid value or the pupil may lose funding-->
						<xsl:if test="contains( ' D E F G U NR 3 2 1 ', concat( ' ', EnglishGCSEHighestPriorAttainment, ' ' ) ) 
								and EnglishGCSEFundingExemption = 'N' ">
							<xsl:call-template name="Error">
								<xsl:with-param name="err_num" select="3030"/>
								<xsl:with-param name="data" select="$data"/>
							</xsl:call-template>
						</xsl:if>
						<!--(AUT) 3035 Where English GCSE achieved is grade A*-C / 9-4, funding exemption should equal ‘N’-->
						<xsl:if test="contains( ' A* A B C 9 8 7 6 5 4 ', concat( ' ', EnglishGCSEHighestPriorAttainment, ' ' ) ) 
								and (contains (' L F ', concat( ' ', EnglishGCSEFundingExemption, ' ') ) ) 
								and string-length(EnglishGCSEFundingExemption) != 0 ">
							<xsl:call-template name="Error">
								<xsl:with-param name="err_num" select="3035"/>
								<xsl:with-param name="data" select="$data"/>
							</xsl:call-template>
						</xsl:if>
						<!--(AUT) RFC 1101 - 3037 Where <MathsGCSEFundingExemption> is equal to 'O' or 'U' <MathsGCSEHighestPriorAttainment> should be NR-->
						<xsl:if test="EnglishGCSEHighestPriorAttainment != 'NR'
								 and contains (' O U ', concat( ' ', EnglishGCSEFundingExemption, ' ') )  
								 and string-length(EnglishGCSEFundingExemption) != 0">
							<xsl:call-template name="Error">
								<xsl:with-param name="err_num" select="3037"/>
								<xsl:with-param name="data" select="$data"/>
							</xsl:call-template>
						</xsl:if>
						<!--(AUT) 3046 new for 19-20-->
						<xsl:if test="count(../ProgrammeAims/ProgrammeAim/LearningAims/LearningAim
									[  translate(LearningStartDate, '-', '') &lt;= $StartCurrentTerm ] ) &gt; 0">
							<xsl:if test=" not(contains( ' A* A B C D E F G U 9 8 7 6 5 4 3 2 1 NR ', concat( ' ', MathsGCSEHighestPriorAttainmentPreviousYear, ' ' ) ) )
												   or (string-length(MathsGCSEHighestPriorAttainmentPreviousYear) = 0 )">
								<xsl:call-template name="Error">
									<xsl:with-param name="err_num" select="3046"/>
									<xsl:with-param name="data" select="$data"/>
								</xsl:call-template>
							</xsl:if>
						</xsl:if>
						<!--(AUT) 3047 new for 19-20 -->
						<xsl:if test="count(../ProgrammeAims/ProgrammeAim/LearningAims/LearningAim
									[  translate(LearningStartDate, '-', '') &lt;= $StartCurrentTerm ] ) &gt; 0">
							<xsl:if test=" not(contains( ' A* A B C D E F G U 9 8 7 6 5 4 3 2 1 NR ', concat( ' ', EnglishGCSEHighestPriorAttainmentPreviousYear, ' ' ) ) )
												   or (string-length(EnglishGCSEHighestPriorAttainmentPreviousYear) = 0 )">
								<xsl:call-template name="Error">
									<xsl:with-param name="err_num" select="3047"/>
									<xsl:with-param name="data" select="$data"/>
								</xsl:call-template>
							</xsl:if>
						</xsl:if>
					</xsl:if>
					<!--End of custom Autumn validation-->
				</xsl:for-each>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>
	<!--Pupil Status %-->
	<xsl:template name="PupilStatusValidation">
		<xsl:variable name="ErrSex">
			<xsl:if test="PupilIdentifiers/Sex = 'M' ">Male</xsl:if>
			<xsl:if test="PupilIdentifiers/Sex = 'F' ">Female</xsl:if>
		</xsl:variable>
		<xsl:variable name="data" select="concat('UPN: ', PupilIdentifiers/UPN, 
						'. Name: ', PupilIdentifiers/Surname, ', ' , PupilIdentifiers/Forename, '.' , 
						' Date of Birth: ', PupilIdentifiers/DOB, ', ',
						 $ErrSex ) "/>
		<xsl:choose>
			<!--PupilStatus module is mandatory so structural error message displayed-->
			<xsl:when test="string-length(PupilStatus) = 0">
				<xsl:call-template name="Error">
					<xsl:with-param name="err_num" select="9999"/>
					<xsl:with-param name="data" select="concat($data , '. PupilStatus') "/>
				</xsl:call-template>
			</xsl:when>
			<xsl:otherwise>
				<xsl:for-each select="PupilStatus">
					<xsl:variable name="ReferenceDateNum" select="translate( ../../../ReferenceDate, '-', '') "/>
					<xsl:variable name="EntryDateNum" select="translate( EntryDate, '-', '') "/>
					<xsl:variable name="LeavingDateNum" select="translate( LeavingDate, '-', '') "/>
					<xsl:variable name="age" select="floor(($AgeCalcDate - translate(../PupilIdentifiers/DOB, '-','')) div 10000)"/>
					<!--Variable used in 2070 changed as it now also need to treat E1 and E2 as type = 'N' IK 2016-05-25-->
					<xsl:variable name="ncyear1st">
						<xsl:choose>
							<xsl:when test="contains(' E1 E2 N1 N2 ', concat(' ', NCyearActual, ' ' ) )">
								<xsl:value-of select="'N' "/>
							</xsl:when>
							<xsl:otherwise>
								<xsl:value-of select="'O' "/>
							</xsl:otherwise>
						</xsl:choose>
					</xsl:variable>
					<!--2112 The school has indicated that it does not follow the national curriculum (year ‘X’) but the pupil has a national curriculum year group other than ‘X’-->
					<xsl:if test="NCyearActual != 'X'
						and /Message/School/SchoolCharacteristics/HighestNCyear = 'X'
						and /Message/School/SchoolCharacteristics/LowestNCyear = 'X' ">
						<xsl:call-template name="Error">
							<xsl:with-param name="err_num" select="2112"/>
							<xsl:with-param name="data" select="$data"/>
						</xsl:call-template>
					</xsl:if>
					<!--RFC1041 Rule added July 2018-->
					<!--2002 Pupil's NC year is not within the range of the school’s lowest and highest NC year-->
					<xsl:if test="../../PupilOnRoll
						and NCyearActual != 'X'
						and (contains(concat(' ', substring-before($ncyears, concat(' ', /Message/School/SchoolCharacteristics/LowestNCyear, ' ')),' '), concat(' ',NCyearActual,' '))
								or contains(concat(' ', substring-after($ncyears, concat(' ', /Message/School/SchoolCharacteristics/HighestNCyear, ' ')),' '), concat(' ',NCyearActual,' ')))">
						<xsl:call-template name="Error">
							<xsl:with-param name="err_num" select="2002"/>
							<xsl:with-param name="data" select="$data"/>
						</xsl:call-template>
					</xsl:if>
					<!--1880, 1930 and 1950 exclude pupils not on roll for nursery schools-->
					<xsl:if test="not(../../PupilNoLongerOnRoll and $Phase='NS')">
						<!--1880: Pupil's Entry Date after Census Date or missing-->
						<xsl:if test="string-length(EntryDate) = 0 or $EntryDateNum &gt; $RefDate ">
							<xsl:call-template name="Error">
								<xsl:with-param name="err_num" select="1880"/>
								<xsl:with-param name="data" select="$data"/>
							</xsl:call-template>
						</xsl:if>
						<!--1930: <PartTime> (100065) must be present and equal to true, false, 1 or 0-->
						<xsl:if test="string-length(PartTime) = 0 
							or not(contains($boolean, concat(' ', PartTime,' ') ) )">
							<xsl:call-template name="Error">
								<xsl:with-param name="err_num" select="1930"/>
								<xsl:with-param name="data" select="$data"/>
							</xsl:call-template>
						</xsl:if>
						<!--1950 if Part Time is true boarder must be N or missing-->
						<xsl:if test="contains( $true, concat(' ', PartTime, ' ') ) 
							and string-length(Boarder) != 0 
							and Boarder != 'N' ">
							<xsl:call-template name="Error">
								<xsl:with-param name="err_num" select="1950"/>
								<xsl:with-param name="data" select="$data"/>
							</xsl:call-template>
						</xsl:if>
					</xsl:if>
					<!--1970: Boarder not present or invalid-->
					<xsl:choose>
						<!--Pt.1 Test applies to on-roll pupils only for nursery schools-->
						<xsl:when test="../../PupilNoLongerOnRoll and $Phase = 'NS' "/>
						<!--Pt.2 <Boarder> equals 'B' or 'N' for nursery, primary, middle deemed primary, middle deemed secondary, secondary and all-through schools and PRUs;-->
						<xsl:when test="contains(' PS MP MS SS AT PR NS ', $_Phase_ )
							and contains(' B N ', concat(' ', Boarder, ' ') ) "/>
						<!--Pt.3 Special Schools type 49 / 52 - exclude valid boarder codes-->
						<xsl:when test="$Phase = 'SP' 
							and $Intake = 'SPEC'
							and contains(' 6 7 N ', concat(' ', Boarder, ' ') ) "/>
						<!--Pt.4 <Boarder> must not be present for special schools with intake of 'HOSP'-->
						<xsl:when test="$Phase = 'SP' 
							and $Intake = 'HOSP'
							and string-length(Boarder) = 0"/>
						<xsl:otherwise>
							<xsl:call-template name="Error">
								<xsl:with-param name="err_num" select="1970"/>
								<xsl:with-param name="data" select="$data"/>
							</xsl:call-template>
						</xsl:otherwise>
					</xsl:choose>
					<!--2020Q Please check: pupil year group and age inconsistent-->
					<!--Amendment 2012-08-06: Formerly this error triggered where age less yeargroup was not exactly 4. Now it's a bit fuzzier - range of age-yeargroup can be 3-5 without raising errors.-->
					<!--If age is 2 or 3 then <NCyearActual> (100583) should be E1, E2, N1, N2-->
					<!--Added from Spr 23 onwards - If age = 4 then <NCyearActual> (100583) should be E1, E2, N1, N2 or R--> 
					<xsl:if test="$age &gt;= 2 
						and $age &lt;= 3">
						<xsl:if test="NCyearActual 
							and not( contains(' E1 E2 N1 N2 ', concat(' ', NCyearActual, ' ') ) ) ">
							<xsl:call-template name="Error">
								<xsl:with-param name="err_num" select="2020"/>
								<xsl:with-param name="data" select="$data"/>
								<xsl:with-param name="err_param1" select="NCyearActual "/>
								<xsl:with-param name="err_param2" select="$age "/>
								<xsl:with-param name="err_param3" select="../PupilIdentifiers/DOB"/>
							</xsl:call-template>
						</xsl:if>
					</xsl:if>
					<xsl:if test="$age = 4">
						<xsl:if test="NCyearActual 
							and not( contains(' E1 E2 N1 N2 R ', concat(' ', NCyearActual, ' ') ) ) ">
							<xsl:call-template name="Error">
								<xsl:with-param name="err_num" select="2020"/>
								<xsl:with-param name="data" select="$data"/>
								<xsl:with-param name="err_param1" select="NCyearActual "/>
								<xsl:with-param name="err_param2" select="$age "/>
								<xsl:with-param name="err_param3" select="../PupilIdentifiers/DOB"/>
							</xsl:call-template>
						</xsl:if>
					</xsl:if>					
					<!--If 5, then NCyearActual must be 1 or R - SO 2008-05-27-->
					<xsl:if test="$age = 5">
						<xsl:if test="NCyearActual 
							and not( NCyearActual = '1' 
								or NCyearActual = 'R' )">
							<xsl:call-template name="Error">
								<xsl:with-param name="err_num" select="2020"/>
								<xsl:with-param name="data" select="$data"/>
								<xsl:with-param name="err_param1" select="NCyearActual "/>
								<xsl:with-param name="err_param2" select="$age "/>
								<xsl:with-param name="err_param3" select="../PupilIdentifiers/DOB"/>
							</xsl:call-template>
						</xsl:if>
					</xsl:if>
					<xsl:if test="$age &gt; 5 and $age &lt; 16">
						<!--Added check for NCyearActual can't be E1 to R - IK 2016-05-25-->
						<xsl:if test="NCyearActual 
							and ( ($age - NCyearActual &lt; 3 ) 
								or ($age - NCyearActual &gt; 5 ) 
								or contains(' E1 E2 N1 N2 R ', concat(' ', NCyearActual, ' ') ) )">
							<xsl:call-template name="Error">
								<xsl:with-param name="err_num" select="2020"/>
								<xsl:with-param name="data" select="$data"/>
								<xsl:with-param name="err_param1" select="NCyearActual "/>
								<xsl:with-param name="err_param2" select="$age "/>
								<xsl:with-param name="err_param3" select="../PupilIdentifiers/DOB"/>
							</xsl:call-template>
						</xsl:if>
					</xsl:if>
					<!--0: Unexpected year groups for school types-->
					<xsl:choose>
						<!--exists and not null-->
						<xsl:when test="string-length(NCyearActual) = 0"/>
						<!--Blanket exception for NS SP AT PR-->
						<!--Error shouldn't trigger for AT schools, so put this trap in as well as excluding AT in the ErrorList.xsl file IK 2016-05-25-->
						<xsl:when test="contains(' NS SP AT PR ', concat(' ',$Phase,' ') ) "/>
						<!--Primary Schools-->
						<xsl:when test="$Phase = 'PS' and $SchoolType = '01' and contains(' E1 E2 N1 N2 R 1 2 3 ', concat(' ', NCyearActual, ' ') ) "/>
						<xsl:when test="$Phase = 'PS' and $SchoolType = '02' and contains(' E1 E2 N1 N2 R 1 2 3 4 ', concat(' ', NCyearActual, ' ') ) "/>
						<xsl:when test="$Phase = 'PS' and $SchoolType = '03' and contains(' E1 E2 N1 N2 R 1 2 3 4 5 ', concat(' ', NCyearActual, ' ') ) "/>
						<xsl:when test="$Phase = 'PS' and $SchoolType = '04' and contains(' E1 E2 N1 N2 R 1 2 3 4 5 6 7 ', concat(' ', NCyearActual, ' ') ) "/>
						<xsl:when test="$Phase = 'PS' and $SchoolType = '16' and contains(' E1 E2 N1 N2 R 1 2 3 ', concat(' ', NCyearActual, ' ') ) "/>
						<xsl:when test="$Phase = 'PS' and $SchoolType = '17' and contains(' 3 4 5 6 ', concat(' ', NCyearActual, ' ') ) "/>
						<xsl:when test="$Phase = 'PS' and $SchoolType = '18' and contains(' E1 E2 N1 N2 R 1 2 3 4 5 6 ', concat(' ', NCyearActual, ' ') ) "/>
						<xsl:when test="$Phase = 'PS' and $SchoolType = '42' and contains(' E1 E2 N1 N2 R 1 2 ', concat(' ', NCyearActual, ' ') ) "/>
						<xsl:when test="$Phase = 'PS' and $SchoolType = '43' and contains(' 3 4 5 ', concat(' ', NCyearActual, ' ') ) "/>
						<xsl:when test="$Phase = 'PS' and $SchoolType = '49' and contains(' E1 E2 N1 N2 R 1 2 3 4 5 6 7 ', concat(' ', NCyearActual, ' ') ) "/>
						<!--Middle Deemed Primary schools-->
						<xsl:when test="$Phase = 'MP' and $SchoolType = '05' and contains(' 4 5 6 7 ', concat(' ', NCyearActual, ' ') ) "/>
						<xsl:when test="$Phase = 'MP' and $SchoolType = '06' and contains(' 5 6 7 8 ', concat(' ', NCyearActual, ' ') ) "/>
						<xsl:when test="$Phase = 'MP' and $SchoolType = '45' and contains(' 5 6 7 ', concat(' ', NCyearActual, ' ') ) "/>
						<xsl:when test="$Phase = 'MP' and $SchoolType = '49' and contains(' 4 5 6 7 8 ', concat(' ', NCyearActual, ' ') ) "/>
						<!--secondary schools-->
						<xsl:when test="($Phase = 'MS' or $Phase = 'SS') and $SchoolType = '07' and contains(' 5 6 7 8 ', concat(' ', NCyearActual, ' ') ) "/>
						<xsl:when test="($Phase = 'MS' or $Phase = 'SS') and $SchoolType = '08' and contains(' 6 7 8 ', concat(' ', NCyearActual, ' ') ) "/>
						<xsl:when test="($Phase = 'MS' or $Phase = 'SS') and $SchoolType = '41' and contains(' 6 7 8 9 ', concat(' ', NCyearActual, ' ') ) "/>
						<xsl:when test="($Phase = 'MS' or $Phase = 'SS') and $SchoolType = '09' and contains(' 8 9 10 11 ', concat(' ', NCyearActual, ' ') ) "/>
						<xsl:when test="($Phase = 'MS' or $Phase = 'SS') and $SchoolType = '10' and contains(' 8 9 10 11 12 13 14 ', concat(' ', NCyearActual, ' ') ) "/>
						<xsl:when test="($Phase = 'MS' or $Phase = 'SS') and contains(' 11 29 ', $_SchoolType_ ) and contains(' 9 10 11 ', concat(' ', NCyearActual, ' ') ) "/>
						<xsl:when test="($Phase = 'MS' or $Phase = 'SS') and contains(' 12 30 31 ', $_SchoolType_ ) and contains(' 9 10 11 12 13 14 ', concat(' ', NCyearActual, ' ') ) "/>
						<xsl:when test="($Phase = 'MS' or $Phase = 'SS') and contains(' 21 27 28 48 ', $_SchoolType_ ) and contains(' 7 8 9 10 11 ', concat(' ', NCyearActual, ' ') ) "/>
						<xsl:when test="($Phase = 'MS' or $Phase = 'SS') and contains(' 22 36 37 38 39 47 ', $_SchoolType_ ) and contains(' 7 8 9 10 11 12 13 14 ', concat(' ', NCyearActual, ' ') ) "/>
						<xsl:when test="($Phase = 'MS' or $Phase = 'SS') and $SchoolType = '25' and contains(' 7 8 ', concat(' ', NCyearActual, ' ') ) "/>
						<xsl:when test="($Phase = 'MS' or $Phase = 'SS') and $SchoolType = '26' and contains(' 7 8 9 ', concat(' ', NCyearActual, ' ') ) "/>
						<xsl:when test="($Phase = 'MS' or $Phase = 'SS') and contains(' 32 33 44 ', $_SchoolType_ ) and contains(' 10 11 12 13 14 ', concat(' ', NCyearActual, ' ') ) "/>
						<xsl:when test="($Phase = 'MS' or $Phase = 'SS') and $SchoolType = '46' and contains(' 6 7 8 9 10 11 ', concat(' ', NCyearActual, ' ') ) "/>
						<xsl:when test="($Phase = 'MS' or $Phase = 'SS') and $SchoolType = '49' and contains(' 5 6 7 8 9 10 11 12 13 14 ', concat(' ', NCyearActual, ' ') ) "/>
						<xsl:otherwise>
							<xsl:call-template name="Error">
								<xsl:with-param name="err_num" select="2030"/>
								<xsl:with-param name="data" select="$data"/>
							</xsl:call-template>
						</xsl:otherwise>
					</xsl:choose>
					<!--Pupil on roll validation-->
					<xsl:if test="../../PupilOnRoll">
						<!--1860: Enrol Status not present or invalid-->
						<xsl:choose>
							<!--PR-->
							<xsl:when test="$Phase='PR' ">
								<xsl:if test="string-length(EnrolStatus) = 0 or not(contains(' C M S F O ', concat(' ', EnrolStatus, ' ' ) ) )">
									<xsl:call-template name="Error">
										<xsl:with-param name="err_num" select="1860"/>
										<xsl:with-param name="data" select="$data"/>
									</xsl:call-template>
								</xsl:if>
							</xsl:when>
							<!--NS, PS, MP, MS, SS, AT, SP-->
							<xsl:when test="contains(' NS PS MP MS SS AT SP ', $_Phase_ )">
								<xsl:if test="string-length(EnrolStatus) = 0 or not(contains(' C M S ', concat(' ', EnrolStatus, ' ' ) ) )">
									<xsl:call-template name="Error">
										<xsl:with-param name="err_num" select="1860"/>
										<xsl:with-param name="data" select="$data"/>
									</xsl:call-template>
								</xsl:if>
							</xsl:when>
						</xsl:choose>
						<!--1940 Part Time must be false if pupil older than 5-->
						<xsl:if test="$age &gt;= 5 
							and $age &lt;= 15 
							and not(contains($false, concat(' ', PartTime,' ') ) )
							and string-length(PartTime) != 0">
							<xsl:call-template name="Error">
								<xsl:with-param name="err_num" select="1940"/>
								<xsl:with-param name="data" select="$data"/>
							</xsl:call-template>
						</xsl:if>
						<!--2000 National Curriculum Actual Year not present or invalid-->
						<xsl:if test="string-length(NCyearActual) = 0 
							or not(contains($ncyears , concat(' ', NCyearActual , ' ') ) ) 
							or NCyearActual = 'M' ">
							<xsl:call-template name="Error">
								<xsl:with-param name="err_num" select="2000"/>
								<xsl:with-param name="data" select="$data"/>
							</xsl:call-template>
						</xsl:if>
						<!--2060: ClassType present and valid-->
						<xsl:if test="contains(' E1 E2 N1 N2 R 1 2 3 4 5 6 ', concat(' ', NCyearActual, ' ') )
							and contains(' PS AT ', $_Phase_ )
							and (string-length(TypeOfClass) = 0 
								or not(contains(' N O ', concat(' ', TypeOfClass, ' ') ) ) )">
							<xsl:call-template name="Error">
								<xsl:with-param name="err_num" select="2060"/>
								<xsl:with-param name="data" select="$data"/>
							</xsl:call-template>
						</xsl:if>
						<!--2070: Class Type and NCyearActual should both start with N ( for nursery)-->
						<xsl:if test="($ncyear1st = 'N' 
							and TypeOfClass != 'N' 
							and string-length(TypeOfClass) != 0 ) 
						or ($ncyear1st != 'N' 
							and TypeOfClass = 'N' 
							and string-length(TypeOfClass) != 0 ) ">
							<xsl:call-template name="Error">
								<xsl:with-param name="err_num" select="2070"/>
								<xsl:with-param name="data" select="$data"/>
							</xsl:call-template>
						</xsl:if>
						<!--2080: If Pupil aged 6 or more Class Type = O(other), not nursery-->
						<xsl:if test="string-length(TypeOfClass) != 0 
							and $age &gt;= 6 
							and TypeOfClass != 'O' ">
							<xsl:call-template name="Error">
								<xsl:with-param name="err_num" select="2080"/>
								<xsl:with-param name="data" select="$data"/>
							</xsl:call-template>
						</xsl:if>
						<!--5048: ClassType only needed when phase = PS or AT. Added 2014-04-11 ACN-->
						<xsl:if test="string-length(TypeOfClass) != 0 
							and (not($Phase = 'PS' or $Phase = 'AT') 
								or not(contains(' E1 E2 N1 N2 R 1 2 3 4 5 6 7 ', concat(' ', NCyearActual, ' ') ) ) )">
							<xsl:call-template name="Error">
								<xsl:with-param name="err_num" select="5048"/>
								<xsl:with-param name="data" select="$data"/>
							</xsl:call-template>
						</xsl:if>
						<!--1881 (SPR/SUM): After key entry dates sessions possible should be 0-->
						<!--Note there's an autumn-specific variant below-->
						<xsl:if test="($term = 'SPR' or $term = 'SUM')
							and translate(EntryDate, '-', '') &gt; $EntryDateRef 
							and ../Attendance/TermlyAttendance/SessionsPossible &gt; 0 ">
							<xsl:call-template name="Error">
								<xsl:with-param name="err_num" select="18815"/>
								<xsl:with-param name="data" select="$data"/>
							</xsl:call-template>
						</xsl:if>
						<!--Autumn constraint applies to 1881(Autumn variant), 1882, 1883, 2870-->
						<xsl:if test="$term = 'AUT' ">
							<!--1881: After key entry dates sessions possible should be 0-->							
							<xsl:if test="translate(EntryDate, '-', '') &gt; $EntryDateRef
								and ../Attendance/TermlyAttendance/SessionsPossible &gt; 0 ">
								<xsl:call-template name="Error">
									<xsl:with-param name="err_num" select="18814"/>
									<xsl:with-param name="data" select="$data"/>
								</xsl:call-template>
							</xsl:if>
							<!--1882 if entry date after previous year and year is R / 12 sessions possible should be 0-->
							<!--$StartCurrentTerm takes different values per term, but this is fine as this validation is autumn-only-->
							<xsl:if test="translate(EntryDate, '-', '') &gt; $StartCurrentTerm 
								and (NCyearActual = '12' or NCyearActual = 'R')
								and (../Attendance/TermlyAttendance/SessionsPossible &gt;= 0 
									or ../Attendance/SummerHalfTerm2Attendance/SessionsPossible &gt;= 0) ">
								<xsl:call-template name="Error">
									<xsl:with-param name="err_num" select="1882"/>
									<xsl:with-param name="data" select="$data"/>
								</xsl:call-template>
							</xsl:if>
							<!--1883 Please check entry date as the sessions possible indicate that the pupil attended the school during the summer term.-->
							<xsl:if test="translate(EntryDate, '-', '') &gt; $StartCurrentTerm
								and NCyearActual != '12' 
								and NCyearActual != 'R'
								and string-length(../Attendance/TermlyAttendance/SessionsPossible) &gt; 0 ">
								<xsl:call-template name="Error">
									<xsl:with-param name="err_num" select="1883"/>
									<xsl:with-param name="data" select="$data"/>
								</xsl:call-template>
							</xsl:if>
							<!--2870: Programme aims for the current academic year should be submitted for a pupil in year 12 or above with single or main registration at the school-->
							<!--criteria updated for Autumn 2016 to include enrolment status F and O IK 2016-06-09-->
							<xsl:if test="NCyearActual &gt; 11 
								and contains( ' C M F O ', concat(' ', EnrolStatus, ' ') ) 
								and $SixthForm = 'Y'
								and count(../ProgrammeAims/ProgrammeAim
									[ (string-length(ProgrammeActualEndDate) = 0 
										or translate(ProgrammeActualEndDate, '-', '') &gt; $StartCurrentTerm ) ] ) &lt; 1 ">
								<xsl:call-template name="Error">
									<xsl:with-param name="err_num" select="2870"/>
									<xsl:with-param name="data" select="$data"/>
								</xsl:call-template>
							</xsl:if>
							<!--2708 Please check: Learning aims for the previous academic year would normally be expected for a pupil in year 13 or above who was also on roll last year (unless they had subsidiary registration at the time of the learning aims)-->
							<!--$StartCurrentTerm takes a different value per-term, this doesn't matter as the validation is autumn-only--> <!-- IW AMENDED TO INCLUDE ProgrammeAims/ProgrammeAim/ - 2021-08-20 -->
							<xsl:if test="NCyearActual &gt; 12 
								and contains( ' C M F O ', concat(' ', EnrolStatus, ' ') ) 
								and translate(EntryDate , '-', '') &lt;= $StartCurrentTerm
								and count(../ProgrammeAims/ProgrammeAim/LearningAims/LearningAim[translate(LearningStartDate, '-', '') &lt;= $StartCurrentTerm ] ) = 0">
								<xsl:call-template name="Error">
									<xsl:with-param name="err_num" select="2708"/>
									<xsl:with-param name="data" select="$data"/>
								</xsl:call-template>
							</xsl:if>
						</xsl:if>
						<!--2712 Where pupils have at least one <LearningAim> node, <FTEmp> must be present and a valid value-->
						<!--New for 2018, but added late - therefore won't take effect until autumn 2019 - SS-->
						<xsl:if test="NCyearActual &gt;= 12 
							and not(contains($boolean, concat(' ', ../PupilCharacteristics/FTEmp, ' ') ) )
							and count(../ProgrammeAims/ProgrammeAim) != 0">
							<xsl:call-template name="Error">
								<xsl:with-param name="err_num" select="2712"/>
								<xsl:with-param name="data" select="$data"/>
							</xsl:call-template>
						</xsl:if>
					</xsl:if>
					<!-- END OF PUPIL ON ROLL CONSTRAINT-->
					<!--Pupil no longer on roll validation-->
					<xsl:if test="../../PupilNoLongerOnRoll">
						<!--1920: Leaving Date must be present and must before Census Date and after or = EntryDate-->
						<xsl:if test="string-length(LeavingDate) = 0
							or $LeavingDateNum &gt;= $RefDate 
							or $LeavingDateNum &lt; $EntryDateNum">
							<xsl:call-template name="Error">
								<xsl:with-param name="err_num" select="1920"/>
								<xsl:with-param name="data" select="$data"/>
							</xsl:call-template>
						</xsl:if>
						<!--1925Q: PupilNoLongerOnRoll only present for specific conditions-->
						<!--SS: Note the modifier to the age - because $age is calculated as at the current year for the rest of the module; but here we're after the attendance age UPDATE - this no longer applies to spring/summer due to the agecalcdate but might still need to be present for autumn.-->
						<!-- RFC1183 UPDATED - IW 2021-08-20-->	
						<xsl:if test="$Phase != 'NS' ">
							<xsl:if test="$term = 'AUT' 
											and not( ($LeavingDateNum &lt;= $RefDate
													and count(../Exclusions/TermlyExclusion) &gt;0 )
												or ( $EntryDateNum &lt; $StartCurrentTerm
														and $LeavingDateNum &gt; $StartPreviousTerm
														and $LeavingDateNum &lt;= $RefDate 
														and ($age - 1) &gt;= 4 
														and ($age - 1) &lt;= 15 
														and Boarder = 'N' )
												or count(../ProgrammeAims/ProgrammeAim) &gt;0 
												or count(../PupilCharacteristics/LearnerFAMModule/LearnerFAM) &gt;0 
												or count(../APPlacementDetails) &gt;0 
												) ">
								<xsl:call-template name="Error">
									<xsl:with-param name="err_num" select="19254"/>
									<xsl:with-param name="data" select="$data"/>
								</xsl:call-template>
							</xsl:if>
							<!-- RFC1183 UPDATED - IW 2021-08-20-->	
							<xsl:if test="($term = 'SPR' or $term = 'SUM') 
											and not( ($LeavingDateNum &lt;= $RefDate
													and count(../Exclusions/TermlyExclusion) &gt;0 )
												or ( $EntryDateNum &lt;= $StartCurrentTerm
														and $LeavingDateNum &gt; $StartPreviousTerm
														and $LeavingDateNum &lt;= $RefDate 
														and $age &gt;= 4 
														and $age &lt;= 15 
														and Boarder = 'N' )
												or count(../PupilCharacteristics/LearnerSupport/LearnerSupportItem) &gt; 0
												or count(../PupilCharacteristics/LearnerFAMModule/LearnerFAM) &gt;0 
												or count(../APPlacementDetails) &gt;0 
												) ">
								<xsl:call-template name="Error">
									<xsl:with-param name="err_num" select="19255"/>
									<xsl:with-param name="data" select="$data"/>
								</xsl:call-template>
							</xsl:if>
						</xsl:if>
						<!--RFC1041 now only permits NCyearLeaving 12, 13, 14.-->
						<!--2005 Pupil’s NC Year on Leaving should be present for pupils who have Learning Aims-->
						<!--<xsl:if test="count(../LearningAims/LearningAim) &gt; 0--><!-- IW AMENDED TO INCLUDE ProgrammeAims/ProgrammeAim/ - 2021-08-20 -->
						<xsl:if test="count(../ProgrammeAims/ProgrammeAim/LearningAims[LearningAim]) &gt; 0
										and $SixthForm = 'Y'
										and not(contains( ' 12 13 14 ', concat(' ', NCyearLeaving , ' ') ) ) ">
							<xsl:call-template name="Error">
								<xsl:with-param name="err_num" select="2005"/>
								<xsl:with-param name="data" select="$data"/>
							</xsl:call-template>
						</xsl:if>
						<!-- RFC1183 NEW RULE ADDED - IW 2021-08-20-->	
						<!--1897 Only previous year’s planned hours and attainment data is required for a pupil who left during the previous term-->
						<xsl:if test="(contains( ' SS AT PR ', $_Phase_))
									and $LeavingDateNum &lt;= $StartCurrentTerm									
									and	(string-length(../PupilCharacteristics/QualHrs) != 0
										 or string-length(../PupilCharacteristics/Non_qualHrs) != 0		
										 or string-length(../PupilCharacteristics/MathsGCSEHighestPriorAttainment) != 0
										 or string-length(../PupilCharacteristics/EnglishGCSEHighestPriorAttainment) != 0 
										 or string-length(../PupilCharacteristics/MathsGCSEFundingExemption) !=  0 
										 or string-length(../PupilCharacteristics/EnglishGCSEFundingExemption) != 0 
										)">
								<xsl:call-template name="Error">
									<xsl:with-param name="err_num" select="1897"/>
									<xsl:with-param name="data" select="$data"/>
								</xsl:call-template>
							</xsl:if>
						<!-- RFC1183 NEW RULE ADDED - IW 2021-08-20-->	
						<!--4009 Learner Funding and Monitoring must not be returned for pupils who left in the previous academic year-->
						<xsl:if test="$LeavingDateNum &lt; $Aug1stAcadYrStart
										and (string-length(../PupilCharacteristics/LearnerFAMModule) != 0
										)">
							<xsl:call-template name="Error">
								<xsl:with-param name="err_num" select="4009"/>
								<xsl:with-param name="data" select="$data"/>
							</xsl:call-template>
						</xsl:if>
					</xsl:if>
					<!-- END OF PUPIL NO LONGER ON ROLL CONSTRAINT-->
				</xsl:for-each>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>
	<!--Special Educational Needs%-->
	<xsl:template name="SpecialEducationalNeedsValidation">
		<xsl:variable name="ErrSex">
			<xsl:if test="PupilIdentifiers/Sex = 'M' ">Male</xsl:if>
			<xsl:if test="PupilIdentifiers/Sex = 'F' ">Female</xsl:if>
		</xsl:variable>
		<xsl:variable name="data" select="concat('UPN: ', PupilIdentifiers/UPN, 
										'. Name: ', PupilIdentifiers/Surname, ', ' , PupilIdentifiers/Forename, '.' , 
										' Date of Birth: ', PupilIdentifiers/DOB, ', ',
										$ErrSex ) "/>
		<!--Structural Test to cater for empty SEN module-->
		<xsl:choose>
			<xsl:when test="../PupilOnRoll and (not(SpecialEducationalNeeds) or SpecialEducationalNeeds ='') ">
				<xsl:call-template name="Error">
					<xsl:with-param name="err_num" select="9999"/>
					<xsl:with-param name="data" select="concat($data, '. SpecialEducationalNeeds') "/>
				</xsl:call-template>
			</xsl:when>
			<xsl:otherwise>
				<xsl:variable name="AllSENneeds">
					 <xsl:for-each select=".">
						  <xsl:sort select="."/>
						  <xsl:copy-of select="SENneeds/SENneed/SENtype"/>
					 </xsl:for-each>
				</xsl:variable>
				<xsl:for-each select="SpecialEducationalNeeds">
					<!--2120: Pupil with missing SEN provision or invalid value -->
					<xsl:if test="string-length(SENprovision) = 0 
						or not(contains($SENProvisioncodes, concat(' ', SENprovision, ' ') ) ) ">
						<xsl:call-template name="Error">
							<xsl:with-param name="err_num" select="2120"/>
							<xsl:with-param name="data" select="$data"/>
						</xsl:call-template>
					</xsl:if>
					<!--2180: Pupil with no SEN in special school -->
					<xsl:if test="$Phase = 'SP' and not(contains(' K E ', concat(' ', SENprovision, ' ') ) ) ">
						<xsl:call-template name="Error">
							<xsl:with-param name="err_num" select="2180"/>
							<xsl:with-param name="data" select="$data"/>
						</xsl:call-template>
					</xsl:if>
					<!--2230: Special provision (SEN Unit) indicator must be provided if SEN provision is equal to K or E-->
					<xsl:if test="contains(' E K ', concat(' ', SENprovision, ' ') ) and not (contains($boolean, concat(' ', SENunitIndicator, ' ' ) ) )">
						<xsl:call-template name="Error">
							<xsl:with-param name="err_num" select="2230"/>
							<xsl:with-param name="data" select="$data"/>
						</xsl:call-template>
					</xsl:if>
					<!--2250: Special provision (resourced provision) indicator must be provided if SEN Provision is equal to K or E-->
					<xsl:if test="contains( ' E K ', concat( ' ', SENprovision, ' ') ) and not (contains($boolean, concat(' ', ResourcedProvisionIndicator, ' ' ) ) )">
						<xsl:call-template name="Error">
							<xsl:with-param name="err_num" select="2250"/>
							<xsl:with-param name="data" select="$data"/>
						</xsl:call-template>
					</xsl:if>
					<!--5049: SEN Unit Indicator is not required from schools with a phase of SP or PR-->
					<xsl:if test="string-length(SENunitIndicator) != 0 and ($Phase = 'PR' or $Phase = 'SP')">
						<xsl:call-template name="Error">
							<xsl:with-param name="err_num" select="5049"/>
							<xsl:with-param name="data" select="$data"/>
						</xsl:call-template>
					</xsl:if>
					<!--5050: Resourced provision indicator is not required from schools with a phase of SP or PR-->
					<xsl:if test="string-length(ResourcedProvisionIndicator) != 0 and ($Phase = 'PR' or $Phase = 'SP')">
						<xsl:call-template name="Error">
							<xsl:with-param name="err_num" select="5050"/>
							<xsl:with-param name="data" select="$data"/>
						</xsl:call-template>
					</xsl:if>
					<!--2125 Pupil shows SEN information where provision is school action or none (two-part validation).-->
					<xsl:if test="contains(' PR SP ', $_Phase_ ) 
						and contains(' N ', concat(' ', SENprovision, ' ') )
						and (SENneeds/SENneed[string-length(SENtypeRank) != 0]
								or SENneeds/SENneed[string-length(SENtype) != 0])">
						<xsl:call-template name="Error">
							<xsl:with-param name="err_num" select="2125"/>
							<xsl:with-param name="data" select="$data"/>
						</xsl:call-template>
					</xsl:if>
					<xsl:if test="not(contains(' PR SP ', $_Phase_ ) ) 
						and contains(' N ', concat(' ', SENprovision, ' ') )
						and (SENneeds/SENneed[string-length(SENtypeRank) != 0]
							 or SENneeds/SENneed[string-length(SENtype) != 0]
							 or SENunitIndicator = 'true' 
							 or ResourcedProvisionIndicator = 'true')">
						<xsl:call-template name="Error">
							<xsl:with-param name="err_num" select="2125"/>
							<xsl:with-param name="data" select="$data"/>
						</xsl:call-template>
					</xsl:if>
					<xsl:if test="$term = 'SPR' ">
						<!--The next block of SEN related rules are spring-only-->
						<xsl:for-each select="SENneeds/SENneed">
							<!--2130 Pupil SEN type code required where SEN type ranking provided-->
							<xsl:if test="contains( ' 1 2 ', concat( ' ', SENtypeRank, ' ') ) and (string-length(SENtype) = 0)">
								<xsl:call-template name="Error">
									<xsl:with-param name="err_num" select="2130"/>
									<xsl:with-param name="data" select="$data"/>
								</xsl:call-template>
							</xsl:if>
							<!--2140 Ranking of special educational need is missing or invalid-->
							<xsl:if test="string-length(SENtype) != 0 
								and ( string-length(SENtypeRank) = 0
										or not (contains( ' 1 2 ', concat( ' ', SENtypeRank, ' ') ) ) )">
								<xsl:call-template name="Error">
									<xsl:with-param name="err_num" select="2140"/>
									<xsl:with-param name="data" select="$data"/>
								</xsl:call-template>
							</xsl:if>
							<!--2175 SEN type code ‘NSA’ (SEN support but no specialist assessment of type of need) can only be used where SEN provision is code ‘K’ (SEN support)-->
							<xsl:if test="SENtype = 'NSA'
										and ../../SENprovision != 'K' ">
								<xsl:call-template name="Error">
									<xsl:with-param name="err_num" select="2175"/>
									<xsl:with-param name="data" select="$data"/>
								</xsl:call-template>
							</xsl:if>
						</xsl:for-each>
						<!--2160 If only one SEN Need - Rank must be 1-->
						<xsl:if test="count(SENneeds/SENneed) = 1 
							and SENneeds/SENneed[ SENtypeRank != '1' ] 
							and SENneeds/SENneed[ string-length(SENtypeRank) != 0 ] ">
							<xsl:call-template name="Error">
								<xsl:with-param name="err_num" select="2160"/>
								<xsl:with-param name="data" select="$data"/>
							</xsl:call-template>
						</xsl:if>
						<!--2165 SEN types 1 and 2 needed-->
						<xsl:if test="count(SENneeds/SENneed[SENtypeRank = '1']) &gt; 1 
							or count(SENneeds/SENneed[SENtypeRank = '2']) &gt; 1">
							<xsl:call-template name="Error">
								<xsl:with-param name="err_num" select="2165"/>
								<xsl:with-param name="data" select="$data"/>
							</xsl:call-template>
						</xsl:if>
						<!-- Added rule 2166 2013-06-13 IK -->
						<xsl:if test="count(SENneeds/SENneed/SENtypeRank) &gt; 2">
							<xsl:call-template name="Error">
								<xsl:with-param name="err_num" select="2166"/>
								<xsl:with-param name="data" select="$data"/>
							</xsl:call-template>
						</xsl:if>
						<!--2170 A valid SEN type must be provided for pupils with a SEN provision = K, S or E-->
						<xsl:if test="contains( ' E K ', concat( ' ', SENprovision, ' ') )
								and (not(contains($provisions, concat(' ', SENneeds/SENneed[1]/SENtype, ' ') ) )
										or (count(SENneeds/SENneed) &gt; 1 and not(contains($provisions, concat(' ', SENneeds/SENneed[2]/SENtype, ' ') ) ) )
								)">
							<xsl:call-template name="Error">
								<xsl:with-param name="err_num" select="2170"/>
								<xsl:with-param name="data" select="$data"/>
							</xsl:call-template>
						</xsl:if>
						<!--2167: Each SEN type must be unique.-->
						<xsl:if test="count(SENneeds/SENneed/SENtype[. = 'SPLD'] ) &gt; 1
							or count(SENneeds/SENneed/SENtype[. = 'MLD'] ) &gt; 1
							or count(SENneeds/SENneed/SENtype[. = 'SLD'] ) &gt; 1
							or count(SENneeds/SENneed/SENtype[. = 'PMLD'] ) &gt; 1
							or count(SENneeds/SENneed/SENtype[. = 'SEMH'] ) &gt; 1
							or count(SENneeds/SENneed/SENtype[. = 'SLCN'] ) &gt; 1
							or count(SENneeds/SENneed/SENtype[. = 'HI'] ) &gt; 1
							or count(SENneeds/SENneed/SENtype[. = 'VI'] ) &gt; 1
							or count(SENneeds/SENneed/SENtype[. = 'MSI'] ) &gt; 1
							or count(SENneeds/SENneed/SENtype[. = 'PD'] ) &gt; 1
							or count(SENneeds/SENneed/SENtype[. = 'ASD'] ) &gt; 1
							or count(SENneeds/SENneed/SENtype[. = 'OTH'] ) &gt; 1">
							<xsl:call-template name="Error">
								<xsl:with-param name="err_num" select="2167"/>
								<xsl:with-param name="data" select="$data"/>
							</xsl:call-template>
						</xsl:if>
					</xsl:if>
				</xsl:for-each>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>
	<!--Exclusions %-->
	<xsl:template name="ExclusionsValidation">
		<xsl:variable name="ErrSex">
			<xsl:if test="../../PupilIdentifiers/Sex = 'M' ">Male</xsl:if>
			<xsl:if test="../../PupilIdentifiers/Sex = 'F' ">Female</xsl:if>
		</xsl:variable>
		<xsl:variable name="data" select="concat('UPN: ', ../../PupilIdentifiers/UPN, 
				   	          '. Name: ', ../../PupilIdentifiers/Surname, ', ' , ../../PupilIdentifiers/Forename, '.' ,  
						 ' Date of Birth: ', ../../PupilIdentifiers/DOB, ', ',
						 $ErrSex ) "/>
		<xsl:choose>
			<xsl:when test="$Phase = 'NS' ">
				<!--5051 Exclusions must not be present for Nursery schools-->
				<xsl:call-template name="Error">
					<xsl:with-param name="err_num" select="5051"/>
					<xsl:with-param name="data" select="$data"/>
				</xsl:call-template>
			</xsl:when>
			<xsl:otherwise>
				<!--(!NS) 2260 For each termly exclusion, where more than one of <Reason1>, <Reason2> and <Reason3> exist, they must be unique-->
				<xsl:if test="
					   ( (string-length(Reason1) != 0 
							and Reason1 = Reason2)
						or (string-length(Reason1) != 0 
							and Reason1 = Reason3)
						or (string-length(Reason2) != 0 
							and Reason2 = Reason3) ) ">
					<xsl:call-template name="Error">
						<xsl:with-param name="err_num" select="2260"/>
						<xsl:with-param name="data" select="$data"/>
					</xsl:call-template>
				</xsl:if>
				<!--(!NS) 2270 Start date, SEN provision or category is missing from exclusion record-->
				<xsl:if test="string-length(StartDate) = 0
							 or string-length(SENprovision) = 0
							 or string-length(Category) = 0">
					<xsl:call-template name="Error">
						<xsl:with-param name="err_num" select="2270"/>
						<xsl:with-param name="data" select="$data"/>
					</xsl:call-template>
				</xsl:if>
				<!--Criterion applies to 2275, 2280-->
				<xsl:if test="string-length(Category) != 0 ">
					<!--(!NS) 2275 Exclusion Category is invalid-->
					<!--for SPR there are 2 different checks depending on start date
						for AUT and SUM there is only 1 test but each term is different -->
					<xsl:if test="not(contains(' SUSP PERM ', concat(' ', Category, ' ') ) ) ">
						<xsl:call-template name="Error">
							<xsl:with-param name="err_num" select="2275"/>
							<xsl:with-param name="data" select="$data"/>
						</xsl:call-template>
					</xsl:if>
					<!--(!NS) 2280 Where exclusion category is present a valid exclusion reason must also be provided-->
					<!-- UPDATED RULE LOGIC - IW 2023-08-24 -->
					<!--<xsl:if test="(string-length(Reason1) + string-length(Reason2) + string-length(Reason3) = 0)
								  or (string-length(Reason1) != 0 and not(contains($ExcludeReason2280, concat(' ', Reason1, ' ') ) ) )
								  or (string-length(Reason2) != 0 and not(contains($ExcludeReason2280, concat(' ', Reason2, ' ') ) ) )
								  or (string-length(Reason3) != 0 and not(contains($ExcludeReason2280, concat(' ', Reason3, ' ') ) ) )
							">-->
					<xsl:if test="(string-length(Reason1) = 0)
								  or (string-length(Reason1) != 0 and not(contains($ExcludeReason2280, concat(' ', Reason1, ' ') ) ) )
							">
						<xsl:call-template name="Error">
							<xsl:with-param name="err_num" select="2280"/>
							<xsl:with-param name="data" select="$data"/>
						</xsl:call-template>
					</xsl:if>
				</xsl:if>
				<!-- NEW RULE 2321 - RFC 1251 -->
				<xsl:if test="( (string-length(Reason2) != 0 and not(contains($ExcludeReason2280, concat(' ', Reason2, ' ') ) ) )
								or (string-length(Reason3) != 0 and not(contains($ExcludeReason2280, concat(' ', Reason3, ' ') ) ) )
								)
							">
						<xsl:call-template name="Error">
							<xsl:with-param name="err_num" select="2321"/>
							<xsl:with-param name="data" select="$data"/>
						</xsl:call-template>
					</xsl:if>
				<!-- NEW RULE 2322 - RFC 1252 -->
				<xsl:if test="( string-length(Reason3) != 0 and (string-length(Reason2) = 0 or not(Reason2) ) )
							">
						<xsl:call-template name="Error">
							<xsl:with-param name="err_num" select="2322"/>
							<xsl:with-param name="data" select="$data"/>
						</xsl:call-template>
					</xsl:if>
				<!--(!NS) 2285 Pupil has more than one permanent exclusion record-->
				<xsl:if test="../../../PupilNoLongerOnRoll
					and count(../TermlyExclusion[Category = 'PERM']) &gt; 1">
					<xsl:call-template name="Error">
						<xsl:with-param name="err_num" select="2285"/>
						<xsl:with-param name="data" select="$data"/>
					</xsl:call-template>
				</xsl:if>
				<!--(!NS) 2290 Exclusion Date invalid -->
				<xsl:if test="translate(StartDate, '-', '') &lt; $XDMin2290 
					or translate(StartDate, '-', '') &gt; $XDMax2290">
					<xsl:call-template name="Error">
						<xsl:with-param name="err_num" select="2290"/>
						<xsl:with-param name="data" select="$data"/>
					</xsl:call-template>
				</xsl:if>
				<!--(!NS) 2295 Due to the appeal process the pupil should not be removed off roll on the same day they are excluded-->
				<xsl:if test="StartDate = ../../PupilStatus/LeavingDate">
					<xsl:call-template name="Error">
						<xsl:with-param name="err_num" select="2295"/>
						<xsl:with-param name="data" select="$data"/>
					</xsl:call-template>
				</xsl:if>
				<!--(!NS) 2300 Where exclusion category is fixed the number of sessions must also be provided-->
				<xsl:if test="contains( ' SUSP ', concat( ' ', Category, ' ') ) 
					and (string-length(Sessions)=0 
						or Sessions &lt; 1)">
					<xsl:call-template name="Error">
						<xsl:with-param name="err_num" select="2300"/>
						<xsl:with-param name="data" select=" $data"/>
					</xsl:call-template>
				</xsl:if>
				<!--(!NS) 2303 Pupil’s leaving date suggests they left the school prior to the start of their exclusion-->
				<xsl:if test="string-length(../../PupilStatus/LeavingDate)
					and translate(StartDate, '-', '') &gt; translate (../../PupilStatus/LeavingDate, '-', '')">
					<xsl:call-template name="Error">
						<xsl:with-param name="err_num" select="2303"/>
						<xsl:with-param name="data" select="$data"/>
					</xsl:call-template>
				</xsl:if>
				<!--(!NS) 2310 Where SENprovision is present it must be a valid value -->
				<xsl:if test="not(contains($SENProvisioncodes, concat(' ', SENprovision, ' ') ) ) ">
					<xsl:call-template name="Error">
						<xsl:with-param name="err_num" select="2310"/>
						<xsl:with-param name="data" select=" $data"/>
					</xsl:call-template>
				</xsl:if>
				<!--(!NS) 2320 Please check: number of sessions excluded is greater than 90-->
				<xsl:if test="Sessions &gt; 90 ">
					<xsl:call-template name="Error">
						<xsl:with-param name="err_num" select="2320"/>
						<xsl:with-param name="data" select=" $data"/>
					</xsl:call-template>
				</xsl:if>
				<xsl:if test="Category = 'PERM' ">
					<!--Applies to 2330, 2335-->
					<!--(!NS) 2330 Where exclusion category is permanent the number of sessions is not applicable-->
					<xsl:if test="string-length(Sessions) != 0">
						<xsl:call-template name="Error">
							<xsl:with-param name="err_num" select="2330"/>
							<xsl:with-param name="data" select=" $data"/>
						</xsl:call-template>
					</xsl:if>
					<!--(!NS) 2335 Permanent exclusion appears for pupil still on roll.-->
					<xsl:if test=" ../../../PupilOnRoll">
						<xsl:call-template name="Error">
							<xsl:with-param name="err_num" select="2335"/>
							<xsl:with-param name="data" select=" $data"/>
						</xsl:call-template>
					</xsl:if>
				</xsl:if>
				<!--End of PERM category-->
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>
		
	<!--Home Information for off roll pupils - Autumn only-->
	<xsl:template name="HomeInformationValidationOffRoll">
		<xsl:variable name="ErrSex">
			<xsl:if test="PupilIdentifiers/Sex = 'M' ">Male</xsl:if>
			<xsl:if test="PupilIdentifiers/Sex = 'F' ">Female</xsl:if>
		</xsl:variable>
		<xsl:variable name="data" select="concat('UPN: ', PupilIdentifiers/UPN, 
								  '. Name: ', PupilIdentifiers/Surname, ', ' , PupilIdentifiers/Forename, '.' ,  
				 ' Date of Birth: ', PupilIdentifiers/DOB, ', ',
				 $ErrSex ) "/>
		<!--5130: Postcode is not required for off roll pupils without learning aims-->
		<xsl:if test="string-length(ProgrammeAims) = 0 
			and string-length(HomeInformation/Address/PostCode) != 0">
			<xsl:call-template name="Error">
				<xsl:with-param name="err_num" select="5130"/>
				<xsl:with-param name="data" select="$data"/>
			</xsl:call-template>
		</xsl:if>
		<xsl:choose>
			<!--2341 Postcode must be present and in correct format however we will need to check if HomeInformation is present-->
			<xsl:when test="count(ProgrammeAims/ProgrammeAim) &gt; 0
				and (string-length(HomeInformation) = 0 
						or string-length(HomeInformation/Address) = 0 )">
				<xsl:call-template name="Error">
					<xsl:with-param name="err_num" select="2341"/>
					<xsl:with-param name="data" select=" $data "/>
				</xsl:call-template>
			</xsl:when>
			<xsl:otherwise>
				<xsl:for-each select="HomeInformation/Address">
					<xsl:variable name="postcode9s" select="translate(PostCode, $digits, $all_9s) "/>
					<xsl:variable name="postcodeAs" select="translate($postcode9s, $alphabet, $all_As) "/>
					<!--2341 Postcode must be present and in correct format-->
					<xsl:choose>
						<xsl:when test="string-length(PostCode) &gt; 5 and 
							contains(' BFPO 9 BFPO 99 BFPO 999 ', concat(' ', $postcode9s, ' ') ) "/>
						<xsl:when test="string-length(PostCode) &gt; 5 and 
							contains( ' A9 9AA A99 9AA AA9 9AA AA99 9AA A9A 9AA AA9A 9AA ', concat(' ', $postcodeAs, ' ') ) "/>
						<xsl:otherwise>
							<xsl:call-template name="Error">
								<xsl:with-param name="err_num" select="2341"/>
								<xsl:with-param name="data" select=" $data"/>
							</xsl:call-template>
						</xsl:otherwise>
					</xsl:choose>
					<!--5155 UPRN is incorrect format (two-part test) -->
					<xsl:if test="string-length(UniquePropertyReferenceNumber) &gt;= 1">
						<xsl:if test="string-length(UniquePropertyReferenceNumber) &gt; 12">
							<xsl:call-template name="Error">
								<xsl:with-param name="err_num" select="5155"/>
								<xsl:with-param name="data" select=" $data"/>
							</xsl:call-template>
						</xsl:if>
						<xsl:if test="number(UniquePropertyReferenceNumber) != number(UniquePropertyReferenceNumber)">
							<xsl:call-template name="Error">
								<xsl:with-param name="err_num" select="5155"/>
								<xsl:with-param name="data" select=" $data"/>
							</xsl:call-template>
						</xsl:if>
					</xsl:if>
					<!--UPRN is provided-->
				</xsl:for-each>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>
	<!--Home Information - On-roll-->
	<!--If the whole Homeinformation or Address structure is missed out then generate query 2355-->
	<xsl:template name="HomeInformationValidation">
		<xsl:variable name="ErrSex">
			<xsl:if test="PupilIdentifiers/Sex = 'M' ">Male</xsl:if>
			<xsl:if test="PupilIdentifiers/Sex = 'F' ">Female</xsl:if>
		</xsl:variable>
		<xsl:variable name="data" select="concat('UPN: ', PupilIdentifiers/UPN, 
								  '. Name: ', PupilIdentifiers/Surname, ', ' , PupilIdentifiers/Forename, '.' ,  
				 ' Date of Birth: ', PupilIdentifiers/DOB, ', ',
				 $ErrSex ) "/>
		<xsl:choose>
			<xsl:when test="string-length(HomeInformation) = 0 
						or string-length(HomeInformation/Address) = 0">
				<xsl:call-template name="Error">
					<xsl:with-param name="err_num" select="2355"/>
					<xsl:with-param name="data" select=" $data "/>
				</xsl:call-template>
			</xsl:when>
			<xsl:otherwise>
				<xsl:for-each select="HomeInformation/Address">
					<xsl:variable name="postcode9s" select="translate(PostCode, $digits, $all_9s) "/>
					<xsl:variable name="postcodeAs" select="translate($postcode9s, $alphabet, $all_As) "/>
					<!--2340 Postcode must be present and in correct format-->
					<xsl:choose>
						<xsl:when test="string-length(PostCode) &gt; 5 and 
							contains(' BFPO 9 BFPO 99 BFPO 999 ', concat(' ', $postcode9s, ' ') ) "/>
						<xsl:when test="string-length(PostCode) &gt; 5 and 
							contains( ' A9 9AA A99 9AA AA9 9AA AA99 9AA A9A 9AA AA9A 9AA ', concat(' ', $postcodeAs, ' ') ) "/>
						<xsl:otherwise>
							<xsl:call-template name="Error">
								<xsl:with-param name="err_num" select="2340"/>
								<xsl:with-param name="data" select=" $data"/>
							</xsl:call-template>
						</xsl:otherwise>
					</xsl:choose>
					<!--2350 PAON or address line1 must be present-->
					<xsl:if test="string-length(BS7666Format/PAON) = 0
						and string-length(LineAddressFormat/AddressLine1) = 0">
						<xsl:call-template name="Error">
							<xsl:with-param name="err_num" select="2350"/>
							<xsl:with-param name="data" select=" $data"/>
						</xsl:call-template>
					</xsl:if>
					<!--2380 Where first line present, at least one other address line must also be present.-->
					<xsl:if test="BS7666Format [ string-length(PAON) != 0 ] ">
						<xsl:if test="BS7666Format [ string-length(Street) + string-length(Locality) + string-length(Town) + string-length(AdministrativeArea) + string-length(PostTown) = 0 ] ">
							<xsl:call-template name="Error">
								<xsl:with-param name="err_num" select="2380"/>
								<xsl:with-param name="data" select=" $data"/>
							</xsl:call-template>
						</xsl:if>
					</xsl:if>
					<!--2400Q if the 1st address line is present so must one of the others-->
					<xsl:if test="LineAddressFormat [ string-length(AddressLine1) != 0 ]
						and LineAddressFormat [ string-length(AddressLine2) + string-length(AddressLine3) + string-length(AddressLine4) + string-length(AddressLine5) = 0 ]">
						<xsl:call-template name="Error">
							<xsl:with-param name="err_num" select="2400"/>
							<xsl:with-param name="data" select=" $data"/>
						</xsl:call-template>
					</xsl:if>
					<!--2445 if any AddressLine 1-5 is present no BS7666Format allowed-->
					<xsl:if test="LineAddressFormat [ string-length(AddressLine1) + string-length(AddressLine2) + string-length(AddressLine3) + string-length(AddressLine4) + string-length(AddressLine5) != 0 ]
						and BS7666Format [string-length(SAON) + string-length(PAON) + string-length(Street) + string-length(Locality) + string-length(Town) + string-length(AdministrativeArea) + string-length(PostTown) != 0 ]">
						<xsl:call-template name="Error">
							<xsl:with-param name="err_num" select="2445"/>
							<xsl:with-param name="data" select=" $data"/>
						</xsl:call-template>
					</xsl:if>
					<!--5155 UPRN is incorrect format (two-part test) -->
					<xsl:if test="string-length(UniquePropertyReferenceNumber) &gt;= 1">
						<xsl:if test="string-length(UniquePropertyReferenceNumber) &gt; 12">
							<xsl:call-template name="Error">
								<xsl:with-param name="err_num" select="5155"/>
								<xsl:with-param name="data" select=" $data"/>
							</xsl:call-template>
						</xsl:if>
						<xsl:if test="number(UniquePropertyReferenceNumber) != number(UniquePropertyReferenceNumber)">
							<xsl:call-template name="Error">
								<xsl:with-param name="err_num" select="5155"/>
								<xsl:with-param name="data" select=" $data"/>
							</xsl:call-template>
						</xsl:if>
					</xsl:if>
					<!--UPRN is provided-->
				</xsl:for-each>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>
	
	<!--Termly Attendance-->
	<xsl:template name="TermlyAttendanceValidation">
		<!--Set template variables-->
		<xsl:variable name="ErrSex">
			<xsl:if test="PupilIdentifiers/Sex = 'M' ">Male</xsl:if>
			<xsl:if test="PupilIdentifiers/Sex = 'F' ">Female</xsl:if>
		</xsl:variable>
		<xsl:variable name="data" select="concat('UPN: ', PupilIdentifiers/UPN, 
				   	          '. Name: ', PupilIdentifiers/Surname, ', ' , PupilIdentifiers/Forename, '.' ,  
				   	          ' Date of Birth: ', PupilIdentifiers/DOB, ', ',
						 $ErrSex ) "/>
		<xsl:variable name="EntryDateNum" select="translate( PupilStatus/EntryDate, '-', '') "/>
		<xsl:variable name="LeavingDateNum" select="translate( PupilStatus/LeavingDate, '-', '') "/>
		<!--The following two variables are used in validation 2520-->
		<xsl:variable name="tasp">
			<xsl:choose>
				<xsl:when test="number(Attendance/TermlyAttendance/SessionsPossible) = Attendance/TermlyAttendance/SessionsPossible">
					<xsl:value-of select="Attendance/TermlyAttendance/SessionsPossible"/>
				</xsl:when>
				<xsl:otherwise>
					<xsl:value-of select="0"/>
				</xsl:otherwise>
			</xsl:choose>
		</xsl:variable>
		<xsl:variable name="sht2sp">
			<xsl:choose>
				<!--Strictly speaking, this shouldn't be necessary - the value shouldn't be present and therefore should miss the test below.-->
				<xsl:when test="$term='SPR' or $term = 'SUM' ">
					<xsl:value-of select="0"/>
				</xsl:when>
				<xsl:when test="number(Attendance/SummerHalfTerm2Attendance/SessionsPossible) = Attendance/SummerHalfTerm2Attendance/SessionsPossible">
					<xsl:value-of select="Attendance/SummerHalfTerm2Attendance/SessionsPossible"/>
				</xsl:when>
				<xsl:otherwise>
					<xsl:value-of select="0"/>
				</xsl:otherwise>
			</xsl:choose>
		</xsl:variable>
		<xsl:variable name="age" select="floor(($AgeCalcDateForAttendance - translate(PupilIdentifiers/DOB, '-','')) div 10000)"/>
		<!--(NS) 5057 Attendance information is not required from schools with a phase of NS-->		
		<xsl:choose>
			<xsl:when test="$Phase = 'NS' ">
				<xsl:if test="string-length(Attendance/TermlyAttendance) != 0 ">
					<xsl:call-template name="Error">
						<xsl:with-param name="err_num" select="5057"/>
						<xsl:with-param name="data" select="$data"/>
					</xsl:call-template>
				</xsl:if>
			</xsl:when>
			<xsl:otherwise>
				<xsl:choose>
					<xsl:when test="contains(' B 6 7 ', concat(' ', PupilStatus/Boarder, ' ') )
						or $age &lt; 4 
						or $age &gt; 15">
						<!--2470: Pupil data is excluded as are a boarder or out of age range-->
						<xsl:if test="string-length(Attendance/TermlyAttendance) != 0 ">
							<xsl:call-template name="Error">
								<xsl:with-param name="err_num" select="2470"/>
								<xsl:with-param name="data" select="$data"/>
							</xsl:call-template>
						</xsl:if>
					</xsl:when>
					<xsl:otherwise>
						<!--2500 For pupil on roll in ($Term) the attendance sessions possible is missing or invalid-->
						<!--Two error messages, as autumn refers to summer first half term-->
						<xsl:if test="../PupilOnRoll
							and $EntryDateNum &lt;= $EntryDateRef
							and (string-length(Attendance/TermlyAttendance) = 0 
								or string-length(Attendance/TermlyAttendance/SessionsPossible) = 0 ) ">
							<xsl:if test="$term = 'AUT' ">
								<xsl:call-template name="Error">
									<xsl:with-param name="err_num" select="25004"/>
									<xsl:with-param name="data" select="$data"/>
								</xsl:call-template>
							</xsl:if>
							<xsl:if test="$term = 'SPR' or $term = 'SUM' ">
								<xsl:call-template name="Error">
									<xsl:with-param name="err_num" select="25005"/>
									<xsl:with-param name="data" select="$data"/>
								</xsl:call-template>
							</xsl:if>
						</xsl:if>
						<!--2510 For pupil no longer on roll the attendance sessions possible is missing or invalid must be gre45ater than or equal to zero-->
						<!--Two error messages, as autumn refers to summer first half term-->
						<xsl:if test="../PupilNoLongerOnRoll
							and $LeavingDateNum &gt;= $StartPreviousTerm
							and $LeavingDateNum &lt; $RefDate 
							and translate(PupilStatus/EntryDate, '-','') &lt;= $EntryDateRef
							and (string-length(Attendance/TermlyAttendance) = 0 
								or string-length(Attendance/TermlyAttendance/SessionsPossible) = 0 ) ">
							<xsl:if test="$term = 'AUT' ">
								<xsl:call-template name="Error">
									<xsl:with-param name="err_num" select="25104"/>
									<xsl:with-param name="data" select="$data"/>
								</xsl:call-template>
							</xsl:if>
							<xsl:if test="$term = 'SPR' or $term = 'SUM' ">
								<xsl:call-template name="Error">
									<xsl:with-param name="err_num" select="25105"/>
									<xsl:with-param name="data" select="$data"/>
								</xsl:call-template>
							</xsl:if>
						</xsl:if>
						<!--2502 Zero attendance sessions possible recorded for pupil on roll. -->
						<!--Two error messages, as autumn refers to summer first half term-->
						<xsl:if test="$EntryDateNum &lt;= $EntryDateRef	
								and ( (	string-length(Attendance/TermlyAttendance/SessionsPossible) &gt; 0 and count(Attendance/TermlyAttendance[SessionsPossible = 0]) = 1 )
									and ( (	(string-length(Attendance/TermlyAttendance/SessionDetails) > 0
											and string-length(Attendance/TermlyAttendance/SessionsExceptional) = 0
											and	( count(Attendance/TermlyAttendance/SessionDetails/SessionDetail[AttendanceReason = 'X' and not(Sessions = '') and Sessions > 0] ) 
												+ count(Attendance/TermlyAttendance/SessionDetails/SessionDetail[AttendanceReason = 'Y' and not(Sessions = '') and Sessions > 0] ) 
												+ count(Attendance/TermlyAttendance/SessionDetails/SessionDetail[AttendanceReason = 'D' and not(Sessions = '') and Sessions > 0] )
												) = 0 
											)
										  )
										or (count(Attendance/TermlyAttendance/SessionDetails/SessionDetail[contains($ValidAttendanceAbsence, concat(' ', AttendanceReason, ' ') ) and not(Sessions = '') and Sessions > 0]) > 0 )
										or
										( (	(string-length(Attendance/TermlyAttendance/SessionDetails) = 0 
											 and (string-length(Attendance/TermlyAttendance/SessionsExceptional) = 0 
												  or count(Attendance/TermlyAttendance[SessionsExceptional = 0]) = 1)
											)
											and 
											(string-length(Attendance/TermlyAttendance/SessionDetails) = 0
											)
										  )
										  or count(Attendance/TermlyAttendance[SessionsEducational > 0]) = 1
										)
									)
								) ">
						<!-- *** ORIGINAL CODE COMMENTED OUT BELOW PRIOR TO IW AMENDMENT - 2021-04-19 ***-->
						
						<!--<xsl:if test="$EntryDateNum &lt;= $EntryDateRef
							and ((string-length(Attendance/TermlyAttendance/SessionsPossible) &gt; 0 and string-length(Attendance/TermlyAttendance/SessionsCoronavirus) &gt; 0
								and (Attendance/TermlyAttendance/SessionsPossible) + (Attendance/TermlyAttendance/SessionsCoronavirus) = 0)
								or (string-length(Attendance/TermlyAttendance/SessionsPossible) &gt; 0 and string-length(Attendance/TermlyAttendance/SessionsCoronavirus) = 0
									and (Attendance/TermlyAttendance/SessionsPossible) = 0)
								or (string-length(Attendance/TermlyAttendance/SessionsPossible) = 0 and string-length(Attendance/TermlyAttendance/SessionsCoronavirus) &gt; 0
									and (Attendance/TermlyAttendance/SessionsCoronavirus) = 0)
								or (string-length(Attendance/TermlyAttendance/SessionsPossible) = 0 and string-length(Attendance/TermlyAttendance/SessionsCoronavirus) = 0))
							and $DisabledValidation != 'true' ">-->
						
							<!--or not(number(Attendance/TermlyAttendance/SessionsPossible) ) )"-->
							<!--INTENTIONALLY COMMENTED OUT-->
							<!--SS - NOTE:  2502 is a query and can be overridden-->
							<!--Where the SessionsPossible entry is missing 2500 should catch it and raise a hard error.-->
							<!--2502 flags the query of why the attendance value is zero which is an unlikely, but possible situation under certain circumstances.-->
							<!--Amended Autumn 2019 under RFC 1105: now applies to on- and off-roll pupils-->
							<xsl:if test="$term = 'AUT' ">
								<xsl:call-template name="Error">
									<xsl:with-param name="err_num" select="25024"/>
									<xsl:with-param name="data" select=" $data"/>
								</xsl:call-template>
							</xsl:if>
							<xsl:if test="$term = 'SPR' or $term = 'SUM' ">
								<xsl:call-template name="Error">
									<xsl:with-param name="err_num" select="25025"/>
									<xsl:with-param name="data" select=" $data"/>
								</xsl:call-template>
							</xsl:if>
						</xsl:if>
						<!--2505: Pupil with double-reporting of termly absences-->
						<xsl:if test="(Attendance/TermlyAttendance/SessionsAuthorised &gt; 0 
								or Attendance/TermlyAttendance/SessionsUnauthorised &gt; 0
								or Attendance/TermlyAttendance/SessionsEducational &gt; 0
								or Attendance/TermlyAttendance/SessionsExceptional &gt; 0 ) 
							 and sum(Attendance/TermlyAttendance/SessionDetails/SessionDetail/Sessions) &gt; 0 ">
							<xsl:call-template name="Error">
								<xsl:with-param name="err_num" select="2505"/>
								<xsl:with-param name="data" select=" $data"/>
							</xsl:call-template>
						</xsl:if>
						<!--2520 Please check: Sessions possible should not be greater than 150-->
						<xsl:if test="$tasp + $sht2sp &gt; 150">
							<xsl:call-template name="Error">
								<xsl:with-param name="err_num" select="2520"/>
								<xsl:with-param name="data" select=" $data"/>
							</xsl:call-template>
						</xsl:if>
						<!--2530: Total sessions missed must be < = Sessions Possible-->
						<!-- Rule updated via RFC1166 to remove this first part, which is now covered by new rule 2531. -->
<!--						<xsl:if test="not(Attendance/TermlyAttendance/SessionsUnauthorised) 
							or not(Attendance/TermlyAttendance/SessionsAuthorised)">
							<xsl:if test="sum(Attendance/TermlyAttendance/SessionDetails/SessionDetail/Sessions[contains($ValidAuthUnAuthAttendance, concat(' ', ../AttendanceReason, ' ') ) ]) &gt; $tasp 
								and $DisabledValidation != 'true' ">
								<xsl:call-template name="Error">
									<xsl:with-param name="err_num" select="2530"/>
									<xsl:with-param name="data" select=" $data"/>
								</xsl:call-template>
							</xsl:if>
						</xsl:if>	-->
						<xsl:if test="not(Attendance/TermlyAttendance/SessionDetails/SessionDetail/Sessions)">
							<xsl:if test="Attendance/TermlyAttendance/SessionsAuthorised + Attendance/TermlyAttendance/SessionsUnauthorised &gt; $tasp 
								or (number(Attendance/TermlyAttendance/SessionsAuthorised) &gt; $tasp  )
								or (number(Attendance/TermlyAttendance/SessionsUnauthorised) &gt; $tasp )">
								<xsl:call-template name="Error">
									<xsl:with-param name="err_num" select="2530"/>
									<xsl:with-param name="data" select=" $data"/>
								</xsl:call-template>
							</xsl:if>
						</xsl:if>
						<!--2531: Sessions possible must be equal to the total of all attendance and absence sessions -->
						<xsl:if test="not(Attendance/TermlyAttendance/SessionsUnauthorised) 
							or not(Attendance/TermlyAttendance/SessionsAuthorised)">
							<!--<xsl:if test="(sum(Attendance/TermlyAttendance/SessionDetails/SessionDetail/Sessions[contains($ValidAttendanceAbsence, concat(' ', ../AttendanceReason, ' ') ) ]) != $tasp 
									or (not(Attendance/TermlyAttendance/SessionDetails) and $tasp &gt; 0))
								and $DisabledValidation != 'true' ">-->	<!--IW AMENDED TO ALIGN WITH SQL VERSION - 2021-08-20-->
							<xsl:if test="( sum(Attendance/TermlyAttendance/SessionDetails/SessionDetail/Sessions[contains($ValidAttendanceAbsence, concat(' ', ../AttendanceReason, ' ') ) ]) != $tasp 
												and $tasp &gt; 0
												and string-length(Attendance/TermlyAttendance/SessionDetails) != 0
											) ">
								<xsl:call-template name="Error">
									<xsl:with-param name="err_num" select="2531"/>
									<xsl:with-param name="data" select=" $data"/>
								</xsl:call-template>
							</xsl:if>
						</xsl:if>
						<!-- RFC1183 NEW RULE ADDED - IW 2021-08-20-->	
						<!--2532 Where a reason for attendance or absence is provided it must be unique-->
						<xsl:if test="count(Attendance/TermlyAttendance/SessionDetails/SessionDetail[AttendanceReason = '/']) &gt; 1
										or count(Attendance/TermlyAttendance/SessionDetails/SessionDetail[AttendanceReason = '\']) &gt; 1
										or count(Attendance/TermlyAttendance/SessionDetails/SessionDetail[AttendanceReason = 'B']) &gt; 1
										or count(Attendance/TermlyAttendance/SessionDetails/SessionDetail[AttendanceReason = 'D']) &gt; 1
										or count(Attendance/TermlyAttendance/SessionDetails/SessionDetail[AttendanceReason = 'J']) &gt; 1
										or count(Attendance/TermlyAttendance/SessionDetails/SessionDetail[AttendanceReason = 'L']) &gt; 1
										or count(Attendance/TermlyAttendance/SessionDetails/SessionDetail[AttendanceReason = 'P']) &gt; 1
										or count(Attendance/TermlyAttendance/SessionDetails/SessionDetail[AttendanceReason = 'V']) &gt; 1
										or count(Attendance/TermlyAttendance/SessionDetails/SessionDetail[AttendanceReason = 'W']) &gt; 1
										or count(Attendance/TermlyAttendance/SessionDetails/SessionDetail[AttendanceReason = 'X']) &gt; 1
										or count(Attendance/TermlyAttendance/SessionDetails/SessionDetail[AttendanceReason = 'I']) &gt; 1
										or count(Attendance/TermlyAttendance/SessionDetails/SessionDetail[AttendanceReason = 'M']) &gt; 1
										or count(Attendance/TermlyAttendance/SessionDetails/SessionDetail[AttendanceReason = 'R']) &gt; 1
										or count(Attendance/TermlyAttendance/SessionDetails/SessionDetail[AttendanceReason = 'S']) &gt; 1
										or count(Attendance/TermlyAttendance/SessionDetails/SessionDetail[AttendanceReason = 'T']) &gt; 1
										or count(Attendance/TermlyAttendance/SessionDetails/SessionDetail[AttendanceReason = 'H']) &gt; 1
										or count(Attendance/TermlyAttendance/SessionDetails/SessionDetail[AttendanceReason = 'E']) &gt; 1
										or count(Attendance/TermlyAttendance/SessionDetails/SessionDetail[AttendanceReason = 'C']) &gt; 1
										or count(Attendance/TermlyAttendance/SessionDetails/SessionDetail[AttendanceReason = 'G']) &gt; 1
										or count(Attendance/TermlyAttendance/SessionDetails/SessionDetail[AttendanceReason = 'U']) &gt; 1
										or count(Attendance/TermlyAttendance/SessionDetails/SessionDetail[AttendanceReason = 'O']) &gt; 1
										or count(Attendance/TermlyAttendance/SessionDetails/SessionDetail[AttendanceReason = 'N']) &gt; 1
										or count(Attendance/TermlyAttendance/SessionDetails/SessionDetail[AttendanceReason = 'Y']) &gt; 1
							">
							<xsl:call-template name="Error">
								<xsl:with-param name="err_num" select="2532"/>
								<xsl:with-param name="err_param1" select="AttendanceReason"/>
								<xsl:with-param name="data" select=" $data"/>
							</xsl:call-template>
						</xsl:if>
						<!-- RFC1183 NEW RULE ADDED - IW 2021-08-20-->	
						<!--2533 Pupil has educational sessions reported but has zero possible sessions-->
						<xsl:if test="sum(Attendance/TermlyAttendance/SessionsEducational) &gt; 0
										and sum(Attendance/TermlyAttendance/SessionsEducational) &gt; sum(Attendance/TermlyAttendance/SessionsPossible)
									">
							<xsl:call-template name="Error">
								<xsl:with-param name="err_num" select="2533"/>
								<xsl:with-param name="data" select=" $data"/>
							</xsl:call-template>
						</xsl:if>
						<xsl:for-each select="Attendance/TermlyAttendance/SessionDetails/SessionDetail">
							<!--2475: valid attendance reason-->
							<xsl:if test="string-length(AttendanceReason) != 0 
								and not(contains($ValidAttendance, concat(' ', AttendanceReason, ' ') ) ) ">
								<xsl:call-template name="Error">
									<xsl:with-param name="err_num" select="2475"/>
									<xsl:with-param name="err_param1" select="AttendanceReason"/>
									<xsl:with-param name="data" select=" $data"/>
								</xsl:call-template>
							</xsl:if>
							<!--2485: If <AttendanceReason> = E there should be at least one exclusion or suspension record-->
							<xsl:if test="AttendanceReason = 'E' 
								and count(../../../../Exclusions/TermlyExclusion
									[translate(StartDate, '-', '') &gt;= $XDMinExclRev 
										and translate(StartDate, '-', '') &lt;= $XDMaxExclRev]) = 0 ">
								<xsl:call-template name="Error">
									<xsl:with-param name="err_num" select="2485"/>
									<xsl:with-param name="data" select=" $data"/>
								</xsl:call-template>
							</xsl:if>
							<!--2480: Attendance reason present so Number Absences > 0-->
							<xsl:if test="string-length(AttendanceReason) != 0 
								and (string-length(Sessions) = 0
										 or Sessions &lt;= 0) ">
								<xsl:call-template name="Error">
									<xsl:with-param name="err_num" select="2480"/>
									<xsl:with-param name="err_param1" select="AttendanceReason"/>
									<xsl:with-param name="data" select=" $data"/>
								</xsl:call-template>
							</xsl:if>
							<!--2490 Number Absences > 0; Attendance Reason needed-->
							<xsl:if test="Sessions &gt; 0 
								and (string-length(AttendanceReason) = 0 
										or not(contains($ValidAttendance, concat(' ', AttendanceReason, ' ') ) ) ) ">
								<xsl:call-template name="Error">
									<xsl:with-param name="err_num" select="2490"/>
									<xsl:with-param name="err_param1" select="AttendanceReason"/>
									<xsl:with-param name="data" select=" $data"/>
								</xsl:call-template>
							</xsl:if>							
							<!--2491 Where <AttendanceReason> is equal to ‘X’ then <DOB> must be between 01-09-2017 to 31-08-2018 at 2022-08-31-->
							<xsl:if test="AttendanceReason = 'X'
										  and (translate(../../../../PupilIdentifiers/DOB, '-', '') &lt; $v2491Min 
											   or translate(../../../../PupilIdentifiers/DOB, '-', '') &gt; $v2491Max )">
								<xsl:call-template name="Error">
									<xsl:with-param name="err_num" select="2491"/>
									<xsl:with-param name="data" select=" $data"/>
								</xsl:call-template>
							</xsl:if>
						</xsl:for-each>
					</xsl:otherwise>
				</xsl:choose>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>

	<xsl:template name="APPlacementDetailsValidation">
		<xsl:variable name="ErrSex">
			<xsl:if test="PupilIdentifiers/Sex = 'M' ">Male</xsl:if>
			<xsl:if test="PupilIdentifiers/Sex = 'F' ">Female</xsl:if>
		</xsl:variable>
		<xsl:variable name="data" select="concat('UPN: ', PupilIdentifiers/UPN, 
				   	          '. Name: ', PupilIdentifiers/Surname, ', ' , PupilIdentifiers/Forename, '.' ,  
				   	          ' Date of Birth: ', PupilIdentifiers/DOB, ', ',
						 $ErrSex ) "/>
		<xsl:variable name="LeavingDateNum" select="translate( PupilStatus/LeavingDate, '-', '') "/>
		<xsl:variable name="EntryDateNum" select="translate( PupilStatus/EntryDate, '-', '') "/>
	
		<xsl:for-each select="APPlacementDetails/APProvisionDetail">
			<!-- 2360 Where <PrevURN> is present, it must be a valid value (6 digit integer) -->
			<xsl:if test="string-length(PrevURN) &gt; 0 
						  and translate (PrevURN, $digits, $all_9s) != '999999' ">
				<xsl:call-template name="Error">
					<xsl:with-param name="err_num" select="2360"/>
					<xsl:with-param name="data" select="$data"/>
				</xsl:call-template>
			</xsl:if>
			<!-- 2361 Where <APProvisionDetail> node exists, <APReason> must be present and a valid value -->
			<xsl:if test="string-length(APReason) = 0 
							or not(contains($APReasoncodes, concat(' ', APReason, ' ') ) ) ">
				<xsl:call-template name="Error">
					<xsl:with-param name="err_num" select="2361"/>
					<xsl:with-param name="data" select="$data"/>
				</xsl:call-template>
			</xsl:if>
			<!-- 2362 Where <APProvisionDetail> node exists, <SENProvisionEntry> must be present and a valid value -->
			<xsl:if test="string-length(SENProvisionEntry) = 0 
						   or not(contains($SENProvisioncodes, concat(' ', SENProvisionEntry, ' ') ) ) ">
				<xsl:call-template name="Error">
					<xsl:with-param name="err_num" select="2362"/>
					<xsl:with-param name="data" select="$data"/>
				</xsl:call-template>
			</xsl:if>
			<!-- 2363 Where <APReason> is equal to 'EHC', <SENprovisionEntry> should equal 'E' -->
			<xsl:if test="contains(' EHC ', concat(' ', APReason, ' ') )
						  and not(contains(' E ', concat(' ', SENProvisionEntry,' ') ) )">
				<xsl:call-template name="Error">
					<xsl:with-param name="err_num" select="2363"/>
					<xsl:with-param name="data" select="$data"/>
				</xsl:call-template>
			</xsl:if>			
			<!-- 2390 <APProvisionDetail> node must only be present for schools with a <Phase> of ‘PR’-->
			<xsl:if test="$Phase != 'PR' ">
				<xsl:call-template name="Error">
					<xsl:with-param name="err_num" select="2390"/>
					<xsl:with-param name="data" select="$data"/>
				</xsl:call-template>
			</xsl:if>
		</xsl:for-each>
		
		<xsl:for-each select="APPlacementDetails/SchoolArrangedAPDetail">
			<!-- 2364 Where <SchoolArrangedAPDetail> node exists, then one of: <URN> or <UKPRN> or <APSettingType> should exist -->
			<xsl:if test="string-length(URN) = 0 
						  and string-length(UKPRN) = 0 
						  and string-length(APSettingType) = 0">
				<xsl:call-template name="Error">
					<xsl:with-param name="err_num" select="2364"/>
					<xsl:with-param name="data" select="$data"/>
				</xsl:call-template>
			</xsl:if>
			<!-- 2365 Where <URN> is present, it must be a valid value -->
			<xsl:if test="string-length(URN) &gt; 0 
						  and translate (URN, $digits, $all_9s) != '999999' ">
				<xsl:call-template name="Error">
					<xsl:with-param name="err_num" select="2365"/>
					<xsl:with-param name="data" select="$data"/>
				</xsl:call-template>
			</xsl:if>
			<!-- 2366 Where <UKPRN> is present, it must be a valid value -->
			<xsl:if test="string-length(UKPRN) &gt; 0 
						  and translate (UKPRN, $digits, $all_9s) != '99999999' ">
				<xsl:call-template name="Error">
					<xsl:with-param name="err_num" select="2366"/>
					<xsl:with-param name="data" select="$data"/>
				</xsl:call-template>
			</xsl:if>
			<!-- 2367 Where <APSettingType> is present, it must be a valid value -->
			<xsl:if test="string-length(APSettingType) &gt; 0 
						  and not(contains($APSettingcodes, concat(' ', APSettingType, ' ') ) ) ">
				<xsl:call-template name="Error">
					<xsl:with-param name="err_num" select="2367"/>
					<xsl:with-param name="data" select="$data"/>
				</xsl:call-template>
			</xsl:if>
			<!-- 2368 The <URN> within the <SchoolArrangedAPDetail> must not be the same as <URN> for current school -->
			<xsl:if test="URN = /Message/Header/Source/URN ">
				<xsl:call-template name="Error">
					<xsl:with-param name="err_num" select="2368"/>
					<xsl:with-param name="data" select="$data"/>
				</xsl:call-template>
			</xsl:if>
			<!-- 2369 <PlacementReason> must be a valid value -->
			<xsl:if test="not(contains($PlacementReasoncodes, concat(' ', PlacementReason, ' ') ) )">
				<xsl:call-template name="Error">
					<xsl:with-param name="err_num" select="2369"/>
					<xsl:with-param name="data" select="$data"/>
				</xsl:call-template>
			</xsl:if>
			<!-- 2370 <EntryDate> must be present and between the range of pupil <EntryDate> at the school and <ReferenceDate> -->		
			<xsl:if test="(string-length(EntryDate) = 0 
							  or translate(EntryDate, '-', '') &lt; $EntryDateNum 
							  or translate(EntryDate, '-', '') &gt; $RefDate) ">
				<xsl:call-template name="Error">
					<xsl:with-param name="err_num" select="2370"/>
					<xsl:with-param name="data" select="$data"/>
				</xsl:call-template>
			</xsl:if>
			<!-- 2371 <SENProvisionEntry> must be a valid value -->
			<xsl:if test="not(contains($SENProvisioncodes, concat(' ', SENProvisionEntry, ' ') ) )">
				<xsl:call-template name="Error">
					<xsl:with-param name="err_num" select="2371"/>
					<xsl:with-param name="data" select="$data"/>
				</xsl:call-template>
			</xsl:if>
			<!-- 2372 Pupil's date of leaving a school arranged alternative provision (AP) placement must be present and on or before the date the pupil left the commissioning school -->		
			<xsl:if test="../../../PupilNoLongerOnRoll
						  and (string-length(LeavingDate) = 0 
							   or translate(LeavingDate, '-', '') &gt; $LeavingDateNum) ">
				<xsl:call-template name="Error">
					<xsl:with-param name="err_num" select="2372"/>
					<xsl:with-param name="data" select="$data"/>
				</xsl:call-template>
			</xsl:if>
			<!-- 2373 Where <SENProvisionLeaving> is present, it should be a valid value -->
			<xsl:if test="not(contains($SENProvisioncodes, concat(' ', SENProvisionLeaving, ' ') ) ) 
						  and string-length(SENProvisionLeaving) &gt; 0">
				<xsl:call-template name="Error">
					<xsl:with-param name="err_num" select="2373"/>
					<xsl:with-param name="data" select="$data"/>
				</xsl:call-template>
			</xsl:if>
			<!-- 2374 <SENProvisionLeaving> must only be present where there is an alternative provision placement <LeavingDate> -->
			<xsl:if test="string-length(LeavingDate) = 0 
						  and string-length(SENProvisionLeaving) &gt; 0 ">
				<xsl:call-template name="Error">
					<xsl:with-param name="err_num" select="2374"/>
					<xsl:with-param name="data" select="$data"/>
				</xsl:call-template>
			</xsl:if>
			<!-- 2375 <APAttendancePattern> must be a valid value -->
			<xsl:if test="not(contains(' FT PT ', concat(' ', APAttendancePattern, ' ') ) ) ">
				<xsl:call-template name="Error">
					<xsl:with-param name="err_num" select="2375"/>
					<xsl:with-param name="data" select="$data"/>
				</xsl:call-template>
			</xsl:if>
			<!-- 2376 Where <APAttendancePattern> equals 'PT', <APSessionsPerWeek> must be present and be between 1 and 9  -->
			<xsl:if test="APAttendancePattern = 'PT'
						  and (APSessionsPerWeek &lt; 1
							   or APSessionsPerWeek &gt; 9
							   or string-length(APSessionsPerWeek) = 0) ">
				<xsl:call-template name="Error">
					<xsl:with-param name="err_num" select="2376"/>
					<xsl:with-param name="data" select="$data"/>
				</xsl:call-template>
			</xsl:if>
			<!-- 2377 Where <APAttendancePattern> equals 'FT', <APSessionsPerWeek> should not be provided -->
			<xsl:if test="APAttendancePattern = 'FT'
						  and string-length(APSessionsPerWeek) &gt; 0 ">
				<xsl:call-template name="Error">
					<xsl:with-param name="err_num" select="2377"/>
					<xsl:with-param name="data" select="$data"/>
				</xsl:call-template>
			</xsl:if>
			<!-- 2378 Where <LeavingDate> is present within <SchoolArrangedAPDetail> node, this must fall between the following dates (inclusive): -->
			<xsl:if test="string-length(LeavingDate) &gt; 0 
						  and (translate(LeavingDate, '-', '') &lt; $PrevTermRefDate 
							   or translate(LeavingDate, '-', '') &gt; $RefDate - 1)">
				<xsl:call-template name="Error">
					<xsl:with-param name="err_num" select="2378"/>
					<xsl:with-param name="data" select="$data"/>
				</xsl:call-template>
			</xsl:if>	
			<!-- 2385 - Where <URN> is not present and <UKPRN> is present, <APSettingType> should not be present -->
			<xsl:if test="string-length(URN) = 0 
						  and string-length(UKPRN) &gt; 0 
						  and string-length(APSettingType) &gt; 0">
				<xsl:call-template name="Error">
					<xsl:with-param name="err_num" select="2385"/>
					<xsl:with-param name="data" select="$data"/>
				</xsl:call-template>
			</xsl:if>
			<!-- 2386 - The URN has been provided, UKPRN and/or AP Setting Type are not required -->
			<xsl:if test="string-length(URN) &gt; 0 
						  and (string-length(UKPRN) &gt; 0 
							   or string-length(APSettingType) &gt; 0)">
				<xsl:call-template name="Error">
					<xsl:with-param name="err_num" select="2386"/>
					<xsl:with-param name="data" select="$data"/>
				</xsl:call-template>
			</xsl:if>
			<!--2395 - Where <APSettingType> is present, <APPlacementPostcode> must be present-->
			<xsl:if test="string-length(APSettingType) &gt; 0
						  and string-length(APPlacementPostcode) = 0">
				<xsl:call-template name="Error">
					<xsl:with-param name="err_num" select="2395"/>
					<xsl:with-param name="data" select="$data"/>
				</xsl:call-template>
			</xsl:if>
			<!--2396 - Where <APSettingType> is not present, both <CompanyNumber> and <APPlacementPostcode> must not be present-->
			<xsl:if test="string-length(APSettingType) = 0
						  and (string-length(CompanyNumber) &gt; 0
							   or string-length(APPlacementPostcode) &gt; 0)">
				<xsl:call-template name="Error">
					<xsl:with-param name="err_num" select="2396"/>
					<xsl:with-param name="data" select="$data"/>
				</xsl:call-template>
			</xsl:if>
			<!--2397 - Where <CompanyNumber> is present, it must be a valid value-->
			<xsl:if test="((not(translate(substring(CompanyNumber, 1, 1), $alphabet, $all_As) = 'A') 
							  and not(translate(substring(CompanyNumber, 1, 1), $digits, $all_9s) = '9') )
						   or (not(translate(substring(CompanyNumber, 2, 1), $alphabet, $all_As) = 'A') 
							  and not(translate(substring(CompanyNumber, 2, 1), $digits, $all_9s) = '9') )
						   or not(translate(substring(CompanyNumber, 3, 6), $digits, $all_9s ) = '999999') 
						   or string-length(CompanyNumber) != 8)
						   and (string-length(CompanyNumber) &gt; 0)">
				<xsl:call-template name="Error">
					<xsl:with-param name="err_num" select="2397"/>
					<xsl:with-param name="data" select="$data"/>
				</xsl:call-template>
			</xsl:if>
			<xsl:variable name="APpostcode9s" select="translate(APPlacementPostcode, $digits, $all_9s) "/>
			<xsl:variable name="APpostcodeAs" select="translate($APpostcode9s, $alphabet, $all_As) "/>
			<!--2398 Where APPlacementPostcode is present it must be a valid format-->		
			<xsl:choose>
				<xsl:when test="string-length(APPlacementPostcode) = 0"/>
				<xsl:when test="string-length(APPlacementPostcode) &gt; 5 and 
					contains(' BFPO 9 BFPO 99 BFPO 999 ', concat(' ', $APpostcode9s, ' ') ) "/>
				<xsl:when test="string-length(APPlacementPostcode) &gt; 5 and 
					contains( ' A9 9AA A99 9AA AA9 9AA AA99 9AA A9A 9AA AA9A 9AA ', concat(' ', $APpostcodeAs, ' ') ) "/>
				<xsl:otherwise>
					<xsl:call-template name="Error">
						<xsl:with-param name="err_num" select="2398"/>
						<xsl:with-param name="data" select=" $data"/>
					</xsl:call-template>
				</xsl:otherwise>
			</xsl:choose>">
			<!--3132 Where <APSettingType> is present, <CompanyNumber> should be present-->
			<xsl:if test="string-length(APSettingType) != 0
						  and string-length(CompanyNumber) = 0">
				<xsl:call-template name="Error">
					<xsl:with-param name="err_num" select="3132"/>
					<xsl:with-param name="data" select="$data"/>
				</xsl:call-template>
			</xsl:if>
			<!-- 3125 - If <APSettingType> equals ‘OTH’ and <APAttendancePattern> = 'FT' <SENProvisionEntry> should not equal ‘E’ -->
			<xsl:if test="APSettingType = 'OTH' and APAttendancePattern = 'FT' and SENProvisionEntry = 'E' ">
				<xsl:call-template name="Error">
					<xsl:with-param name="err_num" select="3125"/>
					<xsl:with-param name="data" select="$data"/>
				</xsl:call-template>
			</xsl:if>
		</xsl:for-each>

		<!-- 2379 Where pupil <EnrolStatus> equals ‘M’ or ‘S’, <APProvisionDetail> node should not exist-->
		<xsl:if test="APPlacementDetails/APProvisionDetail
					  and (contains(' M S ', concat(' ', PupilStatus/EnrolStatus, ' ') ) ) ">
			<xsl:call-template name="Error">
				<xsl:with-param name="err_num" select="2379"/>
				<xsl:with-param name="data" select="$data"/>
			</xsl:call-template>
		</xsl:if>
		<!-- 2391 <SchoolArrangedAPDetail> node must not be present when <Phase> equals 'NS' -->
		<xsl:if test="APPlacementDetails/SchoolArrangedAPDetail
					  and $Phase = 'NS' ">
			<xsl:call-template name="Error">
				<xsl:with-param name="err_num" select="2391"/>
				<xsl:with-param name="data" select="$data"/>
			</xsl:call-template>
		</xsl:if>		
		<!-- 2392 - Where there is more than one <SchoolArrangedAPDetail> node where <LeavingDate> is blank, <APAttendancePattern> for each <SchoolArrangedAPDetail> must be equal to ‘PT’ -->
		<xsl:if test="../PupilOnRoll
					  and count(APPlacementDetails/SchoolArrangedAPDetail[string-length(LeavingDate) = 0]) &gt; 1
					  and APPlacementDetails/SchoolArrangedAPDetail/APAttendancePattern != 'PT'	
					  and string-length(APPlacementDetails/SchoolArrangedAPDetail/LeavingDate) = 0">
			<xsl:call-template name="Error">
				<xsl:with-param name="err_num" select="2392"/>
				<xsl:with-param name="data" select="$data"/>
			</xsl:call-template>
		</xsl:if>
		<!-- 2393 - The sum of all <APSessionsPerWeek> for  <SchoolArrangedAPDetail> nodes where <LeavingDate> is blank, and <APAttendancePattern> is equal to ‘PT’ must not be greater than ‘10’ -->
		<xsl:if test="sum(APPlacementDetails/SchoolArrangedAPDetail[string-length(LeavingDate) = 0 and APAttendancePattern = 'PT']/APSessionsPerWeek) &gt; 10">
			<xsl:call-template name="Error">
				<xsl:with-param name="err_num" select="2393"/>
				<xsl:with-param name="data" select="$data"/>
			</xsl:call-template>
		</xsl:if>			
		<!-- 3131 - Where pupil <EnrolStatus> equals ‘C’, ‘F or ‘O’, <APProvisionDetail> node must be present -->
		<xsl:if test="string-length(APPlacementDetails/APProvisionDetail) = 0
					  and (contains(' C F O ', concat(' ', PupilStatus/EnrolStatus, ' ') ) ) ">
			<xsl:call-template name="Error">
				<xsl:with-param name="err_num" select="3131"/>
				<xsl:with-param name="data" select="$data"/>
			</xsl:call-template>
		</xsl:if>
	</xsl:template>
	
	<!--Summer Half Term 2 Attendance-->
	<xsl:template name="SummerHalfTerm2AttendanceValidation">
		<!--This module is only evaluated in Autumn-->
		<xsl:variable name="ErrSex">
			<xsl:if test="PupilIdentifiers/Sex = 'M' ">Male</xsl:if>
			<xsl:if test="PupilIdentifiers/Sex = 'F' ">Female</xsl:if>
		</xsl:variable>
		<!--Attendance (and only attendance) calculations use the age from the previous year. -->
		<xsl:variable name="age" select="floor(($AgeCalcDateForAttendance - translate(PupilIdentifiers/DOB, '-','')) div 10000) "/>
		<xsl:variable name="data" select="concat('UPN: ', PupilIdentifiers/UPN, 
				   	          '. Name: ', PupilIdentifiers/Surname, ', ' , PupilIdentifiers/Forename, '.' ,  
				   	          ' Date of Birth: ', PupilIdentifiers/DOB, ', ',
						 $ErrSex ) "/>
		<xsl:variable name="EntryDateNum" select="translate( PupilStatus/EntryDate, '-', '') "/>
		<xsl:variable name="LeavingDateNum" select="translate( PupilStatus/LeavingDate, '-', '') "/>
		<xsl:choose>
			<xsl:when test="$Phase = 'NS' ">
				<!--AUT (NS) 5080 Summer half term 2 attendance not required for special school-->
				<xsl:if test="string-length(Attendance/SummerHalfTerm2Attendance) != 0 ">
					<xsl:call-template name="Error">
						<xsl:with-param name="err_num" select="5080"/>
						<xsl:with-param name="data" select="$data"/>
					</xsl:call-template>
				</xsl:if>
			</xsl:when>
			<xsl:otherwise>
				<xsl:choose>
					<xsl:when test="contains(' B 6 7 ', concat(' ', PupilStatus/Boarder, ' ') )
						or $age &lt; 4 
						or $age &gt; 15 ">
						<!--AUT 2571: Attendance age range or Boarder status out of range.-->
						<xsl:if test="string-length(Attendance/SummerHalfTerm2Attendance) != 0 ">
							<xsl:call-template name="Error">
								<xsl:with-param name="err_num" select="2571"/>
								<xsl:with-param name="data" select=" $data"/>
							</xsl:call-template>
						</xsl:if>
					</xsl:when>
					<xsl:otherwise>
						<xsl:if test="$EntryDateNum &lt;= $StartCurrentTerm	
							and (string-length(Attendance/SummerHalfTerm2Attendance) = 0 
								or string-length(Attendance/SummerHalfTerm2Attendance/SessionsPossible) = 0 ) ">
							<xsl:choose>
								<!--AUT 2575 For pupils on roll the attendance sessions possible is missing or invalid for the second half of the summer term.-->
								<xsl:when test="../PupilOnRoll">
									<xsl:call-template name="Error">
										<xsl:with-param name="err_num" select="2575"/>
										<xsl:with-param name="data" select="$data"/>
									</xsl:call-template>
								</xsl:when>
								<xsl:otherwise>
									<!--Pupils no longer on roll-->
									<!--AUT 2579 For pupils no longer on roll the attendance sessions possible is missing or invalid for the second half of the summer term.-->
									<xsl:if test="$LeavingDateNum &gt; $EntryDateRef
										and $LeavingDateNum &lt; $RefDate ">
										<xsl:call-template name="Error">
											<xsl:with-param name="err_num" select="2579"/>
											<xsl:with-param name="data" select="$data"/>
										</xsl:call-template>
									</xsl:if>
								</xsl:otherwise>
							</xsl:choose>
						</xsl:if>
						<!-- RFC1250 ADDED - IW 2023-08-22-->
						<!-- 2492 Attendance code X only used for non-compulsary school age children -->			
						<xsl:if test="Attendance/SummerHalfTerm2Attendance/SessionDetails/SessionDetail[AttendanceReason = 'X']
									  and (
										   (translate(PupilIdentifiers/DOB, '-', '') &lt; $v2491Min 
											   or translate(PupilIdentifiers/DOB, '-', '') &gt; $v2491Max )
										   and (translate(PupilIdentifiers/DOB, '-', '') &lt;= $y18max
											   or translate(PupilIdentifiers/DOB, '-', '') &gt;= $y15min ) 
										  )">
							<xsl:call-template name="Error">
								<xsl:with-param name="err_num" select="2492"/>
								<xsl:with-param name="data" select=" $data"/>
							</xsl:call-template>
						</xsl:if>
						<!-- RFC1183 NEW RULE ADDED - IW 2021-08-20-->	
						<!--2587Q Where a reason for attendance or absence is provided it must be unique-->
						<xsl:if test="count(Attendance/SummerHalfTerm2Attendance/SessionDetails/SessionDetail[AttendanceReason = '/']) &gt; 1
									or count(Attendance/SummerHalfTerm2Attendance/SessionDetails/SessionDetail[AttendanceReason = '\']) &gt; 1
									or count(Attendance/SummerHalfTerm2Attendance/SessionDetails/SessionDetail[AttendanceReason = 'B']) &gt; 1
									or count(Attendance/SummerHalfTerm2Attendance/SessionDetails/SessionDetail[AttendanceReason = 'D']) &gt; 1
									or count(Attendance/SummerHalfTerm2Attendance/SessionDetails/SessionDetail[AttendanceReason = 'J']) &gt; 1
									or count(Attendance/SummerHalfTerm2Attendance/SessionDetails/SessionDetail[AttendanceReason = 'L']) &gt; 1
									or count(Attendance/SummerHalfTerm2Attendance/SessionDetails/SessionDetail[AttendanceReason = 'P']) &gt; 1
									or count(Attendance/SummerHalfTerm2Attendance/SessionDetails/SessionDetail[AttendanceReason = 'V']) &gt; 1
									or count(Attendance/SummerHalfTerm2Attendance/SessionDetails/SessionDetail[AttendanceReason = 'W']) &gt; 1
									or count(Attendance/SummerHalfTerm2Attendance/SessionDetails/SessionDetail[AttendanceReason = 'X']) &gt; 1
									or count(Attendance/SummerHalfTerm2Attendance/SessionDetails/SessionDetail[AttendanceReason = 'I']) &gt; 1
									or count(Attendance/SummerHalfTerm2Attendance/SessionDetails/SessionDetail[AttendanceReason = 'M']) &gt; 1
									or count(Attendance/SummerHalfTerm2Attendance/SessionDetails/SessionDetail[AttendanceReason = 'R']) &gt; 1
									or count(Attendance/SummerHalfTerm2Attendance/SessionDetails/SessionDetail[AttendanceReason = 'S']) &gt; 1
									or count(Attendance/SummerHalfTerm2Attendance/SessionDetails/SessionDetail[AttendanceReason = 'T']) &gt; 1
									or count(Attendance/SummerHalfTerm2Attendance/SessionDetails/SessionDetail[AttendanceReason = 'H']) &gt; 1
									or count(Attendance/SummerHalfTerm2Attendance/SessionDetails/SessionDetail[AttendanceReason = 'E']) &gt; 1
									or count(Attendance/SummerHalfTerm2Attendance/SessionDetails/SessionDetail[AttendanceReason = 'C']) &gt; 1
									or count(Attendance/SummerHalfTerm2Attendance/SessionDetails/SessionDetail[AttendanceReason = 'G']) &gt; 1
									or count(Attendance/SummerHalfTerm2Attendance/SessionDetails/SessionDetail[AttendanceReason = 'U']) &gt; 1
									or count(Attendance/SummerHalfTerm2Attendance/SessionDetails/SessionDetail[AttendanceReason = 'O']) &gt; 1
									or count(Attendance/SummerHalfTerm2Attendance/SessionDetails/SessionDetail[AttendanceReason = 'N']) &gt; 1
									or count(Attendance/SummerHalfTerm2Attendance/SessionDetails/SessionDetail[AttendanceReason = 'Y']) &gt; 1
							">
							<xsl:call-template name="Error">
								<xsl:with-param name="err_num" select="2587"/>
								<xsl:with-param name="err_param1" select="AttendanceReason"/>
								<xsl:with-param name="data" select=" $data"/>
							</xsl:call-template>
						</xsl:if>	
						<!--AUT 2578 Attendance data for the 2nd half of the summer term is not required for this pupil as leaving date shows they left prior to this.-->
						<xsl:if test="../PupilNoLongerOnRoll
							and $LeavingDateNum &lt;= $EntryDateRef
							and string-length(Attendance/SummerHalfTerm2Attendance/SessionsPossible) != 0 ">
							<xsl:call-template name="Error">
								<xsl:with-param name="err_num" select="2578"/>
								<xsl:with-param name="data" select="$data"/>
							</xsl:call-template>
						</xsl:if>
						<!--AUT 2576 Zero attendance sessions possible recorded for pupil on roll in the second half of the summer term.-->
						<!--<xsl:if test="
								Attendance/SummerHalfTerm2Attendance/SessionsPossible = 0 
							and string-length(Attendance/SummerHalfTerm2Attendance/SessionsPossible) &gt;= 0 
							and ( sum(Attendance/SummerHalfTerm2Attendance/SessionDetails/SessionDetail[contains(' X Y D ', concat(' ', AttendanceReason, ' '))]/Sessions) = 0
								or (Attendance/SummerHalfTerm2Attendance/SessionsExceptional = 0
									and string-length(Attendance/SummerHalfTerm2Attendance/SessionsExceptional) &gt;= 0 )
								or (Attendance/SummerHalfTerm2Attendance/SessionsCoronavirus = 0
									and string-length(Attendance/SummerHalfTerm2Attendance/SessionsCoronavirus) &gt;= 0 ))
							and $DisabledValidation != 'true' ">	-->
						<xsl:if test="$EntryDateNum &lt;= $EntryDateRef	
								and ( (	string-length(Attendance/SummerHalfTerm2Attendance/SessionsPossible) &gt; 0 and count(Attendance/SummerHalfTerm2Attendance[SessionsPossible = 0]) = 1 )
									and ( (	(string-length(Attendance/SummerHalfTerm2Attendance/SessionDetails) > 0
											and string-length(Attendance/SummerHalfTerm2Attendance/SessionsExceptional) = 0
											and string-length(Attendance/SummerHalfTerm2Attendance/SessionsCoronavirus) = 0
											and	( count(Attendance/SummerHalfTerm2Attendance/SessionDetails/SessionDetail[AttendanceReason = 'X' and not(Sessions = '') and Sessions > 0] ) 
												+ count(Attendance/SummerHalfTerm2Attendance/SessionDetails/SessionDetail[AttendanceReason = 'Y' and not(Sessions = '') and Sessions > 0] ) 
												+ count(Attendance/SummerHalfTerm2Attendance/SessionDetails/SessionDetail[AttendanceReason = 'D' and not(Sessions = '') and Sessions > 0] )
												) = 0 
											)
										  )
										or (count(Attendance/SummerHalfTerm2Attendance/SessionDetails/SessionDetail[contains($ValidAttendanceAbsence, concat(' ', AttendanceReason, ' ') ) and not(Sessions = '') and Sessions > 0]) > 0 )
										or
										( (	(string-length(Attendance/SummerHalfTerm2Attendance/SessionDetails) = 0 
											 and (string-length(Attendance/SummerHalfTerm2Attendance/SessionsExceptional) = 0 
												  or count(Attendance/SummerHalfTerm2Attendance[SessionsExceptional = 0]) = 1)
											)
											and 
											(string-length(Attendance/SummerHalfTerm2Attendance/SessionDetails) = 0
											 and (string-length(Attendance/SummerHalfTerm2Attendance/SessionsCoronavirus) = 0 
												  or count(Attendance/SummerHalfTerm2Attendance[SessionsCoronavirus = 0]) = 1)
											)
										  )
										  or count(Attendance/SummerHalfTerm2Attendance[SessionsEducational > 0]) = 1
										)
									)
								) ">
							<xsl:call-template name="Error">
								<xsl:with-param name="err_num" select="2576"/>
								<xsl:with-param name="data" select=" $data"/>
							</xsl:call-template>
						</xsl:if>
						<!--AUT 2577 Pupil with double-reporting of termly absences in the second half of the summer term.-->
						<xsl:if test="(Attendance/SummerHalfTerm2Attendance/SessionsAuthorised &gt; 0  
								or Attendance/SummerHalfTerm2Attendance/SessionsUnauthorised &gt; 0
								or Attendance/SummerHalfTerm2Attendance/SessionsEducational &gt; 0
								or Attendance/SummerHalfTerm2Attendance/SessionsExceptional &gt; 0
								or Attendance/SummerHalfTerm2Attendance/SessionsCoronavirus &gt; 0) 
							 and sum(Attendance/SummerHalfTerm2Attendance/SessionDetails/SessionDetail/Sessions) &gt; 0 ">
							<xsl:call-template name="Error">
								<xsl:with-param name="err_num" select="2577"/>
								<xsl:with-param name="data" select=" $data"/>
							</xsl:call-template>
						</xsl:if>
						<!--AUT 2582 Total sessions missed must be less than or equal to sessions possible for the second half of the summer term.-->
						<!--first test no longer required from Aut 21 ACN 24/06/2021-->
						<!--<xsl:if test="not(Attendance/SummerHalfTerm2Attendance/SessionsUnauthorised) 
							or not(Attendance/SummerHalfTerm2Attendance/SessionsAuthorised)">
							<xsl:if test="sum(Attendance/SummerHalfTerm2Attendance/SessionDetails/SessionDetail/Sessions[../AttendanceReason != 'Y']) &gt; number(Attendance/SummerHalfTerm2Attendance/SessionsPossible) 
								and $DisabledValidation != 'true' ">
								<xsl:call-template name="Error">
									<xsl:with-param name="err_num" select="2582"/>
									<xsl:with-param name="data" select=" $data"/>
								</xsl:call-template>
							</xsl:if>
						</xsl:if>	-->
						<xsl:if test="not(Attendance/SummerHalfTerm2Attendance/SessionDetails/SessionDetail/Sessions) ">
							<xsl:if test="Attendance/SummerHalfTerm2Attendance/SessionsAuthorised + Attendance/SummerHalfTerm2Attendance/SessionsUnauthorised &gt; number(Attendance/SummerHalfTerm2Attendance/SessionsPossible) 
								or number(Attendance/SummerHalfTerm2Attendance/SessionsAuthorised) &gt; number(Attendance/SummerHalfTerm2Attendance/SessionsPossible) 
								or number(Attendance/SummerHalfTerm2Attendance/SessionsUnauthorised) &gt; number(Attendance/SummerHalfTerm2Attendance/SessionsPossible) ">
								<xsl:call-template name="Error">
									<xsl:with-param name="err_num" select="2582"/>
									<xsl:with-param name="data" select=" $data"/>
								</xsl:call-template>
							</xsl:if>
						</xsl:if>
						<xsl:for-each select="Attendance/SummerHalfTerm2Attendance/SessionDetails/SessionDetail">
							<!--2572 Attendance code is invalid for absence reported for the second half of the summer term.-->
							<xsl:if test="string-length(AttendanceReason) != 0 
								and not(contains($ValidAttendance, concat(' ', AttendanceReason, ' ') ) )  ">
								<xsl:call-template name="Error">
									<xsl:with-param name="err_num" select="2572"/>
									<xsl:with-param name="err_param1" select="AttendanceReason"/>
									<xsl:with-param name="data" select=" $data"/>
								</xsl:call-template>
							</xsl:if>
							<!--2573: Pupil reporting zero sessions missed with attendance code for the second half of the summer term. This should be provided and be greater than zero.-->
							<xsl:if test="string-length(AttendanceReason) != 0
								 and (string-length(Sessions) = 0 or Sessions &lt;= 0) ">
								<xsl:call-template name="Error">
									<xsl:with-param name="err_num" select="2573"/>
									<xsl:with-param name="err_param1" select="AttendanceReason"/>
									<xsl:with-param name="data" select=" $data"/>
								</xsl:call-template>
							</xsl:if>
							<!--2574 Pupil reporting number of sessions missed with no corresponding reason (attendance code) for the second half of the summer term.-->
							<xsl:if test="Sessions &gt; 0 
								and (string-length(AttendanceReason) = 0 
									or not(contains($ValidAttendance, concat(' ', AttendanceReason, ' ') ) ) ) ">
								<xsl:call-template name="Error">
									<xsl:with-param name="err_num" select="2574"/>
									<xsl:with-param name="err_param1" select="AttendanceReason"/>
									<xsl:with-param name="data" select=" $data"/>
								</xsl:call-template>
							</xsl:if>
						
							<!-- RFC1183 NEW RULE ADDED - IW 2021-08-20-->	
							<!--2588Q Pupil attendance for second half of summer term indicates they are suspended or permanently excluded but no suspension or permanent exclusion is recorded-->
							<xsl:if test=" AttendanceReason = 'E'
											and count(../../../../Exclusions/TermlyExclusion[translate(StartDate, '-', '') &gt;= $StartPrevAYSummerTerm
																							and translate(StartDate, '-', '') &lt;= $StartCurrentTerm ]) = 0
										">
								<xsl:call-template name="Error">
									<xsl:with-param name="err_num" select="2588"/>
									<xsl:with-param name="err_param1" select="AttendanceReason"/>
									<xsl:with-param name="data" select=" $data"/>
								</xsl:call-template>
							</xsl:if>
						</xsl:for-each>
						<xsl:variable name="sht2sessposs">
							<xsl:choose>
								<!--Strictly speaking, this shouldn't be necessary - the value shouldn't be present and therefore should miss the test below.-->
								<xsl:when test="$term='SPR' or $term = 'SUM' ">
									<xsl:value-of select="0"/>
								</xsl:when>
								<xsl:when test="number(Attendance/SummerHalfTerm2Attendance/SessionsPossible) = Attendance/SummerHalfTerm2Attendance/SessionsPossible">
									<xsl:value-of select="Attendance/SummerHalfTerm2Attendance/SessionsPossible"/>
								</xsl:when>
								<xsl:otherwise>
									<xsl:value-of select="0"/>
								</xsl:otherwise>
							</xsl:choose>
						</xsl:variable>
						<!--2586 -->
						<xsl:if test="not(Attendance/SummerHalfTerm2Attendance/SessionsUnauthorised) 
							or not(Attendance/SummerHalfTerm2Attendance/SessionsAuthorised)">
							<!--<xsl:if test="(sum(Attendance/SummerHalfTerm2Attendance/SessionDetails/SessionDetail/Sessions[contains($ValidAttendanceAbsence, concat(' ', ../AttendanceReason, ' ') ) ]) != $sht2sessposs 
											or (string-length(Attendance/SummerHalfTerm2Attendance/SessionDetails) = 0 and $sht2sessposs &gt; 0))
								and $DisabledValidation != 'true' ">-->  <!--IW AMENDED TO ALIGN WITH SQL VERSION - 2021-08-20-->
								<xsl:if test="(sum(Attendance/SummerHalfTerm2Attendance/SessionDetails/SessionDetail/Sessions[contains($ValidAttendanceAbsence, concat(' ', ../AttendanceReason, ' ') ) ]) != $sht2sessposs 
												and $sht2sessposs &gt; 0
												and string-length(Attendance/SummerHalfTerm2Attendance/SessionDetails) != 0
												) ">
								<xsl:call-template name="Error">
									<xsl:with-param name="err_num" select="2586"/>
									<xsl:with-param name="data" select=" $data"/>
								</xsl:call-template>
							</xsl:if>
						</xsl:if>
						<!-- RFC1183 NEW RULE ADDED - ACN 2021-09-06-->	
						<!--2589 Pupil has educational sessions reported but has zero possible sessions (2nd half term)-->
						<xsl:if test="sum(Attendance/SummerHalfTerm2Attendance/SessionsEducational) &gt; 0
										and sum(Attendance/SummerHalfTerm2Attendance/SessionsPossible) = 0
									">
							<xsl:call-template name="Error">
								<xsl:with-param name="err_num" select="2589"/>
								<xsl:with-param name="data" select=" $data"/>
							</xsl:call-template>
						</xsl:if>
					</xsl:otherwise>
				</xsl:choose>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>

	<xsl:template name="Post16LearningAimsValidation">
		<xsl:variable name="ErrSex">
			<xsl:if test="../../../PupilIdentifiers/Sex = 'M' ">Male</xsl:if>
			<xsl:if test="../../../PupilIdentifiers/Sex = 'F' ">Female</xsl:if>
		</xsl:variable>
		<xsl:variable name="data" select="concat('UPN: ', ../../../PupilIdentifiers/UPN, '. Name: ', ../../../PupilIdentifiers/Surname, ', ' , ../../../PupilIdentifiers/Forename, '.' , ' Date of Birth: ', ../../../PupilIdentifiers/DOB, ', ', $ErrSex ) "/>
		<xsl:variable name="age" select="floor(($AgeCalcDate - translate(../../../PupilIdentifiers/DOB, '-','')) div 10000)"/>
		<!--Used in 2710 following new program aims QNs-->
		<xsl:variable name="NewAims" select=" ' ZPROG001 ZWRKX001 ZWRKX002 ZWRKX003 ZTLOS005 ZTPR0001 ZTPR0002 ZTPR0003 ZTPR0004 ZTPR0005 ZTPR0006 ZTPR0007 ZTPR0008 ZTPR0009 ZTPR0010 ZTPR0011 ' " />
		<!--2816 Each learning aim must be accompanied by a programme aim of the same programme type -->
		<!-- removed for 21-22
		<xsl:if test="../../PupilOnRoll
			and $SixthForm = 'Y'
			and $Phase != 'SP' and $Phase !='MS'
			and ((count(LearningAim[ProgType = '01']) &gt; 0
					and count(../ProgrammeAims/ProgrammeAim[ProgType = '01']) = 0)
				or 
					(count(LearningAim[ProgType = '30']) &gt; 0
					and count(../ProgrammeAims/ProgrammeAim[ProgType = '30']) = 0)
				or 
					(count(LearningAim[ProgType = '31']) &gt; 0
					and count(../ProgrammeAims/ProgrammeAim[ProgType = '31']) = 0)
				)">
			<xsl:call-template name="Error">
				<xsl:with-param name="err_num" select="2816"/>
				<xsl:with-param name="data" select="$data"/>
			</xsl:call-template>
		</xsl:if>	-->
		<xsl:for-each select="LearningAim">
			<!--QNValue variable used in 2879-->
			<xsl:variable name="QNvalue" select=" ./QN "/>
			<xsl:variable name="ProgTypevalue" select=" ./ProgType "/>
			<xsl:variable name="QN" select="concat('. QN: ', ./QN) "/>
			<xsl:variable name="ThisLALSD" select="translate(LearningStartDate, '-','' )" />
			<xsl:variable name="ThisLALED" select="translate(LearningActualEndDate, '-','' )" />			
			<!--Learning Aims are only required for schools with 6th forms-->
			<xsl:choose>
				<xsl:when test="$SixthForm = 'Y' and contains( ' SS AT PR ', concat(' ', $Phase, ' ') ) ">
					<!--5570 - Where more than one <CoreAim> equal to 'true' exists, the <LearningStartDate> and <LearningActualEndDate> must not overlap -->
					<!--<xsl:if test="count(../LearningAim[contains($true, concat(' ', CoreAim, ' ') )
														and translate(LearningStartDate, '-', '') &lt; $ThisLALSD
															  and translate(LearningActualEndDate, '-', '') &gt; $ThisLALSD
															or translate(LearningStartDate, '-', '') &lt; $ThisLALED
																and translate(LearningActualEndDate, '-', '') &gt;= $ThisLALED] ) &gt; 1 
									and contains($true, concat(' ', CoreAim, ' ') )" >
						<xsl:call-template name="Error">
							<xsl:with-param name="err_num" select="5570"/>
							<xsl:with-param name="data" select="$data" />
						</xsl:call-template>
					</xsl:if>			-->	
					<!--2700 Qualification number is missing-->
					<xsl:if test="string-length(QN) = 0">
						<xsl:call-template name="Error">
							<xsl:with-param name="err_num" select="2700"/>
							<xsl:with-param name="data" select="concat($data, $QN) "/>
						</xsl:call-template>
					</xsl:if>
					<!--2701 A learning aim withdrawal reason is only required where the learner has withdrawn and the learning aim status is recorded as '3'-->
					<xsl:if test="string-length(LearningAimWithdrawalReason) != 0 
						and string-length(LearningAimStatus) != 0 
						and LearningAimStatus != 3">
						<xsl:call-template name="Error">
							<xsl:with-param name="err_num" select="2701"/>
							<xsl:with-param name="data" select="$data"/>
						</xsl:call-template>
					</xsl:if>
					<!--2710 QN must be correctly formatted-->
					<xsl:if test="string-length(QN) != 0
						and not(substring(QN, 1, 5) = 'ZTLOS')
						and not(contains( $NewAims, concat(' ', QN, ' ') ) ) 
						and ( (not(translate(substring(QN, 1, 1), $alphabet, $all_As) = 'A') 
										and not(translate(substring(QN, 1, 1), $digits, $all_9s) = '9') 
										and not(contains(' # ', concat( ' ', substring(QN, 1, 1), ' ') ) ) )
									or (not(translate(substring(QN, 8, 1), $alphabet, $all_As) = 'A') 
										and not(translate(substring(QN, 8, 1), $digits, $all_9s) = '9') )
									or not(translate(substring(QN, 2, 6), $digits, $all_9s ) = '999999') 
									or string-length(QN) != 8
								) ">
						<xsl:call-template name="Error">
							<xsl:with-param name="err_num" select="2710"/>
							<xsl:with-param name="data" select="concat($data, $QN) "/>
						</xsl:call-template>
					</xsl:if>
					<!--2722 Subject classification code is missing-->
					<xsl:if test="string-length(SCC) = 0 ">
						<xsl:call-template name="Error">
							<xsl:with-param name="err_num" select="2722"/>
							<xsl:with-param name="data" select="concat($data, $QN) "/>
						</xsl:call-template>
					</xsl:if>
					<!--2730 Learning start date present and valid-->
					<xsl:choose>
						<!--check for presence-->
						<xsl:when test="string-length(LearningStartDate) = 0 ">
							<xsl:call-template name="Error">
								<xsl:with-param name="err_num" select="2730"/>
								<xsl:with-param name="data" select="concat($data, $QN) "/>
							</xsl:call-template>
						</xsl:when>
						<!--check for validity-->
						<xsl:otherwise>
							<xsl:call-template name="ValidateDate">
								<xsl:with-param name="vdate" select="LearningStartDate"/>
								<xsl:with-param name="err_no" select="2730"/>
								<xsl:with-param name="err_data" select="concat($data, $QN) "/>
							</xsl:call-template>
						</xsl:otherwise>
					</xsl:choose>
					<!--2735 Learning start date is after the census date-->
					<xsl:if test="translate(LearningStartDate, '-', '') &gt; $RefDate
						and ProgType != '31' ">
						<xsl:call-template name="Error">
							<xsl:with-param name="err_num" select="2735"/>
							<xsl:with-param name="data" select="concat($data, $QN) "/>
						</xsl:call-template>
					</xsl:if>
					<!--2740 Please check: Learning start date seems too early-->
					<xsl:if test="translate(LearningStartDate, '-', '') &lt;= ($MinLearningAimStartDate)">
						<xsl:call-template name="Error">
							<xsl:with-param name="err_num" select="2740"/>
							<xsl:with-param name="err_param1" select="LearningStartDate"/>
							<xsl:with-param name="data" select="concat($data, $QN) "/>
						</xsl:call-template>
					</xsl:if>
					<!--2750 Learning Planned End Date must be present and a valid date-->
					<xsl:choose>
						<!--check for presence-->
						<xsl:when test="string-length(LearningPlannedEndDate) = 0 ">
							<xsl:call-template name="Error">
								<xsl:with-param name="err_num" select="2750"/>
								<xsl:with-param name="data" select="concat($data, $QN) "/>
							</xsl:call-template>
						</xsl:when>
						<!--check for validity-->
						<xsl:otherwise>
							<xsl:call-template name="ValidateDate">
								<xsl:with-param name="vdate" select="LearningPlannedEndDate"/>
								<xsl:with-param name="err_no" select="2750"/>
								<xsl:with-param name="err_data" select="concat($data, $QN) "/>
							</xsl:call-template>
						</xsl:otherwise>
					</xsl:choose>
					<!--2760 Learning aim - the planned end date must be on or after the start date-->
					<xsl:if test="translate(LearningPlannedEndDate, '-', '') &lt; translate(LearningStartDate, '-', '')">
						<xsl:call-template name="Error">
							<xsl:with-param name="err_num" select="2760"/>
							<xsl:with-param name="data" select="concat($data, $QN) "/>
						</xsl:call-template>
					</xsl:if>
					<!--2761 Learning aim - the actual end date must be on or after the start date-->
					<xsl:if test="translate(LearningActualEndDate, '-', '') &lt; translate(LearningStartDate, '-', '')">
						<xsl:call-template name="Error">
							<xsl:with-param name="err_num" select="2761"/>
							<xsl:with-param name="data" select="concat($data, $QN) "/>
						</xsl:call-template>
					</xsl:if>
					<!--2765 Learning planned end date is more than 5 years after census date-->
					<xsl:if test="translate(LearningPlannedEndDate, '-', '') &gt; $MaxLearningAimEndDate">
						<xsl:call-template name="Error">
							<xsl:with-param name="err_num" select="2765"/>
							<xsl:with-param name="data" select="concat($data, $QN) "/>
						</xsl:call-template>
					</xsl:if>
					<!--2766 Learning planned end date must be on or before the 31 July of the academic year the learner is due to finish-->
					<xsl:if test="substring(LearningPlannedEndDate, 6, 2) = 08">
						<xsl:call-template name="Error">
							<xsl:with-param name="err_num" select="2766"/>
							<xsl:with-param name="data" select="concat($data, $QN) "/>
						</xsl:call-template>
					</xsl:if>
					<!--2767 Please check the learning planned end date as only short courses would be expected to have a planned end date in September-->
					<xsl:if test="substring(LearningPlannedEndDate, 6, 2) = 09">
						<xsl:call-template name="Error">
							<xsl:with-param name="err_num" select="2767"/>
							<xsl:with-param name="data" select="concat($data, $QN) "/>
						</xsl:call-template>
					</xsl:if>
					<!--2770 Learning aim end date is not a valid date-->
					<xsl:if test="string-length(LearningActualEndDate) != 0 ">
						<xsl:call-template name="ValidateDate">
							<xsl:with-param name="vdate" select="LearningActualEndDate"/>
							<xsl:with-param name="err_no" select="2770"/>
							<xsl:with-param name="err_data" select="concat($data, $QN) "/>
						</xsl:call-template>
					</xsl:if>
					<!--2785 Learning aim withdrawal reason is missing or invalid value-->
					<xsl:if test="LearningAimStatus = '3' 
						and (string-length(LearningAimWithdrawalReason) = 0 
								or not(contains( ' 1 2 3 4 44 45 97 98 ', concat( ' ', LearningAimWithdrawalReason, ' ' ) ) ) )">
						<xsl:call-template name="Error">
							<xsl:with-param name="err_num" select="2785"/>
							<xsl:with-param name="data" select="concat($data, LearningAimWithdrawalReason) "/>
						</xsl:call-template>
					</xsl:if>
					<!--2790 Learning aim actual end date must be provided where the learning aim status is 2 (completed), 3 (withdrawn) or 4 (transferred)-->
					<xsl:if test="contains(' 2 3 4 ', concat(' ', LearningAimStatus, ' ') ) 
						and string-length(LearningActualEndDate) = 0 ">
						<xsl:call-template name="Error">
							<xsl:with-param name="err_num" select="2790"/>
							<xsl:with-param name="data" select="concat($data, $QN) "/>
						</xsl:call-template>
					</xsl:if>
					<!--2805 Learning aim actual end date must be the same as, or earlier than the census date-->
					<xsl:if test="string-length(LearningActualEndDate) != 0 
						and translate(LearningActualEndDate, '-', '') &gt; $RefDate">
						<xsl:call-template name="Error">
							<xsl:with-param name="err_num" select="2805"/>
							<xsl:with-param name="data" select="concat($data, $QN) "/>
						</xsl:call-template>
					</xsl:if>
					<!--2815 Programme type is missing or invalid-->
					<xsl:if test="not(contains(' 01 30 31 ', concat(' ', ProgType, ' ') ) )
								or ../../ProgType != $ProgTypevalue " >
						<xsl:call-template name="Error">
							<xsl:with-param name="err_num" select="2815"/>
							<xsl:with-param name="data" select="concat($data, $QN) "/>
						</xsl:call-template>
					</xsl:if>
					<!--2820 Completion Status must be 1 2 3 4-->
					<xsl:if test="not(contains(' 1 2 3 4 ', concat(' ', LearningAimStatus, ' ') ) )">
						<xsl:call-template name="Error">
							<xsl:with-param name="err_num" select="2820"/>
							<xsl:with-param name="data" select="concat($data, $QN) "/>
						</xsl:call-template>
					</xsl:if>
					<!--5165 <Traineeship> (199585) must be present and equal to true, false, 1 or 0 added for Autumn 2016 IK 2016-06-10-->
					<xsl:if test="(string-length(Traineeship) = 0 
						or not(contains($boolean, concat(' ', Traineeship, ' ') ) ) )
						and $ThisLALSD &lt; $Aug1stAcadYrStart ">
						<xsl:call-template name="Error">
							<xsl:with-param name="err_num" select="5165"/>
							<xsl:with-param name="data" select="concat($data, $QN) "/>
						</xsl:call-template>
					</xsl:if>
					<!--5166 Traineeship can not be true for a T Level or T Level transition programme-->
					<xsl:if test="(contains($true, concat(' ', Traineeship, ' ') )
						and contains(' 30 31 ', concat(' ', ProgType, ' ') ) )
						and $ThisLALSD &lt;= $Aug1stAcadYrStart ">
						<xsl:call-template name="Error">
							<xsl:with-param name="err_num" select="5166"/>
							<xsl:with-param name="data" select="concat($data, $QN) "/>
						</xsl:call-template>
					</xsl:if>
					<!--2759 <Traineeship> must not be present where <LearningStartDate> is after 2023-07-31 -->
					<xsl:if test="string-length(Traineeship) != 0 
								  and  translate(LearningStartDate, '-', '') &gt;= $Aug1stAcadYrStart ">
						<xsl:call-template name="Error">
							<xsl:with-param name="err_num" select="2759"/>
							<xsl:with-param name="data" select="concat($data, $QN) "/>
						</xsl:call-template>
					</xsl:if>
					<!--END OF LEARNING AIMS VALIDATIONS APPLICABLE TO BOTH ON AND OFF ROLL-->
					<xsl:choose>
						<xsl:when test="../../../../../PupilOnRoll">
							<!--2780 Learning aim actual end date has incorrectly been provided for a learning aim which is continuing ie for which learning aim status = 1-->
							<xsl:if test="LearningAimStatus = 1 
								and string-length(LearningActualEndDate) != 0">
								<xsl:call-template name="Error">
									<xsl:with-param name="err_num" select="2780"/>
									<xsl:with-param name="data" select="concat($data, $QN) "/>
								</xsl:call-template>
							</xsl:if>
						</xsl:when>
						<!--END ON-ROLL SPECIFIC RULES-->
						<xsl:when test="../../../../../PupilNoLongerOnRoll">
							<!--2795 For pupils no longer on roll the learning aim status must be 2 (completed), 3 (withdrawn) or 4 (transferred)-->
							<xsl:if test="not(contains(' 2 3 4 ', concat(' ', LearningAimStatus, ' ') ) )">
								<xsl:call-template name="Error">
									<xsl:with-param name="err_num" select="2795"/>
									<xsl:with-param name="data" select="concat($data, $QN) "/>
								</xsl:call-template>
							</xsl:if>
							<!--2810 Please check: Learning aim actual end date should not be later than the pupil&apos;s leaving date for pupils no longer on roll-->
							<xsl:if test="string-length(LearningActualEndDate) !=0 
								and translate(LearningActualEndDate, '-', '') &gt; translate(../../../../PupilStatus/LeavingDate, '-', '') ">
								<xsl:call-template name="Error">
									<xsl:with-param name="err_num" select="2810"/>
									<xsl:with-param name="data" select="concat($data, $QN) "/>
								</xsl:call-template>
							</xsl:if>
						</xsl:when>
						<!--END OFF-ROLL SPECIFIC RULES-->
					</xsl:choose>
					<!--2878 Where <QN> is equal to one of 'ZWRKX001', 'ZWRKX002' or 'ZWRKX003' Workplace entity items <WPStartDate>, <WPEndDate>, <WPHours>,  <WPMode> and must be provided-->
					<!--QNValue variable defined at start of learningaim section above-->
					<!--See below for another version of this rule that actually checks each field.  That will only trigger when record exists, which this bit is checking for.-->
					<xsl:if test="contains(' ZWRKX001 ZWRKX002 ZWRKX003 ', concat(' ', $QNvalue, ' ') ) 
									and string-length(WorkplaceEntities) = 0 " >
						<xsl:call-template name="Error">
							<xsl:with-param name="err_num" select="2878" />
							<xsl:with-param name="data" select="$data" />
						</xsl:call-template>
					</xsl:if>
					<xsl:for-each select="WorkplaceEntities/WorkplaceEntity">
						<!--2755 If present, <WPHours> must be greater than 0 and equal to or less than 1000-->
						<xsl:if test="string-length(WPHours) != 0 
										and (WPHours &lt;= 0 or WPHours &gt; 1000) ">
							<xsl:call-template name="Error">
								<xsl:with-param name="err_num" select="2755"/>
								<xsl:with-param name="data" select="$data"/>
							</xsl:call-template>
						</xsl:if>
						<!--2756 Where Workplace entity node is present <WPStartDate>, <WPEndDate>, <WPMode>, <WPHours> and <WPEmployerID> must be present-->
						<!--removed for 21-22
						<xsl:if test="string-length(WPStartDate) = 0
											or string-length(WPEndDate) = 0
											or string-length(WPMode) = 0
											or string-length(WPHours) = 0 
											or string-length(WPEmployerID) = 0">
							<xsl:call-template name="Error">
								<xsl:with-param name="err_num" select="2756"/>
								<xsl:with-param name="data" select="$data"/>
							</xsl:call-template>
						</xsl:if> -->
						<!--2757 <WPStartDate> must be on or after <LearningStartDate>  for the associated Learning Aims record -->
						<xsl:if test="translate(WPStartDate, '-', '') &lt; translate(../../LearningStartDate, '-', '') ">
							<xsl:call-template name="Error">
								<xsl:with-param name="err_num" select="2757"/>
								<xsl:with-param name="data" select="$data"/>
							</xsl:call-template>
						</xsl:if>
						<!--2758 <WPEndDate> must be on or before <LearningPlannedEndDate> for the associated Learning Aims record -->
						<xsl:if test="translate(WPEndDate, '-', '') &gt; translate(../../LearningPlannedEndDate, '-', '') ">
							<xsl:call-template name="Error">
								<xsl:with-param name="err_num" select="2758"/>
								<xsl:with-param name="data" select="$data"/>
							</xsl:call-template>
						</xsl:if>
						<!--2874 If present, <WPStartDate> must be a valid date and after 31 July of the current year-->
						<xsl:if test="string-length(WPStartDate) != 0 ">
							<xsl:call-template name="ValidateDate">
								<xsl:with-param name="vdate" select="WPStartDate"/>
								<xsl:with-param name="err_no" select="2874"/>
								<xsl:with-param name="err_data" select="$data"/>
							</xsl:call-template>
						</xsl:if>
						<xsl:if test="translate(WPStartDate, '-', '') &lt;= 20200731 ">	
							<xsl:call-template name="Error">
								<xsl:with-param name="err_num" select="2874"/>
								<xsl:with-param name="data" select="$data"/>
							</xsl:call-template>
						</xsl:if>
						<!--2875 If present, <WPStartDate> must be a valid date-->
						<xsl:if test="string-length(WPEndDate) != 0 ">
							<xsl:call-template name="ValidateDate">
								<xsl:with-param name="vdate" select="WPEndDate"/>
								<xsl:with-param name="err_no" select="2875"/>
								<xsl:with-param name="err_data" select="$data" />
							</xsl:call-template>
						</xsl:if>
						<!--2876 If present, <WPMode> must be valid-->
						<xsl:if test="string-length(WPMode) != 0 
							and not(contains(' 1 2 ', concat(' ', WPMode, ' ') ) ) ">
							<xsl:call-template name="Error">
								<xsl:with-param name="err_num" select="2876"/>
								<xsl:with-param name="data" select="$data" />
							</xsl:call-template>
						</xsl:if>
						<!--2877 WPEmployerID must be correctly formatted-->
						<xsl:if test="string-length(WPEmployerID) != 0 ">
							<xsl:if test="string-length(WPEmployerID) != 9
								or (translate(WPEmployerID, $digits, $all_9s) )!= '999999999' ">
								<xsl:call-template name="Error">
									<xsl:with-param name="err_num" select="2877"/>
									<xsl:with-param name="data" select="$data" />
								</xsl:call-template>
							</xsl:if>
						</xsl:if>						
						<!--2878 Where <QN> is equal to one of 'ZWRKX001', 'ZWRKX002' or 'ZWRKX003' Workplace entity items <WPStartDate>, <WPEndDate>, <WPHours>,  <WPMode> must be provided-->
						<!--QNValue variable defined at start of learningaim section above-->
						<!--See above for 2nd version of this rule that just checks for existence of a WP record.  Will only get here when that record exists.-->
						<xsl:if test="contains(' ZWRKX001 ZWRKX002 ZWRKX003 ', concat(' ', $QNvalue, ' ') ) 
							and (string-length(../WorkplaceEntity) = 0
								or string-length(WPStartDate) = 0 
								or string-length(WPEndDate) = 0 
								or string-length(WPMode) = 0 
								or string-length(WPHours) = 0 ) " >
							<xsl:call-template name="Error">
								<xsl:with-param name="err_num" select="2878" />
								<xsl:with-param name="data" select="$data" />
							</xsl:call-template>
						</xsl:if>
						<!--2879 Workplace entity items <WPStartDate>, <WPEndDate>, <WPMode>, <WPHours> and <WPEmployerID> must not be provided where <QN> is not equal to one of 'ZWRKX001', 'ZWRKX002' or 'ZWRKX003'-->
						<!--QNValue variable defined at start of learningaim section above-->
						<xsl:if test="not(contains(' ZWRKX001 ZWRKX002 ZWRKX003 ', concat(' ', $QNvalue, ' ') ) )
							and (string-length(WPStartDate) != 0 
								or string-length(WPEndDate) != 0 
								or string-length(WPMode) != 0 
								or string-length(WPHours) != 0 
								or string-length(WPEmployerID) != 0 ) " >
							<xsl:call-template name="Error">
								<xsl:with-param name="err_num" select="2879" />
								<xsl:with-param name="data" select="$data" />
							</xsl:call-template>
						</xsl:if>
					</xsl:for-each>
				</xsl:when>
			</xsl:choose>
		</xsl:for-each>
	</xsl:template>

	<xsl:template name="Post16ProgrammeAimsValidation">
		<xsl:variable name="ErrSex">
			<xsl:if test="../PupilIdentifiers/Sex = 'M' ">Male</xsl:if>
			<xsl:if test="../PupilIdentifiers/Sex = 'F' ">Female</xsl:if>
		</xsl:variable>
		<xsl:variable name="data" select="concat('UPN: ', ../PupilIdentifiers/UPN, '. Name: ', ../PupilIdentifiers/Surname, ', ' , ../PupilIdentifiers/Forename, '.' , ' Date of Birth: ', ../PupilIdentifiers/DOB, ', ', $ErrSex ) "/>
		<xsl:variable name="age" select="floor(($AgeCalcDate - translate(../PupilIdentifiers/DOB, '-','')) div 10000)"/>
		<!--old version removed and replaced by version lower down - ACN 23/06/2021-->
		<!--2903 A programme aim must be accompanied by at least one learning aim of the same programme type-->
		<!-- xsl:if test="(count(../LearningAims/LearningAim[ProgType = '01']) = 0
							and count(ProgrammeAim[ProgType = '01']) &gt; 0)
						or 
							(count(../LearningAims/LearningAim[ProgType = '30']) = 0
							and count(ProgrammeAim[ProgType = '30']) &gt; 0)
						or 
							(count(../LearningAims/LearningAim[ProgType = '31']) = 0
							and count(ProgrammeAim[ProgType = '31']) &gt; 0) ">
			<xsl:call-template name="Error">
				<xsl:with-param name="err_num" select="2903"/>
				<xsl:with-param name="data" select="$data"/>
			</xsl:call-template>
		</xsl:if>	-->
		<xsl:for-each select="ProgrammeAim">
			<!--QN codes added to error message for QN level errors and queries-->
			<xsl:variable name="QN" select="concat('. QN: ', ./QN) "/>
			<xsl:variable name="ThisLSD" select="translate(ProgrammeStartDate, '-','' )" />
			<xsl:variable name="ThisLED" select="translate(ProgrammeActualEndDate, '-','' )" />
			<xsl:variable name="ThisPlannedED" select="translate(ProgrammePlannedEndDate, '-','' )" />
			<xsl:variable name="ThisPT" select="ProgType" />
			<!--2705 No Sixth form pupils, therefore Programme Aims must not be present-->
			<xsl:if test="$SixthForm = 'N' ">
				<xsl:call-template name="Error">
					<xsl:with-param name="err_num" select="2705"/>
					<xsl:with-param name="data" select="concat($data, $QN) "/>
				</xsl:call-template>
			</xsl:if>		
			<!--5106 Programme aims are only required for schools with a phase of SS, AT or PR-->	<!-- CHECK REMOVED - IW 2021-08-20 -->
<!--			<xsl:if test="not(contains(' SS PR AT ', concat(' ', $Phase , ' ' ) ) ) ">
				<xsl:call-template name="Error">
					<xsl:with-param name="err_num" select="5106"/>
					<xsl:with-param name="data" select="$data"/>
				</xsl:call-template>
			</xsl:if>	-->			
			<!--2903 Each programme aim must contain at least one learning aim -->
			<xsl:if test="count(LearningAims/LearningAim) = 0 ">
				<xsl:call-template name="Error">
					<xsl:with-param name="err_num" select="2903"/>
					<xsl:with-param name="data" select="$data"/>
				</xsl:call-template>
			</xsl:if>
			<!--2885 <QN> must be present where there is a programme aim record and equal to 'ZPROG001'-->
			<xsl:if test="string-length(QN) = 0 
				or QN != 'ZPROG001' ">
				<xsl:call-template name="Error">
					<xsl:with-param name="err_num" select="2885"/>
					<xsl:with-param name="data" select="$data"/>
				</xsl:call-template>
			</xsl:if>
			<!--2886 Where <ProgrammeAimStatus> does not equal '3',  <ProgrammeAimWithdrawalReason> must not be present-->
			<xsl:if test="string-length(ProgrammeAimWithdrawalReason) != 0 
				and (string-length(ProgrammeAimStatus) = 0 
					or ProgrammeAimStatus != 3) ">
				<xsl:call-template name="Error">
					<xsl:with-param name="err_num" select="2886"/>
					<xsl:with-param name="data" select="$data"/>
				</xsl:call-template>
			</xsl:if>
			<!--2887 <ProgrammeStartDate> must be present and be a valid date-->
			<xsl:choose>
				<xsl:when test="string-length(ProgrammeStartDate) = 0 ">
					<xsl:call-template name="Error">
						<xsl:with-param name="err_num" select="2887"/>
						<xsl:with-param name="data" select="concat($data, $QN) "/>
					</xsl:call-template>
				</xsl:when>
				<!--check for validity-->
				<xsl:otherwise>
					<xsl:call-template name="ValidateDate">
						<xsl:with-param name="vdate" select="ProgrammeStartDate"/>
						<xsl:with-param name="err_no" select="2887"/>
						<xsl:with-param name="err_data" select="concat($data, $QN) "/>
					</xsl:call-template>
				</xsl:otherwise>				
			</xsl:choose>
			<!--2888 <ProgrammePlannedEndDate> must be present and a valid date-->
			<xsl:choose>
				<xsl:when test="string-length(ProgrammePlannedEndDate) = 0 ">
					<xsl:call-template name="Error">
						<xsl:with-param name="err_num" select="2888"/>
						<xsl:with-param name="data" select="concat($data, $QN) "/>
					</xsl:call-template>			
				</xsl:when>
				<!--check for validity-->
				<xsl:otherwise>
					<xsl:call-template name="ValidateDate">
						<xsl:with-param name="vdate" select="ProgrammePlannedEndDate"/>
						<xsl:with-param name="err_no" select="2888"/>
						<xsl:with-param name="err_data" select="concat($data, $QN) "/>
					</xsl:call-template>
				</xsl:otherwise>
			</xsl:choose>
			<!--2889 <ProgrammePlannedEndDate> must be equal to or greater than <LearningStartDate> -->
			<xsl:if test="translate(ProgrammePlannedEndDate, '-', '') &lt; translate(ProgrammeStartDate, '-', '')">
				<xsl:call-template name="Error">
					<xsl:with-param name="err_num" select="2889"/>
					<xsl:with-param name="data" select="$data"/>
				</xsl:call-template>
			</xsl:if>
			<!--2890 <ProgrammeActualEndDate> must be equal to or greater than <LearningStartDate> -->
			<xsl:if test="translate(ProgrammeActualEndDate, '-', '') &lt; translate(ProgrammeStartDate, '-', '')">
				<xsl:call-template name="Error">
					<xsl:with-param name="err_num" select="2890"/>
					<xsl:with-param name="data" select="$data"/>
				</xsl:call-template>
			</xsl:if>
			<!--2891 <ProgrammePlannedEndDate> must not be greater than (<ReferenceDate> plus 5 years)-->
			<xsl:if test="translate(ProgrammePlannedEndDate, '-', '') &gt; $MaxLearningAimEndDate">
				<xsl:call-template name="Error">
					<xsl:with-param name="err_num" select="2891"/>
					<xsl:with-param name="data" select="$data"/>
				</xsl:call-template>
			</xsl:if>
			<!--2892 <ProgrammePlannedEndDate> must not fall in the month of August-->
			<xsl:if test="substring(ProgrammePlannedEndDate, 6, 2) = 08">
				<xsl:call-template name="Error">
					<xsl:with-param name="err_num" select="2892"/>
					<xsl:with-param name="data" select="$data"/>
				</xsl:call-template>
			</xsl:if>
			<!--2893 Programme aim end date is not a valid date-->
			<xsl:if test="string-length(ProgrammeActualEndDate) != 0 ">
				<xsl:call-template name="ValidateDate">
					<xsl:with-param name="vdate" select="ProgrammeActualEndDate"/>
					<xsl:with-param name="err_no" select="2893"/>
					<xsl:with-param name="err_data" select="$data"/>
				</xsl:call-template>
			</xsl:if>
			<!--2894 Programme aim actual end date must be provided where the Programme aim status is 2 (completed), 3 (withdrawn) or 4 (transferred)-->
			<xsl:if test="ProgrammeAimStatus = '1' 
				and string-length(ProgrammeActualEndDate) != 0 ">
				<xsl:call-template name="Error">
					<xsl:with-param name="err_num" select="2894"/>
					<xsl:with-param name="data" select="$data"/>
				</xsl:call-template>
			</xsl:if>
			<!--2895 Programme aim withdrawal reason is missing or invalid value-->
			<xsl:if test="ProgrammeAimStatus = '3' 
				and (string-length(ProgrammeAimWithdrawalReason) = 0 
						or not(contains( ' 1 2 3 4 44 45 97 98 ', concat( ' ', ProgrammeAimWithdrawalReason, ' ' ) ) ) )">
				<xsl:call-template name="Error">
					<xsl:with-param name="err_num" select="2895"/>
					<xsl:with-param name="data" select="concat($data, ProgrammeAimWithdrawalReason) "/>
				</xsl:call-template>
			</xsl:if>
			<!--2896 Programme aim actual end date must be provided where the Programme aim status is 2 (completed), 3 (withdrawn) or 4 (transferred)-->
			<xsl:if test="contains(' 2 3 4 ', concat(' ', ProgrammeAimStatus, ' ') ) 
				and string-length(ProgrammeActualEndDate) = 0 ">
				<xsl:call-template name="Error">
					<xsl:with-param name="err_num" select="2896"/>
					<xsl:with-param name="data" select="$data"/>
				</xsl:call-template>
			</xsl:if>
			<!--2897 If present, <ProgrammeActualEndDate> must be less than or equal to <ReferenceDate> -->
			<xsl:if test="string-length(ProgrammeActualEndDate) != 0 
				and translate(ProgrammeActualEndDate, '-', '') &gt; $RefDate">
				<xsl:call-template name="Error">
					<xsl:with-param name="err_num" select="2897"/>
					<xsl:with-param name="data" select="$data"/>
				</xsl:call-template>
			</xsl:if>
			<!--2898 Completion Status must be 1 2 3 4-->
			<xsl:if test="not(contains(' 1 2 3 4 ', concat(' ', ProgrammeAimStatus, ' ') ) )">
				<xsl:call-template name="Error">
					<xsl:with-param name="err_num" select="2898"/>
					<xsl:with-param name="data" select="$data"/>
				</xsl:call-template>
			</xsl:if>
			<!--2899 <Traineeship> must be present and equal to 'true', 'false', '1' or '0'-->
			<xsl:if test="(not(contains($boolean, concat(' ', Traineeship, ' ') ) )
							or string-length(Traineeship) = 0) 
						and translate(ProgrammeStartDate, '-', '') &lt; $Aug1stAcadYrStart " >
				<xsl:call-template name="Error">
					<xsl:with-param name="err_num" select="2899"/>
					<xsl:with-param name="data" select="$data"/>
				</xsl:call-template>
			</xsl:if>
			<!--2908 <Traineeship> must not equal 'true' or '1' where <ProgType> is equal to '30' or '31'-->
			<xsl:if test="contains($true, concat(' ', Traineeship, ' ') )
						  and contains(' 30 31 ', concat(' ', ProgType, ' ') )
						  and translate(ProgrammeStartDate, '-', '') &lt; $Aug1stAcadYrStart " >
				<xsl:call-template name="Error">
					<xsl:with-param name="err_num" select="2908"/>
					<xsl:with-param name="data" select="$data"/>
				</xsl:call-template>
			</xsl:if>
			<!--2902 <ProgType> must be present and a valid value-->
			<xsl:if test="not(contains(' 01 30 31 ', concat(' ', ProgType, ' ') ) )" >
				<xsl:call-template name="Error">
					<xsl:with-param name="err_num" select="2902"/>
					<xsl:with-param name="data" select="$data" />
				</xsl:call-template>
			</xsl:if>
			<!--2904 Program Types must not overlap-->
			<!--SS: This will come out multiple times, I don't see an method to do this across the program type block-->
			<!--ACN: Removed 2904 as can't get it to work correctly in XSLT-->
			<!--<xsl:if test="count(../ProgrammeAim[translate(ProgrammeStartDate, '-', '') &lt; $ThisLSD
				and translate(ProgrammeActualEndDate, '-', '') &gt; $ThisLSD
					or translate(ProgrammeStartDate, '-', '') &lt; $ThisLED
				and translate(ProgrammeActualEndDate, '-', '') &gt; $ThisLED] ) &gt; 0 " >
				<xsl:call-template name="Error">
					<xsl:with-param name="err_num" select="2904"/>
					<xsl:with-param name="data" select="$data" />
				</xsl:call-template>
			</xsl:if>-->
			<!--2906 Please check: Programme aim start date seems too early-->
			<xsl:if test="translate(ProgrammeStartDate, '-', '') &lt;= ($MinLearningAimStartDate)">
				<xsl:call-template name="Error">
					<xsl:with-param name="err_num" select="2906"/>
					<xsl:with-param name="err_param1" select="ProgrammeStartDate"/>
					<xsl:with-param name="data" select="concat($data, $QN) "/>
				</xsl:call-template>
			</xsl:if>
			<!--2907 The latest <LearningPlannedEndDate> of all <LearningAim> records must be equal to the <ProgrammePlannedEndDate> of the parent <ProgrammeAim> -->
			<!-- Unable to test for "latest" learning aim as can't do that in XSLT.  This just looks for at least one record that matches the value -->
			<!-- Rule made "Collect Only" on RFC 1189 21/09/2021 -->
			<!--<xsl:if test="count(LearningAims/LearningAim[(translate(LearningPlannedEndDate, '-', '') = $ThisPlannedED )]) = 0 " >
				<xsl:call-template name="Error">
					<xsl:with-param name="err_num" select="2907"/>
					<xsl:with-param name="data" select="$data" />
				</xsl:call-template>
			</xsl:if>-->
			<!--2909 The latest <LearningActualEndDate> of all <LearningAim> records must be equal to the <ProgrammeActualEndDate> of the parent <ProgrammeAim> -->
			<!-- Unable to test for "latest" learning aim as can't do that in XSLT.  This just looks for at least one record that matches the value -->
			<!-- Rule made "Collect Only" on RFC 1189 21/09/2021 -->
			<!--<xsl:if test="count(LearningAims/LearningAim) &gt; 0
						  and count(LearningAims/LearningAim[(translate(LearningActualEndDate, '-', '') = $ThisLED )]) = 0 " >
				<xsl:call-template name="Error">
					<xsl:with-param name="err_num" select="2909"/>
					<xsl:with-param name="data" select="$data" />
				</xsl:call-template>
			</xsl:if>-->
			<!-- 2911 Where more than one <ProgrammeAim> exists, only one can have a completion status equal to ‘1’  -->
			<xsl:if test="count(../ProgrammeAim[contains( ' 1 ', concat( ' ', ProgrammeAimStatus, ' ')) ] ) &gt; 1 " >
				<xsl:call-template name="Error">
					<xsl:with-param name="err_num" select="2911"/>
					<xsl:with-param name="data" select="$data" />
				</xsl:call-template>
			</xsl:if>
			<!--2912 <Traineeship> must not be present where <ProgrammeStartDate> is after 2023-07-31 -->
			<xsl:if test="string-length(Traineeship) != 0 
						  and translate(ProgrammeStartDate, '-', '') &gt;= $Aug1stAcadYrStart ">
				<xsl:call-template name="Error">
					<xsl:with-param name="err_num" select="2912"/>
					<xsl:with-param name="data" select="concat($data, $QN) "/>
				</xsl:call-template>
			</xsl:if>
		</xsl:for-each>
	</xsl:template>
	


	<!--Check for valid date-->
	<xsl:template name="ValidateDate">
		<xsl:param name="vdate"/>
		<xsl:param name="err_no"/>
		<xsl:param name="err_data"/>
		<!--Set up variables-->
		<xsl:variable name="date" select="translate($vdate, '-', '') "/>
		<xsl:variable name="year" select="substring($vdate, 1, 4) "/>
		<xsl:variable name="decadeyear" select="substring($vdate, 3, 2) "/>
		<xsl:variable name="month" select="substring($vdate, 6, 2) "/>
		<xsl:variable name="day" select="substring($vdate, 9, 2) "/>
		<xsl:variable name="validdate">
			<xsl:choose>
				<xsl:when test="string-length($date) != 8 ">1</xsl:when>
				<xsl:when test="not(translate( $date, $digits, $all_9s ) = '99999999') ">2</xsl:when>
				<xsl:when test="$year &lt; ($AcademicYear - 100) ">3</xsl:when>
				<xsl:when test="$year &gt; ($AcademicYear + 100) ">4</xsl:when>
				<xsl:when test="$month &lt; 1 or $month &gt; 12">5</xsl:when>
				<xsl:when test="contains(' 00 04 08 12 16 20 24 28 32 36 40 44 48 52 56 60 64 68 72 76 80 84 88 92 96 ', concat(' ', $decadeyear, ' ') ) 
						and $month= '02' and ($day &lt; 1 or $day &gt; 29)">6</xsl:when>
				<xsl:when test="not(contains(' 00 04 08 12 16 20 24 28 32 36 40 44 48 52 56 60 64 68 72 76 80 84 88 92 96 ', concat(' ', $decadeyear, ' ') ) ) 
						and$month = '02' and ($day &lt; 1 or $day &gt; 28) ">7</xsl:when>
				<xsl:when test="contains(' 04 06 09 11 ', $month) and ($day &lt; 1 or $day &gt; 30)">8</xsl:when>
				<xsl:when test="$day &lt; 1 or $day &gt; 31">9</xsl:when>
				<xsl:otherwise>0</xsl:otherwise>
			</xsl:choose>
		</xsl:variable>
		<xsl:if test="$validdate &gt; 0">
			<xsl:call-template name="Error">
				<xsl:with-param name="err_num" select="$err_no"/>
				<xsl:with-param name="data" select="$err_data"/>
			</xsl:call-template>
		</xsl:if>
	</xsl:template>
	<!--Error %-->
	<xsl:template name="Error">
		<xsl:param name="err_num"/>
		<xsl:param name="data"/>
		<xsl:param name="err_param1"/>
		<xsl:param name="err_param2"/>
		<xsl:param name="err_param3"/>
		<Error>
			<Type>
				<xsl:value-of select="document('./SchoolCensus23-24-ErrorList.xsl')/xsl:stylesheet/Error:rule[ @number=$err_num]/@type"/>
			</Type>
			<Sequence>
				<!--<xsl:value-of select="$err_num"/>-->
				<xsl:value-of select="document('./SchoolCensus23-24-ErrorList.xsl')/xsl:stylesheet/Error:rule[ @number=$err_num]/@outputno"/>
			</Sequence>
			<Location>
				<xsl:value-of select="$data"/>
			</Location>
			<Term>
				<xsl:value-of select="document('./SchoolCensus23-24-ErrorList.xsl')/xsl:stylesheet/Error:rule[ @number=$err_num]/@term"/>
			</Term>
			<Phase>
				<xsl:value-of select="document('./SchoolCensus23-24-ErrorList.xsl')/xsl:stylesheet/Error:rule[ @number=$err_num]/@phase"/>
			</Phase>
			<Message>
				<xsl:variable name="msgtext" select="document('./SchoolCensus23-24-ErrorList.xsl')/xsl:stylesheet/Error:rule[ @number=$err_num]/@message"/>
				<xsl:choose>
					<xsl:when test="contains($msgtext,'@@param1@@')">
						<xsl:value-of select="substring-before($msgtext,'@@param1@@') "/>
						<xsl:value-of select="$err_param1"/>
						<xsl:value-of select="substring-after($msgtext,'@@param1@@') "/>
					</xsl:when>
					<xsl:when test="contains($msgtext, '@@param31@@')">
						<xsl:value-of select="concat('Please check: pupil is shown in year group ', $err_param1, ' 
							however pupil is aged ', $err_param2, ' (date of birth is ', $err_param3, ')' ) "/>
					</xsl:when>
					<xsl:otherwise>
						<xsl:value-of select="$msgtext"/>
					</xsl:otherwise>
				</xsl:choose>
			</Message>
		</Error>
	</xsl:template>


	<!--Global Variables-->
	<!--Lists have a leading and trailing space to facilitate use of contains function-->
	<!--Don't forget to use single quotes within double quotes for string types!-->	
	<xsl:variable name="Ph">
		<xsl:choose>
			<xsl:when test="string(/Message/School/SchoolCharacteristics/Phase)">
				<xsl:value-of select="string(/Message/School/SchoolCharacteristics/Phase)"/>
			</xsl:when>
			<xsl:otherwise>
				<xsl:value-of select="'XX' "/>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:variable>
	<xsl:variable name="Phase" select="string($Ph) "/>
	<xsl:variable name="_Phase_" select="concat(' ', $Ph, ' ') "/>
	<xsl:variable name="SchoolType" select="string(/Message/School/SchoolCharacteristics/SchoolType)"/>
	<xsl:variable name="_SchoolType_" select="concat(' ', $SchoolType, ' ') "/>
	<xsl:variable name="Intake" select="string(/Message/School/SchoolCharacteristics/Intake)"/>
	<xsl:variable name="_Intake_" select="concat(' ', $Intake, ' ') "/>
	<xsl:variable name="Governance" select="string(/Message/School/SchoolCharacteristics/Governance)"/>
	<xsl:variable name="Estab" select="number(/Message/Header/Source/Estab)"/>
	<xsl:variable name="term" select="string(Message/Header/CollectionDetails/Term)"/>
	<xsl:variable name="FileYear" select="string(Message/Header/CollectionDetails/Year)"/>
	<xsl:variable name="SixthForm">
		<xsl:choose>
			<xsl:when test="/Message/School/SchoolCharacteristics/HighestNCyear &gt; 11">
				<xsl:value-of select="'Y' "/>
			</xsl:when>
			<xsl:otherwise>
				<xsl:value-of select="'N' "/>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:variable>
	<xsl:variable name="PupilOnRollCount" select="count(/Message/Pupils/PupilsOnRoll/PupilOnRoll) "/>
	<xsl:variable name="PupilNoLongerOnRollCount" select="count(/Message/Pupils/PupilsNoLongerOnRoll/PupilNoLongerOnRoll) "/>
	<xsl:variable name="PupilsAgedLess3" select="count(/Message/Pupils/PupilsOnRoll/PupilOnRoll[ floor(($AgeCalcDate - translate(PupilIdentifiers/DOB, '-','')) div 10000) &lt; 3] ) "/>
	<xsl:variable name="PupilsAgedOver15" select="count(/Message/Pupils/PupilsOnRoll/PupilOnRoll[ floor(($AgeCalcDate - translate(PupilIdentifiers/DOB, '-','')) div 10000) &gt; 15] ) "/>
	<xsl:variable name="PupilsAged3" select="count(/Message/Pupils/PupilsOnRoll/PupilOnRoll[ floor(($AgeCalcDate - translate(PupilIdentifiers/DOB, '-','')) div 10000) =3] ) "/>
	<xsl:variable name="PupilsAged4" select="count(/Message/Pupils/PupilsOnRoll/PupilOnRoll[ floor(($AgeCalcDate - translate(PupilIdentifiers/DOB, '-','')) div 10000) =4] ) "/>
	<xsl:variable name="PupilsAged5" select="count(/Message/Pupils/PupilsOnRoll/PupilOnRoll[ floor(($AgeCalcDate - translate(PupilIdentifiers/DOB, '-','')) div 10000) =5] ) "/>
	<xsl:variable name="PupilsAged6" select="count(/Message/Pupils/PupilsOnRoll/PupilOnRoll[ floor(($AgeCalcDate - translate(PupilIdentifiers/DOB, '-','')) div 10000) =6] ) "/>
	<xsl:variable name="PupilsAged7" select="count(/Message/Pupils/PupilsOnRoll/PupilOnRoll[ floor(($AgeCalcDate - translate(PupilIdentifiers/DOB, '-','')) div 10000) =7] ) "/>
	<xsl:variable name="PupilsAged8" select="count(/Message/Pupils/PupilsOnRoll/PupilOnRoll[ floor(($AgeCalcDate - translate(PupilIdentifiers/DOB, '-','')) div 10000) =8] ) "/>
	<xsl:variable name="PupilsAged9" select="count(/Message/Pupils/PupilsOnRoll/PupilOnRoll[ floor(($AgeCalcDate - translate(PupilIdentifiers/DOB, '-','')) div 10000) =9] ) "/>
	<xsl:variable name="PupilsAged10" select="count(/Message/Pupils/PupilsOnRoll/PupilOnRoll[ floor(($AgeCalcDate - translate(PupilIdentifiers/DOB, '-','')) div 10000) =10] ) "/>
	<xsl:variable name="PupilsAged11" select="count(/Message/Pupils/PupilsOnRoll/PupilOnRoll[ floor(($AgeCalcDate - translate(PupilIdentifiers/DOB, '-','')) div 10000) =11] ) "/>
	<xsl:variable name="PupilsAged12" select="count(/Message/Pupils/PupilsOnRoll/PupilOnRoll[ floor(($AgeCalcDate - translate(PupilIdentifiers/DOB, '-','')) div 10000) =12] ) "/>
	<xsl:variable name="PupilsAged13" select="count(/Message/Pupils/PupilsOnRoll/PupilOnRoll[ floor(($AgeCalcDate - translate(PupilIdentifiers/DOB, '-','')) div 10000) =13] ) "/>
	<xsl:variable name="PupilsAged14" select="count(/Message/Pupils/PupilsOnRoll/PupilOnRoll[ floor(($AgeCalcDate - translate(PupilIdentifiers/DOB, '-','')) div 10000) =14] ) "/>
	<xsl:variable name="PupilsAged15" select="count(/Message/Pupils/PupilsOnRoll/PupilOnRoll[ floor(($AgeCalcDate - translate(PupilIdentifiers/DOB, '-','')) div 10000) =15] ) "/>
	<xsl:variable name="PupilsAged16" select="count(/Message/Pupils/PupilsOnRoll/PupilOnRoll[ floor(($AgeCalcDate - translate(PupilIdentifiers/DOB, '-','')) div 10000) =16] ) "/>
	<xsl:variable name="PupilsAged17" select="count(/Message/Pupils/PupilsOnRoll/PupilOnRoll[ floor(($AgeCalcDate - translate(PupilIdentifiers/DOB, '-','')) div 10000) =17] ) "/>
	<xsl:variable name="PupilsAged18" select="count(/Message/Pupils/PupilsOnRoll/PupilOnRoll[ floor(($AgeCalcDate - translate(PupilIdentifiers/DOB, '-','')) div 10000) =18] ) "/>
	<xsl:variable name="boolean" select=" ' True true False false 1 0 ' "/>
	<xsl:variable name="true" select=" ' True true 1 ' "/>
	<xsl:variable name="false" select=" ' False false 0 ' "/>
	<xsl:variable name="DisabledValidation">
		<xsl:choose>
			<xsl:when test="$term='AUT' and $FileYear='2020' ">  <!--This year does not change as it is the year that rules were disabled due to Covid issues-->
				<xsl:value-of select=" 'true' "/>
			</xsl:when>
			<xsl:otherwise><!--anything not Aut 20-->
				<xsl:value-of select=" 'false' "/>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:variable>
	<!--xsl:variable name="August" select="8"/-->
	<xsl:variable name="AcademicYear" select="2023"/>
	<xsl:variable name="digits" select=" '0123456789' "/>
	<xsl:variable name="all_9s" select=" '9999999999' "/>
	<xsl:variable name="alphabet" select=" 'ABCDEFGHIJKLMNOPQRSTUVWXYZ' "/>
	<xsl:variable name="lowercase" select=" 'abcdefghijklmnopqrstuvwxyz' "/>
	<xsl:variable name="UPNletters" select=" 'ABCDEFGHJKLMNPQRTUVWXYZ' "/>
	<xsl:variable name="all_As" select=" 'AAAAAAAAAAAAAAAAAAAAAAAAAA' "/>
	<!--HG 2008 SC amended * Do not remove 875 and 380 as these are required to validate UPNs and for incare authority values-->
	<xsl:variable name="LEAs" select="' 001 002 003 004 005 201 202 203 204 205 206 207 208 209 210 211 212 213 301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 316 317 318 319 320 330 331 332 333 334 335 336 340 341 342 343 344 350 351 352 353 354 355 356 357 358 359 370 371 372 373 380 381 382 383 384 390 391 392 393 394 420 660 661 662 663 664 665 666 667 668 669 670 671 672 673 674 675 676 677 678 679 680 681 701 702 703 704 705 706 707 708 800 801 802 803 805 806 807 808 810 811 812 813 815 816 820 821 822 823 825 826 830 831 835 836 837 838 839 840 841 845 846 850 851 852 855 856 857 860 861 865 866 867 868 869 870 871 872 873 874 875 876 877 878 879 880 881 882 883 884 885 886 887 888 889 890 891 892 893 894 895 896 908 909 916 919 921 925 926 928 929 931 933 935 936 937 938 940 941 942 943 '"/>
	<xsl:variable name="phases" select=" ' NS PS MP MS SS SP PR AT ' "/>
	<xsl:variable name="Sex" select=" ' F M ' "/>
	<xsl:variable name="ncyears" select=" ' E1 E2 N1 N2 R 1 2 3 4 5 6 7 8 9 10 11 12 13 14 M X ' "/>
	<xsl:variable name="intakes" select=" ' COMP SEL1 SEL2 SEL3 SEL4 SPEC HOSP ' "/>
	<xsl:variable name="governances" select=" ' CO VA VC FO NM CT CA ' "/>
	<xsl:variable name="provisions" select=" ' SPLD MLD SLD PMLD SEMH SLCN HI VI MSI PD ASD OTH NSA ' "/>
	<xsl:variable name="keystages" select=" ' F 1 2 3 M ' "/>
	<!--Valid languages seq 1840-->
	<!--Updated to add two more langauge codes ILO and CKW-->
	<xsl:variable name="Language" select=" ' ACL ADA AFA AFK AKA AKAF AKAT ALB ALU AMR ARA ARAA ARAG ARAI ARAM ARAS ARAY ARM ASM ASR AYB AYM AZE BAI BAL BEJ BEL BEM BHO BIK BLT BMA BNG BNGA BNGC BNGS BSL BSQ BUL CAM CAT CCE CCF CGA CGR CHE CHI CHIA CHIC CHIH CHIK CHIM CKW CRN CTR CWA CYM CZE DAN DGA DGB DIN DUT DZO EBI EDO EFI ENB ENG ESA EST EWE EWO FAN FIJ FIN FON FRN FUL GAA GAE GAL GEO GER GGO GKY GLG GRE GREA GREC GRN GUJ GUN GUR HAU HDK HEB HER HGR HIN IBA IDM IGA IGB IJO ILO ISK ISL ITA JAV JIN JPN KAM KAN KAR KAS KAU KAZ KCH KGZ KHA KHY KIN KIR KIS KLN KMB KME KNK KNY KON KOR KPE KRI KRU KSI KSU KUR KURA KURM KURS LAO LBA LBAC LBAK LGA LGB LGS LIN LIT LNG LOZ LSO LTV LTZ LUE LUN LUO LUY MAG MAI MAK MAN MANA MANB MANJ MAO MAR MAS MDV MEN MKD MLG MLM MLT MLY MLYA MLYI MNA MNG MNX MOR MSC MUN MYA NAH NAM NBN NDB NDBS NDBZ NEP NOR NOT NUE NUP NWA NZM OAM OAMK OAMN OGN ORI ORM OTB OTH OTL PAG PAM PAT PHA PHR PNJ PNJA PNJG PNJM PNJP POL POR PORA PORB PRS PRSA PRSD PRST QUE RAJ REF RME RMI RMN RMNM RMNR RMS RNY RNYN RNYO RUS SAM SCB SCBB SCBC SCBS SCO SHL SHO SID SIO SLO SLV SND SNG SNH SOM SPA SRD SRK SSO SSOO SSOT SSW STS SUN SWA SWAA SWAC SWAK SWAM SWAT SWE TAM TEL TEM TES TGE TGL TGLF TGLG TGR THA TIB TIV TMZ TMZA TMZK TMZT TNG TON TPI TRI TSO TUK TUL TUM TUR UKR UMB URD URH UYG UZB VEN VIE VSY VSYA VSYH VSYS VSYW WAP WCP WOL WPE XHO YAO YDI YOR ZND ZUL ZZZ ' "/>
	<xsl:variable name="ExcludeReason" select=" ' PP PA VP VA BU RA SM DA DM TH DB OT OW LG DS MT PH ' "/>
	<xsl:variable name="ExcludeReason2265" select=" ' PP PA VP VA BU RA SM DA DM TH DB OT ' "/>
	<xsl:variable name="ExcludeReason2280" select=" ' PP PA VP VA BU RA SM DA DM TH DB OW LG DS MT PH ' "/>
	<xsl:variable name="ValidAttendance" select=" ' / \ B D J L P V W X I M R S T H E C G U O N Y ' "/>
	<xsl:variable name="ValidAuthAttendance" select=" ' I M R S T H E C ' "/>
	<xsl:variable name="ValidUnauthAttendance" select=" ' G U O N ' "/>
	<xsl:variable name="ValidAuthUnAuthAttendance" select=" ' I M R S T H E C G U O N ' "/>  <!-- added for change to rule 2530 ACN 18/12/2020 -->
	<xsl:variable name="ValidAttendanceAbsence" select=" ' / \ L B J P V W C E G H I M N O R S T U ' "/>  <!-- added for new rule 2531 ACN 23/03/2021.  Also used on new rule 2586 now ACN 23/06/2021 -->
	<xsl:variable name="DisabilityType" select=" ' NCOL NONE MOB HAND PC EAT MED INC COMM LD HEAR VIS BEH CON AUT DDA OTH ' "/>
	<!--Used in 410 only-->
	<xsl:variable name="SENschoolcodes" select=" ' SPLD MLD SLD PMLD SEMH SLCN HI VI MSI PD ASD OTH ' "/>
	<xsl:variable name="APReasoncodes" select=" ' ASP EHC MHN NEW OTH PEX PHN RHE ' "/>
	<xsl:variable name="APSettingcodes" select=" ' NFE OOT OTH WBP ' "/>
	<xsl:variable name="PlacementReasoncodes" select=" ' BHS SUS EXR MHN OTH PHN ' "/>
	<xsl:variable name="SENProvisioncodes" select=" ' N E K ' "/>
	<!--NSA is part of the codeset but not valid for a school-->
	<!--Variables for valid ethnicity and associated checks - 1630 - 1700Q-->
	<xsl:variable name="EWhite" select=" ' WBRI WCOR WENG WSCO WWEL WOWB WNIR WIRI WIRT WOTH WALB WBOS WCRO WGRE WGRK WGRC WITA WKOS WPOR WSER WTUR WTUK WTUC WEUR WEEU WWEU WOTW WROM WROG WROR WROO ' "/>
	<xsl:variable name="EMixedDual" select=" ' MWBC MWBA MWAS MWAP MWAI MWAO MOTH MAOE MABL MACH MBOE MBCH MCOE MWOE MWCH MOTM ' "/>
	<xsl:variable name="EAsianBritA" select=" ' AIND APKN AMPK AKPA AOPK ABAN AOTH AAFR AKAO ANEP ASNL ASLT ASRO AOTA ' "/>
	<xsl:variable name="EBlackBritB" select=" ' BCRB BAFR BANN BCON BGHA BNGN BSLN BSOM BSUD BAOF BOTH BEUR BNAM BOTB ' "/>
	<xsl:variable name="EChinese" select=" ' CHNE CHKC CMAL CSNG CTWN COCH ' "/>
	<xsl:variable name="EOther" select=" ' OOTH OAFG OARA OEGY OFIL OIRN OIRQ OJPN OKOR OKRD OLAM OLEB OLIB OMAL OMRC OPOL OTHA OVIE OYEM OOEG ' "/>
	<xsl:variable name="ENone" select=" ' REFU NOBT ' "/>
	<!--Used for Spring only, early years funding values-->
	<xsl:variable name="EYPPBFs" select=" ' RE RO RB RU ' "/>
	<xsl:variable name="classactivities" select=" ' AR EN FL GP GS HU MA MD OT PE PL PS RE RS SC TE TV ' "/>
	<xsl:variable name="childcaresignposting" select=" ' YF YL N U ' "/>
	<!--Used throughout-->
	<xsl:variable name="AgeCalcDate" select=" '20230831' "/>
	<xsl:variable name="AgeCalcDateForAttendance">
		<xsl:choose>
			<xsl:when test="$term='AUT' ">
				<xsl:value-of select="$AgeCalcDate - 10000"/>
			</xsl:when>
			<xsl:otherwise><!--spr, sum-->
				<xsl:value-of select="$AgeCalcDate"/>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:variable>
	<xsl:variable name="RefDate">
		<xsl:choose>
			<xsl:when test="$term='AUT' ">
				<xsl:value-of select=" '20231005' "/>
			</xsl:when>
			<xsl:when test="$term='SPR' ">
				<xsl:value-of select=" '20240118' "/>
			</xsl:when>
			<xsl:when test="$term='SUM' ">
				<xsl:value-of select=" '20240516' "/>
			</xsl:when>
		</xsl:choose>
	</xsl:variable>
	<xsl:variable name="PrevYearRefDate"><!--Also used for upper bound of 1763-->
		<xsl:choose>
			<xsl:when test="$term='AUT' ">
				<xsl:value-of select=" '20221006' "/>
			</xsl:when>
			<xsl:when test="$term='SPR' ">
				<xsl:value-of select=" '20230119' "/>
			</xsl:when>
			<xsl:when test="$term='SUM' ">
				<xsl:value-of select=" '20230518' "/>
			</xsl:when>
		</xsl:choose>
	</xsl:variable>	
	<!-- following holds the previous term's reference date.  Originally added to be used by 2378. -->
	<xsl:variable name="PrevTermRefDate">
		<xsl:choose>
			<xsl:when test="$term='AUT' ">
				<xsl:value-of select=" '20230518' "/>	<!--Previous Summer reference date-->
			</xsl:when>
			<xsl:when test="$term='SPR' ">
				<xsl:value-of select=" '20231006' "/>	<!--Previous Autumn reference date-->
			</xsl:when>
			<xsl:when test="$term='SUM' ">
				<xsl:value-of select=" '20230118' "/>	<!--Previous Spring reference date-->
			</xsl:when>
		</xsl:choose>
	</xsl:variable>		
	<!--Used in validation 1763-->
	<xsl:variable name="FSMEndDateLowerBound">
		<xsl:choose>
			<xsl:when test="$term='AUT' ">
				<xsl:value-of select=" '20230519' "/>
			</xsl:when>
			<xsl:when test="$term='SPR' ">
				<xsl:value-of select=" '20231006' "/>
			</xsl:when>
			<xsl:when test="$term='SUM' ">
				<xsl:value-of select=" '20240118' "/>
			</xsl:when>
		</xsl:choose>
	</xsl:variable>
	<!--Used in validation 1885q-->
	<xsl:variable name="EntryDateCheck">
		<xsl:choose>
			<xsl:when test="$term='AUT' ">
				<xsl:value-of select=" '20230801' "/>
			</xsl:when>
			<xsl:when test="$term='SPR' ">
				<xsl:value-of select=" '20240101' "/>
			</xsl:when>
			<xsl:when test="$term='SUM' ">
				<xsl:value-of select=" '20240401' "/>
			</xsl:when>
		</xsl:choose>
	</xsl:variable>
	<!--Used in errors 1890, 1900, 1910 NB. Consider automating SPR/SUM.-->
	<xsl:variable name="StartPreviousTerm">
		<xsl:choose>
			<xsl:when test="$term='AUT' ">
				<xsl:value-of select=" '20230410' "/>
			</xsl:when>
			<xsl:when test="$term='SPR' ">
				<xsl:value-of select=" '20230801' "/>
			</xsl:when>
			<xsl:when test="$term='SUM' ">
				<xsl:value-of select=" '20240101' "/>
			</xsl:when>
		</xsl:choose>
	</xsl:variable>
	<!-- IW ADDED 2021-08-26-->
	<xsl:variable name="StartPrevAYSummerTerm"> <!--Not sure if this is needed for other terms so omitted then for now.-->
		<xsl:value-of select=" '20230529' "/>
	</xsl:variable>
	<!--Used in errors 1890, 1897, 1900, 1910, 1925, 1992, 2575, 2576, 2870. Not to be used with test 2510-->
	<!--Autumn variant also used in 2708, 2775-->
	<!--Note that the boundaries on this rule are out-by-one from specification to permit reuse of the data-->
	<xsl:variable name="StartCurrentTerm">
		<xsl:choose>
			<xsl:when test="$term='AUT' ">
				<xsl:value-of select=" '20230731' "/>
			</xsl:when>
			<xsl:when test="$term='SPR' ">
				<xsl:value-of select=" '20231231' "/>
			</xsl:when>
			<xsl:when test="$term='SUM' ">
				<xsl:value-of select=" '20230331' "/>	<!--Easter Sunday-->
			</xsl:when>
		</xsl:choose>
	</xsl:variable>
	<!--Used in 1881, 2500, 2502, 2510, 2576 (autumn only), 2578 (autumn only)-->
	<xsl:variable name="EntryDateRef">
		<xsl:choose>
			<xsl:when test="$term='AUT' ">
				<!--day before bank holiday monday-->
				<xsl:value-of select=" '20230528' "/> 	
			</xsl:when>
			<xsl:otherwise>
				<xsl:value-of select=" $StartCurrentTerm "/>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:variable>
	<!--Exclusion period, used in 2290 -->	
	<xsl:variable name="XDMin2290">
		<xsl:choose>
			<xsl:when test="$term='AUT' ">
				<xsl:value-of select=" '20230101' "/>
			</xsl:when>
			<xsl:when test="$term='SPR' ">
				<xsl:value-of select=" '20230410' "/>
			</xsl:when>
			<xsl:when test="$term='SUM' ">
				<xsl:value-of select=" '20230801' "/>
			</xsl:when>
		</xsl:choose>
	</xsl:variable>
	<xsl:variable name="XDMax2290">
		<xsl:choose>
			<xsl:when test="$term='AUT' ">
				<xsl:value-of select=" '20230731' "/>
			</xsl:when>
			<xsl:when test="$term='SPR' ">
				<xsl:value-of select=" '20231231' "/>
			</xsl:when>
			<xsl:when test="$term='SUM' ">
				<xsl:value-of select=" '20240331' "/>
			</xsl:when>
		</xsl:choose>
	</xsl:variable>
	<!--Exclusion review period, used in 2485 (probably worth updating varname as exclusion reviews were dropped)-->	
	<xsl:variable name="XDMinExclRev">
		<xsl:choose>
			<xsl:when test="$term='AUT' ">
				<xsl:value-of select=" '20230410' "/>
			</xsl:when>
			<xsl:when test="$term='SPR' ">
				<xsl:value-of select=" '20230801' "/>
			</xsl:when>
			<xsl:when test="$term='SUM' ">
				<xsl:value-of select=" '20240101' "/>
			</xsl:when>
		</xsl:choose>
	</xsl:variable>
	<xsl:variable name="XDMaxExclRev">
		<xsl:choose>
			<xsl:when test="$term='AUT' ">
				<xsl:value-of select=" '20230528' "/>
			</xsl:when>
			<xsl:when test="$term='SPR' ">
				<xsl:value-of select=" '20231231' "/>
			</xsl:when>
			<xsl:when test="$term='SUM' ">
				<xsl:value-of select=" '20240331' "/>
			</xsl:when>
		</xsl:choose>
	</xsl:variable>
	<xsl:variable name="Aug1stAcadYrStart" select="20230801"/> <!--start of academic year. Used in 1894 & 2880, new for 2020-21-->	
	<!--ADDED FOR RFC1184 - ACN 2021-12-02-->	
	<xsl:variable name="EYPPYr5Max">
		<xsl:choose>
			<xsl:when test="$term='AUT' ">
				<xsl:value-of select=" '20180901' "/>
			</xsl:when>
			<xsl:when test="$term='SPR' ">
				<xsl:value-of select=" '20190101' "/>
			</xsl:when>
			<xsl:when test="$term='SUM' ">
				<xsl:value-of select=" '20190401' "/>
			</xsl:when>
		</xsl:choose>
	</xsl:variable>	
	<!--New for 21/22.  Used on new LearnerFAMModule rules-->
	<xsl:variable name="y15min" select=" '20070901' "/>
	<xsl:variable name="y19min" select=" '20020901' "/>
	<xsl:variable name="y18max" select=" '20060831' "/>
	<!--New for AcYr 2018-19-->
	<xsl:variable name="Rising3DoB" select=" '20201231' "/>
	<!--The next six variables are used in rules 3080, 3085, and 3090 to provide date of birth boundaries for school lunch tests-->
	<!--y4DoBmax also used in 1846, 1847, 1848, 1852, 1877, 1878, 2695 (via R12X variables below)-->
	<!--y5DoBmax also used in 1847, 1848-->
	<!--y7DoBmax also used in 1877, 1878, 2695-->
	<xsl:variable name="y4DoBmax" select=" '20190831' "/>
	<xsl:variable name="y5DoBmax" select=" '20180831' "/>
	<xsl:variable name="y6DoBmax" select=" '20170831' "/>
	<xsl:variable name="y7DoBmax" select=" '20160831' "/>
	<xsl:variable name="slThreshold" select="10"/>
	<xsl:variable name="slRatio" select="0.5"/>
	<!--Used in PupilsAged calculation, allows splitting of 2-3 year olds for the change to 2020.-->
	<xsl:variable name="InfRisingDate" select=" $y3DoBmax + 30000 "/>
	<!--Moved from LearningAims module as now also used in ProgrammeAims, rules 2740 and 2906 respectively-->
	<xsl:variable name="MinLearningAimStartDate" select=" (number(substring($RefDate, 1, 4)) - 4) * 10000 + 731 "/>
	<!--Moved from LearningAims module as now also used in ProgrammeAims, rules 2765 and 2891 respectively-->
	<xsl:variable name="MaxLearningAimEndDate" select=" $RefDate + 50000 "/>
	<!--Used in 3120-->
	<xsl:variable name="y3DoBmax">
		<xsl:choose>
			<xsl:when test="$term='AUT' ">
				<xsl:value-of select=" '20200831' "/>
			</xsl:when>
			<xsl:when test="$term='SPR' ">
				<xsl:value-of select=" '20201231' "/>
			</xsl:when>
			<xsl:when test="$term='SUM' ">
				<xsl:value-of select=" '20210331' "/>
			</xsl:when>
		</xsl:choose>
	</xsl:variable>	
	<!--Used in 1852-->	
	<xsl:variable name="y1DoBmax" >
		<xsl:choose>
			<xsl:when test="$term='AUT' ">
				<xsl:value-of select=" '20210831' "/>
			</xsl:when>
			<xsl:when test="$term='SPR' ">
				<xsl:value-of select=" '20211231' "/>
			</xsl:when>
			<xsl:when test="$term='SUM' ">
				<xsl:value-of select=" '20220331' "/>
			</xsl:when>
		</xsl:choose>
	</xsl:variable>	
	
	<!--Added for rule 2491 & used by 2492 as well-->
	<xsl:variable name="v2491Min">
		<xsl:choose>
			<xsl:when test="$term='AUT' ">
				<xsl:value-of select=" '20170901' "/>
			</xsl:when>
			<xsl:when test="$term='SPR' ">
				<xsl:value-of select=" '20190101' "/>
			</xsl:when>
			<xsl:when test="$term='SUM' ">
				<xsl:value-of select=" '20190401' "/>
			</xsl:when>
		</xsl:choose>
	</xsl:variable>		
	<xsl:variable name="v2491Max">
		<xsl:choose>
			<xsl:when test="$term='AUT' ">
				<xsl:value-of select=" '20180831' "/>
			</xsl:when>
			<xsl:when test="$term='SPR' ">
				<xsl:value-of select=" '20190831' "/>
			</xsl:when>
			<xsl:when test="$term='SUM' ">
				<xsl:value-of select=" '20190831' "/>
			</xsl:when>
		</xsl:choose>
	</xsl:variable>			
	
	<!--New for Spr 23 - Date range for rule 5236-->
	<xsl:variable name="v5236Start" select=" '20210101' " />
	<xsl:variable name="v5236End" select=" '20211231' " />
	
	<!--Used in 1852, 1854, 1855-->
	<xsl:variable name="y2DoBmax" select=" $y3DoBmax + 10000 "/>
	<!--R12XPupilsAll is in 1877, 1878, 2695. Declared here because 2695 is school level and 1877/1878 are pupil level.-->
	<xsl:variable name="R12XPupilsAll" select="count(/Message/Pupils/PupilsOnRoll/PupilOnRoll
		[ (contains(' R 1 2 ', concat(' ', PupilStatus/NCyearActual, ' ') ) 
			or (PupilStatus/NCyearActual = 'X' 
				and translate(PupilIdentifiers/DOB, '-', '') &gt; $y7DoBmax 
				and translate(PupilIdentifiers/DOB, '-', '') &lt;= $y4DoBmax ) ) ] ) "/>
	<!--R12XPupilsFSMTaken are in 1877, 1878-->
	<xsl:variable name="R12XPupilsFSMTaken" select="count(/Message/Pupils/PupilsOnRoll/PupilOnRoll
		[ ( (contains(' R 1 2 ', concat(' ', PupilStatus/NCyearActual, ' ') ) 
			or (PupilStatus/NCyearActual = 'X' 
				and translate(PupilIdentifiers/DOB, '-', '') &gt; $y7DoBmax
				and translate(PupilIdentifiers/DOB, '-', '') &lt;= $y4DoBmax ) ) )
				and contains($true, concat(' ', PupilCharacteristics/SchoolLunchTaken, ' ') ) ] ) "/>
	<!--R12XPupilsFSMPeriod is in 2695-->
	<xsl:variable name="R12XPupilsFSMPeriod" select="count(/Message/Pupils/PupilsOnRoll/PupilOnRoll[
		contains(' R 1 2 ', concat(' ', PupilStatus/NCyearActual, ' ') ) 
			and (count(PupilCharacteristics/FSMeligibility/FSMperiod
				[string-length(FSMstartDate) != 0 
					and (string-length(FSMendDate) = 0 
				or translate(FSMendDate, '-', '') &gt;= $RefDate) ] ) &gt; 0) ] ) 
			+ count(/Message/Pupils/PupilsOnRoll/PupilOnRoll
				[PupilStatus/NCyearActual = 'X' 
					and translate(PupilIdentifiers/DOB, '-','') &gt; $y7DoBmax
					and translate(PupilIdentifiers/DOB, '-','') &lt;= $y4DoBmax 
					and (count(PupilCharacteristics/FSMeligibility/FSMperiod
						[string-length(FSMstartDate) != 0 
							and (string-length(FSMendDate) = 0 
						or translate(FSMendDate, '-', '') &gt;= $RefDate) ] 
				) &gt; 0) ] ) "/>
</xsl:stylesheet>
